@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -38,8 +38,6 @@
 #include <gdk/gdkkeysyms.h>
 
 #include "callbacks.h"
-#include "interface.h"
-#include "support.h"
 
 #include "config_user.h"
 #include "fileselect.h"
@@ -51,7 +49,6 @@
 #include "scan_cd.h"
 #include "about_xcfa.h"
 #include "web.h"
-#include "logs.h"
 #include "win_control.h"
 #include "poche.h"
 #include "utils.h"
@@ -59,7 +56,6 @@
 #include "split.h"
 #include "help.h"
 #include "showhide_treeview.h"
-#include "player.h"
 #include "win_play.h"
 #include "cd_cue.h"
 #include "win_choice.h"
@@ -69,6 +65,11 @@
 #include "prg_install.h"
 #include "prg_audio.h"
 #include "split_shuttle.h"
+#include "process.h"
+#include "mplayer.h"
+#include "parse.h"
+#include "logs.h"
+
 
 
 
@@ -115,13 +116,19 @@ void Before_End_Prg (void)
 	PRINT_FUNC_LF();
 	g_print ("--------------------------------------------------\n");
 
-	g_print ("player_remove_fifo ()\n");
-	PlayerExec_user_to_quit ();
-	PlayerExec_remove_fifo ();
+	// g_print ("player_remove_fifo ()\n");
+	// PlayerExec_user_to_quit ();
+	// PlayerExec_remove_fifo ();
+	
+	g_print ("mplayer_fifo_quit ()\n");
+	mplayer_fifo_quit ();
+	g_print ("mplayer_remove_fifo ()\n");
+	mplayer_remove_fifo ();
+
 
 	g_print ("Recuperation position et taille de la fenetre\n");
-	gdk_window_get_root_origin (wind_main->window, &Config_User.WinPos_X, &Config_User.WinPos_Y);
-	gdk_window_get_size (wind_main->window, &Config_User.Win_Width, &Config_User.Win_Height);
+	gdk_window_get_root_origin (wind_main.AdrWin->window, &Config_User.WinPos_X, &Config_User.WinPos_Y);
+	gdk_window_get_size (wind_main.AdrWin->window, &Config_User.Win_Width, &Config_User.Win_Height);
 
 	g_print ("Recuperation value NICE\n");
 	Config_User.Nice = options_get_val_nice ();
@@ -199,14 +206,12 @@ void Before_End_Prg (void)
 			gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_stockage_cdaudio)));
 
 	g_print ("Recuperation du gestionnaire de paquets\n");
-	Config_User.AdministratorOfPackets = options_get_administrator_of_packets ();
-
-	g_print ("Sauvegarde position des onglets\n");
-	Config_User.Bool_save_pos_notebook = gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (lookup_widget (wind_main, "checkbutton_pos_onglets")));
 
 	g_print ("Sauvegarde l'etat de l'expander CD\n");
 	Config_User.BoolEtatExpanderCd = gtk_expander_get_expanded (GTK_EXPANDER (var_cd.Adr_Expander));
-
+	
+	Config_User.Bool_Activate_Journal = logs_button_is_activate ();
+	
 	g_print ("configuser_save_file_config ()\n");
 	configuser_save_file_config ();
 
@@ -251,6 +256,27 @@ void Before_End_Prg (void)
 	g_print ("fileselect_remove_comment ()\n");
 	fileselect_remove_comment ();
 	
+	g_print ("utils_remove_combo ()\n");
+	utils_remove_combo ();
+
+	g_print ("web_remove_temporary_rep ()\n");
+	web_remove_temporary_rep ();
+	
+	g_print ("Parse_remove (PARSE_TYPE_STOCKAGE_CD)\n");
+	Parse_remove (PARSE_TYPE_STOCKAGE_CD);
+	g_print ("Parse_remove (PARSE_TYPE_TITLE_CD)\n");
+	Parse_remove (PARSE_TYPE_TITLE_CD);
+	
+	g_print ("infosong_delete_file:\n\t"
+			XCFA_FILE_LOAD
+			"\n\t"
+			XCFA_PROCESS
+			"\n"			
+			);
+	infosong_delete_file (XCFA_FILE_LOAD);
+	infosong_delete_file (XCFA_PROCESS);
+	infosong_delete_file (XCFA_PID);
+	
 	g_print ("\n");
 
 	gtk_main_quit ();
@@ -286,7 +312,7 @@ gboolean on_wind_main_event (GtkWidget *widget, GdkEvent *event, gpointer user_d
 		g_print("\n");
 	}
 	*/
-	
+
 	if (event->type == GDK_LEAVE_NOTIFY) {
 		splitshuttle_set_out ();
 		utils_puts_statusbar_global ("");
@@ -462,12 +488,22 @@ void on_quitter1_activate (GtkMenuItem *menuitem, gpointer user_data)
 	Before_End_Prg ();
 }
 
+/* MENU  */
+
+void on_fenetre_etat_activate (GtkMenuItem *menuitem, gpointer user_data)
+{
+	gboolean BoolDummy = BoolWindErrorActivate;
+	BoolWindErrorActivate = TRUE;
+	// WinError_add_from_dsk ();
+	BoolWindErrorActivate = BoolDummy;
+}
+
 /* MENU ONGLETS */
 
 void on_dvd_audio1_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
 	gtk_notebook_set_current_page (
-			GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+			GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 			NOTEBOOK_DVD_AUDIO);
 }
 void on_cd_audio1_activate (GtkMenuItem *menuitem, gpointer user_data)
@@ -477,79 +513,76 @@ void on_cd_audio1_activate (GtkMenuItem *menuitem, gpointer user_data)
 	gtk_expander_set_expanded (GTK_EXPANDER (var_file.Adr_Expander), Config_User.BoolEtatExpanderCd);
 
 	gtk_notebook_set_current_page (
-			GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+			GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 			NOTEBOOK_CD_AUDIO);
 }
 void on_fichiers1_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 			NOTEBOOK_FICHIERS);
 
 	Config_User.BoolEtatExpanderFile = TRUE;
 	gtk_expander_set_expanded (GTK_EXPANDER (var_file.Adr_Expander), Config_User.BoolEtatExpanderFile);
 
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_in_file")),
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_in_file")),
 				NOTEBOOK_FICHIERS_CONVERSION);
 }
 void on_wav1_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 			NOTEBOOK_FICHIERS);
 
 	Config_User.BoolEtatExpanderFile = TRUE;
 	gtk_expander_set_expanded (GTK_EXPANDER (var_file.Adr_Expander), Config_User.BoolEtatExpanderFile);
 
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_in_file")),
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_in_file")),
 				NOTEBOOK_FICHIERS_WAV);
 }
 void on_analyse_mp3_ogg1_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 			NOTEBOOK_FICHIERS);
 
 	Config_User.BoolEtatExpanderFile = TRUE;
 	gtk_expander_set_expanded (GTK_EXPANDER (var_file.Adr_Expander), Config_User.BoolEtatExpanderFile);
 
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_in_file")),
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_in_file")),
 				NOTEBOOK_FICHIERS_MP3OGG);
 }
 void on_tags1_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 			NOTEBOOK_FICHIERS);
 
 	Config_User.BoolEtatExpanderFile = TRUE;
 	gtk_expander_set_expanded (GTK_EXPANDER (var_file.Adr_Expander), Config_User.BoolEtatExpanderFile);
 
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_in_file")),
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_in_file")),
 				NOTEBOOK_FICHIERS_TAGS);
 }
 
 void on_logs1_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
 	gtk_notebook_set_current_page (
-			GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+			GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 			NOTEBOOK_POCHETTE);
 }
-void on_pochette1_activate (GtkMenuItem *menuitem, gpointer user_data)
-{
-	gtk_notebook_set_current_page (
-			GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
-			NOTEBOOK_LOGS);
-}
 void on_options1_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
 	gtk_notebook_set_current_page (
-			GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+			GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 			NOTEBOOK_OPTIONS);
 }
 void on_expert2_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
 	gtk_notebook_set_current_page (
-			GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+			GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 			NOTEBOOK_PRGEXTERNES);
 }
-
+void on_Messages1_activate (GtkMenuItem *menuitem, gpointer user_data)
+{
+	// WinError_open ();
+}
 
 
 
@@ -568,7 +601,7 @@ void on_select_popup_tongle_activate (GtkMenuItem *menuitem, gpointer user_data)
 
 	for (cpt = 0; cpt < 3; cpt ++) {
 		if (GTK_WIDGET (menuitem) == GTK_WIDGET (lookup_widget (wind_main, TT[ cpt ].n))) {
-			gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")), TT[ cpt ].i);
+			gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")), TT[ cpt ].i);
 			-- fileshowhide_create_win ();
 			break;
 		}
@@ -582,23 +615,16 @@ void on_select_popup_tongle_activate (GtkMenuItem *menuitem, gpointer user_data)
 void on_applications_externes_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
 	gtk_notebook_set_current_page (
-			GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+			GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 			NOTEBOOK_PRGEXTERNES);
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_app_externes")),
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_app_externes")),
 				NOTEBOOK_OPTIONS_PRGEXTERNES);
 }
-void on_logs2_activate (GtkMenuItem *menuitem, gpointer user_data)
-{
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
-			NOTEBOOK_LOGS);
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_logs")),
-				NOTEBOOK_LOGS_COMPUTER);
-}
 void on_preferences1_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 			NOTEBOOK_OPTIONS);
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_options")),
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_options")),
 				NOTEBOOK_OPTIONS_GENERAL);
 }
 
@@ -701,6 +727,7 @@ void on_file_scrolledwindow_file_realize (GtkWidget *widget, gpointer user_data)
 {
 	file_scrolledwindow_file_realize (widget);
 }
+
 void on_button_import_file_clicked (GtkButton *button, gpointer user_data)
 {
 	file_button_import_file_clicked ();
@@ -760,14 +787,6 @@ void on_filemp3ogg_button_efface_bitrate_clicked (GtkButton *button, gpointer us
 	file_button_efface_bitrate_clicked_file_MP3OGG ();
 }
 
-/*
-*---------------------------------------------------------------------------
-* REALIZE RESTITUTION ONGLETS
-*---------------------------------------------------------------------------
-*/
-void on_checkbutton_pos_onglets_realize (GtkWidget *widget, gpointer user_data)
-{
-}
 
 /*
 *---------------------------------------------------------------------------
@@ -961,28 +980,6 @@ void  on_button_defaut_convertisseur_clicked (GtkButton *button, gpointer user_d
 	options_default_values (button);
 }
 
-/*
-*---------------------------------------------------------------------------
-* ONGLET LOGS
-*---------------------------------------------------------------------------
-*/
-void on_label_computer_realize (GtkWidget *widget, gpointer user_data)
-{
-	var_logs.Adr_label_computer = widget;
-}
-void on_label_import_file_realize (GtkWidget *widget,gpointer user_data)
-{
-	var_logs.Adr_label_import_file = widget;
-}
-void on_checkbutton_goto_files_import_realize (GtkWidget *widget, gpointer user_data)
-{
-	var_logs.Adr_checkbutton_goto_files_import = widget;
-}
-void on_logs_checkbutton_goto_files_import_clicked (GtkButton *button, gpointer user_data)
-{
-	logs_checkbutton_goto_files_import_clicked ();
-}
-
 /*
 *---------------------------------------------------------------------------
 * ONGLET POCHETTE -> REALIZATE
@@ -1050,10 +1047,6 @@ void on_comboboxentry_cdaudio_realize (GtkWidget *widget, gpointer user_data)
 {
 	pocheevnt_comboboxentry_cdaudio_realize (widget);
 }
-void on_comboboxentry_cdaudio_changed (GtkComboBox *combobox, gpointer user_data)
-{
-	pocheevnt_comboboxentry_cdaudio_changed ();
-}
 void on_button_get_from_web_clicked (GtkButton *button, gpointer user_data)
 {
 	pocheevnt_button_get_from_web_clicked ();
@@ -1203,16 +1196,6 @@ void on_textview_text_poche_drag_data_received
 	pocheevnt_textview_text_poche_drag_data_received ((gchar *)data->data);
 }
 
-/* Options */
-
-void on_checkbutton_load_images_init_xcfa_realize (GtkWidget *widget, gpointer user_data)
-{
-	pocheevnt_checkbutton_load_images_init_xcfa_realize (widget);
-}
-void on_checkbutton_load_images_init_xcfa_clicked (GtkButton *button, gpointer user_data)
-{
-	pocheevnt_checkbutton_load_images_init_xcfa_clicked ();
-}
 
 /* Choix, preview, make fichier PostScript */
 
@@ -1317,7 +1300,7 @@ void on_button_del_navigator_clicked (GtkButton *button, gpointer user_data)
 	prgnavigator_button_del_navigator_clicked ();
 }
 
-void on_label_type_paquege_realize (GtkWidget *widget, gpointer user_data)
+void on_label_type_package_realize (GtkWidget *widget, gpointer user_data)
 {
 	/* PRINT_FUNC_LF(); */
 
@@ -1463,11 +1446,6 @@ void on_notebook_pochette_switch_page (GtkNotebook *notebook, GtkNotebookPage *p
 	if (Config_User.Bool_Config_Ok)
 		Config_User.notebook_pochette = page_num;
 }
-void on_notebook_logs_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data)
-{
-	if (Config_User.Bool_Config_Ok)
-		Config_User.notebook_logs = page_num;
-}
 void on_notebook_app_externes_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data)
 {
 	if (Config_User.Bool_Config_Ok)
@@ -1476,40 +1454,52 @@ void on_notebook_app_externes_switch_page (GtkNotebook *notebook, GtkNotebookPag
 
 void on_button_WebInformations_clicked (GtkButton *button, gpointer user_data)
 {
-	if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_WebCdparanoia_homepage")))) {
+	if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_WebCdparanoia_homepage")))) {
 		web_goto_xcfa_page (_("http://www.xiph.org/paranoia/"));
-	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_WebCdparanoia_manpage")))) {
-		web_goto_xcfa_page (_("http://www.delafond.org/traducmanfr/man/man1/cdparanoia.1.html"));
-	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_WebLame_homepage")))) {
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_WebCdparanoia_manpage")))) {
+		// web_goto_xcfa_page (_("http://www.delafond.org/traducmanfr/man/man1/cdparanoia.1.html"));
+		web_goto_manpage ("cdparanoia");
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_WebLame_homepage")))) {
 		web_goto_xcfa_page (_("http://lame.sourceforge.net/index.php"));
-	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_WebLame_wikimp3")))) {
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_WebLame_wikimp3")))) {
 		web_goto_xcfa_page (_("http://fr.wikipedia.org/wiki/Mp3"));
-	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_WebLame_wikilame")))) {
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_WebLame_wikilame")))) {
 		web_goto_xcfa_page (_("http://fr.wikipedia.org/wiki/LAME"));
-	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_WebOggenc_wiki")))) {
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_WebLame_manpage")))) {
+		web_goto_manpage ("lame");
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_WebOggenc_wiki")))) {
 		web_goto_xcfa_page (_("http://fr.wikipedia.org/wiki/Ogg_Vorbis"));
-	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_WebOggenc_manpage")))) {
-		web_goto_xcfa_page (_("http://www.delafond.org/traducmanfr/man/man1/oggenc.1.html"));
-	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_WebFlac_homepage")))) {
-		web_goto_xcfa_page (_("http://flac-tools.sourceforge.net/"));
-	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_WebFlac_framasoft")))) {
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_WebOggenc_manpage")))) {
+		// web_goto_xcfa_page (_("http://www.delafond.org/traducmanfr/man/man1/oggenc.1.html"));
+		web_goto_manpage ("oggenc");
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_WebFlac_homepage")))) {
+		web_goto_xcfa_page (_("http://flac.sourceforge.net/"));
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_WebFlac_framasoft")))) {
 		web_goto_xcfa_page (_("http://www.framasoft.net/article1510.html"));
-	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_WebMac_wiki")))) {
-		web_goto_xcfa_page (_("http://fr.wikipedia.org/wiki/Advanced_Audio_Coding"));
-	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_WebFlac_wiki")))) {
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_WebFlac_manpage")))) {
+		web_goto_manpage ("flac");
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_WebMac_wiki")))) {
+		web_goto_xcfa_page (_("http://en.wikipedia.org/wiki/Monkey's_audio"));
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_WavPack_wiki")))) {
 		web_goto_xcfa_page (_("http://fr.wikipedia.org/wiki/WavPack"));
-	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_WebMusepack_homepage")))) {
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_WavPack_manpage")))) {
+		web_goto_manpage ("wavpack");
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_WebMusepack_homepage")))) {
 		web_goto_xcfa_page (_("http://www.musepack.net/"));
-	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_WebMusepack_framasoft")))) {
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_WebMusepack_framasoft")))) {
 		web_goto_xcfa_page (_("http://www.framasoft.net/article2094.html"));
-	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_faac_homepage")))) {
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_faac_homepage")))) {
 		web_goto_xcfa_page (_("http://www.audiocoding.com/faac.html"));
-	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_faac_web_info")))) {
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_faac_web_info")))) {
 		web_goto_xcfa_page (_("http://freshmeat.net/projects/faac/"));
-	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_aacplusenc_homepage")))) {
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_aacplusenc_homepage")))) {
 		web_goto_xcfa_page (_("http://teknoraver.campuslife.it/software/mp4tools/"));
-	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "button_aacplusenc_web_info")))) {
-		web_goto_xcfa_page (_("http://fr.wikipedia.org/wiki/Advanced_Audio_Coding"));
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_faac_manpage")))) {
+		web_goto_manpage ("faac");
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_aacplusenc_web_info")))) {
+		web_goto_xcfa_page (_("http://en.wikipedia.org/wiki/Monkey's_audio"));
+	} else if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT("button_aacplusenc_manpage")))) {
+		web_goto_manpage ("aacplusenc");
 	}
 }
 
@@ -1630,31 +1620,6 @@ void on_radiobutton_choice_extract_with_clicked (GtkButton *button, gpointer use
 	else if (GTK_BUTTON (var_options.Adr_radiobutton_extract_with_cdparanoia) == button)	Config_User.Extract_cd_with = EXTRACT_WITH_CDPARANOIA;
 }
 
-/*
-*---------------------------------------------------------------------------
-* ONGLET APPLICATIONS EXTERNES -> InstallationSimplifiee
-*---------------------------------------------------------------------------
-*/
-void on_button_selection_globale_InstallSimple_clicked (GtkButton *button, gpointer user_data)
-{
-	prginit_set_selected ();
-	gtk_widget_set_sensitive (GTK_WIDGET (var_prgextern.button_goto_install), prginit_get_bool_install ());
-}
-void on_button_goto_install_InstallSimple_realize (GtkWidget *widget, gpointer user_data)
-{
-	var_prgextern.button_goto_install = widget;
-	gtk_widget_set_sensitive (GTK_WIDGET (var_prgextern.button_goto_install), FALSE);
-}
-void on_button_goto_install_InstallSimple_clicked (GtkButton *button, gpointer user_data)
-{
-	prginstall_systeme_debian ();
-}
-void on_button_selection_globale_InstallSimple_realize (GtkWidget *widget, gpointer user_data)
-{
-	var_prgextern.button_selection_globale = widget;
-	if (var_prgextern.button_selection_globale)
-		gtk_widget_set_sensitive (GTK_WIDGET (var_prgextern.button_selection_globale), prginit_is_not_installed ());
-}
 
 /* SWITCH PAGE IN FILE
 */
@@ -1698,6 +1663,7 @@ void on_label_tag_change_realize (GtkWidget *widget, gpointer user_data)
 void on_button_tag_appliquer_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_file.Adr_button_tag_appliquer = widget;
+	on_button_tag_appliquer_clicked (GTK_BUTTON(widget), NULL);
 }
 void on_table_tag_realize (GtkWidget *widget, gpointer user_data)
 {
@@ -1995,7 +1961,8 @@ void on_notebook_expander_cd_realize (GtkWidget *widget, gpointer user_data)
 */
 void on_button_stop_music_clicked (GtkButton *button, gpointer user_data)
 {
-	Player_button_stop_music_clicked (button);
+	// Player_button_stop_music_clicked (button);
+	mplayer_fifo_quit ();
 }
 
 
@@ -2073,7 +2040,7 @@ void on_combobox_normalise_dvd_realize (GtkWidget *widget, gpointer user_data)
 void on_radiobutton_ioctl_clicked (GtkButton *button, gpointer user_data)
 {
 	if (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (var_options.Adr_radiobutton_ioctl)) == TRUE) {
-		/*gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (lookup_widget (wind_main, "checkbutton_cue_creation_from_cd")), FALSE);*/
+		/*gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (XCFA_GET_OBJECT("checkbutton_cue_creation_from_cd")), FALSE);*/
 	}
 }
 
@@ -2165,12 +2132,12 @@ void on_button_action_split_clicked (GtkButton *button, gpointer user_data)
 void on_checkbutton_creation_fichier_cue_clicked (GtkButton *button, gpointer user_data)
 {
 	if (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (button)) == TRUE)
-		gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (lookup_widget (wind_main, "checkbutton_creation_fichier_unique_cue")), TRUE);
+		gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (XCFA_GET_OBJECT("checkbutton_creation_fichier_unique_cue")), TRUE);
 }
 void on_checkbutton_creation_fichier_unique_cue_clicked (GtkButton *button, gpointer user_data)
 {
 	if (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (button)) == FALSE)
-		gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (lookup_widget (wind_main, "checkbutton_creation_fichier_cue")), FALSE);
+		gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (XCFA_GET_OBJECT("checkbutton_creation_fichier_cue")), FALSE);
 }
 
 /* Nettoyer FICHIERS ****************/
@@ -2248,7 +2215,9 @@ void on_image_button_coller_mark_B_split_realize (GtkWidget *widget, gpointer us
 
 void on_combobox_choice_file_cue_realize (GtkWidget *widget, gpointer user_data)
 {
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "WAV");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "FLAC");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "OGG");
@@ -2428,10 +2397,15 @@ void on_button_paste_comment_clicked (GtkButton *button, gpointer user_data)
 
 /* NOUVEAU WIDGET SPLIT
 */
-
-GtkWidget *splitshuttle_create (gchar *widget_name, gchar *string1, gchar *string2, gint int1, gint int2)
+void on_hbox_splitshuttle_realize (GtkWidget *widget, gpointer user_data)
 {
-	return (splitshuttle_new ());
+	GtkWidget *WidgetNewSplit = NULL;
+	
+	WidgetNewSplit = SplitShuttle_new ();
+	gtk_box_pack_start (GTK_BOX (widget), WidgetNewSplit, TRUE, TRUE, 0);
+	// gtk_container_add (GTK_CONTAINER (widget), WidgetNewSplit);
+	// gdk_window_set_user_data (widget->window, WidgetNewSplit);
+	gtk_widget_show_all (GTK_WIDGET (widget));
 }
 
 void on_checkbutton_contour_split_clicked (GtkButton *button, gpointer user_data)
@@ -2439,3 +2413,11 @@ void on_checkbutton_contour_split_clicked (GtkButton *button, gpointer user_data
 	splitshuttle_force_redraw ();
 }
 
+
+
+
+
+
+
+
+
