@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -66,7 +66,6 @@ void on_wav1_activate (GtkMenuItem *menuitem, gpointer user_data);
 void on_analyse_mp3_ogg1_activate (GtkMenuItem *menuitem, gpointer user_data);
 void on_tags1_activate (GtkMenuItem *menuitem, gpointer user_data);
 void on_logs1_activate (GtkMenuItem *menuitem, gpointer user_data);
-void on_pochette1_activate (GtkMenuItem *menuitem, gpointer user_data);
 void on_options1_activate (GtkMenuItem *menuitem, gpointer user_data);
 void on_expert2_activate (GtkMenuItem *menuitem, gpointer user_data);
 
@@ -75,7 +74,6 @@ void on_select_popup_tongle_activate (GtkMenuItem *menuitem, gpointer user_data)
 /* MENU OUTILS */
 
 void on_applications_externes_activate (GtkMenuItem *menuitem, gpointer user_data);
-void on_logs2_activate (GtkMenuItem *menuitem, gpointer user_data);
 void on_preferences1_activate (GtkMenuItem *menuitem, gpointer user_data);
 
 /* MENU AIDE */
@@ -146,16 +144,6 @@ void on_filewav_spinbutton_frequence_value_changed (GtkSpinButton *spinbutton, g
 
 void on_filemp3ogg_button_efface_bitrate_clicked (GtkButton *button, gpointer user_data);
 
-/*
-*---------------------------------------------------------------------------
-* ONGLET LOGS
-*---------------------------------------------------------------------------
-*/
-
-void on_label_computer_realize (GtkWidget *widget, gpointer user_data);
-void on_label_import_file_realize (GtkWidget *widget,gpointer user_data);
-void on_checkbutton_goto_files_import_realize (GtkWidget *widget, gpointer user_data);
-void on_logs_checkbutton_goto_files_import_clicked (GtkButton *button, gpointer user_data);
 
 /*
 *---------------------------------------------------------------------------
@@ -216,13 +204,6 @@ void on_combobox_ape_compression_realize (GtkWidget *widget, gpointer user_data)
 void on_combobox_ape_compression_changed (GtkComboBox *combobox, gpointer user_data);
 void  on_button_defaut_convertisseur_clicked (GtkButton *button, gpointer user_data);
 
-/*
-*---------------------------------------------------------------------------
-* REALIZE RESTITUTION ONGLETS
-*---------------------------------------------------------------------------
-*/
-
-void on_checkbutton_pos_onglets_realize (GtkWidget *widget, gpointer user_data);
 
 /*
 *---------------------------------------------------------------------------
@@ -247,7 +228,6 @@ void on_viewport_image_preview_realize (GtkWidget *widget, gpointer user_data);
 
 /* Titre volume cd-audio */
 void on_comboboxentry_cdaudio_realize (GtkWidget *widget, gpointer user_data);
-void on_comboboxentry_cdaudio_changed (GtkComboBox *combobox, gpointer user_data);
 
 void on_entry_name_volume_cdaudio_realize (GtkWidget *widget, gpointer user_data);
 void on_entry_name_volume_cdaudio_changed (GtkEditable *editable, gpointer user_data);
@@ -298,10 +278,6 @@ void on_textview_text_poche_drag_data_received
                                         guint            time,
                                         gpointer         user_data);
 
-/* Options */
-
-void on_checkbutton_load_images_init_xcfa_realize (GtkWidget *widget, gpointer user_data);
-void on_checkbutton_load_images_init_xcfa_clicked (GtkButton *button, gpointer user_data);
 
 /* Choix, preview, make fichier PostScript */
 
@@ -352,7 +328,7 @@ void on_button_del_postscript_realize (GtkWidget *widget, gpointer user_data);
 void on_button_del_postscript_clicked (GtkButton *button, gpointer user_data);
 
 
-void on_label_type_paquege_realize (GtkWidget *widget, gpointer user_data);
+void on_label_type_package_realize (GtkWidget *widget, gpointer user_data);
 
 /* DVD AUDIO */
 
@@ -384,7 +360,6 @@ void on_progressbar_wav_realize (GtkWidget *widget, gpointer user_data);
 void on_notebook_general_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data);
 void on_notebook_options_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data);
 void on_notebook_pochette_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data);
-void on_notebook_logs_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data);
 void on_notebook_app_externes_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data);
 
 void on_label_entry_internal_visual_realize (GtkWidget *widget, gpointer user_data);
@@ -440,10 +415,6 @@ void on_radiobutton_extract_with_cdda2wav_realize (GtkWidget *widget, gpointer u
 void on_radiobutton_cdparanoia_mode_expert_realize (GtkWidget *widget, gpointer user_data);
 void on_radiobutton_choice_extract_with_clicked (GtkButton *button, gpointer user_data);
 
-void on_button_selection_globale_InstallSimple_clicked (GtkButton *button, gpointer user_data);
-void on_button_goto_install_InstallSimple_realize (GtkWidget *widget, gpointer user_data);
-void on_button_goto_install_InstallSimple_clicked (GtkButton *button, gpointer user_data);
-void on_button_selection_globale_InstallSimple_realize (GtkWidget *widget, gpointer user_data);
 
 /* SPLIT */
 
@@ -732,6 +703,9 @@ gboolean on_button_split_enter_notify_event (GtkWidget *widget, GdkEventCrossing
 gboolean on_button_split_leave_notify_event (GtkWidget *widget, GdkEventCrossing *event, gpointer user_data);
 void on_checkbutton_contour_split_clicked (GtkButton *button, gpointer user_data);
 
+// void on_button_split_tst_realize (GtkWidget *widget, gpointer user_data);
+// void on_viewport_split_realize (GtkWidget *widget, gpointer user_data);
+void on_hbox_splitshuttle_realize (GtkWidget *widget, gpointer user_data);
 #endif
 
 
