@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -265,7 +265,8 @@ typedef struct {
 	
 	EXTRACT_EXPERT		 ExtractExpert;
 	
-
+	gboolean		 EtatBoolWavpack;
+	
 } AUDIO;
 
 typedef struct {
@@ -396,7 +397,6 @@ void      cdexpander_set_spinbutton_tag_piste (void);
 void      cdexpander_set_entry_tag_titre_fichier_m3u (void);
 void      cdexpander_set_sensitive_notebook (void);
 
-
 void      cdexpander_entry_tag_titre_chanson_changed (void);
 void      cdexpander_entry_tag_titre_album_changed (void);
 void      cdexpander_entry_tag_nom_artiste_changed (void);
@@ -424,7 +424,7 @@ void      cdexpander_notebook_expander_cd_realize (GtkWidget *widget);
 
 /*
 *---------------------------------------------------------------------------
-* CD_ADIO_TOCC
+* CD_AUDIO_TOC
 *---------------------------------------------------------------------------
 */
 void      cdaudiotoc_reffresh_list_cd (void);
