@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -47,8 +47,6 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 
-#include "support.h"
-
 #include <pthread.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -173,7 +171,7 @@ void cdaudioextract_create_list_is_Convert (void)
 	AUDIO		*Audio = NULL;
 	PARAM_FILELC	 param_filelc;
 	
-	PRINT_FUNC_LF();
+	// PRINT_FUNC_LF();
 	List = g_list_first (EnteteCD.GList_Audio_cd);
 	while (List) {
 		if ((Audio = List->data) != NULL) {
@@ -249,6 +247,8 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.tags                  = Audio->tags;
 				param_filelc.cdrom                 = NULL;
 				param_filelc.num_track             = NULL;
+				param_filelc.BoolSetBitrate        = FALSE;
+				param_filelc.PtrStrBitrate         = NULL;
 				
 				Audio->ListConv[ NUM_FLAC ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				Audio->ListConv[ NUM_FLAC ].list = filelc_get_command_line (&param_filelc);
@@ -261,6 +261,8 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.tags                  = Audio->tags;
 				param_filelc.cdrom                 = NULL;
 				param_filelc.num_track             = NULL;
+				param_filelc.BoolSetBitrate        = FALSE;
+				param_filelc.PtrStrBitrate         = NULL;
 				
 				Audio->ListConv[ NUM_APE ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				Audio->ListConv[ NUM_APE ].list = filelc_get_command_line (&param_filelc);
@@ -269,10 +271,12 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.type_conv             = WAVPACK_WAV_TO_WAVPACK;
 				param_filelc.With_CommandLineUser  = Audio->EtatSelection_WavPack >= CD_ETAT_SELECT_EXPERT;
 				param_filelc.filesrc               = Audio->PathName_Dest_Wav;
-				param_filelc.filedest              = Audio->PathName_Dest_Wav;
+				param_filelc.filedest              = Audio->PathName_Dest_WavPack;
 				param_filelc.tags                  = Audio->tags;
 				param_filelc.cdrom                 = NULL;
 				param_filelc.num_track             = NULL;
+				param_filelc.BoolSetBitrate        = FALSE;
+				param_filelc.PtrStrBitrate         = NULL;
 
 				Audio->ListConv[ NUM_WAVPACK ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				Audio->ListConv[ NUM_WAVPACK ].list = filelc_get_command_line (&param_filelc);
@@ -292,6 +296,9 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.tags                  = Audio->tags;
 				param_filelc.cdrom                 = NULL;
 				param_filelc.num_track             = NULL;
+				param_filelc.BoolSetBitrate        = FALSE;
+				param_filelc.PtrStrBitrate         = NULL;
+				param_filelc.PtrStrBitrate         = options_get_params (OGGENC_WAV_TO_OGG, param_filelc, NULL);
 
 				Audio->ListConv[ NUM_OGG ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				Audio->ListConv[ NUM_OGG ].list = filelc_get_command_line (&param_filelc);
@@ -304,6 +311,8 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.tags                  = Audio->tags;
 				param_filelc.cdrom                 = NULL;
 				param_filelc.num_track             = NULL;
+				param_filelc.BoolSetBitrate        = FALSE;
+				param_filelc.PtrStrBitrate         = NULL;
 
 				Audio->ListConv[ NUM_M4A ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				Audio->ListConv[ NUM_M4A ].list = filelc_get_command_line (&param_filelc);
@@ -316,6 +325,9 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.tags                  = Audio->tags;
 				param_filelc.cdrom                 = NULL;
 				param_filelc.num_track             = NULL;
+				param_filelc.BoolSetBitrate        = FALSE;
+				param_filelc.PtrStrBitrate         = NULL;
+				param_filelc.PtrStrBitrate         = options_get_params (AACPLUSENC_WAV_TO_AAC, param_filelc, NULL);
 
 				Audio->ListConv[ NUM_AAC ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				Audio->ListConv[ NUM_AAC ].list = filelc_get_command_line (&param_filelc);
@@ -335,6 +347,8 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.tags                  = Audio->tags;
 				param_filelc.cdrom                 = NULL;
 				param_filelc.num_track             = NULL;
+				param_filelc.BoolSetBitrate        = FALSE;
+				param_filelc.PtrStrBitrate         = NULL;
 
 				Audio->ListConv[ NUM_MPC ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				Audio->ListConv[ NUM_MPC ].list = filelc_get_command_line (&param_filelc);
@@ -347,6 +361,9 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.tags                  = Audio->tags;
 				param_filelc.cdrom                 = NULL;
 				param_filelc.num_track             = NULL;
+				param_filelc.BoolSetBitrate        = FALSE;
+				param_filelc.PtrStrBitrate         = NULL;
+				param_filelc.PtrStrBitrate         = options_get_params (LAME_WAV_TO_MP3, param_filelc, NULL);
 
 				Audio->ListConv[ NUM_MP3 ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				Audio->ListConv[ NUM_MP3 ].list = filelc_get_command_line (&param_filelc);
@@ -372,7 +389,7 @@ gboolean cdaudioextract_create_list_is_Extract (void)
 	PARAM_FILELC	 param_filelc;
 	gboolean	 BoolIsPeakAlbum = FALSE;
 
-	PRINT_FUNC_LF();
+	// PRINT_FUNC_LF();
 	VarCdExtract.NbrFileUnique = 0;
 	List = g_list_first (EnteteCD.GList_Audio_cd);
 	while (List) {
@@ -467,6 +484,8 @@ gboolean cdaudioextract_create_list_is_Extract (void)
 					Audio->ListConv[ NUM_WAV ].Size                = cdaudioextract_get_size (Audio->Num_Track -1);
 					Audio->ListConv[ NUM_WAV ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 					Audio->ListConv[ NUM_WAV ].list                = filelc_get_command_line_extract (&param_filelc);
+					
+					conv.total_convert ++;
 					break;
 				}
 								
@@ -673,6 +692,8 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 	
 	PRINT("DEBUT THREAD EXTRACTION");
 	
+	logs_add_datas_session ("FROM CD");
+	
 	conv.ArgExtract = (ARGS_TO_EXEC *)g_malloc0(sizeof(ARGS_TO_EXEC) * 52);
 	for (pos = 0; pos < 50; pos ++)
 		conv.ArgExtract[ pos ].str = NULL;
@@ -692,18 +713,25 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 				
 				switch (Config_User.Extract_cd_with) {
 				case EXTRACT_WITH_CDPARANOIA :
-					conv_exec_extract (
-							Audio->ListConv[ NUM_WAV ].WithCommandLineUser, 
-							CDPARANOIA_CD_TO_WAV,
-							Audio->ListConv[ NUM_WAV ].list,
-							"CDPARANOIA_CD_TO_WAV"
-							);
+					if (!conv.bool_stop) {
+					
+						logs_writeln_datas ("EXTRACT_WITH_CDPARANOIA: ");
+						
+						conv_exec_extract (
+								Audio->ListConv[ NUM_WAV ].WithCommandLineUser, 
+								CDPARANOIA_CD_TO_WAV,
+								Audio->ListConv[ NUM_WAV ].list,
+								"CDPARANOIA_CD_TO_WAV"
+								);
+					}
 					break;
 				case EXTRACT_WITH_CDPARANOIA_EXPERT :
 					if (!conv.bool_stop) {
 						
 						gchar *Str = NULL;
 						
+						logs_writeln_datas ("EXTRACT_WITH_CDPARANOIA_EXPERT: ");
+						
 						Str = g_strdup_printf (_("\n[Piste: %d]\n"), Audio->Num_Track);
 						cdaudioextract_set_list_textview (Str);
 						g_free (Str);
@@ -759,45 +787,57 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 				
 				case EXTRACT_WITH_CDDA2WAV :
 
-					/*g_chdir (conv.TmpRep);*/
-
-					conv_exec_extract (
-							Audio->ListConv[ NUM_WAV ].WithCommandLineUser, 
-							CDDA2WAV_CD_TO_WAV,
-							Audio->ListConv[ NUM_WAV ].list,
-							"CDDA2WAV_CD_TO_WAV"
-							);
+					if (!conv.bool_stop) {
+						/*g_chdir (conv.TmpRep);*/
 							
-					/*g_chdir (VarCdExtract.PtrDirActuel);*/
-					
-					if (conv.bool_stop == FALSE) {
+						logs_writeln_datas ("EXTRACT_WITH_ICEDAX: ");
+							
+						conv_exec_extract (
+								Audio->ListConv[ NUM_WAV ].WithCommandLineUser, 
+								CDDA2WAV_CD_TO_WAV,
+								Audio->ListConv[ NUM_WAV ].list,
+								"CDDA2WAV_CD_TO_WAV"
+								);
+								
+						/*g_chdir (VarCdExtract.PtrDirActuel);*/
 						
-						gchar *StrOldName = NULL;
-						/*
-						in: PATH_TMP_XCFA_AUDIOCD
-							audio.inf
-							audio.wav
-						*/
-						StrOldName = g_strdup_printf ("%s/audio.wav", conv.TmpRep);
-						conv_copy_src_to_dest (StrOldName, Audio->PathName_Dest_Wav);
-						g_free (StrOldName);
-						StrOldName = NULL;
+						if (conv.bool_stop == FALSE) {
+							
+							gchar *StrOldName = NULL;
+							/*
+							in: PATH_TMP_XCFA_AUDIOCD
+								audio.inf
+								audio.wav
+							*/
+							StrOldName = g_strdup_printf ("%s/audio.wav", conv.TmpRep);
+							conv_copy_src_to_dest (StrOldName, Audio->PathName_Dest_Wav);
+							g_free (StrOldName);
+							StrOldName = NULL;
+						}
 					}
 					break;
 				}
 				
-				if (Audio->EtatNormalise == TRUE) {
+				if (!conv.bool_stop && Audio->EtatNormalise == TRUE) {
 					switch (VarCdExtract.ComboNumActive) {
 					case 0 :
+						logs_writeln_datas ("\tNORMALISATION PEAK/ALBUM");
+						conv.total_convert ++;
+						conv.total_convert ++;
+						conv.total_percent = conv.encode_completed / conv.total_convert;
+						conv.bool_percent_extract = conv.bool_percent_conv = TRUE;
 						Audio->EtatPeak = CD_NORM_PEAK_WAITING;
 						PRINT("ADD PEAK/ALBUM");
 						CdNormalise_add_PeakGroup ();
 						break;
 					case 1 :
+						logs_writeln_datas ("\tNORMALISATION PEAK");
 						Audio->EtatPeak = CD_NORM_PEAK_WAITING;
 						break;
 					}
 				}
+				logs_write_datas ("\t");
+				logs_writeln_datas (Audio->PathName_Dest_Wav);
 				
 				Audio->EtatSelection_Wav = CD_ETAT_ATTENTE;
 
@@ -837,6 +877,7 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 	if (VarCdExtract.BoolListIsPeakAlbum == TRUE) {
 	
 		PRINT("DEBUT NORMALISATION PEAK/ALBUM");
+		logs_write_datas ("\tNORMALISATION PEAK/ALBUM with ");
 		
 		/* Premiere allocation */
 		if (conv.ArgConv == NULL)
@@ -846,11 +887,26 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 			  CdNormalise_get_is_list_PeakGroup () == TRUE &&
 			  CdNormalise_list_PeakGroup_is_ready () == TRUE) {
 			
-			GList	*ListNorm = NULL;
-			GList	*List = NULL;
-			GList	*List2 = NULL;
-			gchar	*Ptr = NULL;
-
+			GList				*ListNorm = NULL;
+			GList				*List2 = NULL;
+			VAR_CD_NORMALISE_ELEMENT	*VarCDNormaliseElement = NULL;
+			
+			conv.total_percent = conv.encode_completed / conv.total_convert;
+			conv.bool_percent_extract = conv.bool_percent_conv = TRUE;
+			
+			// COPIE DES FICHIERS DESTINAION -> TEMPORAIRE
+			
+			List2 = g_list_first (CdNormalise_get_list_PeakGroup ());
+			while (List2) {
+				if ((VarCDNormaliseElement = (VAR_CD_NORMALISE_ELEMENT *)List2->data) != NULL) {
+					// VarCDNormaliseElement->PathNameSrc
+					// VarCDNormaliseElement->PathNameDest
+					conv_copy_src_to_dest (VarCDNormaliseElement->PathNameDest, VarCDNormaliseElement->PathNameSrc);
+					conv_inc_encode_completed ();
+				}
+				List2 = g_list_next(List2);
+			}
+			
 			/*-- CHERCHER LA MOYENNE PEAK */
 			
 			ListNorm = g_list_append (ListNorm, g_strdup ("nice"));
@@ -862,18 +918,22 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 			
 			/*-- AJOUTER LA LISTE DES FICHIERS */
 
-			List2 = List = g_list_first (CdNormalise_get_list_PeakGroup ());
-			while (List) {
-				Ptr = (gchar *)List->data;
-				ListNorm = g_list_append (ListNorm, g_strdup_printf ("%s", Ptr));
-				List = g_list_next(List);
+			List2 = g_list_first (CdNormalise_get_list_PeakGroup ());
+			while (List2) {
+				if ((VarCDNormaliseElement = (VAR_CD_NORMALISE_ELEMENT *)List2->data) != NULL) {
+					ListNorm = g_list_append (ListNorm, g_strdup_printf ("%s", VarCDNormaliseElement->PathNameSrc));
+				}
+				List2 = g_list_next(List2);
 			}
-			/*List = utils_clear_list (List);*/
 			
+			conv.bool_percent_extract = conv.bool_percent_conv = TRUE;
 			VarCdExtract.NbrList = conv_g_list_length (ListNorm, &VarCdExtract.NbrList);
 			conv_exec (FALSE, NORMALISE_GET_LEVEL, ListNorm, "NORMALISE_GET_LEVEL TEST -> PEAK/GROUP");
 			ListNorm = filelc_remove_glist (ListNorm);
 			
+			logs_write_double (conv.value_PEAK_RMS_GROUP_ARGS);
+			logs_writeln_datas ("dB");
+			
 			/*-- APPLIQUER LA MOYENNE PEAK */
 			
 			ListNorm = g_list_append (ListNorm, g_strdup ("nice"));
@@ -885,24 +945,39 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 			
 			/*-- AJOUTER LA LISTE DES FICHIERS */
 			
-			/*List = g_list_first (CdNormalise_get_list_PeakGroup ());*/
+			List2 = g_list_first (CdNormalise_get_list_PeakGroup ());
 			while (List2) {
-				Ptr = (gchar *)List2->data;
-				ListNorm = g_list_append (ListNorm, g_strdup_printf ("\"%s\"", Ptr));
+				if ((VarCDNormaliseElement = (VAR_CD_NORMALISE_ELEMENT *)List2->data) != NULL) {
+					logs_write_datas ("\t");
+					logs_writeln_datas (VarCDNormaliseElement->PathNameDest);
+					ListNorm = g_list_append (ListNorm, g_strdup_printf ("%s", VarCDNormaliseElement->PathNameSrc));
+				}
 				List2 = g_list_next(List2);
-				conv_inc_encode_completed ();
 			}
-			List2 = List = utils_clear_list (List);
+			ListNorm = g_list_append (ListNorm, g_strdup ("--"));
 			
 			/*-- NORMALISATION */
 			
+			conv.bool_percent_extract = conv.bool_percent_conv = TRUE;
 			VarCdExtract.NbrList = conv_g_list_length (ListNorm, &VarCdExtract.NbrList);
 			conv_exec (FALSE, NORMALISE_EXEC, ListNorm, "NORMALISE_EXEC Wav -> PEAK/GROUP");
 			ListNorm = filelc_remove_glist (ListNorm);
 
 			CdNormalise_set_normalise_ok ();
 			
-			conv_inc_encode_completed ();
+			// COPIE DES FICHIERS TEMPORAIRE -> DESTINATION
+			
+			List2 = g_list_first (CdNormalise_get_list_PeakGroup ());
+			while (List2) {
+				if ((VarCDNormaliseElement = (VAR_CD_NORMALISE_ELEMENT *)List2->data) != NULL) {
+					// VarCDNormaliseElement->PathNameSrc
+					// VarCDNormaliseElement->PathNameDest
+					conv_copy_src_to_dest (VarCDNormaliseElement->PathNameSrc, VarCDNormaliseElement->PathNameDest);
+					conv_inc_encode_completed ();
+				}
+				List2 = g_list_next(List2);
+			}
+			
 			conv.Bool_MAJ_select = TRUE;
 			conv.bool_reset_conv = TRUE;
 			conv.BoolPercentFlac = TRUE;
@@ -948,7 +1023,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			ListOne = g_list_next(ListOne);
 			continue;
 		}
-					
+		
 		if (Audio->EtatNormalise == TRUE && VarCdExtract.ComboNumActive == 1) {
 			/*  PEAK
 			 *  Le volume sera ajuste au maximum pour cet element
@@ -960,7 +1035,9 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			     Audio->Etat_Wav == CONV_OK) {
 				
 				GList	*ListNorm = NULL;
-				
+				gchar	*Name = NULL;
+				gchar	*Ptr = NULL;
+
 				/* Creation de la list */
 				ListNorm = g_list_append (ListNorm, g_strdup ("nice"));
 				ListNorm = g_list_append (ListNorm, g_strdup ("-n"));
@@ -968,14 +1045,28 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				// ListNorm = g_list_append (ListNorm, g_strdup (PrgInit.name_normalize));
 				ListNorm = g_list_append (ListNorm, g_strdup (prginit_get_name (NMR_normalize)));
 				ListNorm = g_list_append (ListNorm, g_strdup ("--peak"));
+				
+				Name = g_strdup_printf ("%s0123456789", Audio->PathName_Dest_Wav);
+				Ptr = strrchr (Name, '/');
+				Ptr ++;
+				strcpy (Ptr, "01.wav");
+				conv_copy_src_to_dest (Audio->PathName_Dest_Wav, Name);
+				
+				ListNorm = g_list_append (ListNorm, g_strdup_printf ("%s", Name));
 				ListNorm = g_list_append (ListNorm, g_strdup ("--"));
-				ListNorm = g_list_append (ListNorm, g_strdup_printf ("\"%s\"", Audio->PathName_Dest_Wav));
-
-				/* normalisation */
+				
+				// NORMALISATION PEAK
 				VarCdExtract.NbrList = conv_g_list_length (ListNorm, &VarCdExtract.NbrList);
 				conv_exec (FALSE, NORMALISE_EXEC, ListNorm, "NORMALISE_EXEC Wav -> Peak");
 				ListNorm = filelc_remove_glist (ListNorm);
 				
+				conv_copy_src_to_dest (Name, Audio->PathName_Dest_Wav);
+				infosong_delete_file (Name);
+				
+				g_free (Name);
+				Name = NULL;
+				
+				
 				Audio->EtatPeak = CD_NORM_PEAK_NONE;
 				Audio->EtatNormalise = FALSE;
 				
@@ -1014,8 +1105,8 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				VarCdExtract.NbrList = conv_g_list_length (list, &VarCdExtract.NbrList);
 				conv_exec (FALSE, SOX_WAV_TO_WAV, list, "SOX_WAV_TO_WAV");
 				list = filelc_remove_glist (list);
-	PRINT("DEBUG POUR DZEF");
-	g_print("\t%s = %s\n\n", VarCdExtract.NameFileFormatUnique, infosong_file_is_reg (VarCdExtract.NameFileFormatUnique) ? "EXISTE" : "NOT FOUND");
+	PRINT("DEBUG FOR @DZEF");
+	g_print("\t%s = %s\n\n", VarCdExtract.NameFileFormatUnique, infosong_file_is_reg (VarCdExtract.NameFileFormatUnique) ? "EXIST" : "NOT FOUND");
 	
 				conv.type_conv = NONE_CONV;
 				conv_remove_name_for_label (_CONV_);
@@ -1037,6 +1128,11 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			g_print ("\n");
 			g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
 			g_print ("DEST   FLAC<%s>\n", Audio->PathName_Dest_Flac);
+			
+			logs_write_datas ("\t");
+			logs_write_datas (Audio->PathName_Dest_Wav);
+			logs_write_datas (" -> ");
+			logs_writeln_datas (Audio->PathName_Dest_Flac);
 
 			conv_product_name_for_label (Audio->PathName_Dest_Flac);
 			conv.bool_reset_conv = TRUE;
@@ -1065,6 +1161,12 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			g_print ("\n");
 			g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
 			g_print ("DEST   APE <%s>\n", Audio->PathName_Dest_Ape);
+			
+			logs_write_datas ("\t");
+			logs_write_datas (Audio->PathName_Dest_Wav);
+			logs_write_datas (" -> ");
+			logs_writeln_datas (Audio->PathName_Dest_Ape);
+
 			conv_product_name_for_label (Audio->PathName_Dest_Ape);
 			conv.bool_reset_conv = TRUE;
 			conv.type_conv = MAC_WAV_TO_APE;
@@ -1095,13 +1197,17 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			g_print ("\n");
 			g_print ("SOURCE WAV     <%s>\n", Audio->PathName_Dest_Wav);
 			g_print ("DEST   WAVPACK <%s>\n", Audio->PathName_Dest_WavPack);
+			
+			logs_write_datas ("\t");
+			logs_write_datas (Audio->PathName_Dest_Wav);
+			logs_write_datas (" -> ");
+			logs_writeln_datas (Audio->PathName_Dest_WavPack);
+
 			conv_product_name_for_label (Audio->PathName_Dest_WavPack);
 			conv.bool_reset_conv = TRUE;
 			conv.type_conv = WAVPACK_WAV_TO_WAVPACK;
-
-			logs_add_datas_system ("\n<b>TEST RESULTAT conv_with_wavpack:</b>\n[ ");
-			logs_add_datas_system (Audio->PathName_Dest_WavPack);
-			logs_add_datas_system (" ]\n");
+			
+			Audio->EtatBoolWavpack = TRUE;
 			
 			VarCdExtract.NbrList = conv_g_list_length (Audio->ListConv[ NUM_WAVPACK ].list, &VarCdExtract.NbrList);
 			conv_exec (Audio->ListConv[ NUM_WAVPACK ].WithCommandLineUser,  WAVPACK_WAV_TO_WAVPACK, Audio->ListConv[ NUM_WAVPACK ].list, "WAVPACK_WAV_TO_WAVPACK");
@@ -1141,6 +1247,12 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			g_print ("\n");
 			g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
 			g_print ("DEST   OGG <%s>\n", Audio->PathName_Dest_Ogg);
+			
+			logs_write_datas ("\t");
+			logs_write_datas (Audio->PathName_Dest_Wav);
+			logs_write_datas (" -> ");
+			logs_writeln_datas (Audio->PathName_Dest_Ogg);
+
 			conv_product_name_for_label (Audio->PathName_Dest_Ogg);
 			conv.bool_reset_conv = TRUE;
 			conv.type_conv = OGGENC_WAV_TO_OGG;
@@ -1168,6 +1280,12 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			g_print ("\n");
 			g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
 			g_print ("DEST   M4A <%s>\n", Audio->PathName_Dest_M4a);
+			
+			logs_write_datas ("\t");
+			logs_write_datas (Audio->PathName_Dest_Wav);
+			logs_write_datas (" -> ");
+			logs_writeln_datas (Audio->PathName_Dest_M4a);
+
 			conv_product_name_for_label (Audio->PathName_Dest_M4a);
 			conv.bool_reset_conv = TRUE;
 			conv.type_conv = FAAC_WAV_TO_M4A;
@@ -1195,6 +1313,12 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			g_print ("\n");
 			g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
 			g_print ("DEST   AAC <%s>\n", Audio->PathName_Dest_Aac);
+			
+			logs_write_datas ("\t");
+			logs_write_datas (Audio->PathName_Dest_Wav);
+			logs_write_datas (" -> ");
+			logs_writeln_datas (Audio->PathName_Dest_Aac);
+
 			conv_product_name_for_label (Audio->PathName_Dest_Aac);
 			conv.bool_reset_conv = TRUE;
 			conv.type_conv = AACPLUSENC_WAV_TO_AAC;
@@ -1223,6 +1347,12 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			g_print ("\n");
 			g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
 			g_print ("DEST   MPC <%s>\n", Audio->PathName_Dest_Mpc);
+			
+			logs_write_datas ("\t");
+			logs_write_datas (Audio->PathName_Dest_Wav);
+			logs_write_datas (" -> ");
+			logs_writeln_datas (Audio->PathName_Dest_Mpc);
+
 			conv_product_name_for_label (Audio->PathName_Dest_Mpc);
 			conv.bool_reset_conv = TRUE;
 			conv.type_conv = MPPENC_WAV_TO_MPC;
@@ -1250,6 +1380,12 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			g_print ("\n");
 			g_print ("SOURCE WAV <%s>\n", Audio->PathName_Dest_Wav);
 			g_print ("DEST   MP3 <%s>\n", Audio->PathName_Dest_Mp3);
+			
+			logs_write_datas ("\t");
+			logs_write_datas (Audio->PathName_Dest_Wav);
+			logs_write_datas (" -> ");
+			logs_writeln_datas (Audio->PathName_Dest_Mp3);
+
 			conv_product_name_for_label (Audio->PathName_Dest_Mp3);
 			conv.bool_reset_conv = TRUE;
 			conv.type_conv = LAME_WAV_TO_MP3;
@@ -1375,7 +1511,7 @@ static gint cdaudioextract_timeout (gpointer data)
 			gtk_text_buffer_place_cursor (Buf, &End);
 	 		if ((List = g_list_first (conv.ListPutTextview)) != NULL) {
 				
-				Adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (GTK_WIDGET (lookup_widget (conv.Adr_wind, "scrolledwindow_wind_extract"))));
+				Adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (GTK_WIDGET (XCFA_GET_OBJECT("scrolledwindow_wind_extract"))));
 				
 				while (List) {
 					if ((Ptr = (gchar *)List->data)) {
@@ -1384,14 +1520,14 @@ static gint cdaudioextract_timeout (gpointer data)
 						Ptr = NULL;
 						List->data = NULL;
 						gtk_adjustment_set_value (Adj, Adj->upper + 50.0);
-						gtk_scrolled_window_set_vadjustment (GTK_SCROLLED_WINDOW (GTK_WIDGET (lookup_widget (conv.Adr_wind, "scrolledwindow_wind_extract"))), Adj);
+						gtk_scrolled_window_set_vadjustment (GTK_SCROLLED_WINDOW (GTK_WIDGET (XCFA_GET_OBJECT("scrolledwindow_wind_extract"))), Adj);
 					}
 					List = g_list_next(List);
 				}
 				conv.BoolPutTextview = FALSE;
 				
 				gtk_adjustment_set_value (Adj, Adj->upper + 50.0);
-				gtk_scrolled_window_set_vadjustment (GTK_SCROLLED_WINDOW (GTK_WIDGET (lookup_widget (conv.Adr_wind, "scrolledwindow_wind_extract"))), Adj);
+				gtk_scrolled_window_set_vadjustment (GTK_SCROLLED_WINDOW (GTK_WIDGET (XCFA_GET_OBJECT("scrolledwindow_wind_extract"))), Adj);
 			}
 		}
 	}
@@ -1525,6 +1661,11 @@ static gint cdaudioextract_timeout (gpointer data)
 		List = g_list_first (EnteteCD.GList_Audio_cd);
 		while (List) {
 			if ((Audio = (AUDIO *)List->data) != NULL) {
+					
+				if (Audio->EtatBoolWavpack == TRUE) {
+					// WinError_add_to_dsk_ (Audio->PathName_Dest_WavPack);
+				}
+
 				if (Audio->PathName_Dest_Flac) {
 					if (Audio->Bool_Delette_Flac) {
 						g_print ("infosong_delete_file (%s)\n", Audio->PathName_Dest_Flac);
@@ -1647,7 +1788,6 @@ static gint cdaudioextract_timeout (gpointer data)
 		if (conv.bool_set_log_wavpack == TRUE || conv.bool_set_log_wvunpack == TRUE) {
 			conv.bool_set_log_wvunpack = FALSE;
 			conv.bool_set_log_wavpack = FALSE;
-			logs_set_datas_system ();
 		}
 		conv_set_struct_not_used ();
 g_chdir (VarCdExtract.PtrDirActuel);
@@ -1661,6 +1801,11 @@ g_chdir (VarCdExtract.PtrDirActuel);
 		cdaudioextract_remove_list ();
 		
 		NotifySend_msg (_("XCFA: Extraction CD"), _("Ok"));
+
+		g_print("conv.total_convert    = %d\n", conv.total_convert);
+		g_print("conv.rip_completed    = %d\n", conv.rip_completed);
+		g_print("conv.encode_completed = %d\n", conv.encode_completed);
+		g_print("conv.total_rip        = %d\n", conv.total_rip);
 	}
 	return (TRUE);
 }
@@ -1678,7 +1823,7 @@ ETAT_CONV cdaudioextract_get_etat_sox (void)
 	Ptr = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_name_file_cue));
 	
 	if (cdaudio_get_bool_is_wav_extract_to_cue () == TRUE &&
-	    gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (lookup_widget (wind_main, "checkbutton_creation_fichier_unique_cue"))) == TRUE &&
+	    gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (XCFA_GET_OBJECT("checkbutton_creation_fichier_unique_cue"))) == TRUE &&
 	    *Ptr != '\0') {
 		return (WAITING);
 	}
@@ -1702,7 +1847,7 @@ void cdaudioextract_set_flags_before_extraction (void)
 
 	if (cdaudioextract_get_etat_sox () == WAITING) {
 		VarCdExtract.BoolFormatUnique = TRUE;
-		VarCdExtract.ChoiceFileCue = gtk_combo_box_get_active ( GTK_COMBO_BOX ( GTK_WIDGET (lookup_widget (wind_main, "combobox_choice_file_cue"))));
+		VarCdExtract.ChoiceFileCue = gtk_combo_box_get_active ( GTK_COMBO_BOX ( GTK_WIDGET (XCFA_GET_OBJECT("combobox_choice_file_cue"))));
 		/* Pour SOX */
 		/* conv.total_convert ++; */
 		/* Si conversion vers FLAC | OGG | MPC */
@@ -1718,6 +1863,9 @@ void cdaudioextract_set_flags_before_extraction (void)
 			cdcue_set_BoolExtract (IndexExtraction, FALSE);
 						
 			Audio->BoolM3uForWav = FALSE;
+			
+			// INIT ETAT
+			Audio->EtatBoolWavpack = FALSE;
 	
 			/* MAJ des flags
 			*/
@@ -1779,6 +1927,7 @@ void cdaudioextract_set_flags_before_extraction (void)
 			if (Audio->EtatSelection_Mpc     >= CD_ETAT_SELECT)	conv.total_convert ++;
 			if (Audio->EtatSelection_Ape     >= CD_ETAT_SELECT)	conv.total_convert ++;
 			if (Audio->EtatSelection_WavPack >= CD_ETAT_SELECT)	conv.total_convert ++;
+			if (Audio->EtatNormalise == TRUE) conv.total_convert += 2;
 			
 			/* init var to FALSE and NULL
 			*/
@@ -1903,6 +2052,11 @@ void cdaudioextract_set_flags_before_extraction (void)
 
 	g_free (PathDest);
 	PathDest = NULL;
+
+	g_print("conv.total_convert    = %d\n", conv.total_convert);
+	g_print("conv.rip_completed    = %d\n", conv.rip_completed);
+	g_print("conv.encode_completed = %d\n", conv.encode_completed);
+	g_print("conv.total_rip        = %d\n", conv.total_rip);
 }
 
 /*
@@ -1918,7 +2072,7 @@ void cdaudioextract_extraction_cd_to_file_action (void)
 	/* PRINT_FUNC_LF(); */
 
 	if (cdaudio_get_bool_is_wav_extract_to_cue () == TRUE &&
-	    gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (lookup_widget (wind_main, "checkbutton_creation_fichier_unique_cue"))) == TRUE) {
+	    gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (XCFA_GET_OBJECT("checkbutton_creation_fichier_unique_cue"))) == TRUE) {
 		
 		gchar *Ptr = NULL;
 		Ptr = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_name_file_cue));
@@ -1944,6 +2098,8 @@ void cdaudioextract_extraction_cd_to_file_action (void)
 	conv_reset_struct ();
 	conv_set_type_oper (_EXTRACT_);
  	VarCdExtract.BoolFormatUnique = FALSE;
+ 	if (VarCdExtract.NameFileFormatUnique != NULL)
+  		g_free (VarCdExtract.NameFileFormatUnique);
 	VarCdExtract.NameFileFormatUnique = NULL;
 	g_free (BaseIoctl.PathNameDestFileCue);
 	BaseIoctl.PathNameDestFileCue = NULL;
@@ -1967,7 +2123,7 @@ void cdaudioextract_extraction_cd_to_file_action (void)
 	cdaudioextract_create_list_is_Convert ();
 
 	VarCdExtract.PtrDirActuel = g_get_current_dir ();
-g_chdir (conv.TmpRep);
+	g_chdir (conv.TmpRep);
 
  	pthread_create (&nmr_tid, NULL ,(void *)cdaudioextract_thread_conversion_from_cd, (void *)NULL);
 	pthread_detach (nmr_tid);
