@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -41,8 +41,6 @@
 #include <pthread.h>
 #include <stdlib.h>
 
-#include "support.h"
-
 #include "global.h"
 #include "file.h"
 #include "options.h"
@@ -51,7 +49,6 @@
 #include "config_user.h"
 #include "scan_cd.h"
 #include "cdtoc.h"
-#include "logs.h"
 #include "secu.h"
 #include "info_song.h"
 #include "file.h"
@@ -59,7 +56,7 @@
 #include "popup.h"
 #include "cd_cue.h"
 #include "cd_audio.h"
-#include "player.h"
+#include "mplayer.h"
 #include "win_info.h"
 #include "win_play.h"
 
@@ -101,8 +98,8 @@ void *cdaudiotoc_thread_do_read_toc_cd (void *data)
 static gint cdaudiotoc_timeout_do_read_toc_cd (gpointer data)
 {
 	if (var_cd.bool_thread_read_toc_cd == FALSE) {
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_rafraichir_cd")), TRUE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "frame185")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_rafraichir_cd")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("frame185")), TRUE);
 		gtk_widget_set_sensitive (GTK_WIDGET (var_cd.Adr_Combo_Box), TRUE);
 		gtk_widget_set_sensitive (GTK_WIDGET (var_cd.Adr_Button_Destination), TRUE);
 
@@ -111,9 +108,9 @@ static gint cdaudiotoc_timeout_do_read_toc_cd (gpointer data)
 
 		gtk_widget_hide (GTK_WIDGET (var_cd.Adr_Progressbar));
 		gtk_widget_hide (GTK_WIDGET (var_cd.Adr_Button_Cancel_cddb));
-		gtk_widget_hide (GTK_WIDGET (lookup_widget (wind_main, "frame185")));
+		gtk_widget_hide (GTK_WIDGET (XCFA_GET_OBJECT("frame185")));
 		
-		gtk_widget_show (GTK_WIDGET (lookup_widget (wind_main, "hbox_cache_cd")));
+		gtk_widget_show (GTK_WIDGET (XCFA_GET_OBJECT("hbox_cache_cd")));
 
 		/* SI lecture OK, affichage du resultat */
 		cdaudio_put_label_status_bar_cd (_INFO_, _SHOW_, EnteteCD.Message);
@@ -172,6 +169,11 @@ static gint cdaudiotoc_timeout_do_read_toc_cd (gpointer data)
 		val = gtk_progress_get_value(GTK_PROGRESS(var_cd.Adr_Progressbar));
 		val = val >= 100.0 ? 0.0 : val;
 		gtk_progress_set_value(GTK_PROGRESS(var_cd.Adr_Progressbar), val + 0.01);
+		
+		if (cddb_get_bool_cancel_cddb () == TRUE) {
+			// PRINT("ARRET");
+			conv_stop_conversion ();
+		}
 	}
 	return (TRUE);
 }
@@ -191,7 +193,7 @@ void cdaudiotoc_button_eject_cd_clicked (void)
 	}	
 	cdaudio_clear_all_pixbuf_cd_play ();
 	cdaudio_affiche_all_pixbuf_cd_play ();
-	PlayerExec_user_to_quit ();
+	mplayer_fifo_quit ();
 	cdaudio_deallocate_glist_context ();
 	cdaudio_deallocate_glist_cd ();
 	cdcue_remove_base_ioctl ();
@@ -214,12 +216,12 @@ void cdaudiotoc_reffresh_list_cd (void)
 
 	if (var_cd.Adr_Combo_Box == NULL) return;
 	
-	if (utils_scan_by_which ("cddb-tool", NULL) == FALSE) {
+	if (utils_scan_by_which ("icedax", NULL) == FALSE) {
 		PRINT_FUNC_LF();
-		utils_puts_statusbar_global (_("cddb-tool NOT FOUND: Please, install package [ abcde ]"));
+		utils_puts_statusbar_global (_("icedax NOT FOUND: Please, install package [ icedax ]"));
 		wininfo_create (
-			_("cddb-tool NOT FOUND !"),
-			_("    Please, install package [ abcde ]  "),
+			_("icedax NOT FOUND !"),
+			_("    Please, install package [ icedax ]  "),
 	 	  	"     \n\n",
 		  	"");
 		return;
@@ -229,7 +231,7 @@ void cdaudiotoc_reffresh_list_cd (void)
 	
 	cdaudio_clear_all_pixbuf_cd_play ();
 	cdaudio_affiche_all_pixbuf_cd_play ();
-	PlayerExec_user_to_quit ();
+	mplayer_fifo_quit ();
 
 	EnteteCD.NameCD_Device = scancd_get_text_combo_cd (_CD_);
 
@@ -245,20 +247,20 @@ void cdaudiotoc_reffresh_list_cd (void)
 	/* recherche CDDB is TRUE */
 	cddb_set_bool_cancel_cddb (FALSE);
 
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_rafraichir_cd")), FALSE);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_rafraichir_cd")), FALSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (var_cd.Adr_Combo_Box), FALSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (var_cd.Adr_Button_Destination), FALSE);
 	
 	cdaudio_put_label_status_bar_cd (_DUREE_, _HIDE_, "");
 	cdaudio_put_label_status_bar_cd (_TITRE_, _HIDE_, "");
 
-	gtk_widget_hide (GTK_WIDGET (lookup_widget (wind_main, "hbox_cache_cd")));
+	gtk_widget_hide (GTK_WIDGET (XCFA_GET_OBJECT("hbox_cache_cd")));
 
 	/* Montre button: CANCEL_CDDB */
 	gtk_widget_show (var_cd.Adr_Progressbar);
 	gtk_widget_show (GTK_WIDGET (var_cd.Adr_Button_Cancel_cddb));
-	gtk_widget_set_sensitive (lookup_widget (wind_main, "frame185"), TRUE);
-	gtk_widget_show (GTK_WIDGET (lookup_widget (wind_main, "frame185")));
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("frame185")), TRUE);
+	gtk_widget_show (GTK_WIDGET (XCFA_GET_OBJECT("frame185")));
 	gtk_widget_set_sensitive (var_cd.Adr_Button_Cancel_cddb, TRUE);
 	
 	gtk_progress_bar_pulse (GTK_PROGRESS_BAR (var_cd.Adr_Progressbar));
