@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -35,8 +35,6 @@
 #  include <config.h>
 #endif
 
-#include "support.h"
-
 #include <gtk/gtk.h>
 #include <glib/gprintf.h>
 
@@ -577,7 +575,7 @@ void cdcue_write_cue_ok_partiel (void)
 	fprintf (fp,   "TITLE \"%s\"\n", BaseIoctl.Title);
 
 
-	switch (gtk_combo_box_get_active ( GTK_COMBO_BOX ( GTK_WIDGET (lookup_widget (wind_main, "combobox_choice_file_cue"))))) {
+	switch (gtk_combo_box_get_active ( GTK_COMBO_BOX ( GTK_WIDGET (XCFA_GET_OBJECT("combobox_choice_file_cue"))))) {
 	case 0 : fprintf (fp,   "FILE \"%s.wav\" WAVE\n", Ptr);	break;
 	case 1 : fprintf (fp,   "FILE \"%s.flac\" WAVE\n", Ptr);	break;
 	case 2 : fprintf (fp,   "FILE \"%s.ogg\" WAVE\n", Ptr);	break;
@@ -648,7 +646,7 @@ void cdcue_write_cue (void)
 		Ptr = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_name_file_cue));
 		PathName = g_strdup_printf ("%s/%s.cue", (gchar *)Config_User.Path_Destination_CD, Ptr);
 		*/
-		if (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (lookup_widget (wind_main, "checkbutton_creation_fichier_cue"))) == TRUE) {
+		if (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (XCFA_GET_OBJECT("checkbutton_creation_fichier_cue"))) == TRUE) {
 			
 			/*if (infosong_file_is_reg (PathName) == TRUE) {*/
 			if (infosong_file_is_reg (BaseIoctl.PathNameDestFileCue) == TRUE) {
@@ -722,10 +720,6 @@ void cdcue_button_cue_creation_from_cd_clicked (void)
 		/* DEBUT de creation de fichier CUE */
 		var_cd.TypeCreateCue = TYPE_CUE_CD;
 		
-		/*
-		cdcue_make_cue ();
-		cdcue_make_cue_with_cdtoc (CdToc);
-		*/
 		cdcue_write_cue ();
 	}
 	else {
