@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -38,8 +38,6 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#include "support.h"
-
 #include <string.h>
 #include <stdlib.h>
 
@@ -48,6 +46,7 @@
 #include "file.h"
 #include "cd_audio.h"
 #include "config_user.h"
+#include "parse.h"
 
 
 /*
@@ -74,8 +73,8 @@ void cdexpander_set_sensitive_notebook (void)
 	
 	if (!var_cd.Adr_notebook) return;
 	Audio = cdaudio_get_line_selected ();
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "table_tags_expanderCD")), Audio ? TRUE : FALSE);
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "vbox_titres_expanderCD")), Audio ? TRUE : FALSE);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("table_tags_expanderCD")), Audio ? TRUE : FALSE);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("vbox_titres_expanderCD")), Audio ? TRUE : FALSE);
 	
 	/*
 	if (!Audio) return;
@@ -480,10 +479,35 @@ void cdexpander_combobox_tag_genre_cd_changed (void)
 	}
 	cdaudio_set_titre_chanson ();
 }
+
+gboolean cdexpander_bool_entree_cd_verif_car = TRUE;
 void cdexpander_entry_new_titre_cdaudio_changed (void)
 {
-	if (var_cd.Adr_entry_new_titre_cdaudio)
+	if (cdexpander_bool_entree_cd_verif_car == FALSE) return;
+	
+	if (var_cd.Adr_entry_new_titre_cdaudio != NULL) {
+		gchar	*StrVerif = NULL;
+		gchar	*ptr = NULL;
+		
+		// PRINT_FUNC_LF();
+		
+		// LA CARACTERE / EST INTERDIT
+		StrVerif = g_strdup ((gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_new_titre_cdaudio)));
+		if (strchr (StrVerif, '/')) {
+			cdexpander_bool_entree_cd_verif_car = FALSE;
+			while ((ptr = strchr (StrVerif, '/'))) {
+				strcpy (ptr, ptr+1);
+			}
+			gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_new_titre_cdaudio), StrVerif);
+			cdexpander_bool_entree_cd_verif_car = TRUE;
+		}
+		g_free (StrVerif);
+		StrVerif = NULL;
+		
+		Parse_entry (PARSE_TYPE_TITLE_CD);
+
 		cdaudio_set_titre_chanson ();
+	}
 }
 
 /* FROM CALLBACKS.C REALIZE
@@ -527,7 +551,9 @@ void cdexpander_entry_tag_titre_fichier_m3u_realize (GtkWidget *widget)
 }
 void cdexpander_combobox_tag_genre_cd_realize (GtkWidget *widget)
 {
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	infosong_set_elements_combobox (widget);
 	gtk_combo_box_set_wrap_width (GTK_COMBO_BOX (widget), 4);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
