@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -53,6 +53,7 @@
 #include "showhide_treeview.h"
 #include "config_user.h"
 #include "prg_audio.h"
+#include "cdtoc.h"
 
 
 
@@ -118,7 +119,10 @@ CONFIG_USER Config_User = {
 	NULL,     /* Path Dest File PostScript						*/
 	NULL,     /* Path Load File DVD							*/
 	NULL,     /* Path d'extractions / conversions					*/
-
+	
+	NULL,    /* Path_Dest_Journal							*/
+	FALSE,   /* Bool_Activate_Journal						*/
+	
 	NULL,    /* Nom du fichier m3u							*/
 	
 	TRUE,    /* TRUE if set tag artist						*/
@@ -131,7 +135,7 @@ CONFIG_USER Config_User = {
 
 	0,        /* auto, at, ca, de, fi, fr, no, uk, us				*/
 	TRUE,     /* TRUE = ioctl, FALSE = cdparanoia					*/
-	0,        /* Extract_cd_with: cdparanoia=0, icedax=1, CdparanoiaExpert=2	*/
+	0,        /* Extract_cd_with: cdparanoia OR icedax OR CdparanoiaExpert		*/
 	5,        /* compression_level_flac in 0 .. 12					*/
 	1,        /* compression_level_ape in 0 .. 4 					*/
 
@@ -152,10 +156,6 @@ CONFIG_USER Config_User = {
 	7,        /* aacplusenc_choice_mono						*/
 	4,        /* aacplusenc_choice_stereo						*/
 
-	TRUE,     /* GoTo tongle							*/
-
-	FALSE,     /* TRUE = Load images ELSE FALSE = none				*/
-
 	50,       /* Valeur de FIX onglet dvd-audio					*/
 	50,       /* Valeur de FIX onglet cd-audio					*/
 	50,       /* Valeur de FIX onglet fichiers					*/
@@ -178,13 +178,11 @@ CONFIG_USER Config_User = {
 
 	0,        /* Gestionnaire de paquets: 0 = apt-get, 1 = aptitude			*/
 
-	TRUE,     /* Bool_save_pos_notebook						*/
 	0,        /* notebook_general							*/
 	0,        /* notebook_expander_cd						*/
 	0,        /* notebook_file							*/
 	0,        /* notebook_options							*/
 	0,        /* notebook_pochette							*/
-	0,        /* notebook_logs							*/
 	0 ,       /* notebook_app							*/
 
 	NULL,     /* *StringBoolFieldsIsVisible						*/
@@ -244,6 +242,10 @@ PATH_STOCKE_POCHE_IMAGES,
 PATH_DEST_FILE_POSTSCRIPT,
 PATH_LOAD_FILE_DVD,
 PATH_TMP,
+
+PATH_DEST_JOURNAL,
+BOOL_ACTIVATE_JOURNAL,
+
 NAME_FILE_M3U,
 IS_TAG_ARTIST,
 IS_TAG_TITLE,
@@ -276,9 +278,7 @@ FAAC_SET_CHOICE_VBR,
 FAAC_SET_CHOICE_ABR,
 AACPLUSENC_CHOICE_MONO,
 AACPLUSENC_CHOICE_STEREO,
-GOTO_TONGLE_FILE_IMPORT,
 SERVER_FREECDDB,
-INIT_LOAD_IMG_XCFA,
 VALUE_FIX_DVDAUDIO,
 VALUE_FIX_CDAUDIO,
 VALUE_FIX_FICHIERS,
@@ -296,13 +296,11 @@ String_expander_Mppenc,
 String_expander_Mac,
 String_expander_Wavpack,
 ADMINISTRATOR_OF_PACKETS,
-BOOL_SAVE_POS_NOTEBOOK,
 POS_NOTEBOOK_GENERAL,
 POS_NOTEBOOK_EXPANDER_CD,
 POS_NOTEBOOK_FILE,
 POS_NOTEBOOK_OPTIONS,
 POS_NOTEBOOK_POCHETTE,
-POS_NOTEBOOK_LOGS,
 POS_NOTEBOOK_APP,
 STRING_BOOL_FIELD_IS_VISIBLE,
 STRING_POS_FIELDS_NAME,
@@ -373,6 +371,10 @@ MOTS_CLEFS mots_clefs[] = {
 {"PATH_DEST_FILE_POSTSCRIPT",		PATH_DEST_FILE_POSTSCRIPT,	FALSE },
 {"PATH_LOAD_FILE_DVD",			PATH_LOAD_FILE_DVD,		FALSE },
 {"PATH_TMP",				PATH_TMP,			FALSE },
+
+{"PATH_DEST_JOURNAL",			PATH_DEST_JOURNAL,		FALSE },
+{"BOOL_ACTIVATE_JOURNAL",		BOOL_ACTIVATE_JOURNAL,		FALSE },
+
 {"NAME_FILE_M3U",			NAME_FILE_M3U,			FALSE },
 {"IS_TAG_ARTIST",			IS_TAG_ARTIST,			FALSE },
 {"IS_TAG_TITLE",			IS_TAG_TITLE,			FALSE },
@@ -408,9 +410,7 @@ MOTS_CLEFS mots_clefs[] = {
 {"AACPLUSENC_CHOICE_MONO",		AACPLUSENC_CHOICE_MONO,		FALSE },
 {"AACPLUSENC_CHOICE_STEREO",		AACPLUSENC_CHOICE_STEREO,	FALSE },
 
-{"GOTO_TONGLE_FILE_IMPORT",		GOTO_TONGLE_FILE_IMPORT,	FALSE },
 {"SERVER_FREECDDB",			SERVER_FREECDDB,		FALSE },
-{"INIT_LOAD_IMG_XCFA",			INIT_LOAD_IMG_XCFA,		FALSE },
 {"VALUE_FIX_DVDAUDIO",			VALUE_FIX_DVDAUDIO,		FALSE },
 {"VALUE_FIX_CDAUDIO",			VALUE_FIX_CDAUDIO,		FALSE },
 {"VALUE_FIX_FICHIERS",			VALUE_FIX_FICHIERS,		FALSE },
@@ -428,13 +428,11 @@ MOTS_CLEFS mots_clefs[] = {
 {"String_expander_Mac",			String_expander_Mac,		FALSE },
 {"String_expander_Wavpack",		String_expander_Wavpack,	FALSE },
 {"ADMINISTRATOR_OF_PACKETS",		ADMINISTRATOR_OF_PACKETS,	FALSE },
-{"BOOL_SAVE_POS_NOTEBOOK",		BOOL_SAVE_POS_NOTEBOOK,		FALSE },
 {"POS_NOTEBOOK_GENERAL",		POS_NOTEBOOK_GENERAL,		FALSE },
 {"POS_NOTEBOOK_EXPANDER_CD",		POS_NOTEBOOK_EXPANDER_CD,	FALSE },
 {"POS_NOTEBOOK_FILE",			POS_NOTEBOOK_FILE,		FALSE },
 {"POS_NOTEBOOK_OPTIONS",		POS_NOTEBOOK_OPTIONS,		FALSE },
 {"POS_NOTEBOOK_POCHETTE",		POS_NOTEBOOK_POCHETTE,		FALSE },
-{"POS_NOTEBOOK_LOGS",			POS_NOTEBOOK_LOGS,		FALSE },
 {"POS_NOTEBOOK_APP",			POS_NOTEBOOK_APP,		FALSE },
 {"STRING_BOOL_FIELD_IS_VISIBLE",	STRING_BOOL_FIELD_IS_VISIBLE,	FALSE },
 {"STRING_POS_FIELDS_NAME",		STRING_POS_FIELDS_NAME,		FALSE },
@@ -867,7 +865,20 @@ void configuser_change_parameters (DEFS_MOTS def_mot, gchar *value)
 		}
 		Config_User.Path_TMP = g_strdup (value);
 		break;
+	
+	case PATH_DEST_JOURNAL :
+		if (!infosong_file_is_dir (value)) g_sprintf (value, "%s", getenv ("HOME"));
+		if (Config_User.Path_Dest_Journal) {
+			g_free (Config_User.Path_Dest_Journal);
+			Config_User.Path_Dest_Journal = NULL;
+		}
+		Config_User.Path_Dest_Journal = g_strdup (value);
+		break;
+	case BOOL_ACTIVATE_JOURNAL :
+		Config_User.Bool_Activate_Journal = configuser_get_bool (value);
+		break;
 		
+
 	case NAME_FILE_M3U :
 		if (Config_User.Name_file_m3u == NULL) {
 			Config_User.Name_file_m3u = g_strdup (value);
@@ -986,15 +997,9 @@ void configuser_change_parameters (DEFS_MOTS def_mot, gchar *value)
 		Config_User.aacplusenc_choice_stereo = atoi (value);
 		break;
 
-	case GOTO_TONGLE_FILE_IMPORT :
-		Config_User.Bool_GoTo_Togle_Import_File = configuser_get_bool (value);
-		break;
 	case SERVER_FREECDDB :
 		Config_User.serveur_cddb = atoi (value);
 		break;
-	case INIT_LOAD_IMG_XCFA :
-		Config_User.Bool_init_img_xcfa = configuser_get_bool (value);
-		break;
 	case VALUE_FIX_DVDAUDIO :
 		Config_User.Value_fix_dvdaudio = atoi (value);
 		if (Config_User.Value_fix_dvdaudio < 1 || Config_User.Value_fix_dvdaudio > 99) Config_User.Value_fix_dvdaudio = 50;
@@ -1064,9 +1069,6 @@ void configuser_change_parameters (DEFS_MOTS def_mot, gchar *value)
 	case ADMINISTRATOR_OF_PACKETS :
 		Config_User.AdministratorOfPackets = atoi (value);
 		break;
-	case BOOL_SAVE_POS_NOTEBOOK :
-		Config_User.Bool_save_pos_notebook = configuser_get_bool (value);
-		break;
 	case POS_NOTEBOOK_GENERAL :
 		Config_User.notebook_general = atoi (value);
 		break;
@@ -1082,9 +1084,6 @@ void configuser_change_parameters (DEFS_MOTS def_mot, gchar *value)
 	case POS_NOTEBOOK_POCHETTE :
 		Config_User.notebook_pochette = atoi (value);
 		break;
-	case POS_NOTEBOOK_LOGS :
-		Config_User.notebook_logs = atoi (value);
-		break;
 	case POS_NOTEBOOK_APP :
 		Config_User.notebook_app = atoi (value);
 		break;
@@ -1334,6 +1333,15 @@ void configuser_verify_parameters (void)
 				Config_User.Path_TMP = g_strdup ("/tmp");
 			}
 			break;
+
+		case PATH_DEST_JOURNAL :
+			if (!Config_User.Path_Dest_Journal) {
+				Config_User.Path_Dest_Journal = g_strdup_printf ("%s", getenv ("HOME"));
+			}
+			break;
+		case BOOL_ACTIVATE_JOURNAL :
+			break;
+
 		
 		case NAME_FILE_M3U :
 		break;
@@ -1424,16 +1432,10 @@ void configuser_verify_parameters (void)
 			Config_User.aacplusenc_choice_stereo = 0;
 		break;
 
-
-		case GOTO_TONGLE_FILE_IMPORT :
-		break;
-		
 		case SERVER_FREECDDB :
-			if (Config_User.serveur_cddb < 0 || Config_User.serveur_cddb > 9)
-				Config_User.serveur_cddb = 0;
+			if (Config_User.serveur_cddb < SERVER_CDDB_LOCAL || Config_User.serveur_cddb > SERVER_CDDB_NONE)
+				Config_User.serveur_cddb = SERVER_CDDB_LOCAL;
 			break;
-		case INIT_LOAD_IMG_XCFA :
-		break;
 		case VALUE_FIX_DVDAUDIO :
 			if (Config_User.Value_fix_dvdaudio < 1 || Config_User.Value_fix_dvdaudio > 99) Config_User.Value_fix_dvdaudio = 50;
 			break;
@@ -1511,8 +1513,6 @@ void configuser_verify_parameters (void)
 		
 		case ADMINISTRATOR_OF_PACKETS :
 		break;
-		case BOOL_SAVE_POS_NOTEBOOK :
-		break;
 		case POS_NOTEBOOK_GENERAL :
 		break;
 		case POS_NOTEBOOK_EXPANDER_CD :
@@ -1523,8 +1523,6 @@ void configuser_verify_parameters (void)
 		break;
 		case POS_NOTEBOOK_POCHETTE :
 		break;
-		case POS_NOTEBOOK_LOGS :
-		break;
 		case POS_NOTEBOOK_APP :
 		break;
 		
@@ -1604,11 +1602,6 @@ void configuser_read_file_config (void)
 	NameFile = NULL;
 
 	configuser_verify_parameters ();
-
-	if (mots_clefs[ BOOL_SAVE_POS_NOTEBOOK ].BoolPass == FALSE) {
-		mots_clefs[ BOOL_SAVE_POS_NOTEBOOK ].BoolPass = TRUE;
-		Config_User.Bool_save_pos_notebook = TRUE;
-	}
 }
 
 /* Cette fonction effectue une sauvegarde les principaux parametres qui
@@ -1704,6 +1697,9 @@ void configuser_save_file_config (void)
 	fprintf (fp,   "PATH_LOAD_FILE_DVD            =%s\n", Config_User.Path_Load_File_DVD);
 	fprintf (fp,   "PATH_TMP                      =%s\n", Config_User.Path_TMP);
 
+	fprintf (fp,   "PATH_DEST_JOURNAL             =%s\n", Config_User.Path_Dest_Journal);
+	fprintf (fp,   "BOOL_ACTIVATE_JOURNAL         =%s\n", Config_User.Bool_Activate_Journal ? "TRUE" : "FALSE");
+
 	fprintf (fp,   "\n");
 	fprintf (fp,   "# M3U file\n");
 	fprintf (fp,   "#\n");
@@ -1822,7 +1818,6 @@ void configuser_save_file_config (void)
 	/* wavpack_extra_encoding */
 	fprintf (fp,   "WAVPACK_EXTRA_ENCODING      =%d\n", Config_User.wavpack_extra_encoding);
 
-	
 	/* FAAC OPTIONS */
 	fprintf (fp,   "\n");
 	fprintf (fp,   "# faac options\n");
@@ -1832,7 +1827,6 @@ void configuser_save_file_config (void)
 	fprintf (fp,   "FAAC_SET_CHOICE_VBR         =%d\n", Config_User.faac_set_choice_vbr);
 	fprintf (fp,   "FAAC_SET_CHOICE_ABR         =%d\n", Config_User.faac_set_choice_abr);
 
-
 	/* AACPLUSENC OPTIONS */
 	fprintf (fp,   "\n");
 	fprintf (fp,   "# aacplusenc options\n");
@@ -1840,22 +1834,11 @@ void configuser_save_file_config (void)
 	fprintf (fp,   "AACPLUSENC_CHOICE_MONO     =%d\n", Config_User.aacplusenc_choice_mono);
 	fprintf (fp,   "AACPLUSENC_CHOICE_STEREO   =%d\n", Config_User.aacplusenc_choice_stereo);
 	
-
-	fprintf (fp,   "\n");
-	fprintf (fp,   "# Rapport bad file import\n");
-	fprintf (fp,   "#\n");
-	fprintf (fp,   "GOTO_TONGLE_FILE_IMPORT =%s\n", Config_User.Bool_GoTo_Togle_Import_File ? "TRUE" : "FALSE");
-
 	fprintf (fp,   "\n");
 	fprintf (fp,   "# Value server freecddb\n");
 	fprintf (fp,   "#\n");
 	fprintf (fp,   "SERVER_FREECDDB =%d\n", Config_User.serveur_cddb);
 
-	fprintf (fp,   "\n");
-	fprintf (fp,   "# Init load images xcfa\n");
-	fprintf (fp,   "#\n");
-	fprintf (fp,   "INIT_LOAD_IMG_XCFA =%s\n", Config_User.Bool_init_img_xcfa ? "TRUE" : "FALSE");
-
 	fprintf (fp,   "\n");
 	fprintf (fp,   "# FIX val for dvd-audio & cd-audio & fichiers\n");
 	fprintf (fp,   "#\n");
@@ -1917,15 +1900,13 @@ void configuser_save_file_config (void)
 	fprintf (fp,   "ADMINISTRATOR_OF_PACKETS =%d\n", Config_User.AdministratorOfPackets);
 
 	fprintf (fp,   "\n");
-	fprintf (fp,   "# Pos of Notebooks\n");
+	fprintf (fp,   "# Pos of Notebooks : Context restitution\n");
 	fprintf (fp,   "#\n");
-	fprintf (fp,   "BOOL_SAVE_POS_NOTEBOOK   =%s\n", Config_User.Bool_save_pos_notebook ? "TRUE" : "FALSE");
 	fprintf (fp,   "POS_NOTEBOOK_GENERAL     =%d\n", Config_User.notebook_general);
 	fprintf (fp,   "POS_NOTEBOOK_EXPANDER_CD =%d\n", Config_User.notebook_expander_cd);
 	fprintf (fp,   "POS_NOTEBOOK_FILE        =%d\n", Config_User.notebook_file);
 	fprintf (fp,   "POS_NOTEBOOK_OPTIONS     =%d\n", Config_User.notebook_options);
 	fprintf (fp,   "POS_NOTEBOOK_POCHETTE    =%d\n", Config_User.notebook_pochette);
-	fprintf (fp,   "POS_NOTEBOOK_LOGS        =%d\n", Config_User.notebook_logs);
 	fprintf (fp,   "POS_NOTEBOOK_APP         =%d\n", Config_User.notebook_app);
 
 	fprintf (fp,   "\n");
