@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -34,8 +34,6 @@
 
 #include <gtk/gtk.h>
 #include "callbacks.h"
-#include "interface.h"
-#include "support.h"
 
 #include <pthread.h>
 #include <sys/types.h>
@@ -53,8 +51,8 @@
 #include "info_song.h"
 #include "conv.h"
 #include "win_control.h"
-#include "prg_init.h"
 #include "logs.h"
+#include "prg_init.h"
 #include "config_user.h"
 
 
@@ -87,11 +85,26 @@ CONV conv = { FALSE }; /* conv.BoolUsed = FALSE */
 
 void conv_inc_rip_completed (void)
 {
-	if (conv.rip_completed < conv.total_rip) conv.rip_completed ++;
+	if (conv.rip_completed < conv.total_rip) {
+		conv.rip_completed ++;
+		conv.total_percent = (conv.rip_completed +
+					conv.encode_completed +
+					conv.extract_percent +
+					conv.conversion_percent) /
+					(conv.total_rip + conv.total_convert);
+	}
 }
 void conv_inc_encode_completed (void)
 {
-	if (conv.encode_completed < conv.total_convert) conv.encode_completed ++;
+	if (conv.encode_completed < conv.total_convert) {
+		conv.encode_completed ++;
+		// conv.total_percent = conv.encode_completed / conv.total_convert;
+		conv.total_percent = (conv.rip_completed +
+					conv.encode_completed +
+					conv.extract_percent +
+					conv.conversion_percent) /
+					(conv.total_rip + conv.total_convert);
+	}
 }
 
 void conv_stop_conversion (void)
@@ -206,34 +219,27 @@ void on_button_stop_wind_extract_clicked (GtkButton *button, gpointer user_data)
 
 void conv_close_window (void)
 {
-	gtk_widget_destroy(conv.Adr_wind);
-	conv.Adr_wind = NULL;
-wincontrol_remove_last ();
+	NEW_wincontrol_realize_window (&conv.Adr_wind, "wind_extract", &conv.Bool, WIND_IS_SHOW, WIND_USE_STRUCT, WIND_IS_MODAL, WIND_IS_TRANSIENT);
 }
 
 void conv_create_window_extract (gchar *title_wind, gboolean BoolModeExpert)
 {
 	gchar	*Str = NULL;
 	
-	conv.Adr_wind = create_wind_extract ();
-	/*
-	gtk_window_set_modal (GTK_WINDOW (conv.Adr_wind), TRUE);
-	gtk_window_set_transient_for (GTK_WINDOW(conv.Adr_wind), GTK_WINDOW(wind_main));
-	*/
-	wincontrol_set_adr (conv.Adr_wind, "conv.Adr_wind", TRUE, TRUE);
-	utils_set_default_icone_xcfa (conv.Adr_wind);
-	gtk_widget_show (conv.Adr_wind);
+	NEW_wincontrol_realize_window (&conv.Adr_wind, "wind_extract", &conv.Bool, WIND_IS_SHOW, WIND_USE_STRUCT, WIND_IS_MODAL, WIND_IS_TRANSIENT);
+	
 	Str = g_strdup_printf ("<span font_desc=\"sans 15\"><span color=\"black\"><b>%s</b></span></span>", title_wind);
 	gtk_label_set_label (GTK_LABEL (conv.Adr_label_info_wind), Str);
 	g_free (Str);
 	Str = NULL;
-	gtk_widget_show (GTK_WIDGET (lookup_widget (conv.Adr_wind, "hbox_extraction_wind_extract")));
+	
+	gtk_widget_show (GTK_WIDGET (XCFA_GET_OBJECT("hbox_extraction_wind_extract")));
 	if (BoolModeExpert == TRUE)
-		gtk_widget_show (GTK_WIDGET (lookup_widget (conv.Adr_wind, "hbox_expander_extraction_wind_extract")));
-	else	gtk_widget_hide (GTK_WIDGET (lookup_widget (conv.Adr_wind, "hbox_expander_extraction_wind_extract")));
-	gtk_widget_show (GTK_WIDGET (lookup_widget (conv.Adr_wind, "hbox_conversion_wind_extract")));
+		gtk_widget_show (GTK_WIDGET (XCFA_GET_OBJECT("hbox_expander_extraction_wind_extract")));
+	else	gtk_widget_hide (GTK_WIDGET (XCFA_GET_OBJECT("hbox_expander_extraction_wind_extract")));
+	gtk_widget_show (GTK_WIDGET (XCFA_GET_OBJECT("hbox_conversion_wind_extract")));
 	gtk_window_set_title (GTK_WINDOW (conv.Adr_wind), title_wind);
-	gtk_expander_set_expanded (GTK_EXPANDER (GTK_WIDGET (lookup_widget (conv.Adr_wind, "expander_wind_extract"))), BoolModeExpert);
+	gtk_expander_set_expanded (GTK_EXPANDER (GTK_WIDGET (XCFA_GET_OBJECT("expander_wind_extract"))), BoolModeExpert);
 }
 
 /*
@@ -246,21 +252,15 @@ void conv_create_window (gchar *title_wind)
 {
 	gchar	*Str = NULL;
 	
-	conv.Adr_wind = create_wind_extract ();
-	/*
-	gtk_window_set_modal (GTK_WINDOW (conv.Adr_wind), TRUE);
-	gtk_window_set_transient_for (GTK_WINDOW(conv.Adr_wind), GTK_WINDOW(wind_main));
-	*/
-	wincontrol_set_adr (conv.Adr_wind, "conv.Adr_wind", TRUE, TRUE);
-	utils_set_default_icone_xcfa (conv.Adr_wind);
-	gtk_widget_show (conv.Adr_wind);
+	NEW_wincontrol_realize_window (&conv.Adr_wind, "wind_extract", &conv.Bool, WIND_IS_SHOW, WIND_USE_STRUCT, WIND_IS_MODAL, WIND_IS_TRANSIENT);
+	
 	Str = g_strdup_printf ("<span font_desc=\"sans 14\"><span color=\"black\"><b>%s</b></span></span>", title_wind);
 	gtk_label_set_label (GTK_LABEL (conv.Adr_label_info_wind), Str);
 	g_free (Str);
 	Str = NULL;
-	gtk_widget_hide (GTK_WIDGET (lookup_widget (conv.Adr_wind, "hbox_extraction_wind_extract")));
-	gtk_widget_hide (GTK_WIDGET (lookup_widget (conv.Adr_wind, "hbox_expander_extraction_wind_extract")));
-	gtk_widget_show (GTK_WIDGET (lookup_widget (conv.Adr_wind, "hbox_conversion_wind_extract")));
+	gtk_widget_hide (GTK_WIDGET (XCFA_GET_OBJECT("hbox_extraction_wind_extract")));
+	gtk_widget_hide (GTK_WIDGET (XCFA_GET_OBJECT("hbox_expander_extraction_wind_extract")));
+	gtk_widget_show (GTK_WIDGET (XCFA_GET_OBJECT("hbox_conversion_wind_extract")));
 	gtk_window_set_title (GTK_WINDOW (conv.Adr_wind), title_wind);
 }
 
@@ -320,11 +320,19 @@ void conv_set_data_progressBar (GtkWidget *Adr_Progressbar, double Etat)
 		case FAAC_WAV_TO_M4A         : Total = g_strdup_printf ("faac : wav -> m4a : %d%%", (int)(Etat*100)); break;
 		case MPLAYER_WAV_TO_WAV      : Total = g_strdup_printf ("mplayer : wav -> wav : %d%%", (int)(Etat*100)); break;
 		case MPLAYER_WMA_TO_WAV      : Total = g_strdup_printf ("mplayer : wma -> wav : %d%%", (int)(Etat*100)); break;
+		case MPLAYER_RM_TO_WAV       : Total = g_strdup_printf ("mplayer : rm -> wav : %d%%", (int)(Etat*100)); break;
+		case MPLAYER_DTS_TO_WAV      : Total = g_strdup_printf ("mplayer : dts -> wav : %d%%", (int)(Etat*100)); break;
+		case MPLAYER_AIFF_TO_WAV     : Total = g_strdup_printf ("mplayer : aif -> wav : %d%%", (int)(Etat*100)); break;
 		case COPY_FILE               : Total = g_strdup_printf ("Copy : %d%%", (int)(Etat*100)); break;
 		case NORMALISE_CALCUL        : Total = g_strdup_printf ("Normalise : Calcul niveau : %d%%", (int)(Etat*100)); break;
 		case NORMALISE_APPLIQUE      : Total = g_strdup_printf ("Normalise : Applique niveau : %d%%", (int)(Etat*100)); break;
-		case MPPDEC_MPC_TO_WAV       : Total = g_strdup_printf ("mppdec : mpc -> wav : %d%%", (int)(Etat*100)); break;
-		case MPPENC_WAV_TO_MPC       : Total = g_strdup_printf ("mppenc : wav -> mpc : %d%%", (int)(Etat*100)); break;
+		
+		// case MPPDEC_MPC_TO_WAV       : Total = g_strdup_printf ("mppdec : mpc -> wav : %d%%", (int)(Etat*100)); break;
+		case MPPDEC_MPC_TO_WAV       : Total = g_strdup_printf ("%s : mpc -> wav : %d%%", prginit_get_name (NMR_musepack_tools_mppdec), (int)(Etat*100)); break;
+		
+		// case MPPENC_WAV_TO_MPC       : Total = g_strdup_printf ("mppenc : wav -> mpc : %d%%", (int)(Etat*100)); break;
+		case MPPENC_WAV_TO_MPC       : Total = g_strdup_printf ("%s : wav -> mpc : %d%%", prginit_get_name (NMR_musepack_tools_mppenc), (int)(Etat*100)); break;
+		
 		case MAC_APE_TO_WAV          : Total = g_strdup_printf ("mac : ape -> wav : %d%%", (int)(Etat*100)); break;
 		case MAC_WAV_TO_APE          : Total = g_strdup_printf ("mac : wav -> ape : %d%%", (int)(Etat*100)); break;
 		case WAVPACK_WAV_TO_WAVPACK  : Total = g_strdup_printf ("wavpack : wav -> wavpack : %d%%", (int)(Etat*100)); break;
@@ -342,7 +350,8 @@ void conv_set_data_progressBar (GtkWidget *Adr_Progressbar, double Etat)
 		case NORMALISE_EXEC          : 
 		case NORMALISE_GET_LEVEL     : 
 		case SPLIT                   : 
-		case CDDB_TOOL               : break;
+		case CDDB_TOOL               :
+		case ICEDAX		     : break;
 		case AACPLUSENC_WAV_TO_AAC   : Total = g_strdup_printf ("aacplusenc : wav -> aac : %d%%", (int)(Etat*100)); break;
 		}
 	}
@@ -404,6 +413,9 @@ void conv_set_label_conversion (void)
 	case FAAD_M4A_TO_WAV         :
 	case FAAC_WAV_TO_M4A         :
 	case MPLAYER_WMA_TO_WAV      :
+	case MPLAYER_RM_TO_WAV       :
+	case MPLAYER_DTS_TO_WAV      :
+	case MPLAYER_AIFF_TO_WAV     :
 	case MPLAYER_WAV_TO_WAV      :
 	case COPY_FILE               :
 	case NORMALISE_CALCUL        :
@@ -438,7 +450,8 @@ void conv_set_label_conversion (void)
 	case NORMALISE_EXEC          :  
 	case NORMALISE_GET_LEVEL     :  
 	case SPLIT                   :  
-	case CDDB_TOOL               :  break;
+	case CDDB_TOOL               :
+	case ICEDAX                  :  break;
 	}
 
 	gtk_label_set_label (GTK_LABEL (conv.Adr_label_conversion), Str_Label);
@@ -572,6 +585,7 @@ int conv_extract_call_exec (ARGS_TO_EXEC *args, pid_t *p, gint p_output)
 
 gboolean conv_copy_src_to_dest (gchar *filesrc, gchar *filedest)
 {
+#define SIZE_COPY  4096
 	FILE     *fpsrc = NULL;
 	FILE     *fpdest = NULL;
 	gint      nmr_fpsrc;
@@ -579,8 +593,8 @@ gboolean conv_copy_src_to_dest (gchar *filesrc, gchar *filedest)
 	gulong    cpt = 0;
 	gulong    blk;
 	size_t    size;
-	gint      modulo;
-	gchar     buffer [ 2048 ];
+	// gint      modulo;
+	gchar     buffer [ (SIZE_COPY + 256) ];
 	
 	if (infosong_file_is_reg (filesrc) == FALSE) {
 		PRINT_FUNC_LF();
@@ -591,7 +605,7 @@ gboolean conv_copy_src_to_dest (gchar *filesrc, gchar *filedest)
 	
 	g_print ("conv_copy_src_to_dest:\n\t%s\n\t%s\n", filesrc, filedest);
 
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 
 	size = infosong_get_size_file (filesrc);
 	if (size == 0) {
@@ -601,7 +615,7 @@ gboolean conv_copy_src_to_dest (gchar *filesrc, gchar *filedest)
 		return (FALSE);
 	}
 	
-	blk = size / 1024;
+	blk = size / SIZE_COPY;
 
 	if (blk <= 0) {
 		blk = 1;
@@ -620,31 +634,30 @@ gboolean conv_copy_src_to_dest (gchar *filesrc, gchar *filedest)
 		fclose (fpsrc);
 		return (FALSE);
 	}
-	flockfile (fpsrc);
+	// flockfile (fpsrc);
 	
 	nmr_fpsrc  = fileno (fpsrc);
 	nmr_fpdest = fileno (fpdest);
 	
 	cpt = 0;
-	modulo = 0;
+	// modulo = 0;
 	while (TRUE) {
-		if ((size = fread (&buffer[0], sizeof(gchar), 1024, fpsrc)) > 0) {
+		if ((size = fread (&buffer[0], sizeof(gchar), SIZE_COPY, fpsrc)) > 0) {
 
 			fwrite (&buffer[0], sizeof(gchar), size, fpdest);
+			// fflush (fpdest);
 		} else {
 			break;
 		}
 		if (feof (fpsrc)) {
 			break;
 		}
-		if (modulo ++ > 50) {
-			/*fflush (fpdest);*/
-			/*
-			fsync (nmr_fpsrc);
-			fsync (nmr_fpdest);
-			*/
-			modulo = 0;
-		}
+		// if (modulo ++ > 50) {
+			// fflush (fpdest);
+			// fsync (nmr_fpsrc);
+			// fsync (nmr_fpdest);
+		// 	modulo = 0;
+		// }
 		cpt ++;
 
 		conv.conversion_percent = (double)cpt / (double)blk;
@@ -653,13 +666,15 @@ gboolean conv_copy_src_to_dest (gchar *filesrc, gchar *filedest)
 		conv.bool_percent_conv = TRUE;
 		
 	}
-	funlockfile (fpsrc);
-	
+	// funlockfile (fpsrc);
+	fflush (fpdest);
 	fclose (fpdest);
 	fclose (fpsrc);
 	
+	conv_inc_encode_completed ();
 	conv.conversion_percent = 0.0;
 	/*conv.bool_reset_conv = TRUE;*/
+#undef SIZE_COPY
 	return (TRUE);
 }
 void conv_product_name_for_label_extract (gchar *NameFile)
@@ -736,6 +751,7 @@ void conv_reset_struct (void)
 	
 	conv.typeoper = _CONV_;
 
+	/*
 	conv.Adr_wind = NULL;
 	conv.Adr_label_extract = NULL;
 	conv.Adr_progressbar_extract = NULL;
@@ -746,6 +762,7 @@ void conv_reset_struct (void)
 	conv.Adr_textview = NULL;
 	conv.BoolPutTextview = FALSE;
 	conv.ListPutTextview = NULL;
+	*/
 	
 	if (conv.name_extract) g_free (conv.name_extract);
 	conv.name_extract = NULL;
@@ -810,14 +827,15 @@ void conv_set_type_oper (TYPE_OPER typeoper)
 	conv.typeoper = typeoper;
 }
 
-void conv_with_flac_ARGS (ARGS_TO_EXEC *args)
+gboolean conv_with_flac_ARGS (ARGS_TO_EXEC *args)
 {
-	gint   pos = 0;
-	gint   fd;
-	gint   size;
-	gint   sector = 0;
-	gchar  buf [ CONV_MAX_CARS + 10 ];
-	gchar *Ptr = NULL;
+	gint		 pos = 0;
+	gint		 fd;
+	gint		 size;
+	gint		 sector = 0;
+	gchar		 buf [ CONV_MAX_CARS + 10 ];
+	gchar		*Ptr = NULL;
+	gboolean	 BoolNoErrorRet = TRUE;
 
 	fd = conv_call_exec (args, &conv.code_fork_conv, STDERR_FILENO);
 
@@ -838,7 +856,17 @@ void conv_with_flac_ARGS (ARGS_TO_EXEC *args)
 		} while ((buf[pos] != '\b') && (buf[pos] != '\r') && (buf[pos] != '\n') && (size > 0));
 		pos ++;
 		buf[ pos ] = '\0';
-
+		
+		if ((Ptr = strstr (buf, "ERROR"))) {
+			/*
+			coldplay_test.flac: ERROR, MD5 signature mismatch
+			coldplay_test.wav: ERROR while decoding metadata
+				state = FLAC__STREAM_DECODER_END_OF_STREAM
+			*/
+			BoolNoErrorRet = FALSE;
+			break;
+		}
+		
 		/* exemple du contenu de buf
 		*
 		a.wav: 5% complete, ratio=0,534
@@ -883,6 +911,8 @@ void conv_with_flac_ARGS (ARGS_TO_EXEC *args)
 	conv.conversion_percent = 0.0;
 	conv.bool_reset_conv = TRUE;
 	conv.BoolPercentFlac = TRUE;
+	
+	return (BoolNoErrorRet);
 }
 
 void conv_with_lame_ARGS (ARGS_TO_EXEC *args)
@@ -1148,21 +1178,44 @@ GList *conv_with_glist_sox_get_param (GList *p_list, gchar *filedest)
 		}
 		PtrList = g_list_next (PtrList);
 	}
-	list = g_list_append (list, g_strdup ("-ql"));
-	list = g_list_append (list, g_strdup ("-t"));
-	list = g_list_append (list, g_strdup (".wav"));
-	list = g_list_append (list, g_strdup ("-S"));
-	list = g_list_append (list, g_strdup ("-r"));
-	list = g_list_append (list, g_strdup ("44100"));
-	list = g_list_append (list, g_strdup ("-c"));
+	
+	// -r 44100 -c 2 -S -t .wav -o ./all.wav
+	
+	// list = g_list_append (list, g_strdup ("-ql"));	// resample
+	list = g_list_append (list, g_strdup ("-t"));		// type file
+	list = g_list_append (list, g_strdup (".wav"));		// 
+	list = g_list_append (list, g_strdup ("-S"));		// --show-progress
+	list = g_list_append (list, g_strdup ("-r"));		// --rate 
+	list = g_list_append (list, g_strdup ("44100"));	// 
+	list = g_list_append (list, g_strdup ("-c"));		// --channels
 	list = g_list_append (list, g_strdup ("2"));
-	list = g_list_append (list, g_strdup ("-w"));
+	// list = g_list_append (list, g_strdup ("-w"));	// 
+	list = g_list_append (list, g_strdup ("-o"));		// 
+	list = g_list_append (list, g_strdup (filedest));	// 
+	
+	return ((GList *)list);
+}
+
+GList *conv_with_sox_float_get_param (gchar *filesrc, gchar *filedest)
+{
+	GList *list = NULL;
+	
+	list = g_list_append (list, g_strdup ("nice"));
+	list = g_list_append (list, g_strdup ("-n"));
+	list = g_list_append (list, g_strdup_printf ("%d", Config_User.Nice));
+	list = g_list_append (list, g_strdup ("sox"));
+	
+	list = g_list_append (list, g_strdup (filesrc));
+	list = g_list_append (list, g_strdup ("-t"));
+	list = g_list_append (list, g_strdup ("wavpcm"));
+	list = g_list_append (list, g_strdup ("-S"));
+	list = g_list_append (list, g_strdup ("-f"));
 	list = g_list_append (list, g_strdup ("-o"));
 	list = g_list_append (list, g_strdup (filedest));
 	
 	return ((GList *)list);
 }
-
+	
 GList *conv_with_sox_get_param (gchar *filesrc, gchar *filedest, gchar *frequence, gchar *voie, gchar *bits)
 {
 	GList *list = NULL;
@@ -1172,7 +1225,7 @@ GList *conv_with_sox_get_param (gchar *filesrc, gchar *filedest, gchar *frequenc
 	list = g_list_append (list, g_strdup_printf ("%d", Config_User.Nice));
 	list = g_list_append (list, g_strdup ("sox"));
 	
-	list = g_list_append (list, g_strdup ("-ql"));
+	// list = g_list_append (list, g_strdup ("-ql"));
 	
 	list = g_list_append (list, g_strdup ("-t"));
 	list = g_list_append (list, g_strdup (".wav"));
@@ -1182,6 +1235,8 @@ GList *conv_with_sox_get_param (gchar *filesrc, gchar *filedest, gchar *frequenc
 	list = g_list_append (list, g_strdup (frequence));
 	list = g_list_append (list, g_strdup ("-c"));
 	list = g_list_append (list, g_strdup (voie));
+	
+	/*
 	switch (atoi (bits)) {
 		case 8 :  list = g_list_append (list, g_strdup ("-b")); break;
 		case 16 : list = g_list_append (list, g_strdup ("-w")); break;
@@ -1189,6 +1244,24 @@ GList *conv_with_sox_get_param (gchar *filesrc, gchar *filedest, gchar *frequenc
 		case 64 : list = g_list_append (list, g_strdup ("-d")); break;
 		default : list = g_list_append (list, g_strdup ("-b")); break;
 	}
+	*/
+	// AJOUT DU 24 BITS
+	// Sat, 21 Nov 2009 23:24:17 +0100
+	//
+	// -1	8 bits
+	// -2	16 bits
+	// -3	24 bits
+	// -4	32 bits
+	// -8	64 bits
+	switch (atoi (bits)) {
+		case 8 :  list = g_list_append (list, g_strdup ("-1")); break;
+		case 16 : list = g_list_append (list, g_strdup ("-2")); break;
+		case 24 : list = g_list_append (list, g_strdup ("-3")); break;
+		case 32 : list = g_list_append (list, g_strdup ("-4")); break;
+		case 64 : list = g_list_append (list, g_strdup ("-8")); break;
+		default : list = g_list_append (list, g_strdup ("-2")); break;
+	}
+	list = g_list_append (list, g_strdup ("-o"));
 	list = g_list_append (list, g_strdup (filedest));
 	
 	return ((GList *)list);
@@ -1231,8 +1304,8 @@ void conv_with_sox_ARGS (ARGS_TO_EXEC *args)
 		if (BoolTst && (buf[0] == '\0' || strstr (buf, "Input File     :"))) {
 			BoolTst = FALSE;
 			if (conv.encode_completed < conv.total_convert) {
-				conv.encode_completed ++;
-				/*g_print("conv.encode_completed = %d -> %d\n", conv.encode_completed -1, conv.encode_completed);*/
+				// conv.encode_completed ++;
+				// g_print("conv.encode_completed = %d -> %d\n", conv.encode_completed -1, conv.encode_completed);
 				conv.bool_percent_conv = TRUE;
 				conv.bool_reset_conv = TRUE;
 				TT_Sector = -1;
@@ -1781,18 +1854,26 @@ void conv_with_normalise_get_PEAK_RMS_GROUP_ARGS (ARGS_TO_EXEC *args)
 
 void conv_with_normalise_ARGS (ARGS_TO_EXEC *args)
 {
-	gint       end;
+	gint       end = 0;
 	gchar     *ptr = NULL;
 	gchar      buf [ CONV_MAX_CARS + 10 ];
 	gint       fd;
-	gint       size;
+	gint       size = 0;
 	gint       pos = 0;
 	gboolean   bool_pass_2 = TRUE;
 
-	fd = conv_call_exec (args, &conv.code_fork_conv, STDERR_FILENO);
+	fd = conv_call_exec (args, &conv.code_fork_conv, STDOUT_FILENO);
 
 	do
 	{
+		/*
+		$ normalize-audio --peak "/home/cat/Musique/CD/PEAK_Charles Aznavour/01.wav" --
+		Computing levels...
+		 01.wav            100% done, ETA 00:00:00 (batch 100% done, ETA 00:00:00) 
+		Applying adjustment of 0,82dB to /home/cat/Musique/CD/PEAK_Charles Aznavour/01.wav...
+		 01.wav            100% done, ETA 00:00:00 (batch 100% done, ETA 00:00:00) 
+		*/
+
 		pos = -1;
 		do
 		{
@@ -1803,14 +1884,16 @@ void conv_with_normalise_ARGS (ARGS_TO_EXEC *args)
 				pos --;
 			}
 			size = read(fd, &buf[pos], 1);
-			
 		} while ((buf[pos] != '\b') && (buf[pos] != '\r') && (buf[pos] != '\n') && (size > 0));
 		buf[pos] = '\0';
-
+		
+		// g_print("buf = %s\n", buf);
+		
 		if ((ptr = strstr (&buf[0], "batch"))) {
+			
 			ptr += 6;
 			while (*ptr == ' ') ptr ++;
-
+			
 			if (sscanf(ptr, "%d",&end) == 1) {
 
 				if (bool_pass_2 == TRUE) {
@@ -1987,6 +2070,8 @@ void conv_with_wavpack_ARGS (ARGS_TO_EXEC *args)
 	gchar      buf [ CONV_MAX_CARS + 10 ];
 	gchar     *ptr = NULL;
 	gint       percent;
+	
+	gint	   PassMess = 0;
 
 	fd = conv_call_exec (args, &conv.code_fork_conv, STDERR_FILENO);
 
@@ -2008,22 +2093,22 @@ conv.bool_percent_conv = TRUE;
 		} while ((buf[pos] != '\b') && (buf[pos] != '\r') && (buf[pos] != '\n') && (size > 0));
 		buf[pos] = '\0';
 
-/*
-fish@debian:~/tmp$ wavpack -y -f -j0 ./1.wav
+		/*
+		fish@debian:~/tmp$ wavpack -y -f -j0 ./1.wav
 
- WAVPACK  Hybrid Lossless Audio Compressor  Linux Version 4.32  2006-04-05
- Copyright (c) 1998 - 2005 Conifer Software.  All Rights Reserved.
+		 WAVPACK  Hybrid Lossless Audio Compressor  Linux Version 4.32  2006-04-05
+		 Copyright (c) 1998 - 2005 Conifer Software.  All Rights Reserved.
 
-creating ./1.wv,  10% done...
- 14% done...
- 18% done...
- 32% done...
- 38% done...
- 41% done...
- 49% done...
- 53% done...
-created ./1.wv in 4.25 secs (lossless, 20.89%)
-*/
+		creating ./1.wv,  10% done...
+		 14% done...
+		 18% done...
+		 32% done...
+		 38% done...
+		 41% done...
+		 49% done...
+		 53% done...
+		created ./1.wv in 4.25 secs (lossless, 20.89%)
+		*/
 
 		if ((ptr = strstr (&buf[0], "done"))) {
 			ptr -= 5;
@@ -2059,16 +2144,33 @@ created ./1.wv in 4.25 secs (lossless, 20.89%)
 			}
 		}
 		else if ((ptr = strstr (&buf[0], "original md5 signature:"))) {
-			logs_add_datas_system (buf);
-			logs_add_datas_system ("\n");
+			
+			PassMess = 1;
+			logs_write_datas ("\t");
+			logs_writeln_datas (buf);
 		}
 		else if ((ptr = strstr (&buf[0], "created"))) {
-			logs_add_datas_system (buf);
-			logs_add_datas_system ("\n");
+			
+			PassMess = 2;
+			logs_write_datas ("\t");
+			logs_writeln_datas (buf);
+		}
+		else if (PassMess == 0) {
+			PassMess = 3;
 		}
 
 	} while (size != 0);
-
+	
+	switch (PassMess) {
+	case 0 :
+	case 1 :
+	case 2 :
+		break;
+	case 3 :
+		logs_writeln_datas (_("Wav to Wavpack"));
+		break;
+	}
+	
 	if (BoolPass == FALSE) {
 		
 		percent = 100;
@@ -2111,17 +2213,17 @@ void conv_with_wvunpack_ARGS (ARGS_TO_EXEC *args)
 		} while ((buf[pos] != '\b') && (buf[pos] != '\r') && (buf[pos] != '\n') && (size > 0));
 		buf[pos] = '\0';
 
-/*
-fish@debian:~/Musique/aaa$ wvunpack -y ./1.wv
+		/*
+		fish@debian:~/Musique/aaa$ wvunpack -y ./1.wv
 
- WVUNPACK  Hybrid Lossless Audio Decompressor  Linux Version 4.32  2006-04-05
- Copyright (c) 1998 - 2005 Conifer Software.  All Rights Reserved.
+		 WVUNPACK  Hybrid Lossless Audio Decompressor  Linux Version 4.32  2006-04-05
+		 Copyright (c) 1998 - 2005 Conifer Software.  All Rights Reserved.
 
-restoring ./1.wav,  49% done...
- 61% done...
- 82% done...
-restored ./1.wav in 3.21 secs (lossless, 20.89%)
-*/
+		restoring ./1.wav,  49% done...
+		 61% done...
+		 82% done...
+		restored ./1.wav in 3.21 secs (lossless, 20.89%)
+		*/
 		if ((ptr = strstr (&buf[0], "done"))) {
 			ptr -= 5;
 			while (*ptr == ' ') ptr ++;
@@ -2166,16 +2268,13 @@ restored ./1.wav in 3.21 secs (lossless, 20.89%)
 		restored ./20.wav in 17.23 secs (lossless, 26.45%)
 		*/
 		else if ((ptr = strstr (&buf[0], "original md5:"))) {
-			logs_add_datas_system (buf);
-			logs_add_datas_system ("\n");
+			logs_writeln_datas (buf);
 		}
 		else if ((ptr = strstr (&buf[0], "unpacked md5:"))) {
-			logs_add_datas_system (buf);
-			logs_add_datas_system ("\n");
+			logs_writeln_datas (buf);
 		}
 		else if ((ptr = strstr (&buf[0], "restored"))) {
-			logs_add_datas_system (buf);
-			logs_add_datas_system ("\n");
+			logs_writeln_datas (buf);
 		}
 	} while (size != 0);
 
@@ -2609,6 +2708,39 @@ void conv_with_cddb_tool_ARGS (ARGS_TO_EXEC *args)
 	close(fd);
 }
 
+void conv_with_icedax_tool_ARGS (ARGS_TO_EXEC *args)
+{
+	gint             pos = 0;
+	gint             size = 0;
+	gchar            buf[CONV_MAX_CARS + 10];
+	gint             fd;
+
+	conv.bool_percent_conv = TRUE;
+	fd = conv_call_exec (args, &conv.code_fork_conv, STDERR_FILENO);
+		
+	do {
+		pos = -1;
+		do {
+			pos++;
+			if (pos >= CONV_MAX_CARS) {
+				PRINT_FUNC_LF();
+				g_print ("pos(%d) >= CONV_MAX_CARS(%d)\n", pos, CONV_MAX_CARS);
+				pos --;
+			}
+			size = read(fd, &buf[pos], 1);
+			
+		} while ((buf[pos] != '\b') && (buf[pos] != '\r') && (buf[pos] != '\n') && (size > 0));
+		buf[pos ++ ] = '\n';
+		buf[pos] = '\0';
+		
+		if (buf [ 0 ] != '\n') g_print("BUF = %s", buf);
+		
+	} while (size != 0);
+
+	conv.code_fork_conv = -1;
+	close(fd);
+}
+
 void conv_with_aacplusenc_ARGS (ARGS_TO_EXEC *args)
 {
 	gint             pos = 0;
@@ -2709,7 +2841,7 @@ gboolean conv_exec (gboolean WithParameter, TYPE_CONV type_conv, GList *p_list,
 		break;
 	case FLAC_FLAC_TO_WAV :
 	case FLAC_WAV_TO_FLAC :
-		conv_with_flac_ARGS (conv.ArgConv);
+		RetBool = conv_with_flac_ARGS (conv.ArgConv);
 		break;
 	case LAME_WAV_TO_MP3 :
 	case LAME_FLAC_TO_MP3 :
@@ -2738,6 +2870,9 @@ gboolean conv_exec (gboolean WithParameter, TYPE_CONV type_conv, GList *p_list,
 		conv_with_faac_ARGS (conv.ArgConv);
 		break;
 	case MPLAYER_WMA_TO_WAV :
+	case MPLAYER_RM_TO_WAV :
+	case MPLAYER_DTS_TO_WAV :
+	case MPLAYER_AIFF_TO_WAV :
 	case MPLAYER_WAV_TO_WAV :
 	case MPLAYER_AUDIO_TO_WAV :
 	case MPLAYER_M4A_TO_WAV :
@@ -2789,6 +2924,11 @@ gboolean conv_exec (gboolean WithParameter, TYPE_CONV type_conv, GList *p_list,
 	case CDDB_TOOL :
 		conv_with_cddb_tool_ARGS (conv.ArgConv);
 		break;
+	
+	case ICEDAX :
+		conv_with_icedax_tool_ARGS (conv.ArgConv);
+		break;
+
 	case AACPLUSENC_WAV_TO_AAC :
 		conv_with_aacplusenc_ARGS (conv.ArgConv);
 		break;
