@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -62,6 +62,9 @@ typedef enum {						/* Les types de conversions possibles */
 	MPLAYER_AUDIO_TO_WAV,				/*  */
 	MPLAYER_M4A_TO_WAV,				/*  */
 	MPLAYER_OGG_TO_WAV,				/*  */
+	MPLAYER_RM_TO_WAV,				/*  */
+	MPLAYER_DTS_TO_WAV,				/*  */
+	MPLAYER_AIFF_TO_WAV,				/*  */
 	COPY_FILE,					/*  */
 	NORMALISE_CALCUL,				/*  */
 	NORMALISE_APPLIQUE,				/*  */
@@ -81,6 +84,7 @@ typedef enum {						/* Les types de conversions possibles */
 	LSDVD,						/*  */
 	SPLIT,						/*  */
 	CDDB_TOOL,					/*  */
+	ICEDAX,						/*  */
 	AACPLUSENC_WAV_TO_AAC				/*  */
 	
 } TYPE_CONV;
@@ -103,6 +107,7 @@ typedef struct {
 	gboolean       BoolUsed;
 	
 	GtkWidget     *Adr_wind;			/* Adresse fenetre							*/
+	gboolean	Bool;
 
 	GtkWidget     *Adr_label_info_wind;		/* Adresse label information						*/
 	GtkWidget     *Adr_label_extract;		/* Adresse label extraction						*/
@@ -214,6 +219,7 @@ void          conv_set_label_conversion (void);
 void          conv_set_label_total (TYPE_OPER type);
 GList        *conv_with_lsdvd_get_param (gchar *pathdev);
 GList        *conv_with_glist_sox_get_param (GList *p_list, gchar *filedest);
+GList        *conv_with_sox_float_get_param (gchar *filesrc, gchar *filedest);
 GList        *conv_with_sox_get_param (gchar *filesrc, gchar *filedest, gchar *frequence, gchar *voie, gchar *bits);
 ARGS_TO_EXEC *conv_alloc_arg (GList *p_list);
 gint          conv_g_list_length (GList *p_list, gint *p_NbrList);
