@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -45,8 +45,6 @@
 #include <sys/types.h>
 #include <signal.h>
 
-#include "support.h"
-
 #include "global.h"
 #include "file.h"
 #include "utils.h"
@@ -58,7 +56,7 @@
 #include "dvd_audio.h"
 #include "conv.h"
 #include "popup.h"
-#include "player.h"
+#include "mplayer.h"
 #include "win_play.h"
 #include "scan_cd.h"
 
@@ -186,13 +184,17 @@ void dvdaudio_affiche_list (void)
 	gchar           *str = NULL;
 	gint             NumStruct = 1;
 	GtkAdjustment   *Adj = NULL;
+	gdouble          AdjValue;
 
 	gtk_tree_store_clear ((GtkTreeStore *)var_dvdaudio.Adr_Tree_Model);
 	
 	/* Mise a jour du scroll vertical */
 	Adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (var_dvdaudio.Adr_scroll));
-	gtk_adjustment_set_value (Adj, 0.0);
+	AdjValue = gtk_adjustment_get_value (Adj);
+	gtk_adjustment_set_value (Adj, AdjValue);
 	gtk_scrolled_window_set_vadjustment (GTK_SCROLLED_WINDOW (var_dvdaudio.Adr_scroll), Adj);
+	
+	gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (GTK_SCROLLED_WINDOW (var_dvdaudio.Adr_scroll)), NULL, NULL, TRUE, 0.5, 0.5);
 
 	list = g_list_first (GlistDvd);
 	while (list) {
@@ -395,22 +397,22 @@ void dvdaudio_set_flag_buttons_dvd (void)
 	var_dvdaudio.total_selected = 0;
 
 	if (GlistDvd == NULL) {
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_deplier_dvd")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_replier_dvd")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_extraction_dvd")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "frame187")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "frame110")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_deplier_dvd")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_replier_dvd")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_extraction_dvd")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("frame187")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("frame110")), FALSE);
 		str = g_strdup ("");
 		if (var_dvdaudio.Adr_combobox_normalise_dvd != NULL)
 			gtk_widget_set_sensitive (GTK_WIDGET (GTK_COMBO_BOX (var_dvdaudio.Adr_combobox_normalise_dvd)), FALSE);
 	}
 	else {
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_deplier_dvd")), TRUE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_replier_dvd")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_deplier_dvd")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_replier_dvd")), TRUE);
 		gtk_tree_model_foreach (GTK_TREE_MODEL(var_dvdaudio.Adr_Tree_Model), dvdaudio_foreach_func_if, NULL);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_extraction_dvd")), var_dvdaudio.total_selected > 0);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "frame187")), TRUE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "frame110")), var_dvdaudio.bool_sa);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_extraction_dvd")), var_dvdaudio.total_selected > 0);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("frame187")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("frame110")), var_dvdaudio.bool_sa);
 
 		gtk_widget_set_sensitive (GTK_WIDGET (GTK_COMBO_BOX (var_dvdaudio.Adr_combobox_normalise_dvd)), dvdaudio_get_is_norm_selected ());
 		
@@ -674,7 +676,7 @@ gboolean dvdaudio_event_click_mouse (GtkWidget *treeview, GdkEventButton *event,
 				/*gtk_tree_model_foreach (GTK_TREE_MODEL(var_dvdaudio.Adr_Tree_Model), dvdaudio_foreach_stop_play, NULL);
 				*/
 				dvdaudio_set_etat_music_pixbuf (&var->BoolDvdPlay, FALSE);
-				PlayerExec_user_to_quit ();
+				mplayer_fifo_quit ();
 			}
 			else if (WinPlay_Is_Ok () == TRUE) {
 
@@ -682,17 +684,17 @@ gboolean dvdaudio_event_click_mouse (GtkWidget *treeview, GdkEventButton *event,
 				gchar *Chapter = NULL;
 
 				/*
-				LIST_PLAY_FROM_DVD
-				LIST_PLAY_FROM_CD
-				LIST_PLAY_FROM_FILE
+				LIST_MPLAYER_FROM_DVD
+				LIST_MPLAYER_FROM_CD
+				LIST_MPLAYER_FROM_FILE
 				*/
 				if (WinPlay_IsOpen () == FALSE) {
 
-					WinPlay_Open (LIST_PLAY_FROM_DVD, "From DVD", "DVD");
+					WinPlay_Open (LIST_MPLAYER_FROM_DVD, "From DVD", "DVD");
 				}
 				else {
 
-					WinPlay_set_label_namefile (LIST_PLAY_FROM_DVD, "From DVD", "DVD");
+					WinPlay_set_label_namefile (LIST_MPLAYER_FROM_DVD, "From DVD", "DVD");
 				}
 
 				dvdaudio_set_etat_music_pixbuf (&var->BoolDvdPlay, TRUE);
@@ -720,7 +722,7 @@ gboolean dvdaudio_event_click_mouse (GtkWidget *treeview, GdkEventButton *event,
 				var_dvdaudio.PlayDvdAudio.guint_TempsTotal  = var_dvdaudio.GUINT_TempsTotal;
 				var_dvdaudio.PlayDvdAudio.list              = list;
 				
-				PlayerExec_set_list (LIST_PLAY_FROM_DVD, (gdouble)var->GUINT_TempsTotal, var_dvdaudio.GUINT_TempsTotal, list);
+				mplayer_set_list (LIST_MPLAYER_FROM_DVD, (gdouble)var->GUINT_TempsTotal, var_dvdaudio.GUINT_TempsTotal, list);
 				
 				g_free (Chapter);
 				Chapter = NULL;
@@ -1265,8 +1267,9 @@ void dvdaudio_combobox_peripherique_dvd_realize (GtkWidget *widget)
 
 	/* PRINT_FUNC_LF(); */
 
-	utils_clear_elements_combobox (widget);
-
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	List = g_list_first (scancd_get_glist ());
 	while (List) {
 		if ((Media = (MEDIA *)List->data)) {
@@ -1333,16 +1336,16 @@ static gint dvdaudio_Timeout_Update_Handler (gpointer data)
 			}
 		}
 
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "frame106")), TRUE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "frame107")), TRUE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "scrolledwindow_dvd_audio")), TRUE);
-		gtk_widget_hide (GTK_WIDGET (lookup_widget (wind_main, "button_annuler_lecture_dvd")));
-		gtk_widget_hide (GTK_WIDGET (lookup_widget (wind_main, "progressbar_dvd_audio")));
-		gtk_widget_hide (GTK_WIDGET (lookup_widget (wind_main, "frame_lecture_dvd")));
-		gtk_widget_show (GTK_WIDGET (lookup_widget (wind_main, "frame187")));
-		gtk_widget_show (GTK_WIDGET (lookup_widget (wind_main, "frame109")));
-		gtk_widget_show (GTK_WIDGET (lookup_widget (wind_main, "frame110")));
-		gtk_widget_show (GTK_WIDGET (lookup_widget (wind_main, "frame184")));
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("frame106")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("frame107")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("scrolledwindow_dvd_audio")), TRUE);
+		gtk_widget_hide (GTK_WIDGET (XCFA_GET_OBJECT("button_annuler_lecture_dvd")));
+		gtk_widget_hide (GTK_WIDGET (XCFA_GET_OBJECT("progressbar_dvd_audio")));
+		gtk_widget_hide (GTK_WIDGET (XCFA_GET_OBJECT("frame_lecture_dvd")));
+		gtk_widget_show (GTK_WIDGET (XCFA_GET_OBJECT("frame187")));
+		gtk_widget_show (GTK_WIDGET (XCFA_GET_OBJECT("frame109")));
+		gtk_widget_show (GTK_WIDGET (XCFA_GET_OBJECT("frame110")));
+		gtk_widget_show (GTK_WIDGET (XCFA_GET_OBJECT("frame184")));
 
 		dvdaudio_set_flag_buttons_dvd ();
 
@@ -1365,17 +1368,17 @@ void dvdaudio_reffresh_list_dvd_action (void)
 
 	dvdaudio_remove_GtkTree ();
 
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "frame106")), FALSE);
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "frame107")), FALSE);
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "scrolledwindow_dvd_audio")), FALSE);
-	gtk_widget_hide (GTK_WIDGET (lookup_widget (wind_main, "frame187")));
-	gtk_widget_hide (GTK_WIDGET (lookup_widget (wind_main, "frame109")));
-	gtk_widget_hide (GTK_WIDGET (lookup_widget (wind_main, "frame110")));
-	gtk_widget_hide (GTK_WIDGET (lookup_widget (wind_main, "frame184")));
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("frame106")), FALSE);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("frame107")), FALSE);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("scrolledwindow_dvd_audio")), FALSE);
+	gtk_widget_hide (GTK_WIDGET (XCFA_GET_OBJECT("frame187")));
+	gtk_widget_hide (GTK_WIDGET (XCFA_GET_OBJECT("frame109")));
+	gtk_widget_hide (GTK_WIDGET (XCFA_GET_OBJECT("frame110")));
+	gtk_widget_hide (GTK_WIDGET (XCFA_GET_OBJECT("frame184")));
 
-	gtk_widget_show (GTK_WIDGET (lookup_widget (wind_main, "button_annuler_lecture_dvd")));
-	gtk_widget_show (GTK_WIDGET (lookup_widget (wind_main, "progressbar_dvd_audio")));
-	gtk_widget_show (GTK_WIDGET (lookup_widget (wind_main, "frame_lecture_dvd")));
+	gtk_widget_show (GTK_WIDGET (XCFA_GET_OBJECT("button_annuler_lecture_dvd")));
+	gtk_widget_show (GTK_WIDGET (XCFA_GET_OBJECT("progressbar_dvd_audio")));
+	gtk_widget_show (GTK_WIDGET (XCFA_GET_OBJECT("frame_lecture_dvd")));
 
 	conv_reset_struct ();
 
@@ -1413,7 +1416,7 @@ void dvdaudio_reffresh_list_directory_dvd (gchar *path)
 	Config_User.Path_Load_File_DVD = NULL;
 	Config_User.Path_Load_File_DVD = g_strdup (path);
 
-	PlayerExec_user_to_quit ();
+	mplayer_fifo_quit ();
 	dvdaudio_reffresh_list_dvd_action ();
 }
 
@@ -1445,7 +1448,7 @@ void dvdaudio_reffresh_list_dvd (void)
 		var_dvdaudio.from.bool_dvd = TRUE;
 		g_free (var_dvdaudio.from.path);
 		var_dvdaudio.from.path = NULL;
-		PlayerExec_user_to_quit ();
+		mplayer_fifo_quit ();
 		dvdaudio_reffresh_list_dvd_action ();
 	}
 }
@@ -1677,14 +1680,15 @@ void dvdaudio_button_extraction_dvd_clicked (void)
 	
 	gtk_tree_model_foreach (GTK_TREE_MODEL(var_dvdaudio.Adr_Tree_Model), dvdaudio_foreach_func, NULL);
 
-	PlayerExec_user_to_quit ();
+	mplayer_fifo_quit ();
 	dvdaudioextract_dvd_to_file ();
 }
 
 void dvdaudio_combobox_sub_dvd_realize (GtkWidget *widget)
 {
 	/*PRINT_FUNC_LF();*/
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
 
 	var_dvdaudio.Adr_combobox_sub_dvd = GTK_COMBO_BOX (widget);
 
@@ -1696,8 +1700,9 @@ void dvdaudio_combobox_sub_dvd_realize (GtkWidget *widget)
 void dvdaudio_combobox_ambiance_dvd_realize (GtkWidget *widget)
 {
 	/*PRINT_FUNC_LF();*/
-	utils_clear_elements_combobox (widget);
-
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	var_dvdaudio.Adr_combobox_ambiance_dvd = GTK_COMBO_BOX (widget);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Normal");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "-3dB");
@@ -1708,7 +1713,9 @@ void dvdaudio_combobox_ambiance_dvd_realize (GtkWidget *widget)
 
 void dvdaudio_combobox_normalise_dvd_realize (GtkWidget *widget)
 {
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	var_dvdaudio.Adr_combobox_normalise_dvd = GTK_COMBO_BOX (widget);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Peak/Album");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Peak");
