@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -37,7 +37,6 @@
 #endif
 
 #include <gtk/gtk.h>
-#include "support.h"
 
 #include <pthread.h>
 #include <sys/types.h>
@@ -194,8 +193,7 @@ void dvdexec_create_list (TYPE_LIST_DVD type_list_dvd,
 		var->GUINT_TempsTotal += S;
 		
 		/*g_print ("var->GUINT_TempsTotal = %d\n", var->GUINT_TempsTotal);*/
-
-/*g_print ("var->GUINT_TempsTotal=%4d %02d:%02d:%02d\n",var->GUINT_TempsTotal, H,M,S);*/
+		/*g_print ("var->GUINT_TempsTotal=%4d %02d:%02d:%02d\n",var->GUINT_TempsTotal, H,M,S);*/
 	}
 
 
@@ -214,8 +212,7 @@ void dvdexec_create_list (TYPE_LIST_DVD type_list_dvd,
 	
 	GlistDvd = g_list_append (GlistDvd, var);
 
-
-/*g_print ("[ %02d ][ %02d ]var->GUINT_TempsTotal=%4d \n", NumerateTitle, NumerateChapter, var->GUINT_TempsTotal);*/
+	/*g_print ("[ %02d ][ %02d ]var->GUINT_TempsTotal=%4d \n", NumerateTitle, NumerateChapter, var->GUINT_TempsTotal);*/
 }
 
 void dvdexec_compteur (void)
@@ -593,6 +590,7 @@ void dvdexec_create_recap_audio (void)
 	gint          cpt;
 	gchar        *LineCommand = NULL;
 	FILE         *fp = NULL;
+	gint          Dummy;
 
 	/*PRINT_FUNC_LF();*/
 
@@ -627,10 +625,10 @@ void dvdexec_create_recap_audio (void)
 
 	fclose (fp);
 
-	system ("chmod +x /tmp/get_infos_dvd.sh");
+	Dummy = system ("chmod +x /tmp/get_infos_dvd.sh");
 
 	/*dvdexec_exec_system_sh ();*/
-	system ("/tmp/get_infos_dvd.sh");
+	Dummy = system ("/tmp/get_infos_dvd.sh");
 	infosong_delete_file ("/tmp/get_infos_dvd.sh");
 }
 
@@ -703,7 +701,7 @@ void dvdexec_read_info_audio (void)
 	size = infosong_get_size_file ("/tmp/infos_dvd.txt");
 	buf = (gchar *)g_malloc0 (sizeof (gchar) * (size +10));
 	fp = fopen ("/tmp/infos_dvd.txt", "r");
-	fread (buf, size, 1, fp);
+	size = fread (buf, size, 1, fp);
 	fclose (fp);
 
 	Larrbuf = g_strsplit (buf, "\n", 0);
@@ -1088,17 +1086,16 @@ gboolean dvdexec_dvd_found (void)
 	
 	/*ListLsdvd = conv_with_lsdvd_get_param (scancd_get_text_combo_cd (_DVD_));*/
 
-PRINT("ENTREE ListLsdvd =");
 	ListLsdvd = conv_with_lsdvd_get_param (var_dvdaudio.PathDvd);
-PRINT("SORTIE ListLsdvd =");
+
 	if (conv.ArgConv != NULL) {
 		g_free (conv.ArgConv);
 		conv.ArgConv = NULL;
 	}
 	conv.ArgConv = conv_alloc_arg (ListLsdvd);
-PRINT("ENTREE");
+
 	conv_exec (FALSE, LSDVD, ListLsdvd, "NEW1:-> LSDVD");
-PRINT("SORTIE");
+
 	g_free (conv.ArgConv);
 	conv.ArgConv = NULL;
 	ListLsdvd = filelc_remove_glist (ListLsdvd);
@@ -1107,7 +1104,6 @@ PRINT("SORTIE");
 	/*conv_with_lsdvd_get_info (scancd_get_text_combo_cd (_DVD_));*/
 	
 	if ((buf = utils_get_datas_on_disk ()) == NULL) {
-		PRINT("BUF == NULL");
 		return (FALSE);
 	}
 	if (buf != NULL && (*buf == '\b' || *buf == '\r' || *buf == '\n')) {
