@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -142,6 +142,21 @@ typedef struct {
 	TAGS			*tags;					/* Tags								*/
 } INFO_WMA;
 
+typedef struct {
+	gchar			*namefile;				/* Nom complet du fichier					*/
+	TAGS			*tags;					/* Tags								*/
+} INFO_RM;
+
+typedef struct {
+	gchar			*namefile;				/* Nom complet du fichier					*/
+	TAGS			*tags;					/* Tags								*/
+} INFO_DTS;
+
+typedef struct {
+	gchar			*namefile;				/* Nom complet du fichier					*/
+	TAGS			*tags;					/* Tags								*/
+} INFO_AIFF;
+
 typedef struct {
 	gchar			*namefile;				/* Nom complet du fichier					*/
 	TAGS			*tags;					/* Tags								*/
@@ -255,6 +270,9 @@ typedef enum {
 	FILE_IS_AAC,
 	FILE_IS_SHN,
 	FILE_IS_WMA,
+	FILE_IS_RM,
+	FILE_IS_DTS,
+	FILE_IS_AIFF,
 	FILE_IS_MPC,
 	FILE_IS_APE,
 	FILE_IS_WAVPACK,
@@ -369,6 +387,20 @@ typedef enum {
 	
 } ETAT_TRASH_FILE;
 
+enum {
+	ETAT_FROM_WAV_TO_FLAC = 0,
+	ETAT_FROM_WAV_TO_APE,
+	ETAT_BOOL_WAVPACK,
+	ETAT_FROM_WAV_TO_OGG,
+	ETAT_FROM_WAV_TO_M4A,
+	ETAT_FROM_WAV_TO_AAC,
+	ETAT_FROM_WAV_TO_MPC,
+	ETAT_FROM_WAV_TO_MP3,
+	
+	ETAT_BOOL_TOTAL
+};
+
+
 typedef struct {
 
 	ETAT_PLAY_FILE		 EtatPlay;				/*								*/
@@ -399,18 +431,25 @@ typedef struct {
 	gchar			*dest_wavpack_md5;			/*								*/
 	gchar			*tmp_flac;				/*								*/
 	gchar			*tmp_wav;				/*								*/
+		
 	gchar			*tmp_sox;				/* wav to wav							*/
+	gchar			*tmp_sox_24;				/* wav to wav							*/
 	gchar			*tmp_mp3;				/*								*/
 	gchar			*tmp_ogg;				/*								*/
 	gchar			*tmp_m4a;				/*								*/
 	gchar			*tmp_aac;				/*								*/
 	gchar			*tmp_shn;				/*								*/
 	gchar			*tmp_wma;				/*								*/
+	gchar			*tmp_rm;				/*								*/
+	gchar			*tmp_dts;				/*								*/
+	gchar			*tmp_aiff;				/*								*/
 	gchar			*tmp_mpc;				/*								*/
 	gchar			*tmp_ape;				/*								*/
 	gchar			*tmp_wavpack;				/*								*/
 	gchar			*tmp_wavpack_md5;			/*								*/
-
+	
+	gboolean		 BoolEtatConv [ ETAT_BOOL_TOTAL ];	/*								*/
+	
 	ETAT_CONV_FILE		 Etat_Flac;				/*								*/
 	ETAT_CONV_FILE		 Etat_Wav;				/*								*/
 	ETAT_CONV_FILE		 Etat_Mp3;				/*								*/
@@ -667,13 +706,8 @@ void       file_combobox_oggenc_bitrate_mp3ogg_changed (void);
 void       file_combobox_oggenc_managed_mp3ogg_changed (void);
 void       file_combobox_oggenc_downmix_m3ogg_changed (void);
 
-gchar       *file_get_val_bitrate_oggenc (void);
-gchar       *file_get_val_managed_oggenc (void);
-gchar       *file_get_val_downmix_oggenc (void);
-gchar       *file_get_param_lame (void);
 gchar       *file_get_param_lame_print (void);
 gchar       *file_get_param_lame_affiche (gint abr_cbr_vbr, gint bitrate, gint mode);
-gchar       *file_get_param_oggenc (void);
 gchar       *file_get_param_oggenc_print (void);
 gchar       *file_get_param_oggenc_affiche (gint bitrate, gint managed, gint downmix);
 
@@ -840,6 +874,7 @@ typedef struct {
 	gchar		*cdrom;
 	gchar		*num_track;
 	gboolean	 BoolSetBitrate;
+	gchar		*PtrStrBitrate;
 } PARAM_FILELC;
 
 GList     *filelc_get_command_line (PARAM_FILELC *param_filelc);
