@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -44,8 +44,6 @@
 #include <sys/stat.h>
 #include <stdlib.h>
 
-#include "support.h"
-
 #include "global.h"
 #include "file.h"
 #include "win_pulse.h"
@@ -61,7 +59,7 @@
 #include "level.h"
 #include "split.h"
 #include "config_user.h"
-#include "player.h"
+#include "mplayer.h"
 #include "process.h"
 #include "split_shuttle.h"
 #include "fileselect.h"
@@ -146,11 +144,17 @@ FIC *fileanalyze_remove_info_fic (FIC *fic) {
 		g_free (fic->dest_ogg);
 		g_free (fic->tmp_flac);
 		g_free (fic->tmp_wav);
+				
 		g_free (fic->tmp_sox);
+		g_free (fic->tmp_sox_24);
+		
 		g_free (fic->tmp_mp3);
 		g_free (fic->tmp_ogg);
 		g_free (fic->tmp_shn);
 		g_free (fic->tmp_wma);
+		g_free (fic->tmp_rm);
+		g_free (fic->tmp_dts);
+		g_free (fic->tmp_aiff);
 		g_free (fic->tmp_mpc);
 		g_free (fic->tmp_ape);
 		g_free (fic->tmp_wavpack);
@@ -260,6 +264,17 @@ void fileanalyze_remove_entetefile (void) {
 			else if (detail->type_infosong_file_is == FILE_IS_WMA) {
 				detail->info = tagswma_remove_info ((INFO_WMA *)detail->info);
 			}
+			
+			else if (detail->type_infosong_file_is == FILE_IS_RM) {
+				detail->info = tagsrm_remove_info ((INFO_RM *)detail->info);
+			}
+			else if (detail->type_infosong_file_is == FILE_IS_DTS) {
+				detail->info = tagsdts_remove_info ((INFO_DTS *)detail->info);
+			}
+			else if (detail->type_infosong_file_is == FILE_IS_AIFF) {
+				detail->info = tagsaiff_remove_info ((INFO_AIFF *)detail->info);
+			}
+			
 			else if (detail->type_infosong_file_is == FILE_IS_MPC) {
 				detail->info = tagsmpc_remove_info ((INFO_MPC *)detail->info);
 			}
@@ -352,6 +367,9 @@ FIC *fileanalyze_set_data_fic (DETAIL *detail, gchar *namefile)
 	    detail->type_infosong_file_is == FILE_IS_OGG ||
 	    detail->type_infosong_file_is == FILE_IS_M4A ||
 	    detail->type_infosong_file_is == FILE_IS_WMA ||
+	    detail->type_infosong_file_is == FILE_IS_RM  ||
+	    detail->type_infosong_file_is == FILE_IS_DTS ||
+	    detail->type_infosong_file_is == FILE_IS_AIFF ||
 	    detail->type_infosong_file_is == FILE_IS_MPC ||
 	    detail->type_infosong_file_is == FILE_IS_WAVPACK ||
 	    detail->type_infosong_file_is == FILE_IS_APE ||
@@ -384,18 +402,24 @@ FIC *fileanalyze_set_data_fic (DETAIL *detail, gchar *namefile)
 
 	fic->tmp_flac = NULL;
 	fic->tmp_wav = NULL;
+	
 	fic->tmp_sox = NULL;
+	fic->tmp_sox_24 = NULL;
+
 	fic->tmp_mp3 = NULL;
 	fic->tmp_ogg = NULL;
 	fic->tmp_shn = NULL;
 	fic->tmp_wma = NULL;
+	fic->tmp_rm  = NULL;
+	fic->tmp_dts = NULL;
+	fic->tmp_aiff = NULL;
 	fic->tmp_mpc = NULL;
 	fic->tmp_ape = NULL;
 	fic->tmp_m4a = NULL;
 	fic->tmp_aac = NULL;
 	fic->tmp_wavpack = NULL;
 	fic->tmp_wavpack_md5 = NULL;
-
+		
 	fic->Etat_Flac          = FILE_NONE;
 	fic->Etat_Mp3           = FILE_NONE;
 	fic->Etat_Mp3           = FILE_NONE;
@@ -558,11 +582,13 @@ gboolean fileanalyze_set_data_treeview (gchar *namefile, TYPE_FILE_IS type, gboo
 		else if (type == FILE_IS_OGG)     detail->info = tagsogg_get_info (detail, namefile);
 		else if (type == FILE_IS_SHN)     detail->info = tagsshn_get_info (namefile);
 		else if (type == FILE_IS_WMA)     detail->info = tagswma_get_info (namefile);
+		else if (type == FILE_IS_RM)      detail->info = tagsrm_get_info (namefile);
+		else if (type == FILE_IS_DTS)     detail->info = tagsdts_get_info (namefile);
+		else if (type == FILE_IS_AIFF)    detail->info = tagsaiff_get_info (namefile);
 		else if (type == FILE_IS_M4A)     detail->info = tagsm4a_get_info (detail, namefile);
 		else if (type == FILE_IS_MPC)     detail->info = tagsmpc_get_info (namefile);
 		else if (type == FILE_IS_APE)     detail->info = tagsape_get_info (namefile);
 		else if (type == FILE_IS_WAVPACK) detail->info = tagswavpack_get_info (detail, namefile);
-		
 	}
 	
 	switch (detail->choice_treeview) {
@@ -604,62 +630,68 @@ guint fileanalyze_get_total_file (void)
 		if ((fa = (FILE_ANALIZE *)list->data)) {
 			if (fa->bool_recursif == FALSE) var_analize.total_elem ++;
 		}
-		/*
-		if ((FILE_ANALIZE *)list->data) var_analize.total_elem ++;
-		*/
 		list = g_list_next (list);
 	}
 	return (var_analize.total_elem);
 }
 
 extern int lstat(const char *file_name, struct stat *buf);
-extern char *get_current_dir_name (void);
+// extern char *get_current_dir_name (void);
 
 gchar   *ptrdir = NULL;
 gchar   *name = NULL;
 
-void fileanalyze_print_dir (gchar *dir)
+void fileanalyze_recherche_recursive (gchar *Directory)
 {
 	DIR    *dp;
 	struct  dirent *entry;
 	struct  stat statbuf;
-
-	if ((dp = opendir (dir)) == NULL) {
+	gint	Dummy;
+	
+	if ((dp = opendir (Directory)) == NULL) {
 		/*g_print ("ERREUR OPEN REP\n");*/
 		return;
 	}
 	
-	chdir (dir);
+	Dummy = chdir (Directory);
 	while ((entry = readdir (dp)) != NULL) {
 		if (winpulse_event_set_close () == FALSE) {
 
-		lstat (entry->d_name, &statbuf);
+			lstat (entry->d_name, &statbuf);
+			
 			if (S_ISDIR (statbuf.st_mode)) {
 				if (strcmp (".", entry->d_name) == 0 || strcmp ("..", entry->d_name) == 0) continue;
-				fileanalyze_print_dir (entry->d_name);
+				fileanalyze_recherche_recursive (entry->d_name);
 			}
 			else {
-				/*ptrdir = g_get_current_dir ();*/
-				ptrdir = get_current_dir_name();
-				name = g_strdup_printf ("%s/%s", ptrdir, entry->d_name);
+				// ptrdir = g_get_current_dir ();
+				// ptrdir = get_current_dir_name();
 				
-				fileselect_set_glist_from_str (name);
+				// Comme  une  extension  du  standard POSIX.1-2001, la version  Linux (libc4, libc5, glibc) de getcwd() alloue le
+				// tampon dynamiquement avec malloc(3), si buf est NULL. Dans ce cas, le tampon alloué a la longueur size à moins
+				// que size soit égal à zéro, auquel cas buf est alloué avec la taille nécessaire.
+				// L'appelant doit libérer avec free(3) le tampon renvoyé.
 				
-				/*g_print ("name=%s\n", name);*/
-				g_free (ptrdir);
-				ptrdir = NULL;
-				g_free (name);
-				name = NULL;
+				if ((ptrdir = getcwd(ptrdir, 0)) != NULL) {
+								
+					name = g_strdup_printf ("%s/%s", ptrdir, entry->d_name);
+					
+					free (ptrdir);
+					ptrdir = NULL;
+					
+					// g_print("name  = %s\n", name);
+					
+					fileselect_set_glist_from_str (name);
+				
+					g_free (name);
+					name = NULL;
+				}
 			}
 		}
 	}
-	chdir ("..");
+	Dummy = chdir ("..");
 	closedir (dp);
 }
-void fileanalyze_recherche_recursive (gchar *path)
-{
-	fileanalyze_print_dir (path);
-}
 
 gdouble fileanalyze_get_percentage (gchar *p_str, FIC_SPLIT *FicSplit)
 {
@@ -771,14 +803,12 @@ void fileanalyze_add_list_cue (gchar *NameCueFile)
 					if (DecoupesFicSplit != NULL) {
 						DecoupesFicSplit->AdrValueMarkA = fileanalyze_get_percentage (buf, FicSplit);
 					}
-
 				} 
 				
 				/* FIN */
 				
 				else if (strstr (buf, "INDEX 00")) {
 					
-					
 					g_print("%s", buf);
 					List = g_list_last (FicSplit->ListDecoupes);
 					if ((List = g_list_previous (List)) != NULL) {
@@ -788,8 +818,6 @@ void fileanalyze_add_list_cue (gchar *NameCueFile)
 							Prev->AdrValueMarkB = fileanalyze_get_percentage (buf, FicSplit);
 						}
 					}
-					
-					
 				}
 				
 				else if (strstr (buf, "TITLE ")) {
@@ -802,7 +830,7 @@ void fileanalyze_add_list_cue (gchar *NameCueFile)
 			
 			fclose (fp);
 			
-			PRINT("....................AJOUTER LE CONTENU DE :");
+			PRINT("AJOUTER LE CONTENU DE :");
 			g_print ("\t%s\n", NameCueFile);
 			
 			if (DecoupesFicSplit != NULL) {
@@ -839,14 +867,6 @@ void fileanalyze_add_list_cue (gchar *NameCueFile)
 #undef SPLIT_MAX_CARS
 }
 
-void fileanalyze_title_textview (gchar *txt, gint value)
-{
-	gchar * str = g_strdup_printf ("\n<b>---------------\n%s:  %d\n---------------</b>\n", txt, value);
-	logs_label_import_file_add (str);
-	g_free (str);
-	str = NULL;
-}
-
 
 gboolean fileanalyze_linecommand_exist (void)
 {
@@ -902,7 +922,7 @@ void fileanalyze_modify_glist_entetefile (void)
 				fic->Etat_Normalise = NORM_NONE;
 				if (fic->EtatPlay == FILE_ETAT_PLAY) {
 					fic->EtatPlay = FILE_ETAT_PLAY_ATTENTE;
-					PlayerExec_user_to_quit ();
+					mplayer_fifo_quit ();
 					g_print("STOP PLAYSONG OF: %s\n",detail->namefile);
 				}
 			}
@@ -1134,6 +1154,20 @@ void fileanalyze_update_info (void)
 				INFO_WMA *info = (INFO_WMA *)detail->info;
 				detail->info = (INFO_WMA *)tagswma_remove_info (info);
 			}
+			
+			else if (detail->type_infosong_file_is == FILE_IS_RM) {
+				INFO_RM *info = (INFO_RM *)detail->info;
+				detail->info = (INFO_RM *)tagsrm_remove_info (info);
+			}
+			else if (detail->type_infosong_file_is == FILE_IS_DTS) {
+				INFO_DTS *info = (INFO_DTS *)detail->info;
+				detail->info = (INFO_WMA *)tagsdts_remove_info (info);
+			}
+			else if (detail->type_infosong_file_is == FILE_IS_AIFF) {
+				INFO_AIFF *info = (INFO_AIFF *)detail->info;
+				detail->info = (INFO_WMA *)tagsaiff_remove_info (info);
+			}
+			
 			else if (detail->type_infosong_file_is == FILE_IS_MPC) {
 				INFO_MPC *info = (INFO_MPC *)detail->info;
 				detail->info = (INFO_MPC *)tagsmpc_remove_info (info);
@@ -1192,7 +1226,7 @@ static gint Timeout_fileanalyze_do_verif_analyze_file_ (gpointer data)
 	if (process_bool_action_is_ready () == FALSE && var_analize.BoolAnalyseIsOk == FALSE) {
 		return (TRUE);
 	}
-	
+
 	if (var_analize.event == EVENT_PROGRESS) {
 		var_analize.event = EVENT_NONE;
 		winpulse_set_elem_actif (var_analize.elem_actif);
@@ -1200,13 +1234,22 @@ static gint Timeout_fileanalyze_do_verif_analyze_file_ (gpointer data)
 	else if (var_analize.Bool_Thread_Do == FALSE && var_analize.event == EVENT_END_THREAD) {
 
 		gchar        *str = NULL;
-		/*
-		gdouble       gt;
-		gulong        microseconds;
-		*/
+		// gdouble       gt;
+		// gulong        microseconds;
+		
 		GList        *list = NULL;
 		FILE_ANALIZE *fa = NULL;
 		
+		logs_add_datas_session ("FILES ANALYSE");
+		str = g_strdup_printf ("Analyse de %d fichier(s)", var_analize.total_elem);
+		logs_writeln_datas (str);
+		g_free (str);
+		str = NULL;
+		var_analize.total_elem -= (var_analize.cpt_modif_ext + var_analize.cpt_no_analizer);
+		// if (var_analize.total_elem == 0) {
+		// 	WinError_add_to_dsk_ (_("Import de fichier(s) non valide(s)\n"));
+		// }
+		
 		if (!var_analize.bool_checkmp3_ok && !var_analize.bool_ogginfo_ok)
 			str = g_strdup (_("ATTENTION: Il faut installer OGGINFO et CHECKMP3"));
 		else if (!var_analize.bool_checkmp3_ok)
@@ -1218,67 +1261,65 @@ static gint Timeout_fileanalyze_do_verif_analyze_file_ (gpointer data)
 
 		if (str) {
 			utils_puts_statusbar_global (str);
-			/*filemp3ogg_puts_label_statusbar (str);*/
 			g_free (str);
 			str = NULL;
 		}
 
-		if (!var_analize.bool_checkmp3_ok)	logs_label_import_file_add ("CHECKMP3 ABSENT\n");
-		if (!var_analize.bool_ogginfo_ok)	logs_label_import_file_add ("OGGINFO ABSENT\n");
-		if (!var_analize.bool_faad_ok)		logs_label_import_file_add ("FAAD ABSENT\n");
-
 		if (var_analize.cpt_size_is_zero > 0) {
-			fileanalyze_title_textview (_("LA TAILLE EST ZERO"), var_analize.cpt_size_is_zero);
-			list = g_list_first (var_analize.glist_analize);
-			while (list) {
-				if ((fa = (FILE_ANALIZE *)list->data)) {
-					if (fa->because == SIZE_IS_ZERO) {
-						logs_label_import_file_add (fa->name);
-						logs_label_import_file_add ("\n");
+			if ((list = g_list_first (var_analize.glist_analize)) != NULL) {
+				while (list) {
+					if ((fa = (FILE_ANALIZE *)list->data)) {
+						if (fa->because == SIZE_IS_ZERO) {
+							// WinError_add_to_dsk_ ("\t");
+							// WinError_add_to_dsk_ (fa->name);
+							// WinError_add_to_dsk_ ("\n");
+						}
 					}
+					list = g_list_next (list);
 				}
-				list = g_list_next (list);
 			}
 		}
 		
+		/*
 		if (var_analize.cpt_no_analizer > 0) {
-			fileanalyze_title_textview (_("ANALISEUR MANQUANT"), var_analize.cpt_no_analizer);
+			WinError_add_to_dsk_ (_("ANALISEUR MANQUANT"));
+			WinError_add_to_dsk_ ("\n");
 			list = g_list_first (var_analize.glist_analize);
 			while (list) {
 				if ((fa = (FILE_ANALIZE *)list->data)) {
 					if (fa->because == NO_ANALIZER) {
-					if (fa->file_real == FILE_IS_MP3 && !var_analize.bool_checkmp3_ok)
-						logs_label_import_file_add (_("CHECKMP3 absent  "));
-					else if (fa->file_real == FILE_IS_OGG && !var_analize.bool_ogginfo_ok)
-						logs_label_import_file_add (_("OGGINFO absent   "));
-					logs_label_import_file_add (fa->name);
-					logs_label_import_file_add ("\n");
+						if (fa->file_real == FILE_IS_MP3 && !var_analize.bool_checkmp3_ok) {
+							WinError_add_to_dsk_ (_("CHECKMP3 absent  "));
+						} else if (fa->file_real == FILE_IS_OGG && !var_analize.bool_ogginfo_ok) {
+							WinError_add_to_dsk_ (_("OGGINFO absent   "));
+						}
+						WinError_add_to_dsk_ (fa->name);
+						WinError_add_to_dsk_ ("\n");
 					}
 				}
 				list = g_list_next (list);
 			}
 		}
+		*/
 		
 		if (var_analize.cpt_modif_ext > 0) {
-			fileanalyze_title_textview (_("MODIFICATION DE L'EXTENTION"), var_analize.cpt_modif_ext);
+			logs_writeln_datas (_("MODIFICATION DE L'EXTENTION"));
 			list = g_list_first (var_analize.glist_analize);
 			while (list) {
 				if ((fa = (FILE_ANALIZE *)list->data)) {
 					if (fa->because == MODIF_EXT) {
-						logs_label_import_file_add (infosong_get_str_type_file_is (fa->file_ext));
-						logs_label_import_file_add ("   to   ");
-						logs_label_import_file_add (infosong_get_str_type_file_is (fa->file_real));
-						logs_label_import_file_add ("     ");
-						logs_label_import_file_add (fa->name);
-						logs_label_import_file_add ("\n");
+						logs_write_datas ("\t");
+						logs_write_datas (infosong_get_str_type_file_is (fa->file_ext));
+						logs_write_datas ("   to   ");
+						logs_write_datas (infosong_get_str_type_file_is (fa->file_real));
+						logs_write_datas ("     ");
+						logs_writeln_datas (fa->name);	
 					}
 				}
 				list = g_list_next (list);
 			}
 		}
 
-		var_analize.total_elem -= (var_analize.cpt_modif_ext + var_analize.cpt_no_analizer);
-
 		/*
 		g_timer_stop (gtime);
 		gt = g_timer_elapsed (gtime, &microseconds);
@@ -1286,16 +1327,10 @@ static gint Timeout_fileanalyze_do_verif_analyze_file_ (gpointer data)
 		gtime = NULL;
 		utils_time_end ("FILE CLAUDE ");
 		*/
-
-		str = g_strdup_printf (_("\n<b>ANALYSE DE %d FICHIERS</b>\n"), var_analize.elem_actif);
-		logs_label_import_file_add (str);
-		g_free (str);
-		str = NULL;
 		
 		switch (var_analize.choice_treeview) {
 		case _TREEVIEW_ALL_ :
 			file_notebook_in_file_switch_page (Config_User.notebook_file);
-
 			fileanalyze_modify_glist_entetefile ();
 
 			/*
@@ -1306,8 +1341,8 @@ static gint Timeout_fileanalyze_do_verif_analyze_file_ (gpointer data)
 				SOLUCE:
 				Forcer le passage sur NOTEBOOK_DVD_AUDIO avant d'aller sur NOTEBOOK_FICHIERS
 			*/
-			gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")), NOTEBOOK_DVD_AUDIO);
-			gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")), NOTEBOOK_FICHIERS);
+			gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")), NOTEBOOK_DVD_AUDIO);
+			gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")), NOTEBOOK_FICHIERS);
 			break;
 		case _TREEVIEW_SPLIT_ :
 		case _TREEVIEW_SPLIT_ALL_ :
@@ -1316,28 +1351,27 @@ static gint Timeout_fileanalyze_do_verif_analyze_file_ (gpointer data)
 			break;
 		}
 
-
 		fileanalyze_clear_analyze_files_glist ();
 
-		if (logs_get_checkbutton_goto_files_import () &&
-			(var_analize.cpt_size_is_zero > 0 || var_analize.cpt_modif_ext > 0 || var_analize.cpt_no_analizer > 0)) {
-			gtk_notebook_set_current_page (
-				GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
-				NOTEBOOK_LOGS);
-			gtk_notebook_set_current_page (
-				GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_logs")),
-				NOTEBOOK_LOGS_FILE_IMPORT);
-		}
+		// if (logs_get_checkbutton_goto_files_import () &&
+		// 	(var_analize.cpt_size_is_zero > 0 || var_analize.cpt_modif_ext > 0 || var_analize.cpt_no_analizer > 0)) {
+		// 	gtk_notebook_set_current_page (
+		// 		GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
+		// 		NOTEBOOK_LOGS);
+		// 	gtk_notebook_set_current_page (
+		// 		GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_logs")),
+		// 		NOTEBOOK_LOGS_FILE_IMPORT);
+		// }
 		
-		if (logs_set_datas_system () == TRUE) {
-		
-			gtk_notebook_set_current_page (
-				GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
-				NOTEBOOK_LOGS);
-			gtk_notebook_set_current_page (
-				GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_logs")),
-				NOTEBOOK_LOGS_FILE_IMPORT);
-		}
+		// if (logs_set_datas_system () == TRUE) {
+		// 
+		// 	gtk_notebook_set_current_page (
+		// 		GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
+		// 		NOTEBOOK_LOGS);
+		// 	gtk_notebook_set_current_page (
+		// 		GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_logs")),
+		// 		NOTEBOOK_LOGS_FILE_IMPORT);
+		// }
 		
 		file_set_flag_buttons_audio_file ();
 		/* END OF progress and timeout */
@@ -1451,14 +1485,17 @@ static void fileanalyze_thread_do_verif_analyze_file_ (void *arg)
 
 			if (var_analize.choice_treeview == _TREEVIEW_SPLIT_) {
 				if (
-				    fa->file_real == FILE_IS_WAV /* ||
+				    fa->file_real == FILE_IS_WAV ||
 				    fa->file_real == FILE_IS_MP3 ||
 				    fa->file_real == FILE_IS_OGG ||
 				    fa->file_real == FILE_IS_FLAC ||
 				    fa->file_real == FILE_IS_SHN ||
-				    fa->file_real == FILE_IS_WAVPACK*/
+				    fa->file_real == FILE_IS_WAVPACK
 				    ) {
 					
+					PRINT("TODO: AJOUT ICI DE LA RECONNAISSANCE DES TYPES: MP3, OGG, FLAC, SHN, WAVPACK\n\t"
+					      "TODO: VOIR splitshuttle_read_file_spectre (DETAIL *detail) pour callbacks relatif au type de fichier"
+						);
 					
 					if (fa->BoolCueFile == FALSE) {
 					
@@ -1467,22 +1504,12 @@ static void fileanalyze_thread_do_verif_analyze_file_ (void *arg)
 						TagsWavGetHearder (namefile, &HeaderWav);
 						if (HeaderWav.NbrBytes == 0) {
 							
-							gchar	  *str = NULL;
+							logs_writeln_datas (fa->name);
+							logs_write_datas ("\t");
+							logs_writeln_datas (_("Mauvaise structure ou alors le fichier est compresse !"));
+							logs_writeln_datas (_("Essayez depuis Fichier->Wav de modifier la frequence puis"));
+							logs_writeln_datas (_("renouvelez l'operation d'import depuis Split."));
 							
-							str = g_strdup_printf ("<span color=\"blue\"><b>%s</b></span>", fa->name);
-							logs_add_datas_system (str);
-							g_free (str);
-							str = NULL;
-							logs_add_datas_system ("\n");
-							logs_add_datas_system ("<b><i>");
-							logs_add_datas_system (_("Mauvaise structure ou alors le fichier est compresse !"));
-							logs_add_datas_system ("\n");
-							logs_add_datas_system (_("Essayez depuis Fichier->Wav de modifier la frequence puis"));
-							logs_add_datas_system ("\n");
-							logs_add_datas_system (_("renouvelez l'operation d'import depuis Split."));
-							logs_add_datas_system ("</i></b>");
-							
-							PRINT("CONTINUE");
 							list = g_list_next (list);
 							continue;
 						}
@@ -1505,27 +1532,27 @@ static void fileanalyze_thread_do_verif_analyze_file_ (void *arg)
 							g_print("\t%d voie,  %d hertz,  %d bits\n", Channel, Hertz, Bits);
 							
 							str = g_strdup_printf ("<span color=\"blue\"><b>%s</b></span>", fa->name);
-							logs_add_datas_system (str);
+							WinError_add_to_dsk (str);
 							g_free (str);
 							str = NULL;
-							logs_add_datas_system ("\n");
+							WinError_add_to_dsk ("\n");
 							
-							logs_add_datas_system ("<b>Requis: </b>\n\t");
+							WinError_add_to_dsk ("<b>Requis: </b>\n\t");
 							
-							if (Hertz != 44100)			logs_add_datas_system ("<b>");
-							logs_add_datas_system ("41000 hertz,  ");
-							if (Hertz != 44100)			logs_add_datas_system ("</b>");
+							if (Hertz != 44100)			WinError_add_to_dsk ("<b>");
+							WinError_add_to_dsk ("41000 hertz,  ");
+							if (Hertz != 44100)			WinError_add_to_dsk ("</b>");
 							
-							if (Channel != 2)			logs_add_datas_system ("<b>");
-							logs_add_datas_system ("2 channel(s),  ");
-							if (Channel != 2)			logs_add_datas_system ("</b>");
+							if (Channel != 2)			WinError_add_to_dsk ("<b>");
+							WinError_add_to_dsk ("2 channel(s),  ");
+							if (Channel != 2)			WinError_add_to_dsk ("</b>");
 							
-							if (Bits != 16)				logs_add_datas_system ("<b>");
-							logs_add_datas_system ("16 bits");
-							if (Bits != 16)				logs_add_datas_system ("</b>");
-							logs_add_datas_system ("\n");
+							if (Bits != 16)				WinError_add_to_dsk ("<b>");
+							WinError_add_to_dsk ("16 bits");
+							if (Bits != 16)				WinError_add_to_dsk ("</b>");
+							WinError_add_to_dsk ("\n");
 							
-							logs_add_datas_system ("<b>Actuel: </b>\n\t");
+							WinError_add_to_dsk ("<b>Actuel: </b>\n\t");
 							str = g_strdup_printf("%s%d hertz%s,  %s%d channel(s)%s,  %s%d bits%s",
 									(Hertz != 44100) ? "<span color=\"red\"><b>" : "",
 									Hertz,
@@ -1537,8 +1564,8 @@ static void fileanalyze_thread_do_verif_analyze_file_ (void *arg)
 									Bits,
 									(Bits != 16) ? "</b></span>" : ""
 									);
-							logs_add_datas_system (str);
-							logs_add_datas_system ("\n");
+							WinError_add_to_dsk (str);
+							WinError_add_to_dsk ("\n");
 							g_free (str);
 							str = NULL;
 						
@@ -1550,10 +1577,12 @@ static void fileanalyze_thread_do_verif_analyze_file_ (void *arg)
 					*/
 					
 					PRINT("ANALYSE LE FICHIER ...");
+					g_print("\t%s\n\n", namefile);
 					if (fileanalyze_set_data_treeview (namefile, fa->file_real, fa->BoolCueFile) == FALSE) {
 						
 						if (fa->BoolCueFile == TRUE) {
 							PRINT("ANALYSE LE CUE ...");
+							g_print("\t%s\n\n", fa->NameCueFile);
 							fileanalyze_add_list_cue (fa->NameCueFile);
 						}
 					}
@@ -1576,27 +1605,27 @@ static void fileanalyze_thread_do_verif_analyze_file_ (void *arg)
 							detail->remove = STRUCT_FIC_REMOVE_SPLIT;
 							
 							str = g_strdup_printf ("<span color=\"blue\"><b>%s</b></span>",  detail->namefile);
-							logs_add_datas_system (str);
+							WinError_add_to_dsk (str);
 							g_free (str);
 							str = NULL;
-							logs_add_datas_system ("\n");
+							WinError_add_to_dsk ("\n");
 							
-							logs_add_datas_system ("<b>Requis: </b>\n\t");
+							WinError_add_to_dsk ("<b>Requis: </b>\n\t");
 							
-							if (Hertz != 44100)			logs_add_datas_system ("<b>");
-							logs_add_datas_system ("41000 hertz,  ");
-							if (Hertz != 44100)			logs_add_datas_system ("</b>");
+							if (Hertz != 44100)			WinError_add_to_dsk ("<b>");
+							WinError_add_to_dsk ("41000 hertz,  ");
+							if (Hertz != 44100)			WinError_add_to_dsk ("</b>");
 							
-							if (Channel != 2)			logs_add_datas_system ("<b>");
-							logs_add_datas_system ("2 channel(s),  ");
-							if (Channel != 2)			logs_add_datas_system ("</b>");
+							if (Channel != 2)			WinError_add_to_dsk ("<b>");
+							WinError_add_to_dsk ("2 channel(s),  ");
+							if (Channel != 2)			WinError_add_to_dsk ("</b>");
 							
-							if (Bits != 16)				logs_add_datas_system ("<b>");
-							logs_add_datas_system ("16 bits");
-							if (Bits != 16)				logs_add_datas_system ("</b>");
-							logs_add_datas_system ("\n");
+							if (Bits != 16)				WinError_add_to_dsk ("<b>");
+							WinError_add_to_dsk ("16 bits");
+							if (Bits != 16)				WinError_add_to_dsk ("</b>");
+							WinError_add_to_dsk ("\n");
 							
-							logs_add_datas_system ("<b>Actuel: </b>\n\t");
+							WinError_add_to_dsk ("<b>Actuel: </b>\n\t");
 							str = g_strdup_printf("%s%d hertz%s,  %s%d channel(s)%s,  %s%d bits%s",
 									(Hertz != 44100) ? "<span color=\"red\"><b>" : "",
 									Hertz,
@@ -1608,8 +1637,8 @@ static void fileanalyze_thread_do_verif_analyze_file_ (void *arg)
 									Bits,
 									(Bits != 16) ? "</b></span>" : ""
 									);
-							logs_add_datas_system (str);
-							logs_add_datas_system ("\n");
+							WinError_add_to_dsk (str);
+							WinError_add_to_dsk ("\n");
 							g_free (str);
 							str = NULL;
 						}
@@ -1824,30 +1853,32 @@ static void fileanalyze_thread_do_create_glist_analyze_file_ (void *arg)
 			continue;
 		}
 		
-		// TODO
-		// TROPS DE TEMPS D'ANALYZE DEPUIS:
-		//	infosong_file_is ();
+		// TODO: TROPS DE TEMPS D'ANALYZE DEPUIS: infosong_file_is ();
 		TypeFileIs    = infosong_file_is (FILE_IS_NONE, namefile);
 		TypeGetExt    = infosong_get_type_file_is (namefile);
 		
 		/*
-		if (TypeFileIs == FILE_IS_FLAC)		logs_add_datas_system ("TypeFileIs == FILE_IS_FLAC\n");
-		if (TypeFileIs == FILE_IS_WAV)		logs_add_datas_system ("TypeFileIs == FILE_IS_WAV\n");
-		if (TypeFileIs == FILE_IS_MP3)		logs_add_datas_system ("TypeFileIs == FILE_IS_MP3\n");
-		if (TypeFileIs == FILE_IS_OGG)		logs_add_datas_system ("TypeFileIs == FILE_IS_OGG\n");
-		if (TypeFileIs == FILE_IS_M4A)		logs_add_datas_system ("TypeFileIs == FILE_IS_M4A\n");
-		if (TypeFileIs == FILE_IS_AAC)		logs_add_datas_system ("TypeFileIs == FILE_IS_AAC\n");
-		if (TypeFileIs == FILE_IS_SHN)		logs_add_datas_system ("TypeFileIs == FILE_IS_SHN\n");
-		if (TypeFileIs == FILE_IS_WMA)		logs_add_datas_system ("TypeFileIs == FILE_IS_WMA\n");
-		if (TypeFileIs == FILE_IS_MPC)		logs_add_datas_system ("TypeFileIs == FILE_IS_MPC\n");
-		if (TypeFileIs == FILE_IS_APE)		logs_add_datas_system ("TypeFileIs == FILE_IS_APE\n");
-		if (TypeFileIs == FILE_IS_WAVPACK)	logs_add_datas_system ("TypeFileIs == FILE_IS_WAVPACK\n");
+		if (TypeFileIs == FILE_IS_FLAC)		g_print ("TypeFileIs == FILE_IS_FLAC\n");
+		if (TypeFileIs == FILE_IS_WAV)		g_print ("TypeFileIs == FILE_IS_WAV\n");
+		if (TypeFileIs == FILE_IS_MP3)		g_print ("TypeFileIs == FILE_IS_MP3\n");
+		if (TypeFileIs == FILE_IS_OGG)		g_print ("TypeFileIs == FILE_IS_OGG\n");
+		if (TypeFileIs == FILE_IS_M4A)		g_print ("TypeFileIs == FILE_IS_M4A\n");
+		if (TypeFileIs == FILE_IS_AAC)		g_print ("TypeFileIs == FILE_IS_AAC\n");
+		if (TypeFileIs == FILE_IS_SHN)		g_print ("TypeFileIs == FILE_IS_SHN\n");
+		if (TypeFileIs == FILE_IS_WMA)		g_print ("TypeFileIs == FILE_IS_WMA\n");
+		if (TypeFileIs == FILE_IS_RM)		g_print ("TypeFileIs == FILE_IS_RM\n");
+		if (TypeFileIs == FILE_IS_DTS)		g_print ("TypeFileIs == FILE_IS_DTS\n");
+		if (TypeFileIs == FILE_IS_AIFF)		g_print ("TypeFileIs == FILE_IS_AIFF\n");
+		if (TypeFileIs == FILE_IS_MPC)		g_print ("TypeFileIs == FILE_IS_MPC\n");
+		if (TypeFileIs == FILE_IS_APE)		g_print ("TypeFileIs == FILE_IS_APE\n");
+		if (TypeFileIs == FILE_IS_WAVPACK)	g_print ("TypeFileIs == FILE_IS_WAVPACK\n");
 		*/
-				
+		
 		if (BoolFileIsDir == FALSE) {
 			
-			gchar		*LineCommand = NULL;
-			
+			gchar	*LineCommand = NULL;
+			gint	 Dummy;
+
 			if (TypeFileIs != FILE_IS_NONE && TypeGetExt == FILE_IS_NONE) {
 
 				if (TypeFileIs == FILE_IS_FLAC)		PathNameFile = g_strdup_printf ("%s.flac", namefile);
@@ -1858,6 +1889,9 @@ static void fileanalyze_thread_do_create_glist_analyze_file_ (void *arg)
 				else if (TypeFileIs == FILE_IS_AAC)     PathNameFile = g_strdup_printf ("%s.aac", namefile);
 				else if (TypeFileIs == FILE_IS_SHN)	PathNameFile = g_strdup_printf ("%s.shn", namefile);
 				else if (TypeFileIs == FILE_IS_WMA)	PathNameFile = g_strdup_printf ("%s.wma", namefile);
+				else if (TypeFileIs == FILE_IS_RM)	PathNameFile = g_strdup_printf ("%s.rm", namefile);
+				else if (TypeFileIs == FILE_IS_DTS)	PathNameFile = g_strdup_printf ("%s.dts", namefile);
+				else if (TypeFileIs == FILE_IS_AIFF)	PathNameFile = g_strdup_printf ("%s.aif", namefile);
 				else if (TypeFileIs == FILE_IS_MPC)	PathNameFile = g_strdup_printf ("%s.mpc", namefile);
 				else if (TypeFileIs == FILE_IS_APE)	PathNameFile = g_strdup_printf ("%s.ape", namefile);
 				else if (TypeFileIs == FILE_IS_WAVPACK) PathNameFile = g_strdup_printf ("%s.wv", namefile);
@@ -1867,7 +1901,7 @@ static void fileanalyze_thread_do_create_glist_analyze_file_ (void *arg)
 				}
 				
 				LineCommand = g_strdup_printf ("mv \"%s\" \"%s\"", namefile, PathNameFile);
-				system (LineCommand);
+				Dummy = system (LineCommand);
 				g_free (LineCommand);
 				LineCommand = NULL;
 			}
@@ -1881,6 +1915,9 @@ static void fileanalyze_thread_do_create_glist_analyze_file_ (void *arg)
 				else if (TypeFileIs == FILE_IS_AAC)	PathNameFile = g_strdup_printf ("%s.aac", namefile);
 				else if (TypeFileIs == FILE_IS_SHN)	PathNameFile = g_strdup_printf ("%s.shn", namefile);
 				else if (TypeFileIs == FILE_IS_WMA)	PathNameFile = g_strdup_printf ("%s.wma", namefile);
+				else if (TypeFileIs == FILE_IS_RM)	PathNameFile = g_strdup_printf ("%s.rm", namefile);
+				else if (TypeFileIs == FILE_IS_DTS)	PathNameFile = g_strdup_printf ("%s.dts", namefile);
+				else if (TypeFileIs == FILE_IS_AIFF)	PathNameFile = g_strdup_printf ("%s.aif", namefile);
 				else if (TypeFileIs == FILE_IS_MPC)	PathNameFile = g_strdup_printf ("%s.mpc", namefile);
 				else if (TypeFileIs == FILE_IS_APE)	PathNameFile = g_strdup_printf ("%s.ape", namefile);
 				else if (TypeFileIs == FILE_IS_WAVPACK) PathNameFile = g_strdup_printf ("%s.wv", namefile);
@@ -1890,7 +1927,7 @@ static void fileanalyze_thread_do_create_glist_analyze_file_ (void *arg)
 				}
 				
 				LineCommand = g_strdup_printf ("mv \"%s\" \"%s\"", namefile, PathNameFile);
-				system (LineCommand);
+				Dummy = system (LineCommand);
 				g_free (LineCommand);
 				LineCommand = NULL;
 			}
@@ -1899,6 +1936,24 @@ static void fileanalyze_thread_do_create_glist_analyze_file_ (void *arg)
 				TypeFileIs = TypeGetExt;
 			}
 		}
+
+		if ((TypeFileIs != FILE_IS_WAV) &&
+		    (TypeFileIs != FILE_IS_FLAC) &&
+		    (TypeFileIs != FILE_IS_APE) &&
+		    (TypeFileIs != FILE_IS_WAVPACK) &&
+		    (TypeFileIs != FILE_IS_OGG) &&
+		    (TypeFileIs != FILE_IS_M4A) &&
+		    (TypeFileIs != FILE_IS_MPC) &&
+		    (TypeFileIs != FILE_IS_MP3) &&
+		    (TypeFileIs != FILE_IS_WMA) &&
+		    (TypeFileIs != FILE_IS_RM) &&
+		    (TypeFileIs != FILE_IS_DTS) &&
+		    (TypeFileIs != FILE_IS_AIFF) &&
+		    (TypeFileIs != FILE_IS_SHN)) {
+		
+			List = g_list_next (List);
+			continue;
+		}
 		
 		// OTHERS PROCESS NO RUN
 		var_analize.BoolAnalyseIsOk = FALSE;
@@ -1936,7 +1991,6 @@ static void fileanalyze_thread_do_create_glist_analyze_file_ (void *arg)
 
 			fa->name     = g_strdup (PathNameFile);
 			fa->because  = SIZE_IS_ZERO;
-			g_print ("TAILLE EST ZERO: %s\n", PathNameFile);
 			var_analize.glist_analize = g_list_append (var_analize.glist_analize, fa);
 			var_analize.cpt_size_is_zero ++;
 			
