@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -38,8 +38,6 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#include "support.h"
-
 #include <string.h>
 #include <stdlib.h>
 
@@ -108,6 +106,9 @@ TAGS *filexpander_get_tag (DETAIL *detail)
 	INFO_WAV     *infoWAV = NULL;
 	INFO_SHN     *infoSHN = NULL;
 	INFO_WMA     *infoWMA = NULL;
+	INFO_RM      *infoRM  = NULL;
+	INFO_DTS     *infoDTS = NULL;
+	INFO_AIFF    *infoAIFF = NULL;
 	INFO_APE     *infoAPE = NULL;
 	
 	INFO_FLAC     *infoFLAC = NULL;
@@ -149,6 +150,21 @@ TAGS *filexpander_get_tag (DETAIL *detail)
 		infoWMA = (INFO_WMA *)detail->info;
 		tags = (TAGS  *)infoWMA->tags;
 		break;
+	case FILE_IS_RM :
+		infoRM = (INFO_RM *)detail->info;
+		tags = (TAGS  *)infoRM->tags;
+		break;
+	
+	case FILE_IS_DTS :
+		infoDTS = (INFO_DTS *)detail->info;
+		tags = (TAGS  *)infoDTS->tags;
+		break;
+
+	case FILE_IS_AIFF :
+		infoAIFF = (INFO_AIFF *)detail->info;
+		tags = (TAGS  *)infoDTS->tags;
+		break;
+	
 	case FILE_IS_APE :
 		infoAPE = (INFO_APE *)detail->info;
 		tags = (TAGS  *)infoAPE->tags;
@@ -359,14 +375,142 @@ void filexpander_set_label_tag_change (void)
 
 void on_combobox_tag_genre_file_realize (GtkWidget *widget, gpointer user_data)
 {
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	infosong_set_elements_combobox (widget);
 	gtk_combo_box_set_wrap_width (GTK_COMBO_BOX (widget), 4);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
 	var_file.Adr_combobox_tag_genre = GTK_COMBO_BOX (widget);
 }
+
+#define	TAG_GENRE	0
+#define	TAG_TRACK	1
+#define	TAG_YEAR	2
+#define	TAG_COMMENT	3
+#define	TAG_ARTIST	4
+#define	TAG_ALBUM	5
+#define	TAG_TITLE	6
+
+void fileexpander_changed_all_tags (gint TYPE_TAG)
+{
+	GtkTreeIter       iter;
+	GtkTreeModel     *model = NULL;
+	GList            *begin_list = NULL;
+	GList            *list = NULL;
+	GtkTreePath      *path;
+	DETAIL           *detail = NULL;
+	TAGS		 *tags = NULL;
+
+	if (!var_file.Adr_TreeView) return;
+	if (!var_file.Adr_Tree_Model) return;
+	if (!var_file.Adr_Line_Selected) return;
+
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW(var_file.Adr_TreeView));
+	begin_list = gtk_tree_selection_get_selected_rows (var_file.Adr_Line_Selected, &model);
+	list = g_list_first (begin_list);
+	while (list) {
+		if ((path = list->data)) {
+			gtk_tree_model_get_iter (model, &iter, path);
+			gtk_tree_model_get (var_file.Adr_Tree_Model, &iter, file_get_pointer_struct (), &detail, -1);
+			
+			if ((DETAIL *)detail != NULL) {
+
+				switch (TYPE_TAG) {
+				case TAG_GENRE :
+					if ((tags = filexpander_get_tag (detail)) != NULL) {
+						g_free (tags->Genre);
+						tags->Genre = NULL;
+						tags->Genre = g_strdup ((gchar *)gtk_combo_box_get_active_text (var_file.Adr_combobox_tag_genre));
+						tags->IntGenre = infosong_get_num_combobox ((gint)gtk_combo_box_get_active (var_file.Adr_combobox_tag_genre));
+						tags_set_flag_modification (tags, TRUE);
+						filexpander_set_label_tag_change ();
+					}
+					break;
+				case TAG_TRACK :
+					if ((tags = filexpander_get_tag (detail)) != NULL) {
+						g_free (tags->Number);
+						tags->Number = NULL;
+						tags->IntNumber = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(var_file.Adr_spinbutton_tag_track));
+						tags->Number    = g_strdup_printf ("%d", tags->IntNumber);
+						tags_set_flag_modification (tags, TRUE);
+						filexpander_set_label_tag_change ();
+					}
+					break;
+				case TAG_YEAR :
+					if ((tags = filexpander_get_tag (detail)) != NULL) {
+						g_free (tags->Year);
+						tags->Year = NULL;
+						tags->IntYear = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(var_file.Adr_spinbutton_tag_year));
+						tags->Year    = g_strdup_printf ("%d", tags->IntYear);
+						tags_set_flag_modification (tags, TRUE);
+						filexpander_set_label_tag_change ();
+					}
+					break;
+				case TAG_COMMENT :
+					if ((tags = filexpander_get_tag (detail)) != NULL) {
+						g_free (tags->Comment);
+						tags->Comment = NULL;
+						tags->Comment = g_strdup ((gchar *)gtk_entry_get_text (GTK_ENTRY (var_file.Adr_entry_tag_comment)));
+						tags_set_flag_modification (tags, TRUE);
+						filexpander_set_label_tag_change ();
+					}
+					break;
+				case TAG_ARTIST :
+					if ((tags = filexpander_get_tag (detail)) != NULL) {
+						g_free (tags->Artist);
+						tags->Artist = NULL;
+						tags->Artist = g_strdup ((gchar *)gtk_entry_get_text (GTK_ENTRY (var_file.Adr_entry_tag_artist)));
+						tags_set_flag_modification (tags, TRUE);
+						filexpander_set_label_tag_change ();
+					}
+					break;
+				case TAG_ALBUM :
+					if ((tags = filexpander_get_tag (detail)) != NULL) {
+						g_free (tags->Album);
+						tags->Album = NULL;
+						tags->Album = g_strdup ((gchar *)gtk_entry_get_text (GTK_ENTRY (var_file.Adr_entry_tag_album)));
+						tags_set_flag_modification (tags, TRUE);
+						filexpander_set_label_tag_change ();
+					}
+					break;
+				case TAG_TITLE :
+					if ((tags = filexpander_get_tag (detail)) != NULL) {
+						gchar	*str = NULL;
+						gchar	*ptr = NULL;
+												
+						g_free (tags->Title);
+						tags->Title = NULL;
+						tags->Title = g_strdup ((gchar *)gtk_entry_get_text (GTK_ENTRY (var_file.Adr_entry_tag_title)));
+						
+						// Suppression du caracteres '/' interdit si il existe
+						str = g_strdup (tags->Title);
+						if (strchr (str, '/')) {
+							while ((ptr = strchr (str, '/'))) {
+								strcpy (ptr, ptr+1);
+							}
+							gtk_entry_set_text (GTK_ENTRY (var_file.Adr_entry_tag_title), str);
+						}
+						g_free (tags->Title);
+						tags->Title = NULL;
+						tags->Title = g_strdup (str);
+						g_free (str);
+						str = NULL;
+						
+						tags_set_flag_modification (tags, TRUE);
+						filexpander_set_label_tag_change ();
+					}
+					break;
+				}
+			}
+		}
+		list = g_list_next (list);
+	}
+}
+
 void on_combobox_tag_genre_file_changed (GtkEditable *editable, gpointer user_data)
 {
+/*
 	TAGS  *tags = filexpander_get_tag (NULL);
 	
 	if (!var_file.Adr_combobox_tag_genre) return;
@@ -379,9 +523,14 @@ void on_combobox_tag_genre_file_changed (GtkEditable *editable, gpointer user_da
 	tags->IntGenre = infosong_get_num_combobox ((gint)gtk_combo_box_get_active (var_file.Adr_combobox_tag_genre));
 	tags_set_flag_modification (tags, TRUE);
 	filexpander_set_label_tag_change ();
+*/
+	if (!var_file.Adr_combobox_tag_genre) return;
+	if(!filexpander_bool_changed_OK) return;
+	fileexpander_changed_all_tags (TAG_GENRE);
 }
 void on_spinbutton_tag_track_file_changed (GtkSpinButton *spinbutton, gpointer user_data)
 {
+/*
 	TAGS  *tags = filexpander_get_tag (NULL);
 	
 	if (!var_file.Adr_spinbutton_tag_track) return;
@@ -395,10 +544,14 @@ void on_spinbutton_tag_track_file_changed (GtkSpinButton *spinbutton, gpointer u
 
 	tags_set_flag_modification (tags, TRUE);
 	filexpander_set_label_tag_change ();
+*/
+	if (!var_file.Adr_spinbutton_tag_track) return;
+	if(!filexpander_bool_changed_OK) return;
+	fileexpander_changed_all_tags (TAG_TRACK);
 }
 void on_spinbutton_tag_year_file_changed (GtkSpinButton *spinbutton, gpointer user_data)
 {
-	TAGS  *tags = filexpander_get_tag (NULL);
+/*	TAGS  *tags = filexpander_get_tag (NULL);
 
 	if (!var_file.Adr_spinbutton_tag_year) return;
 	if(!filexpander_bool_changed_OK) return;
@@ -411,9 +564,14 @@ void on_spinbutton_tag_year_file_changed (GtkSpinButton *spinbutton, gpointer us
 
 	tags_set_flag_modification (tags, TRUE);
 	filexpander_set_label_tag_change ();
+*/
+	if (!var_file.Adr_spinbutton_tag_year) return;
+	if(!filexpander_bool_changed_OK) return;
+	fileexpander_changed_all_tags (TAG_YEAR);
 }
 void on_entry_tag_comment_file_changed (GtkEditable *editable, gpointer user_data)
 {
+/*
 	TAGS  *tags = filexpander_get_tag (NULL);
 	
 	if (!var_file.Adr_entry_tag_comment) return;
@@ -426,9 +584,15 @@ void on_entry_tag_comment_file_changed (GtkEditable *editable, gpointer user_dat
 	
 	tags_set_flag_modification (tags, TRUE);
 	filexpander_set_label_tag_change ();
+*/
+	
+	if (!var_file.Adr_entry_tag_comment) return;
+	if(!filexpander_bool_changed_OK) return;
+	fileexpander_changed_all_tags (TAG_COMMENT);
 }
 void on_entry_tag_artist_file_changed (GtkEditable *editable, gpointer user_data)
 {
+/*
 	TAGS  *tags = filexpander_get_tag (NULL);
 	
 	if (!var_file.Adr_entry_tag_artist) return;
@@ -441,9 +605,14 @@ void on_entry_tag_artist_file_changed (GtkEditable *editable, gpointer user_data
 	
 	tags_set_flag_modification (tags, TRUE);
 	filexpander_set_label_tag_change ();
+*/
+	if (!var_file.Adr_entry_tag_artist) return;
+	if(!filexpander_bool_changed_OK) return;
+	fileexpander_changed_all_tags (TAG_ARTIST);
 }
 void on_entry_tag_album_file_changed (GtkEditable *editable, gpointer user_data)
 {
+/*
 	TAGS  *tags = filexpander_get_tag (NULL);
 	
 	if (!var_file.Adr_entry_tag_album) return;
@@ -456,9 +625,14 @@ void on_entry_tag_album_file_changed (GtkEditable *editable, gpointer user_data)
 	
 	tags_set_flag_modification (tags, TRUE);
 	filexpander_set_label_tag_change ();
+*/
+	if (!var_file.Adr_entry_tag_album) return;
+	if(!filexpander_bool_changed_OK) return;
+	fileexpander_changed_all_tags (TAG_ALBUM);
 }
 void on_entry_tag_title_file_changed (GtkEditable *editable, gpointer user_data)
 {
+/*
 	TAGS	*tags = filexpander_get_tag (NULL);
 	gchar	*str = NULL;
 	gchar	*ptr = NULL;
@@ -471,7 +645,7 @@ void on_entry_tag_title_file_changed (GtkEditable *editable, gpointer user_data)
 	tags->Title = NULL;
 	tags->Title = g_strdup ((gchar *)gtk_entry_get_text (GTK_ENTRY (var_file.Adr_entry_tag_title)));
 	
-	/* Suppression du caracteres '/' interdit si il existe */
+	// Suppression du caracteres '/' interdit si il existe
 	str = g_strdup (tags->Title);
 	if (strchr (str, '/')) {
 		while ((ptr = strchr (str, '/'))) {
@@ -487,6 +661,10 @@ void on_entry_tag_title_file_changed (GtkEditable *editable, gpointer user_data)
 	
 	tags_set_flag_modification (tags, TRUE);
 	filexpander_set_label_tag_change ();
+*/
+	if (!var_file.Adr_entry_tag_title) return;
+	if(!filexpander_bool_changed_OK) return;
+	fileexpander_changed_all_tags (TAG_TITLE);
 }
 
 void on_button_tag_appliquer_clicked (GtkButton *button, gpointer user_data)
