@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -32,7 +32,6 @@
 
 
 #include <gtk/gtk.h>
-#include "support.h"
 
 #include <string.h>
 #include <stdlib.h>
@@ -235,7 +234,9 @@ GList *filelc_analyse_command_line (PARAM_FILELC *param_filelc, gchar *entry)
 		New = g_list_append (New, g_strdup ("-n"));
 		New = g_list_append (New, g_strdup_printf ("%d", options_get_val_nice ()));
 		// New = g_list_append (New, g_strdup_printf ("%s", PrgInit.name_mppenc));
-		New = g_list_append (New, g_strdup (prginit_get_name (NMR_mppenc)));
+		// New = g_list_append (New, g_strdup (prginit_get_name (NMR_mppenc)));
+		// New = g_list_append (New, g_strdup ("mppenc"));
+		New = g_list_append (New, g_strdup (prginit_get_name (NMR_musepack_tools_mppenc)));
 
 		filelc_analyse_line (entry, New, param_filelc->tags);
 
@@ -685,28 +686,42 @@ GList *filelc_get_command_line (PARAM_FILELC *param_filelc)
 		New = g_list_append (New, g_strdup ("-h"));
 		New = g_list_append (New, g_strdup ("--nohist"));
 		New = g_list_append (New, g_strdup ("--noreplaygain"));
+		// New = g_list_append (New, g_strdup ("-r"));
 		
-		if (param_filelc->BoolSetBitrate == TRUE) {
-			Larrbuf = g_strsplit (file_get_param_lame (), " ", 0);
+		if (param_filelc->PtrStrBitrate != NULL) {
+			Larrbuf = g_strsplit (param_filelc->PtrStrBitrate, " ", 0);
 			for (i=0; Larrbuf[i]; i++) {
 				New = g_list_append (New, g_strdup (Larrbuf[i]));
 			}
 			g_strfreev(Larrbuf);
+			g_free (param_filelc->PtrStrBitrate);
+			param_filelc->PtrStrBitrate = NULL;
 		}
 		else {
-			if ((Ptr = optionsLame_get_param_lame ()) != NULL) {
-				Larrbuf = g_strsplit (Ptr, " ", 0);
-				for (i=0; Larrbuf[i]; i++) {
-					New = g_list_append (New, g_strdup (Larrbuf[i]));
-				}
-				g_strfreev(Larrbuf);
-				
-				g_free (Ptr);
-				Ptr = NULL;
-			}
-			
+			// TO REMOVE
+			// if (param_filelc->BoolSetBitrate == TRUE) {
+			// 	Larrbuf = g_strsplit (file_get_param_lame (), " ", 0);
+			// 	for (i=0; Larrbuf[i]; i++) {
+			// 		New = g_list_append (New, g_strdup (Larrbuf[i]));
+			// 	}
+			// 	g_strfreev(Larrbuf);
+			// }
+			// else {
+			// 	if ((Ptr = optionsLame_get_param_lame ()) != NULL) {
+			// 		Larrbuf = g_strsplit (Ptr, " ", 0);
+			// 		for (i=0; Larrbuf[i]; i++) {
+			// 			New = g_list_append (New, g_strdup (Larrbuf[i]));
+			// 		}
+			// 		g_strfreev(Larrbuf);
+			// 		
+			// 		g_free (Ptr);
+			// 		Ptr = NULL;
+			// 	}
+			// 	
+			// }
 		}
-
+		
+		
 		if (conv.Bool_artist_tag || conv.Bool_title_tag || conv.Bool_album_tag ||
 		    conv.Bool_numerate_tag || conv.Bool_genre_tag || conv.Bool_year_tag || conv.Bool_comment_tag) {
 			New = g_list_append (New, g_strdup ("--add-id3v2"));
@@ -772,8 +787,8 @@ GList *filelc_get_command_line (PARAM_FILELC *param_filelc)
 			g_free (Ptr);	Ptr = NULL;
 		}
 		
-		
 		New = g_list_append (New, g_strdup (param_filelc->filesrc));
+		New = g_list_append (New, g_strdup ("-o"));
 		New = g_list_append (New, g_strdup (param_filelc->filedest));
 	}
 	else if (param_filelc->type_conv == OGGENC_WAV_TO_OGG || param_filelc->type_conv == OGGENC_FLAC_TO_OGG) {
@@ -787,20 +802,32 @@ GList *filelc_get_command_line (PARAM_FILELC *param_filelc)
 		New = g_list_append (New, g_strdup ("oggenc"));
 		New = g_list_append (New, g_strdup_printf ("%s", param_filelc->filesrc));
 		
-		if (param_filelc->type_conv == OGGENC_WAV_TO_OGG && param_filelc->BoolSetBitrate == TRUE) {
-			
-			Larrbuf = g_strsplit (file_get_param_oggenc (), " ", 0);
+		if (param_filelc->PtrStrBitrate != NULL) {
+			Larrbuf = g_strsplit (param_filelc->PtrStrBitrate, " ", 0);
 			for (i=0; Larrbuf[i]; i++) {
 				New = g_list_append (New, g_strdup (Larrbuf[i]));
 			}
 			g_strfreev(Larrbuf);
+			g_free (param_filelc->PtrStrBitrate);
+			param_filelc->PtrStrBitrate = NULL;
 		}
 		else {
-			Larrbuf = g_strsplit (optionsOggenc_get_param_oggenc (), " ", 0);
-			for (i=0; Larrbuf[i]; i++) {
-				New = g_list_append (New, g_strdup (Larrbuf[i]));
-			}
-			g_strfreev(Larrbuf);
+			// TO REMOVE
+			// if (param_filelc->type_conv == OGGENC_WAV_TO_OGG && param_filelc->BoolSetBitrate == TRUE) {
+			// 	
+			// 	Larrbuf = g_strsplit (file_get_param_oggenc (), " ", 0);
+			// 	for (i=0; Larrbuf[i]; i++) {
+			// 		New = g_list_append (New, g_strdup (Larrbuf[i]));
+			// 	}
+			// 	g_strfreev(Larrbuf);
+			// }
+			// else {
+			// 	Larrbuf = g_strsplit (optionsOggenc_get_param_oggenc (), " ", 0);
+			// 	for (i=0; Larrbuf[i]; i++) {
+			// 		New = g_list_append (New, g_strdup (Larrbuf[i]));
+			// 	}
+			// 	g_strfreev(Larrbuf);
+			// }
 		}
 
 		if (conv.Bool_artist_tag && param_filelc->tags && param_filelc->tags->Artist && *param_filelc->tags->Artist) {
@@ -833,7 +860,7 @@ GList *filelc_get_command_line (PARAM_FILELC *param_filelc)
 		}
 
 		New = g_list_append (New, g_strdup ("-o"));
-		New = g_list_append (New, g_strdup_printf ("%s", param_filelc->filedest));
+		New = g_list_append (New, g_strdup (param_filelc->filedest));
 	}
 	else if (param_filelc->type_conv == FLAC_WAV_TO_FLAC || param_filelc->type_conv == FLAC_FLAC_TO_WAV) {
 
@@ -937,7 +964,8 @@ GList *filelc_get_command_line (PARAM_FILELC *param_filelc)
 		New = g_list_append (New, g_strdup ("-n"));
 		New = g_list_append (New, g_strdup_printf ("%d", options_get_val_nice ()));
 		// New = g_list_append (New, g_strdup_printf ("%s", PrgInit.name_mppenc));
-		New = g_list_append (New, g_strdup (prginit_get_name (NMR_mppenc)));
+		// New = g_list_append (New, g_strdup (prginit_get_name (NMR_mppenc)));
+		New = g_list_append (New, g_strdup ("mppenc"));
 		New = g_list_append (New, g_strdup ("--verbose"));
 		New = g_list_append (New, g_strdup ("--overwrite"));
 		New = g_list_append (New, g_strdup_printf ("%s", optionsMusepack_get_quality_mppenc ()));
@@ -1055,6 +1083,9 @@ GList *filelc_get_command_line (PARAM_FILELC *param_filelc)
 		}
 
 		New = g_list_append (New, g_strdup_printf ("%s", param_filelc->filesrc));
+		
+		New = g_list_append (New, g_strdup ("-o"));
+		New = g_list_append (New, g_strdup_printf ("%s", param_filelc->filedest));
 	}
 	else if (param_filelc->type_conv == CDPARANOIA_CD_TO_WAV) {
 		New = g_list_append (New, g_strdup ("nice"));
@@ -1155,6 +1186,7 @@ GList *filelc_get_command_line_extract (PARAM_FILELC *param_filelc)
 		New = g_list_append (New, g_strdup ("wav"));
 		New = g_list_append (New, g_strdup ("-t"));
 		New = g_list_append (New, g_strdup (param_filelc->num_track));
+		New = g_list_append (New, g_strdup ("--no-infofile"));
 	}
 
 	return ((GList *)New);
