@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -36,7 +36,6 @@
 #endif
 
 #include <gtk/gtk.h>
-#include "support.h"
 
 #include <pthread.h>
 #include <string.h>
@@ -135,26 +134,26 @@ static void filemp3oggconv_do_conversion_file_to_mp3ogg (void *arg)
 					conv.type_conv = MPLAYER_WAV_TO_WAV;
 					conv.bool_reset_conv = TRUE;
 				GDK_THREADS_ENTER();
-					list = g_list_append (list, g_strdup ("nice"));
-					list = g_list_append (list, g_strdup ("-n"));
-					list = g_list_append (list, g_strdup_printf ("%d", options_get_val_nice ()));
-					list = g_list_append (list, g_strdup ("mplayer"));
-					list = g_list_append (list, g_strdup ("-nojoystick"));
-					list = g_list_append (list, g_strdup ("-nolirc"));
-					list = g_list_append (list, g_strdup (detail->namefile));
-					list = g_list_append (list, g_strdup ("-ao"));
-					list = g_list_append (list, g_strdup ("pcm"));
-					list = g_list_append (list, g_strdup ("-ao"));
-					list = g_list_append (list, g_strdup_printf ("pcm:file=%s", fic->destwav));
-					list = g_list_append (list, g_strdup ("-af"));
-					list = g_list_append (list, g_strdup ("channels=2"));
-					list = g_list_append (list, g_strdup ("-srate"));
-					list = g_list_append (list, g_strdup ("44100"));
-					conv.ArgConv = conv_alloc_arg (list);
+					listmplayer = g_list_append (listmplayer, g_strdup ("nice"));
+					listmplayer = g_list_append (listmplayer, g_strdup ("-n"));
+					listmplayer = g_list_append (listmplayer, g_strdup_printf ("%d", options_get_val_nice ()));
+					listmplayer = g_list_append (listmplayer, g_strdup ("mplayer"));
+					listmplayer = g_list_append (listmplayer, g_strdup ("-nojoystick"));
+					listmplayer = g_list_append (listmplayer, g_strdup ("-nolirc"));
+					listmplayer = g_list_append (listmplayer, g_strdup_printf ("%s", detail->namefile));
+					listmplayer = g_list_append (listmplayer, g_strdup ("-ao"));
+					listmplayer = g_list_append (listmplayer, g_strdup ("pcm"));
+					listmplayer = g_list_append (listmplayer, g_strdup ("-ao"));
+					listmplayer = g_list_append (listmplayer, g_strdup_printf ("pcm:file=%s", fic->destwav));
+					listmplayer = g_list_append (listmplayer, g_strdup ("-af"));
+					listmplayer = g_list_append (listmplayer, g_strdup ("channels=2"));
+					listmplayer = g_list_append (listmplayer, g_strdup ("-srate"));
+					listmplayer = g_list_append (listmplayer, g_strdup ("44100"));
+					conv.ArgConv = conv_alloc_arg (listmplayer);
 				GDK_THREADS_LEAVE();
-					conv_exec (FALSE, MPLAYER_WAV_TO_WAV, list, "MPLAYER_WAV_TO_WAV");
+					conv_exec (FALSE, MPLAYER_WAV_TO_WAV, listmplayer, "MPLAYER_WAV_TO_WAV");
 				GDK_THREADS_ENTER();
-					list = filelc_remove_glist (list);
+					listmplayer = filelc_remove_glist (listmplayer);
 					g_free (conv.ArgConv);
 					conv.ArgConv = NULL;
 				GDK_THREADS_LEAVE();
@@ -211,6 +210,7 @@ static void filemp3oggconv_do_conversion_file_to_mp3ogg (void *arg)
 					param_filelc.cdrom                = NULL;
 					param_filelc.num_track            = NULL;
 					param_filelc.BoolSetBitrate       = TRUE;
+					param_filelc.PtrStrBitrate        = options_get_params (LAME_WAV_TO_MP3, param_filelc, fic);
 
 				GDK_THREADS_ENTER();
 					list = filelc_get_command_line (&param_filelc);
@@ -237,7 +237,6 @@ static void filemp3oggconv_do_conversion_file_to_mp3ogg (void *arg)
 
 						conv_copy_src_to_dest (fic->destmp3, fic->destfile);
 
-						conv.encode_completed ++;
 						conv_remove_name_for_label (_CONV_);
 						conv.type_conv = NONE_CONV;
 					}
@@ -296,6 +295,11 @@ static void filemp3oggconv_do_conversion_file_to_mp3ogg (void *arg)
 					listmplayer = g_list_append (listmplayer, g_strdup_printf ("%s", detail->namefile));
 					listmplayer = g_list_append (listmplayer, g_strdup ("-ao"));
 					listmplayer = g_list_append (listmplayer, g_strdup_printf ("pcm:file=%s", fic->destwav));
+					
+					listmplayer = g_list_append (listmplayer, g_strdup ("-af"));
+					listmplayer = g_list_append (listmplayer, g_strdup ("channels=2"));
+					listmplayer = g_list_append (listmplayer, g_strdup ("-srate"));
+					listmplayer = g_list_append (listmplayer, g_strdup ("44100"));
 
 					conv.ArgConv = conv_alloc_arg (listmplayer);
 				GDK_THREADS_LEAVE();
@@ -327,6 +331,7 @@ static void filemp3oggconv_do_conversion_file_to_mp3ogg (void *arg)
 					param_filelc.cdrom                = NULL;
 					param_filelc.num_track            = NULL;
 					param_filelc.BoolSetBitrate       = TRUE;
+					param_filelc.PtrStrBitrate        = options_get_params (OGGENC_WAV_TO_OGG, param_filelc, fic);
 
 				GDK_THREADS_ENTER();
 					list = filelc_get_command_line (&param_filelc);
@@ -350,7 +355,6 @@ static void filemp3oggconv_do_conversion_file_to_mp3ogg (void *arg)
 
 						conv_copy_src_to_dest (fic->destogg, fic->destfile);
 
-						conv.encode_completed ++;
 						conv_remove_name_for_label (_CONV_);
 						conv.type_conv = NONE_CONV;
 					}
@@ -475,7 +479,7 @@ void filemp3oggconv_set_flags_before_conversion (void)
 
 					detail->modif = TRUE;
 
-					conv.total_convert += 2;
+					conv.total_convert += 3;
 
 					if (detail->type_infosong_file_is == FILE_IS_MP3) {
 						INFO_MP3 *info = (INFO_MP3 *)detail->info;
@@ -489,47 +493,16 @@ void filemp3oggconv_set_flags_before_conversion (void)
 						conv.total_convert ++;
 					}
 					
-
 					fic->Bool_Conv = TRUE;
 
+					fic->destwav  = g_strdup_printf ("%s/tmp.wav", conv.TmpRep);
+					fic->destsox  = g_strdup_printf ("%s/tmp_sox.wav.", conv.TmpRep);
+					fic->destmp3  = g_strdup_printf ("%s/tmp.mp3", conv.TmpRep);
+					fic->destogg  = g_strdup_printf ("%s/tmp.ogg", conv.TmpRep);
+
 					ptr = strrchr (detail->namefile, '/');
 					ptr ++;
-
-					fic->destwav  = g_strdup_printf ("%s/%s12345678", conv.TmpRep, ptr);
-					fic->destsox  = g_strdup_printf ("%s/%s12345678", conv.TmpRep, ptr);
-					fic->destmp3  = g_strdup_printf ("%s/%s12345678", conv.TmpRep, ptr);
-					fic->destogg  = g_strdup_printf ("%s/%s12345678", conv.TmpRep, ptr);
 					fic->destfile = g_strdup_printf ("%s/%s", file_make_pathname_file (detail, FALSE), ptr);
-					
-					ptr = strrchr (fic->destwav, '.');
-					ptr ++;
-					*(ptr +0) = 'w';
-					*(ptr +1) = 'a';
-					*(ptr +2) = 'v';
-					*(ptr +3) ='\0';
-
-					ptr = strrchr (fic->destsox, '.');
-					*(ptr +0) = '_';
-					*(ptr +1) = 's';
-					*(ptr +2) = '.';
-					*(ptr +3) = 'w';
-					*(ptr +4) = 'a';
-					*(ptr +5) = 'v';
-					*(ptr +6) ='\0';
-
-					ptr = strrchr (fic->destmp3, '.');
-					ptr ++;
-					*(ptr +0) = 'm';
-					*(ptr +1) = 'p';
-					*(ptr +2) = '3';
-					*(ptr +3) ='\0';
-
-					ptr = strrchr (fic->destogg, '.');
-					ptr ++;
-					*(ptr +0) = 'o';
-					*(ptr +1) = 'g';
-					*(ptr +2) = 'g';
-					*(ptr +3) ='\0';
 				}
 			}
 		}
