@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -44,9 +44,6 @@
 #include <unistd.h>
 #include <string.h>
 
-#include "interface.h"
-#include "support.h"
-
 #include "global.h"
 #include "file.h"
 #include "utils.h"
@@ -69,6 +66,7 @@
 
 typedef struct {
 	GtkWidget	*AdrWin;
+	gboolean	 Bool;
 	GtkWidget	*AdrLabelTitre;
 	GtkWidget	*AdrLabelCompteur;
 	GtkWidget	*AdrProgressBar;
@@ -102,22 +100,24 @@ VAR_FILEWAVCONF VarFilewavconv;
 *---------------------------------------------------------------------------
 */
 
+void filewavconv_quit (void)
+{
+	NEW_wincontrol_realize_window (&VarFilewavconv.AdrWin, "wind_wav_to_wav", &VarFilewavconv.Bool, WIND_IS_SHOW, WIND_USE_STRUCT, WIND_IS_MODAL, WIND_IS_TRANSIENT);
+}
+
 gboolean filewavconv_delete_event (void)
 {
-	gtk_widget_destroy(VarFilewavconv.AdrWin);
-	wincontrol_remove_last ();
-	return (FALSE);
+	filewavconv_quit ();
+	return TRUE;
 }
 gboolean filewavconv_destroy_event (void)
 {
-	gtk_widget_destroy(VarFilewavconv.AdrWin);
-	wincontrol_remove_last ();
-	return (FALSE);
+	filewavconv_quit ();
+	return TRUE;
 }
 void filewavconv_stop_wav_to_wav_clicked (void)
 {
-	gtk_widget_destroy(VarFilewavconv.AdrWin);
-	wincontrol_remove_last ();
+	filewavconv_quit ();
 }
 
 static void filewavconv_thread (void *arg)
@@ -197,6 +197,10 @@ static void filewavconv_thread (void *arg)
 					listmplayer = g_list_append (listmplayer, g_strdup ("-n"));
 					listmplayer = g_list_append (listmplayer, g_strdup (conv.valuenice));
 					listmplayer = g_list_append (listmplayer, g_strdup ("mplayer"));
+					
+					listmplayer = g_list_append (listmplayer, g_strdup ("-nojoystick"));
+					listmplayer = g_list_append (listmplayer, g_strdup ("-nolirc"));
+
 					listmplayer = g_list_append (listmplayer, g_strdup (FicWav->TmpSrc));
 					listmplayer = g_list_append (listmplayer, g_strdup ("-ao"));
 					listmplayer = g_list_append (listmplayer, g_strdup ("pcm"));
@@ -408,11 +412,17 @@ static gint filewavconv_timeout (gpointer data)
 	if (VarFilewavconv.BoolMplayer == TRUE) {
     		
     		gchar *spinner="|/-\\";
+		gchar  foo [ 2 ];
 		
- 		g_free (VarFilewavconv.Mess);
- 		VarFilewavconv.Mess = NULL;
-		VarFilewavconv.Mess = g_strdup_printf (_("Traitement Mplayer:   %c   %d%%"),
-						spinner[VarFilewavconv.PassMplayer++%4],
+		foo [ 0 ] = spinner[VarFilewavconv.PassMplayer++%4];
+		foo [ 1 ] = '\0';
+    		
+ 		if (VarFilewavconv.Mess != NULL) {
+ 			g_free (VarFilewavconv.Mess);
+ 			VarFilewavconv.Mess = NULL;
+ 		}
+		VarFilewavconv.Mess = g_strdup_printf (_("Traitement Mplayer:   %s   %d%%"),
+						foo,
 						(gint)(conv.conversion_percent * 100));
 		filewavconv_puts_statusbar (VarFilewavconv.Mess);
  		g_free (VarFilewavconv.Mess);
@@ -421,8 +431,7 @@ static gint filewavconv_timeout (gpointer data)
 	
 	if (conv.bool_thread_conv == FALSE) {
 		gtk_timeout_remove (conv.handler_timeout_conv);
-		gtk_widget_destroy(VarFilewavconv.AdrWin);
-		wincontrol_remove_last ();	
+		filewavconv_quit ();
 
 		/* mise a jour des champs de 'EnteteWav.glist' */
 		file_update_glist_wav ();
@@ -547,26 +556,17 @@ void filewavconv_apply (void)
 
 	PRINT_FUNC_LF();
 
-	VarFilewavconv.AdrWin =  create_wind_wav_to_wav ();
-	wincontrol_set_adr (
-		VarFilewavconv.AdrWin,		/* Window adress                */
-		"wav_to_wav",			/* Window name			*/
-		TRUE,				/* gtk_window_set_transient_for */
-		TRUE				/* gtk_window_set_modal         */
-		);
-	
-	VarFilewavconv.AdrLabelTitre    = GTK_WIDGET (lookup_widget (VarFilewavconv.AdrWin, "label_wav_to_wav"));
-	VarFilewavconv.AdrLabelCompteur = GTK_WIDGET (lookup_widget (VarFilewavconv.AdrWin, "label_compteur_wav_to_wav"));
-	VarFilewavconv.AdrProgressBar   = GTK_WIDGET (lookup_widget (VarFilewavconv.AdrWin, "progressbar_wav_to_wav"));
+	NEW_wincontrol_realize_window (&VarFilewavconv.AdrWin, "wind_wav_to_wav", &VarFilewavconv.Bool, WIND_IS_SHOW, WIND_USE_STRUCT, WIND_IS_MODAL, WIND_IS_TRANSIENT);
+
+	VarFilewavconv.AdrLabelTitre    = GTK_WIDGET (XCFA_GET_OBJECT("label_wav_to_wav"));
+	VarFilewavconv.AdrLabelCompteur = GTK_WIDGET (XCFA_GET_OBJECT("label_compteur_wav_to_wav"));
+	VarFilewavconv.AdrProgressBar   = GTK_WIDGET (XCFA_GET_OBJECT("progressbar_wav_to_wav"));
 
 	gtk_label_set_use_markup (GTK_LABEL (VarFilewavconv.AdrLabelTitre), TRUE);
 	gtk_label_set_justify (GTK_LABEL (VarFilewavconv.AdrLabelTitre), GTK_JUSTIFY_CENTER);
 	gtk_label_set_markup (GTK_LABEL (VarFilewavconv.AdrLabelTitre),
 			"<span font_desc=\"Courier bold 11\"><span color=\"black\"><b>Conversions WAV TO WAV</b></span></span>");
 	
-	utils_set_default_icone_xcfa (VarFilewavconv.AdrWin);
-	gtk_widget_show_all (VarFilewavconv.AdrWin);
-	
 	conv_reset_struct ();
 	filewavconv_set_flags_before ();
 
