@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -36,7 +36,7 @@
 #endif
 
 #include <gtk/gtk.h>
-#include "support.h"
+
 #include <stdlib.h>
 #include <string.h>
 
@@ -101,21 +101,19 @@ void ON_button_PATH_DESTINATION_DVD_clicked (GtkButton *button, gpointer user_da
 void ON_button_PATH_DESTINATION_FILE_clicked (GtkButton *button, gpointer user_data);
 void ON_button_PATH_DESTINATION_FILE_WAV_clicked (GtkButton *button, gpointer user_data);
 void ON_button_PATH_DESTINATION_FILE_MP3OGG_clicked (GtkButton *button, gpointer user_data);
-
 void ON_button_PATH_DESTINATION_SPLIT_clicked (GtkButton *button, gpointer user_data);
-
 void ON_button_LOAD_FILE_clicked (GtkButton *button, gpointer user_data);
 void ON_button_PATH_IMPORT_FILE_WAV_clicked (GtkButton *button, gpointer user_data);
 void ON_button_PATH_IMPORT_FILE_MP3OGG_clicked (GtkButton *button, gpointer user_data);
 void ON_button_PATH_IMPORT_FILE_SPLIT_clicked (GtkButton *button, gpointer user_data);
 void ON_button_PATH_IMPORT_IMAGES_clicked (GtkButton *button, gpointer user_data);
-
 void ON_button_PATH_STOCKE_IMAGES_POCHETTE_clicked (GtkButton *button, gpointer user_data);
 void ON_button_PATH_DEST_FILE_POSTSCRIPT_clicked (GtkButton *button, gpointer user_data);
 void ON_button_PATH_LOAD_DVD_FROM_DIRECTORY_clicked (GtkButton *button, gpointer user_data);
-
 void ON_button_PATH_TEMP_clicked (GtkButton *button, gpointer user_data);
 
+void ON_button_PATH_DEST_JOURNAL_clicked (GtkButton *button, gpointer user_data);
+
 /*
 *---------------------------------------------------------------------------
 * DATAS
@@ -169,6 +167,9 @@ SELECT Select [ ] =
 {NULL,
  &Config_User.Path_TMP,				_REP_SIMPLE_,		NULL, ON_button_PATH_TEMP_clicked,			NULL},
 
+{NULL,
+ &Config_User.Path_Dest_Journal,		_REP_SIMPLE_,		NULL, ON_button_PATH_DEST_JOURNAL_clicked,		NULL},
+ 
 {NULL, NULL, -1}
 };
 
@@ -228,6 +229,22 @@ GList *fileselect_get_glist (void)
 * FUNCTIONS
 *---------------------------------------------------------------------------
 */
+void ON_button_PATH_DEST_JOURNAL_clicked (GtkButton *button, gpointer user_data)
+{
+	gint    Choice = GPOINTER_TO_INT(user_data);
+	gchar  *Path = NULL;
+
+	/* PRINT_FUNC_LF(); */
+
+	Path = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (Select[ Choice ].AdrFileChooser));
+wincontrol_remove_last ();
+	if (Select[ Choice ].Func_Extern) (*Select[ Choice ].Func_Extern) (Path);
+	g_free (Path);
+	Path = NULL;
+
+	gtk_widget_destroy(Select[ Choice ].AdrFileChooser);
+	Select[ Choice ].AdrFileChooser = NULL;
+}
 void ON_button_PATH_TEMP_clicked (GtkButton *button, gpointer user_data)
 {
 	gint    Choice = GPOINTER_TO_INT(user_data);
@@ -762,6 +779,7 @@ void fileselect_init_comment (void)
 	Select[ _PATH_DEST_FILE_POSTSCRIPT_ ].Title	= g_strdup (_("Repertoire de stockage des images pochette"));
 	Select[ _PATH_LOAD_DVD_FROM_DIRECTORY_ ].Title	= g_strdup (_("Importer un dossier contenant un DVD"));
 	Select[ _PATH_TEMP_ ].Title			= g_strdup (_("Choix d'un dossier temporaire"));
+	Select[ _PATH_DEST_JOURNAL_ ].Title		= g_strdup (_("Choix d'un dossier pour le journal"));
 
 }
 
@@ -835,7 +853,7 @@ void fileselect_create (TYPE_FILESELECTION Choice, void *Func_Extern)
 		if (Choice == _PATH_IMPORT_FILE_WAV_) {
 		
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("WAV (*.wav)"));
+			gtk_file_filter_set_name (filter, "WAV (*.wav)");
 			gtk_file_filter_add_pattern (filter, "*.wav");
 			gtk_file_filter_add_pattern (filter, "*.WAV");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
@@ -849,7 +867,7 @@ void fileselect_create (TYPE_FILESELECTION Choice, void *Func_Extern)
 		else if (Choice == _PATH_IMPORT_FILE_MP3OGG_) {
 		
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("All Files (*.*)"));
+			gtk_file_filter_set_name (filter, "All Files (*.*)");
 			gtk_file_filter_add_pattern (filter, "*.mp3");
 			gtk_file_filter_add_pattern (filter, "*.MP3");
 			gtk_file_filter_add_pattern (filter, "*.ogg");
@@ -858,13 +876,13 @@ void fileselect_create (TYPE_FILESELECTION Choice, void *Func_Extern)
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("MP3 (*.mp3)"));
+			gtk_file_filter_set_name (filter, "MP3 (*.mp3)");
 			gtk_file_filter_add_pattern (filter, "*.mp3");
 			gtk_file_filter_add_pattern (filter, "*.MP3");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("OGG (*.ogg)"));
+			gtk_file_filter_set_name (filter, "OGG (*.ogg)");
 			gtk_file_filter_add_pattern (filter, "*.ogg");
 			gtk_file_filter_add_pattern (filter, "*.OGG");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
@@ -891,13 +909,43 @@ void fileselect_create (TYPE_FILESELECTION Choice, void *Func_Extern)
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("WAV (*.wav)"));
+			gtk_file_filter_set_name (filter, "WAV (*.wav)");
 			gtk_file_filter_add_pattern (filter, "*.wav");
 			gtk_file_filter_add_pattern (filter, "*.WAV");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 			
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("CUE (*.cue)"));
+			gtk_file_filter_set_name (filter, "MP3 (*.mp3)");
+			gtk_file_filter_add_pattern (filter, "*.mp3");
+			gtk_file_filter_add_pattern (filter, "*.MP3");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
+
+			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, "OGG (*.ogg)");
+			gtk_file_filter_add_pattern (filter, "*.ogg");
+			gtk_file_filter_add_pattern (filter, "*.OGG");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
+			
+			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, "FLAC (*.flac)");
+			gtk_file_filter_add_pattern (filter, "*.flac");
+			gtk_file_filter_add_pattern (filter, "*.FLAC");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
+			
+			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, "SHN (*.shn)");
+			gtk_file_filter_add_pattern (filter, "*.shn");
+			gtk_file_filter_add_pattern (filter, "*.SHN");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
+			
+			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, "WV (*.wv)");
+			gtk_file_filter_add_pattern (filter, "*.wv");
+			gtk_file_filter_add_pattern (filter, "*.WV");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
+			
+			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, "CUE (*.cue)");
 			gtk_file_filter_add_pattern (filter, "*.cue");
 			gtk_file_filter_add_pattern (filter, "*.CUE");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
@@ -906,6 +954,14 @@ void fileselect_create (TYPE_FILESELECTION Choice, void *Func_Extern)
 		else {
 			filter = gtk_file_filter_new ();
 			gtk_file_filter_set_name (filter, _("All Files (*.*)"));
+			gtk_file_filter_add_pattern (filter, "*.rm");
+			gtk_file_filter_add_pattern (filter, "*.RM");
+			gtk_file_filter_add_pattern (filter, "*.dts");
+			gtk_file_filter_add_pattern (filter, "*.DTS");
+			gtk_file_filter_add_pattern (filter, "*.aif");
+			gtk_file_filter_add_pattern (filter, "*.aiff");
+			gtk_file_filter_add_pattern (filter, "*.AIF");
+			gtk_file_filter_add_pattern (filter, "*.AIFF");
 			gtk_file_filter_add_pattern (filter, "*.shn");
 			gtk_file_filter_add_pattern (filter, "*.SHN");
 			gtk_file_filter_add_pattern (filter, "*.wma");
@@ -934,67 +990,85 @@ void fileselect_create (TYPE_FILESELECTION Choice, void *Func_Extern)
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("SHORTEN (*.shn)"));
+			gtk_file_filter_set_name (filter, "AIFF (*.aif*)");
+			gtk_file_filter_add_pattern (filter, "*.aif*");
+			gtk_file_filter_add_pattern (filter, "*.AIF*");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
+
+			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, "RM (*.rm)");
+			gtk_file_filter_add_pattern (filter, "*.rm");
+			gtk_file_filter_add_pattern (filter, "*.RM");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
+
+			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, "DTS (*.dts)");
+			gtk_file_filter_add_pattern (filter, "*.dts");
+			gtk_file_filter_add_pattern (filter, "*.DTS");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
+
+			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, "SHORTEN (*.shn)");
 			gtk_file_filter_add_pattern (filter, "*.shn");
 			gtk_file_filter_add_pattern (filter, "*.SHN");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("WMA (*.wma)"));
+			gtk_file_filter_set_name (filter, "WMA (*.wma)");
 			gtk_file_filter_add_pattern (filter, "*.wma");
 			gtk_file_filter_add_pattern (filter, "*.WMA");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("MP3 (*.mp3)"));
+			gtk_file_filter_set_name (filter, "MP3 (*.mp3)");
 			gtk_file_filter_add_pattern (filter, "*.mp3");
 			gtk_file_filter_add_pattern (filter, "*.MP3");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("MPC (*.mpc)"));
+			gtk_file_filter_set_name (filter, "MPC (*.mpc)");
 			gtk_file_filter_add_pattern (filter, "*.mpc");
 			gtk_file_filter_add_pattern (filter, "*.MPC");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("M4A (*.m4a)"));
+			gtk_file_filter_set_name (filter, "M4A (*.m4a)");
 			gtk_file_filter_add_pattern (filter, "*.m4a");
 			gtk_file_filter_add_pattern (filter, "*.M4A");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 			
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("AAC (*.aac)"));
+			gtk_file_filter_set_name (filter, "AAC (*.aac)");
 			gtk_file_filter_add_pattern (filter, "*.aac");
 			gtk_file_filter_add_pattern (filter, "*.AAC");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("OGG (*.ogg)"));
+			gtk_file_filter_set_name (filter, "OGG (*.ogg)");
 			gtk_file_filter_add_pattern (filter, "*.ogg");
 			gtk_file_filter_add_pattern (filter, "*.OGG");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("WAVPACK (*.wv)"));
+			gtk_file_filter_set_name (filter, "WAVPACK (*.wv)");
 			gtk_file_filter_add_pattern (filter, "*.wv");
 			gtk_file_filter_add_pattern (filter, "*.WV");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("APE (*.ape)"));
+			gtk_file_filter_set_name (filter, "APE (*.ape)");
 			gtk_file_filter_add_pattern (filter, "*.ape");
 			gtk_file_filter_add_pattern (filter, "*.APE");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("FLAC (*.flac)"));
+			gtk_file_filter_set_name (filter, "FLAC (*.flac)");
 			gtk_file_filter_add_pattern (filter, "*.flac");
 			gtk_file_filter_add_pattern (filter, "*.FLAC");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 
 			filter = gtk_file_filter_new ();
-			gtk_file_filter_set_name (filter, _("WAV (*.wav)"));
+			gtk_file_filter_set_name (filter, "WAV (*.wav)");
 			gtk_file_filter_add_pattern (filter, "*.wav");
 			gtk_file_filter_add_pattern (filter, "*.WAV");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
