@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -33,7 +33,6 @@
 
 
 #include <gtk/gtk.h>
-#include "support.h"
 
 #include <pthread.h>
 #include <sys/types.h>
@@ -101,6 +100,8 @@ gint get_exec_with_output (gchar **args, pid_t *p, gint Streams)
 	if ((*p = fork()) == 0)
 	{
 		dup2 (get.tube [ 1 ], Streams); /* STDOUT_FILENO STDERR_FILENO */
+		// TODO: close (get.tube [ 1 ]);
+		close (get.tube [ 1 ]);
 		execvp (args[0], args);
 		fprintf (stderr, "error: exec");
 		exit (2);
@@ -175,6 +176,48 @@ GString *get_with_file (gchar *file)
 	return (gstr);
 }
 
+
+gchar *get_set_cpu_info (void)
+{	
+	gchar	 buf [ GET_MAX_CARS + 10 ];
+	FILE	*fp;
+	gchar	*Ptr = NULL;
+	
+	fp = fopen ("/proc/cpuinfo", "r");
+	while (fgets (buf,  GET_MAX_CARS, fp) != NULL) {
+		// g_print("BUF = %s", buf);
+		Ptr = buf;
+		if (*(Ptr + 0) == 'm' &&
+		    *(Ptr + 1) == 'o' &&
+		    *(Ptr + 2) == 'd' &&
+		    *(Ptr + 3) == 'e' &&
+		    *(Ptr + 4) == 'l' &&
+		    *(Ptr + 5) == ' ' &&
+		    *(Ptr + 6) == 'n' &&
+		    *(Ptr + 7) == 'a' &&
+		    *(Ptr + 8) == 'm' &&
+		    *(Ptr + 9) == 'e'
+		    
+		) {
+			// g_print("---------BUF = %s", buf);
+			
+			Ptr = buf;
+			while (*Ptr ++)
+				if (*Ptr == '\n') *Ptr = '\0';
+			for ( Ptr = buf; *Ptr != ':'; Ptr ++ );
+			Ptr ++;
+			while (*Ptr == ' ') Ptr ++;
+			// g_print("---------BUF = %s", Ptr);
+			
+			fclose (fp);
+			return (g_strdup (Ptr));
+		}
+	}
+	fclose (fp);
+	return (NULL);
+}
+	
+
 GString *get_with_faad (gchar *file)
 {
 	gint     fd;
@@ -814,7 +857,7 @@ SHNTAG *get_with_shntool (gchar *file)
 
 	/*
 	g_print ("!-----------------------------------!\n");
-	g_print ("!         M E T A F L A C           !\n");
+	g_print ("!          S H N T O O L            !\n");
 	g_print ("!-----------------------------------!\n");
 	for (pos = 0; args[ pos ] != NULL; pos++)
 		g_print ("args [ %02d ] = '%s'\n", pos, args [ pos ]);
