@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -40,8 +40,6 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 
-#include "support.h"
-
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -96,7 +94,7 @@ void help_file_enter_notify_event (GtkWidget *widget)
 
 	for (cpt = 0; cpt < MAX_TYPE_BUTTON_ENTER_NOTIFY_FILE; cpt ++) {
 
-		if (widget == GTK_WIDGET (lookup_widget (wind_main, "eventbox_combobox_normalise_file"))) {
+		if (widget == GTK_WIDGET (XCFA_GET_OBJECT("eventbox_combobox_normalise_file"))) {
 
 			gint value = gtk_combo_box_get_active (GTK_COMBO_BOX (var_file.AdrComboboxNormalise));
 
@@ -120,7 +118,7 @@ void help_file_enter_notify_event (GtkWidget *widget)
 				return;
 			}
 		}
-		else if (widget == GTK_WIDGET (lookup_widget (wind_main, TypeButton [ cpt ].widget))) {
+		else if (widget == GTK_WIDGET (XCFA_GET_OBJECT(TypeButton [ cpt ].widget))) {
 			utils_puts_statusbar_global (TypeButton [ cpt ].def);
 			break;
 		}
@@ -149,7 +147,7 @@ void help_dvdaudio_enter_notify_event (GtkWidget *widget)
 	gint cpt;
 
 	for (cpt = 0; cpt < MAX_TYPE_BUTTON_ENTER_NOTIFY_DVD; cpt ++) {
-		if (widget == GTK_WIDGET (lookup_widget (wind_main, "eventbox_combobox_normalise_dvd"))) {
+		if (widget == GTK_WIDGET (XCFA_GET_OBJECT("eventbox_combobox_normalise_dvd"))) {
 
 			gint value = gtk_combo_box_get_active (GTK_COMBO_BOX (var_dvdaudio.Adr_combobox_normalise_dvd));
 
@@ -167,7 +165,7 @@ void help_dvdaudio_enter_notify_event (GtkWidget *widget)
 				return;
 			}
 		}
-		else if (widget == GTK_WIDGET (lookup_widget (wind_main, TypeButton [ cpt ].widget))) {
+		else if (widget == GTK_WIDGET (XCFA_GET_OBJECT(TypeButton [ cpt ].widget))) {
 			utils_puts_statusbar_global (TypeButton [ cpt ].def);
 			break;
 		}
@@ -208,7 +206,7 @@ void help_cdaudio_enter_notify_event (GtkWidget *widget)
 	gint cpt;
 
 	for (cpt = 0; cpt < MAX_TYPE_BUTTON_ENTER_NOTIFY_CD; cpt ++) {
-		if (widget == GTK_WIDGET (lookup_widget (wind_main, "eventbox_combobox_normalise_cd"))) {
+		if (widget == GTK_WIDGET (XCFA_GET_OBJECT("eventbox_combobox_normalise_cd"))) {
 
 			gint value = gtk_combo_box_get_active (GTK_COMBO_BOX (var_cd.Adr_combobox_normalise_cd));
 
@@ -227,7 +225,7 @@ void help_cdaudio_enter_notify_event (GtkWidget *widget)
 			}
 
 		}
-		else if (widget == GTK_WIDGET (lookup_widget (wind_main, TypeButton [ cpt ].widget))) {
+		else if (widget == GTK_WIDGET (XCFA_GET_OBJECT(TypeButton [ cpt ].widget))) {
 			utils_puts_statusbar_global (TypeButton [ cpt ].def);
 			break;
 		}
@@ -250,12 +248,12 @@ void help_pocheevnt_enter_notify_event (GtkWidget *widget)
 	{"eventbox_combobox_zoom_choiximage",		_("Choisir le zoom")},
 	{"button_load_choiximage",			_("Importer des images")},
 	{"togglebutton_remove",				_("Nettoyer les images importees")},	
+	{"entry_web_search",				_("Saisie de recherche")},
 	{"button_get_from_web",				_("Importer depuis le Net des images")},
 	{"button_get_title_cdaudio",			_("Importation du titre du cd-audio")},
 	{"spinbutton_zoom_recto",			_("Choix de la taille de l'image au recto")},
 	{"spinbutton_zoom_verso",			_("Choix de la taille de l'image au verso")},
 	{"button_path_image_preview",			_("Lieu de stockage des images")},
-	{"checkbutton_load_images_init_xcfa",		_("Chargement d'images au lancement d'Xcfa")},
 	{"entry_titre_ps",				_("Le titre de la pochette")},
 	{"entry_foottext_ps",				_("Le pied de page de la pochette")},
 	{"eventbox_combobox_text_recto",		_("Disposition du texte au recto de la pochette")},
@@ -270,7 +268,7 @@ void help_pocheevnt_enter_notify_event (GtkWidget *widget)
 	gint cpt;
 
 	for (cpt = 0; cpt < MAX_TYPE_BUTTON_ENTER_NOTIFY_POCHETTE; cpt ++) {
-		if (widget == GTK_WIDGET (lookup_widget (wind_main, TypeButton [ cpt ].widget))) {
+		if (widget == GTK_WIDGET (XCFA_GET_OBJECT(TypeButton [ cpt ].widget))) {
 			utils_puts_statusbar_global (TypeButton [ cpt ].def);
 			break;
 		}
@@ -283,14 +281,10 @@ void help_prgextern_enter_notify_event (GtkWidget *widget)
 		gchar  *widget;
 		gchar  *def;
 	} TYPE_BUTTON;
-	#define MAX_TYPE_BUTTON_ENTER_NOTIFY_PRGEXT 15
+	#define MAX_TYPE_BUTTON_ENTER_NOTIFY_PRGEXT 11
 	TYPE_BUTTON TypeButton [ MAX_TYPE_BUTTON_ENTER_NOTIFY_PRGEXT ] = {
 	{"button_scan",					_("Recherche si tous les logiciels tiers sont installes")},
 	{"button_scan_without_deb",			_("Recherche si tous les logiciels tiers sont installes")},
-	{"radiobutton_install_aptget",			_("L'installation se fera par apt-get")},
-	{"radiobutton_install_aptitude",		_("L'installation se fera par aptitude")},
-	{"button_selection_globale_InstallSimple",	_("Selection globale des applications")},
-	{"button_goto_install_InstallSimple",		_("Installation des applications")},
 	{"button_add_navigator",			_("Ajouter un navigateur de fichiers")},
 	{"entry_name_navigator",			_("Saisie du nom d'un navigateur de fichiers")},
 	{"button_del_navigator",			_("Supprimer un navigateur de fichiers")},
@@ -304,7 +298,7 @@ void help_prgextern_enter_notify_event (GtkWidget *widget)
 	gint cpt;
 
 	for (cpt = 0; cpt < MAX_TYPE_BUTTON_ENTER_NOTIFY_PRGEXT; cpt ++) {
-		if (widget == GTK_WIDGET (lookup_widget (wind_main, TypeButton [ cpt ].widget))) {
+		if (widget == GTK_WIDGET (XCFA_GET_OBJECT(TypeButton [ cpt ].widget))) {
 			utils_puts_statusbar_global (TypeButton [ cpt ].def);
 			break;
 		}
@@ -317,13 +311,14 @@ void help_options_enter_notify_event (GtkWidget *widget)
 		gchar  *widget;
 		gchar  *def;
 	} TYPE_BUTTON;
-	#define MAX_TYPE_BUTTON_ENTER_NOTIFY_OPTIONS 69
+	#define MAX_TYPE_BUTTON_ENTER_NOTIFY_OPTIONS 76
 	TYPE_BUTTON TypeButton [ MAX_TYPE_BUTTON_ENTER_NOTIFY_OPTIONS ] = {
 
 	/* General */
 	{"eventbox_combobox_nice",				_("Priorite systeme de: 0 (fort) a 19 (faible)")},
 	{"checkbutton_pos_onglets",				_("Cochez ce bouton pour une restitution du contexte")},
 	{"button_dossier_de_conversion",			_("Choix du dossier des conversions")},
+	{"button_dossier_journal",				_("Choix du dossier pour le journal")},
 
 	/* CD */
 	{"radiobutton_cdparanoia",				_("Lecture base cd-audio avec cdparanoia")},
@@ -334,7 +329,7 @@ void help_options_enter_notify_event (GtkWidget *widget)
 	{"entry_stockage_cdaudio",				_("Definition du nom de dossier de stockage")},
 	{"button_WebCdparanoia_homepage",			_("Site officiel de cdparanoia")},
 	{"button_WebCdparanoia_manpage",			_("Manuel de cdparanoia")},
-
+	
 	/* Lame */
 	{"eventbox_combobox_lame_bitrate",			_("Choix du type d'encodage")},
 	{"eventbox_combobox_lame_abr_cbr_vbr",			_("Choix du debit")},
@@ -344,7 +339,8 @@ void help_options_enter_notify_event (GtkWidget *widget)
 	{"button_WebLame_wikimp3",				_("Wiki mp3")},
 	{"button_WebLame_wikilame",				_("Wiki Lame")},
 	{"entry_lame_mp3",					_("Possibilite de saisie d'options pour Lame")},
-
+	{"button_WebLame_manpage",				_("Manuel de lame")},
+	
 	/* Oggenc */
 	{"eventbox_combobox_oggenc_bitrate",			_("Debit")},
 	{"eventbox_combobox_oggenc_managed",			_("Flux")},
@@ -353,14 +349,16 @@ void help_options_enter_notify_event (GtkWidget *widget)
 	{"button_WebOggenc_wiki",				_("Wiki Oggenc")},
 	{"button_WebOggenc_manpage",				_("Manuel Oggenc")},
 	{"entry_oggenc_ogg",					_("Possibilite de saisie d'options pour Oggenc")},
-
+	{"button_WebOggenc_manpage",				_("Manuel de oggenc")},
+	
 	/* Flac */
 	{"eventbox_flac_compression",				_("Choix du taux de compression")},
 	{"button_defaut_flac",					_("Options par defaut")},
 	{"button_WebFlac_homepage",				_("Site officiel Flac")},
 	{"button_WebFlac_framasoft",				_("Description de Flac chez Framasoft")},
 	{"entry_flac_flac",					_("Possibilite de saisie d'options pour Flac")},
-
+	{"button_WebFlac_manpage",				_("Manuel de flac")},
+	
 	/* Mac */
 	{"eventbox_combobox_ape_compression",			_("Choix du taux de compression")},
 	{"button_defaut_mac",					_("Options par defaut")},
@@ -378,7 +376,8 @@ void help_options_enter_notify_event (GtkWidget *widget)
 	{"button_defaut_wavpack",				_("Options par defaut")},
 	{"button_WebFlac_wiki",					_("Wiki Wavpack")},
 	{"entry_wavpack_wv",					_("Possibilite de saisie d'options pour Wavpack")},
-
+	{"button_WavPack_manpage",				_("Manuel de wavpack")},
+	
 	/* MusePack */
 	{"eventbox_combobox_mppenc",				_("Choix du taux de compression")},
 	{"button_defaut_musepack",				_("Options par defaut")},
@@ -395,13 +394,15 @@ void help_options_enter_notify_event (GtkWidget *widget)
 	{"button_faac_homepage",				_("Site officiel Faac")},
 	{"button_faac_web_info",				_("Diverses informations Faac")},
 	{"entry_faac_m4a",					_("Possibilite de saisie d'options pour Faac")},
+	{"button_faac_manpage",					_("Manuel de faac")},
 
-	/* Faac */
+	/* Aacplusenc */
 	{"eventbox_combobox_accplusenc_stereo",			_("Choix bitrate si le fichier source est en stereo")},
 	{"eventbox_combobox_accplusenc_mono",			_("Choix bitrate si le fichier source est en mono")},
-
 	{"button_aacplusenc_homepage",				_("Site officiel AacPlusEnc")},
 	{"button_aacplusenc_web_info",				_("Wiki AacPlusEnc")},
+	{"button_aacplusenc_manpage",				_("Manuel de aacplusenc")},
+	
 	/* Tags */
 	{"checkbutton_artist_tag",				_("Validation du tag Artiste")},
 	{"checkbutton_title_tag",				_("Validation du tag Titre")},
@@ -413,11 +414,34 @@ void help_options_enter_notify_event (GtkWidget *widget)
 
 	};
 	gint cpt;
-
-	for (cpt = 0; cpt < MAX_TYPE_BUTTON_ENTER_NOTIFY_OPTIONS; cpt ++) {
-		if (widget == GTK_WIDGET (lookup_widget (wind_main, TypeButton [ cpt ].widget))) {
-			utils_puts_statusbar_global (TypeButton [ cpt ].def);
-			break;
+	
+	if (widget == GTK_WIDGET (XCFA_GET_OBJECT("button_WebCdparanoia_manpage")) && utils_scan_by_which ("cdparanoia", NULL) == FALSE) {
+		utils_puts_statusbar_global (_("CDPARANOIA absent"));
+	}
+	else if (widget == GTK_WIDGET (XCFA_GET_OBJECT("button_WebLame_manpage")) && utils_scan_by_which ("lame", NULL) == FALSE) {
+		utils_puts_statusbar_global (_("LAME absent"));
+	}
+	else if (widget == GTK_WIDGET (XCFA_GET_OBJECT("button_WebOggenc_manpage")) && utils_scan_by_which ("oggenc", NULL) == FALSE) {
+		utils_puts_statusbar_global (_("OGGENC absent"));
+	}
+	else if (widget == GTK_WIDGET (XCFA_GET_OBJECT("button_WebFlac_manpage")) && utils_scan_by_which ("flac", NULL) == FALSE) {
+		utils_puts_statusbar_global (_("FLAC absent"));
+	}
+	else if (widget == GTK_WIDGET (XCFA_GET_OBJECT("button_WavPack_manpage")) && utils_scan_by_which ("wavpack", NULL) == FALSE) {
+		utils_puts_statusbar_global (_("WAVPACK absent"));
+	}
+	else if (widget == GTK_WIDGET (XCFA_GET_OBJECT("button_faac_manpage")) && utils_scan_by_which ("faac", NULL) == FALSE) {
+		utils_puts_statusbar_global (_("FAAC absent"));
+	}
+	else if (widget == GTK_WIDGET (XCFA_GET_OBJECT("button_aacplusenc_manpage")) && utils_scan_by_which ("aacplusenc", NULL) == FALSE) {
+		utils_puts_statusbar_global (_("AACPLUSENC absent"));
+	}
+	else {
+		for (cpt = 0; cpt < MAX_TYPE_BUTTON_ENTER_NOTIFY_OPTIONS; cpt ++) {
+			if (widget == GTK_WIDGET (XCFA_GET_OBJECT(TypeButton [ cpt ].widget))) {
+				utils_puts_statusbar_global (TypeButton [ cpt ].def);
+				break;
+			}
 		}
 	}
 }
@@ -447,7 +471,7 @@ void help_split_enter_notify_event (GtkWidget *widget)
 	gint cpt;
 
 	/*
-	if (widget == GTK_WIDGET (lookup_widget (wind_main, "button_ajouter_tache_split"))) {
+	if (widget == GTK_WIDGET (XCFA_GET_OBJECT("button_ajouter_tache_split"))) {
 
 		gchar *Str = NULL;
 
@@ -470,23 +494,23 @@ void help_split_enter_notify_event (GtkWidget *widget)
 	}
 	*/
 
-	if (widget == GTK_WIDGET (lookup_widget (wind_main, "button_action_split")) && PrgInit.bool_wavsplit == FALSE) {
-		gchar *Str = g_strdup_printf (_("wavsplit NOT FOUND / ABSENT :: %s"), TypeButton [ 5 ].def);
+	if (widget == GTK_WIDGET (XCFA_GET_OBJECT("button_action_split")) && PrgInit.bool_wavsplit == FALSE) {
+		gchar *Str = g_strdup_printf (_("wavsplit ABSENT :: %s"), TypeButton [ 5 ].def);
 		utils_puts_statusbar_global (Str);
 		g_free (Str);
 		Str = NULL;
 		return;
 	}
 
-	if (widget == GTK_WIDGET (lookup_widget (wind_main, "button_action_split")) && PrgInit.bool_mp3splt == FALSE) {
-		gchar *Str = g_strdup_printf (_("mp3splt NOT FOUND / ABSENT :: %s"), TypeButton [ 5 ].def);
+	if (widget == GTK_WIDGET (XCFA_GET_OBJECT("button_action_split")) && PrgInit.bool_mp3splt == FALSE) {
+		gchar *Str = g_strdup_printf (_("mp3splt ABSENT :: %s"), TypeButton [ 5 ].def);
 		utils_puts_statusbar_global (Str);
 		g_free (Str);
 		Str = NULL;
 		return;
 	}
-	if (widget == GTK_WIDGET (lookup_widget (wind_main, "button_lecture_split")) && PrgInit.bool_mplayer == FALSE) {
-		gchar *Str = g_strdup_printf (_("mplayer NOT FOUND / ABSENT :: %s"), TypeButton [ 4 ].def);
+	if (widget == GTK_WIDGET (XCFA_GET_OBJECT("button_lecture_split")) && PrgInit.bool_mplayer == FALSE) {
+		gchar *Str = g_strdup_printf (_("mplayer ABSENT :: %s"), TypeButton [ 4 ].def);
 		utils_puts_statusbar_global (Str);
 		g_free (Str);
 		Str = NULL;
@@ -494,7 +518,7 @@ void help_split_enter_notify_event (GtkWidget *widget)
 	}
 
 	for (cpt = 0; cpt < MAX_TYPE_BUTTON_ENTER_NOTIFY_SPLIT; cpt ++) {
-		if (widget == GTK_WIDGET (lookup_widget (wind_main, TypeButton [ cpt ].widget))) {
+		if (widget == GTK_WIDGET (XCFA_GET_OBJECT(TypeButton [ cpt ].widget))) {
 			utils_puts_statusbar_global (TypeButton [ cpt ].def);
 			break;
 		}
@@ -526,7 +550,7 @@ void help_lecture_enter_notify_event (GtkWidget *widget)
 	gint cpt;
 
 	for (cpt = 0; cpt < MAX_TYPE_BUTTON_ENTER_NOTIFY_LECTURE; cpt ++) {
-		if (widget == GTK_WIDGET (lookup_widget (VarLecture.AdrWin, TypeButton [ cpt ].widget))) {
+		if (widget == GTK_WIDGET (XCFA_GET_OBJECT(TypeButton [ cpt ].widget))) {
 			WinPlay_puts_statusbar (TypeButton [ cpt ].def);
 			break;
 		}
