@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -40,8 +40,6 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 
-#include "support.h"
-
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -86,14 +84,16 @@ gboolean OLDinfosong_create_dir (gchar *NameDir)
  */
 gboolean infosong_create_dir (gchar *NameDir)
 {
-	gchar *LineCommand = NULL;
+	gchar	*LineCommand = NULL;
+	gint	 Dummy;
+	
 	/* PRINT_FUNC_LF(); */
 	if (infosong_file_is_dir (NameDir) == TRUE) {
 		return (TRUE);
 	}
 	LineCommand = g_strdup_printf ("mkdir -p \"%s\"", NameDir);
 	g_print ("CREATE REP:\n\t%s\n", NameDir);
-	system (LineCommand);
+	Dummy = system (LineCommand);
 	g_free (LineCommand);
 	LineCommand = NULL;
 	
@@ -163,6 +163,7 @@ gchar *infosong_remove_rep (gchar *path)
 		*/
 		gchar   * Ptr = NULL;
 		GString *cmd = NULL;
+		gint	 Dummy;
 		
 		cmd = g_string_new (NULL);
 		for (Ptr = path; *Ptr; Ptr ++) {
@@ -174,7 +175,7 @@ gchar *infosong_remove_rep (gchar *path)
 			}
 		}
 		LineCommand = g_strdup_printf ("rm -rf \"%s\"", cmd->str);
-		system (LineCommand);
+		Dummy = system (LineCommand);
 		g_free (LineCommand);
 		LineCommand = NULL;
 		g_string_free (cmd, TRUE);
@@ -231,22 +232,36 @@ size_t infosong_get_size_file (gchar *PathName)
 
 void infosong_rename_file (gchar *oldname, gchar *newname)
 {
-	if (infosong_file_is_reg (oldname)) {
+	gchar	*OldName = g_strdup_printf ("%s", oldname);
+	gchar	*NewName = g_strdup_printf ("%s", newname);
+	
+	if (infosong_file_is_reg (OldName)) {
 		pid_t  pid;
 		gint   status;
 
+		g_print("mv %s %s\n", OldName, NewName);
+		
 		if ((pid = fork ()) == 0) {
 			execlp (
 				"mv",
 				"mv",
-				oldname,
-				newname,
+				OldName,
+				NewName,
 				NULL, NULL
 				);
 				exit (2);
 		}
 		waitpid (pid, &status, WUNTRACED);
 	}
+	else {
+		g_print("NOT EXIST: OldName = %s\n", OldName);
+	}
+	// infosong_delete_file (OldName);
+	PRINT("infosong_rename_file ()  = OK");
+	g_free (OldName);
+	OldName = NULL;
+	g_free (NewName);
+	NewName = NULL;
 }
 
 void infosong_copy_file (gchar *oldname, gchar *newname)
@@ -318,12 +333,13 @@ gboolean  infosong_access_mode (RET_ACCESS_MODE Flag_Ret_Mode, const char *nom_f
 	gint	         ret;
 	ACCESS_MODE      FileAccessMode;
 	gboolean         Flag = FALSE;
+	// struct tm	*tm;
 
-	/* PRINT_FUNC_LF(); */
+	// PRINT_FUNC_LF();
 	FileAccessMode.FileExist   = access (nom_fichier, F_OK) == -1 ? FALSE : TRUE;
 	if (FileAccessMode.FileExist == TRUE) {
-		/* Si le fichier existe
-		 */
+		
+		// Si le fichier existe
 		FileAccessMode.ReadFileOk    = access (nom_fichier, R_OK) == -1 ? FALSE : TRUE;
 		FileAccessMode.WriteFileOk   = access (nom_fichier, W_OK) == -1 ? FALSE : TRUE;
 		FileAccessMode.ExecFileOk    = access (nom_fichier, X_OK) == -1 ? FALSE : TRUE;
@@ -333,14 +349,32 @@ gboolean  infosong_access_mode (RET_ACCESS_MODE Flag_Ret_Mode, const char *nom_f
 		FileAccessMode.FileIsDir     = (ret > -1 && S_ISDIR (status.st_mode));
 		FileAccessMode.FileIsBlok    = (ret > -1 && S_ISBLK (status.st_mode));
 
-		/* getuid:        UID reel du processus en cours.
-		 * status.st_uid: UID du proprietaire du fichier
-		 */
+		// getuid:        UID reel du processus en cours.
+		// status.st_uid: UID du proprietaire du fichier
 		FileAccessMode.BoolManipFile = (ret > -1 && status.st_uid == getuid ()) ? TRUE : FALSE;
-
+		
+		/*
+		g_print("Heure dernier accès           status.st_atime = %lu    ", status.st_atime);
+		tm = localtime (&status.st_atime);
+		g_print ("%02d/%02d/%02d    %02d:%02d:%02d\n",
+				tm->tm_mday, tm->tm_mon+1, tm->tm_year % 100,
+				tm->tm_hour, tm->tm_min, tm->tm_sec
+				);
+		g_print("Heure dernière modification   status.st_mtime = %lu    ", status.st_mtime);
+		tm = localtime (&status.st_mtime);
+		g_print ("%02d/%02d/%02d    %02d:%02d:%02d\n",
+				tm->tm_mday, tm->tm_mon+1, tm->tm_year % 100,
+				tm->tm_hour, tm->tm_min, tm->tm_sec
+				);
+		g_print("Heure dernier changement état status.st_ctime = %lu    ", status.st_ctime);
+		tm = localtime (&status.st_ctime);
+		g_print ("%02d/%02d/%02d    %02d:%02d:%02d\n",
+				tm->tm_mday, tm->tm_mon+1, tm->tm_year % 100,
+				tm->tm_hour, tm->tm_min, tm->tm_sec
+				);
+		*/
 	} else {
-		/* Si le fichier n'existe pas
-		 */
+		// Si le fichier n'existe pas
 		FileAccessMode.ReadFileOk    = FALSE;
 		FileAccessMode.WriteFileOk   = FALSE;
 		FileAccessMode.ExecFileOk    = FALSE;
@@ -480,8 +514,8 @@ TYPE_FILE_IS infosong_file_is (TYPE_FILE_IS type_infosong_file_is, gchar *PathNa
 
 	lenfile = infosong_get_size_file (PathName);
 	if (lenfile == 0) {
-		g_print ("TAILLE = ZERO\n");
-		g_print ("\t%s\n", PathName);
+		// g_print ("TAILLE = ZERO\n");
+		// g_print ("\t%s\n", PathName);
 		return (FILE_IS_NONE);
 	}
 	
@@ -505,22 +539,31 @@ TYPE_FILE_IS infosong_file_is (TYPE_FILE_IS type_infosong_file_is, gchar *PathNa
 		if (tagsflac_file_is_flac (PathName)) return (FILE_IS_FLAC);
 	}
 
-	if (type_infosong_file_is == FILE_IS_MP3) {
-		if (tagsmp3_file_is_mp3 (PathName)) return (FILE_IS_MP3);
+	if (type_infosong_file_is == FILE_IS_APE) {
+		if (tagsape_file_is_ape (PathName)) return (FILE_IS_APE);
 	}
 
 	if (type_infosong_file_is == FILE_IS_MPC) {
 		if (tagsmpc_file_is_mpc (PathName)) return (FILE_IS_MPC);
 	}
-
-	if (type_infosong_file_is == FILE_IS_APE) {
-		if (tagsape_file_is_ape (PathName)) return (FILE_IS_APE);
+	
+	if (type_infosong_file_is == FILE_IS_MP3) {
+		if (tagsmp3_file_is_mp3 (PathName)) return (FILE_IS_MP3);
 	}
 
+
 	if (type_infosong_file_is == FILE_IS_WAVPACK) {
 		if (tagswavpack_file_is_wavpack (PathName)) return (FILE_IS_WAVPACK);
 	}
+	
+	if (type_infosong_file_is == FILE_IS_RM) {
+		if (tagsrm_file_is_rm (PathName)) return (FILE_IS_RM);
+	}
 
+	if (type_infosong_file_is == FILE_IS_AIFF) {
+		if (tagsaiff_file_is_aiff (PathName)) return (FILE_IS_AIFF);
+	}
+	
 	gstr = get_with_file (PathName);
 
 	Lout = gstr->str;
@@ -536,6 +579,9 @@ TYPE_FILE_IS infosong_file_is (TYPE_FILE_IS type_infosong_file_is, gchar *PathNa
 			FILE_IS_AAC,
 			FILE_IS_SHN,
 			FILE_IS_WMA,
+			FILE_IS_RM,
+			FILE_IS_DTS,
+			FILE_IS_AIFF,
 			FILE_IS_MPC,
 			FILE_IS_APE,
 			FILE_IS_WAVPACK,
@@ -547,6 +593,10 @@ TYPE_FILE_IS infosong_file_is (TYPE_FILE_IS type_infosong_file_is, gchar *PathNa
 			*/
 			switch (type_infosong_file_is) {
 
+			case FILE_IS_AIFF :
+				Bool_Ret = strstr (Lout, "AIFF audio") ? FILE_IS_AIFF : FILE_IS_NONE;
+				break;
+
 			case FILE_IS_FLAC :
 				Bool_Ret = strstr (Lout, "FLAC audio") ? FILE_IS_FLAC : FILE_IS_NONE;
 				if (Bool_Ret == FILE_IS_FLAC) Bool_Ret = strstr (Lout, "bitstream data") ? FILE_IS_FLAC : FILE_IS_NONE;
@@ -556,10 +606,14 @@ TYPE_FILE_IS infosong_file_is (TYPE_FILE_IS type_infosong_file_is, gchar *PathNa
 				if (Bool_Ret == FILE_IS_WAV) Bool_Ret = strstr (Lout, "WAVE audio") ? FILE_IS_WAV : FILE_IS_NONE;
 				break;
 			
+			case FILE_IS_APE :
+				Bool_Ret = strstr (Lout, "Monkey's Audio") ? FILE_IS_APE : FILE_IS_NONE;
+				break;
+
 			case FILE_IS_MP3 :
 				Bool_Ret = strstr (Lout, "MP3 file") ? FILE_IS_MP3 : FILE_IS_NONE;
 				if (Bool_Ret != FILE_IS_MP3) Bool_Ret = strstr (Lout, "MP3 encoding")  ? FILE_IS_MP3 : FILE_IS_NONE;
-				if (Bool_Ret != FILE_IS_MP3) Bool_Ret = strstr (Lout, "MPEG ADTS")     ? FILE_IS_MP3 : FILE_IS_NONE;
+				// if (Bool_Ret != FILE_IS_MP3) Bool_Ret = strstr (Lout, "MPEG ADTS")     ? FILE_IS_MP3 : FILE_IS_NONE;
 				if (Bool_Ret != FILE_IS_MP3) Bool_Ret = strstr (Lout, "XWD X Window Dump image data")  ? FILE_IS_MP3 : FILE_IS_NONE;
 				
 				/*	XWD X Window Dump image data
@@ -584,12 +638,17 @@ TYPE_FILE_IS infosong_file_is (TYPE_FILE_IS type_infosong_file_is, gchar *PathNa
 			case FILE_IS_WMA :
 				Bool_Ret = strstr (Lout, "Microsoft ASF") ? FILE_IS_WMA : FILE_IS_NONE;
 				break;
+			
+			case FILE_IS_RM :
+				Bool_Ret = strstr (Lout, "RealMedia file") ? FILE_IS_RM : FILE_IS_NONE;
+				break;
+			case FILE_IS_DTS :
+				Bool_Ret = strstr (Lout, "data") ? FILE_IS_DTS : FILE_IS_NONE;
+				break;
+			
 			case FILE_IS_MPC :
 				Bool_Ret = strstr (Lout, "Musepack") ? FILE_IS_MPC : FILE_IS_NONE;
 				break;
-			case FILE_IS_APE :
-				Bool_Ret = strstr (Lout, "Monkey's Audio") ? FILE_IS_APE : FILE_IS_NONE;
-				break;
 			/* ? FILE_IS_WAVPACK, FILE_IS_WAVPACK_MD5 */
 			case FILE_IS_WAVPACK :
 			case FILE_IS_WAVPACK_MD5 :
@@ -641,52 +700,84 @@ TYPE_FILE_IS infosong_file_is (TYPE_FILE_IS type_infosong_file_is, gchar *PathNa
 			FILE_IS_XCFA_GEN_CONF
 			*/
 			
-			if (tagsflac_file_is_flac (PathName))				Bool_Ret = FILE_IS_FLAC;
-			if (tagsmp3_file_is_mp3 (PathName))			Bool_Ret = FILE_IS_MP3;
-			/*
-			else if (tagswav_file_is_wav (PathName))			Bool_Ret = FILE_IS_WAV;
-			else if (tagsogg_file_is_ogg (PathName))			Bool_Ret = FILE_IS_OGG;
-			else if (tagsflac_file_is_flac (PathName))			Bool_Ret = FILE_IS_FLAC;
-			else if (tagsmp3_file_is_mp3 (PathName))			Bool_Ret = FILE_IS_MP3;
-			else if (tagsmpc_file_is_mpc (PathName))			Bool_Ret = FILE_IS_MPC;
-			else if (tagsape_file_is_ape (PathName))			Bool_Ret = FILE_IS_APE;
-			*/
-			else if (strstr (Lout, "FLAC audio") && strstr (Lout, "bitstream data"))
+			if (tagsaiff_file_is_aiff (PathName)) {
+				Bool_Ret = FILE_IS_AIFF;
+			}
+			else if (tagsflac_file_is_flac (PathName)) {
 				Bool_Ret = FILE_IS_FLAC;
-			else if (strstr (Lout, "RIFF") && strstr (Lout, "WAVE audio"))
+			}
+			else if (tagsape_file_is_ape (PathName)) {
+				Bool_Ret = FILE_IS_APE;
+			}
+			else if (tagsmpc_file_is_mpc (PathName)) {
+			// else if (strstr (Lout, "Musepack")) {
+				Bool_Ret = FILE_IS_MPC;
+			}
+			else if (tagswav_file_is_wav (PathName)) {
+			// else if (strstr (Lout, "RIFF") && strstr (Lout, "WAVE audio")) {
 				Bool_Ret = FILE_IS_WAV;
-				
+			}
+			else if (tagsmp3_file_is_mp3 (PathName)) {
+				Bool_Ret = FILE_IS_MP3;
+			}
+			else if (tagsflac_file_is_flac (PathName)) {
+			// else if (strstr (Lout, "FLAC audio") && strstr (Lout, "bitstream data")) {
+				Bool_Ret = FILE_IS_FLAC;
+			}
+			else if (tagsape_file_is_ape (PathName)) {
+			// else if (strstr (Lout, "Monkey's Audio")) {
+				Bool_Ret = FILE_IS_APE;
+			}
+			else if (tagsshn_file_is_shn (PathName)) {
+				Bool_Ret = FILE_IS_SHN;
+			}
+			
 			/*	XWD X Window Dump image data
 			 *	
 			 *	http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=511764
 			 */
-			else if (strstr (Lout, "MP3 file") || strstr (Lout, "MP3 encoding") || strstr (Lout, "MPEG ADTS") ||  strstr (Lout, "XWD X Window Dump image data"))
+			else if (strstr (Lout, "MP3 file") ||
+				 strstr (Lout, "MP3 encoding") ||
+				 // strstr (Lout, "MPEG ADTS") ||
+				 strstr (Lout, "XWD X Window Dump image data")) {
 				 Bool_Ret = FILE_IS_MP3;
-				 
-			else if (strstr (Lout, "Ogg data") && strstr (Lout, "Vorbis audio"))
+			}
+			else if (strstr (Lout, "Ogg data") && strstr (Lout, "Vorbis audio")) {
 				Bool_Ret = FILE_IS_OGG;
-			else if (strstr (Lout, "ISO Media, MPEG v4 system"))
+			}
+			else if (strstr (Lout, "ISO Media, MPEG v4 system")) {
 				Bool_Ret = FILE_IS_M4A;
-			else if (strstr (Lout, "MPEG ADTS, AAC, v4 LC"))
+			}
+			else if (strstr (Lout, "MPEG ADTS, AAC, v4 LC")) {
 				Bool_Ret = FILE_IS_AAC;
-			/* ? FILE_IS_SHN */
-			else if (strstr (Lout, "Microsoft ASF"))
+			}
+			else if (strstr (Lout, "Microsoft ASF")) {
 				Bool_Ret = FILE_IS_WMA;
-			else if (strstr (Lout, "Musepack"))
-				Bool_Ret = FILE_IS_MPC;
-			else if (strstr (Lout, "Monkey's Audio"))
-				Bool_Ret = FILE_IS_APE;
-			/* ? FILE_IS_WAVPACK, FILE_IS_WAVPACK_MD5 */
-			else if (strstr (Lout, "image data") || strstr (Lout, "PNG image"))
+			}
+			else if (tagswavpack_file_is_wavpack (PathName)) {
+				Bool_Ret =  FILE_IS_WAVPACK;
+			}
+			else if (strstr (Lout, "RealMedia file")) {
+				Bool_Ret = FILE_IS_RM;
+			}
+			else if (strstr (Lout, "data")) {
+				Bool_Ret = FILE_IS_DTS;
+			}
+			else if (strstr (Lout, "image data") || strstr (Lout, "PNG image")) {
 				Bool_Ret = FILE_IS_IMG;
-			else if (strstr (Lout, "HTML document text"))
+			}
+			else if (strstr (Lout, "HTML document text")) {
 				Bool_Ret = FILE_IS_HTML;
-			else if (strstr (Lout, "ASCII") && strstr (Lout, "text"))
+			}
+			else if (strstr (Lout, "ASCII") && strstr (Lout, "text")) {
 				Bool_Ret = FILE_IS_TXT;
-			else if (strstr (Lout, "ASCII") && strstr (Lout, "text") && infosong_test_xcfa_gen_conf (PathName))
+			}
+			else if (strstr (Lout, "ASCII") && strstr (Lout, "text") && infosong_test_xcfa_gen_conf (PathName)) {
 				Bool_Ret = FILE_IS_XCFA_GEN_CONF;
-			else
+			}
+			else {
 				Bool_Ret = FILE_IS_NONE;
+			}
 		}
 	}
 
@@ -722,18 +813,28 @@ TYPE_FILE_IS infosong_get_type_file_is (gchar *NameSong)
 			if (*Ptr) Ext [3] = toupper (*Ptr);
 			Ext [4] = '\0';
 
-			if (Ext[0] == 'F' && Ext[1] == 'L' && Ext[2] == 'A' && Ext[3] == 'C' && Ext[4] == '\0') return (FILE_IS_FLAC);
-			else if (Ext[0] == 'W' && Ext[1] == 'A' && Ext[2] == 'V' && Ext[3] == '\0')             return (FILE_IS_WAV);
-			else if (Ext[0] == 'M' && Ext[1] == 'P' && Ext[2] == '3' && Ext[3] == '\0')             return (FILE_IS_MP3);
-			else if (Ext[0] == 'O' && Ext[1] == 'G' && Ext[2] == 'G' && Ext[3] == '\0')             return (FILE_IS_OGG);
-			else if (Ext[0] == 'S' && Ext[1] == 'H' && Ext[2] == 'N' && Ext[3] == '\0')             return (FILE_IS_SHN);
-			else if (Ext[0] == 'M' && Ext[1] == '4' && Ext[2] == 'A' && Ext[3] == '\0')             return (FILE_IS_M4A);
-			else if (Ext[0] == 'A' && Ext[1] == 'A' && Ext[2] == 'C' && Ext[3] == '\0')             return (FILE_IS_AAC);
-			else if (Ext[0] == 'W' && Ext[1] == 'M' && Ext[2] == 'A' && Ext[3] == '\0')             return (FILE_IS_WMA);
-			else if (Ext[0] == 'M' && Ext[1] == 'P' && Ext[2] == 'C' && Ext[3] == '\0')             return (FILE_IS_MPC);
-			else if (Ext[0] == 'A' && Ext[1] == 'P' && Ext[2] == 'E' && Ext[3] == '\0')             return (FILE_IS_APE);
-			else if (Ext[0] == 'W' && Ext[1] == 'V' && Ext[2] == '\0')                              return (FILE_IS_WAVPACK);
-			else if (Ext[0] == 'C' && Ext[1] == 'U' && Ext[2] == 'E' && Ext[3] == '\0')             return (FILE_IS_CUE);
+			if      (Ext[0] == 'F' && Ext[1] == 'L' && Ext[2] == 'A' && Ext[3] == 'C'    && Ext[4] == '\0') return (FILE_IS_FLAC);
+			else if (Ext[0] == 'W' && Ext[1] == 'A' && Ext[2] == 'V' && Ext[3] == '\0')             	return (FILE_IS_WAV);
+			else if (Ext[0] == 'M' && Ext[1] == 'P' && Ext[2] == '3' && Ext[3] == '\0')             	return (FILE_IS_MP3);
+			else if (Ext[0] == 'O' && Ext[1] == 'G' && Ext[2] == 'G' && Ext[3] == '\0')             	return (FILE_IS_OGG);
+			else if (Ext[0] == 'S' && Ext[1] == 'H' && Ext[2] == 'N' && Ext[3] == '\0')            		return (FILE_IS_SHN);
+			else if (Ext[0] == 'M' && Ext[1] == '4' && Ext[2] == 'A' && Ext[3] == '\0')			return (FILE_IS_M4A);
+			else if (Ext[0] == 'A' && Ext[1] == 'A' && Ext[2] == 'C' && Ext[3] == '\0')			return (FILE_IS_AAC);
+			else if (Ext[0] == 'W' && Ext[1] == 'M' && Ext[2] == 'A' && Ext[3] == '\0')			return (FILE_IS_WMA);
+			else if (Ext[0] == 'R' && Ext[1] == 'M' && Ext[2] == '\0' && Ext[3] == '\0')            	return (FILE_IS_RM);
+			else if (Ext[0] == 'D' && Ext[1] == 'T' && Ext[2] == 'S' && Ext[3] == '\0')			return (FILE_IS_DTS);
+			
+			// AIF
+			// AIFF
+			// AIFC
+			else if (Ext[0] == 'A' && Ext[1] == 'I' && Ext[2] == 'F' && Ext[3] == '\0')             	return (FILE_IS_AIFF);
+			else if (Ext[0] == 'A' && Ext[1] == 'I' && Ext[2] == 'F' && Ext[3] == 'F'    && Ext[4] == '\0') return (FILE_IS_AIFF);
+			else if (Ext[0] == 'A' && Ext[1] == 'I' && Ext[2] == 'F' && Ext[3] == 'C'    && Ext[4] == '\0') return (FILE_IS_AIFF);
+			
+			else if (Ext[0] == 'M' && Ext[1] == 'P' && Ext[2] == 'C' && Ext[3] == '\0')			return (FILE_IS_MPC);
+			else if (Ext[0] == 'A' && Ext[1] == 'P' && Ext[2] == 'E' && Ext[3] == '\0')			return (FILE_IS_APE);
+			else if (Ext[0] == 'W' && Ext[1] == 'V' && Ext[2] == '\0')					return (FILE_IS_WAVPACK);
+			else if (Ext[0] == 'C' && Ext[1] == 'U' && Ext[2] == 'E' && Ext[3] == '\0')			return (FILE_IS_CUE);
 		}
 	}
 	return (type);
@@ -782,6 +883,9 @@ gboolean infosong_type_is_song (gchar *NameSong)
 		type == FILE_IS_M4A ||
 		type == FILE_IS_AAC ||
 		type == FILE_IS_WMA ||
+		type == FILE_IS_RM  ||
+		type == FILE_IS_DTS ||
+		type == FILE_IS_AIFF ||
 		type == FILE_IS_MPC ||
 		type == FILE_IS_APE ||
 		type == FILE_IS_WAVPACK) return (TRUE);
@@ -802,6 +906,9 @@ gchar *infosong_get_str_type_file_is (TYPE_FILE_IS type)
 	else if (type == FILE_IS_M4A)      strcpy (str_type_file, "M4A ");
 	else if (type == FILE_IS_AAC)      strcpy (str_type_file, "AAC ");
 	else if (type == FILE_IS_WMA)      strcpy (str_type_file, "WMA ");
+	else if (type == FILE_IS_RM)       strcpy (str_type_file, "RM ");
+	else if (type == FILE_IS_DTS)      strcpy (str_type_file, "DTS ");
+	else if (type == FILE_IS_AIFF)     strcpy (str_type_file, "AIFF ");
 	else if (type == FILE_IS_MPC)      strcpy (str_type_file, "MPC ");
 	else if (type == FILE_IS_APE)      strcpy (str_type_file, "APE ");
 	else if (type == FILE_IS_WAVPACK)  strcpy (str_type_file, "WVP ");
