@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -34,27 +34,10 @@
 #ifndef __logs_h__
 #define __logs_h__ 1
 
-
-typedef struct {
-	GtkWidget   *Adr_checkbutton_goto_files_import;
-	
-	GtkWidget   *Adr_label_computer;
-	GtkWidget   *Adr_label_import_file;
-} VAR_LOGS;
-
-extern VAR_LOGS var_logs;
-
-
-gboolean logs_get_checkbutton_goto_files_import (void);
-void     logs_set_checkbutton_goto_files_import (void);
-void     logs_checkbutton_goto_files_import_clicked (void);
-
-void     logs_label_computer_add (gchar *text);
-void     logs_label_import_file_add (gchar *text);
-
-void     logs_add_datas_system (gchar *data);
-gboolean logs_set_datas_system (void);
-
-void     logs_trace_datas (gchar *data);
+gboolean logs_button_is_activate (void);
+void logs_write_datas (gchar *data);
+void logs_writeln_datas (gchar *data);
+void logs_add_datas_session (gchar *data);
+void logs_write_double (gdouble DataInt);
 
 #endif
