@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -38,8 +38,6 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#include "support.h"
-
 #include <string.h>
 #include <ctype.h>
 #include <stdlib.h>
@@ -55,66 +53,11 @@
 #include "prg_init.h"
 #include "win_control.h"
 #include "win_norm_replay.h"
+#include "logs.h"
 #include "normalise.h"
 
 
 
-/*
-SI file != (Ogg,Mp3) ALORS
-	(Ogg,Mp3) -> /tmp/file.Wav
-FINSI
-normalise-audio -a -xx,0000dB /tmp/file.Wav
-SI Convert ALORS
-	/tmp/file.Wav -> (Ogg,Mp3)
-FINSI
-
-CORRECTION ALGO REPLAYGAIN
---------------------------
-
-IL FAUT TRAVAILLER SUR DES ENSEMBLES:
-
-EFFACER: Ensemble SOURCE
-
-ALBUM:   Ensemble DESTINATION
-PISTE:
-
-ACTION SUR LA SOURCES		FileAction.bool_ReplaygainClear    = file_get_bool_ReplaygainClear_file ();
-ACTION SUR LA SOURCES		FileAction.bool_normalize          = file_get_bool_normalize_file ();
-ACTION SUR LA SOURCES		FileAction.bool_NormalizeCollectif = file_get_bool_NormalizeCollectif_file ();
-CREATION DESTINATION		FileAction.bool_conversion         = file_get_bool_conversion_file ();
-ACTION SUR LA DESTINATION	FileAction.bool_ReplaygainApply    = file_get_bool_ReplaygainApply_file ();
-
-
-fic->Etat_Normalise
-	NORM_RMS_FIX,				-- INDIVIDUEL	niveau de volume rms
-	NORM_PEAK,				-- INDIVIDUEL	ajustement maximal du volume
-
-fic->Etat_NormCollectif
-	NORM_RMS_MIX_ALBUM,				-- COLLECTIF	ajustement global du volume
-	NORM_PEAK,				-- COLLECTIF	ajustement maximal du volume
-
-
-Individuel
-	FIX
-		Wav	normalise-audio		Etat_Normalise		NORM_RMS_FIX
-		Ogg	vorbisgain		Etat_Normalise		NORM_RMS_FIX
-		Mp3	wvgain			Etat_Normalise		NORM_RMS_FIX
-	PEAK
-		Wav	normalise-audio		Etat_Normalise		NORM_PEAK
-		Ogg	vorbisgain		Etat_Normalise		NORM_PEAK
-		Mp3	wvgain			Etat_Normalise		NORM_PEAK
-
-Collectif
-	MIX
-		Wav	normalise-audio		Etat_NormCollectif	NORM_RMS_MIX_ALBUM
-		Ogg	vorbisgain		Etat_NormCollectif	NORM_RMS_MIX_ALBUM
-		Mp3	wvgain			Etat_NormCollectif	NORM_RMS_MIX_ALBUM
-	PEAK
-		Wav	normalise-audio		Etat_NormCollectif	NORM_PEAK
-		Ogg	vorbisgain		Etat_NormCollectif	NORM_PEAK
-		Mp3	wvgain			Etat_NormCollectif	NORM_PEAK
-
-*/
 
 /*
 *---------------------------------------------------------------------------
@@ -303,6 +246,14 @@ void normalise_copy_wav_to_tmp (GList *p_list)
 	}
 }
 
+void normalise_set_mess (gchar *p_Mess)
+{
+	if (normalise.bool_etat == FALSE) {
+		// normalise.bool_etat = TRUE;
+		// normalise.MessUser = g_strdup (p_Mess);
+	}
+}
+
 void normalise_FIX_wav (void)
 {
 	GList         *List = NULL;
@@ -317,8 +268,7 @@ void normalise_FIX_wav (void)
 			*/
 			normalise.ElementActif ++;
 
-			normalise.MessUser = g_strdup ("Copie");
-			normalise.bool_etat = TRUE;
+			normalise_set_mess ("Copie");
 			conv_copy_src_to_dest (IndiFix->NameFile, IndiFix->NameFileCopieWav);
 
 			/* Normalisation du Wav
@@ -332,8 +282,7 @@ void normalise_FIX_wav (void)
 			ListNorm = g_list_append (ListNorm, g_strdup_printf ("%s,0000dB", IndiFix->StrDBFS));
 			ListNorm = g_list_append (ListNorm, g_strdup (IndiFix->NameFileCopieWav));
 
-			normalise.MessUser = g_strdup ("Normalise Wav -> Fix");
-			normalise.bool_etat = TRUE;
+			normalise_set_mess ("Normalise Wav -> Fix");
 
 			conv.ArgConv = conv_alloc_arg (ListNorm);
 			conv_exec (FALSE, NORMALISE_EXEC, ListNorm, "NORMALISE_EXEC Wav -> Fix");
@@ -351,12 +300,16 @@ void normalise_FIX_wav (void)
 			NameDestMp3
 			*/
 			if (IndiFix->BoolWithConvert == FALSE) {
-				normalise.MessUser = g_strdup ("Restitution");
-				normalise.bool_etat = TRUE;
+
+				normalise_set_mess ("Restitution");
 
 				conv_copy_src_to_dest (IndiFix->NameFileCopieWav, IndiFix->NameDestWav);
 				infosong_delete_file (IndiFix->NameFileCopieWav);
 				
+				logs_writeln_datas ("FIX WAV");
+				logs_write_datas ("\t");
+				logs_writeln_datas (IndiFix->NameDestWav);
+				
 				normalise.ElementActif ++;
 			}
 
@@ -380,8 +333,8 @@ void normalise_FIX_ogg (void)
 
 			/* Conversion Ogg vers Wav
 			*/
-			normalise.MessUser = g_strdup ("Conversion Ogg vers Wav");
-			normalise.bool_etat = TRUE;
+
+			normalise_set_mess ("Conversion Ogg vers Wav");
 			/*
 			ListNorm = g_list_append (ListNorm, g_strdup ("nice"));
 			ListNorm = g_list_append (ListNorm, g_strdup ("-n"));
@@ -427,8 +380,8 @@ void normalise_FIX_ogg (void)
 
 			/* Normalisation du Wav
 			*/
-			normalise.MessUser = g_strdup ("Normalise Wav -> Fix");
-			normalise.bool_etat = TRUE;
+
+			normalise_set_mess ("Normalise Wav -> Fix");
 
 			ListNorm = g_list_append (ListNorm, g_strdup ("nice"));
 			ListNorm = g_list_append (ListNorm, g_strdup ("-n"));
@@ -455,8 +408,8 @@ void normalise_FIX_ogg (void)
 			NameDestMp3
 			*/
 			if (IndiFix->BoolWithConvert == FALSE) {
-				normalise.MessUser = g_strdup ("Conversion Wav vers Ogg");
-				normalise.bool_etat = TRUE;
+
+				normalise_set_mess ("Conversion Wav vers Ogg");
 
 				param_filelc.type_conv             = OGGENC_WAV_TO_OGG;
 				param_filelc.With_CommandLineUser  = FALSE;
@@ -473,7 +426,11 @@ void normalise_FIX_ogg (void)
 				infosong_delete_file (IndiFix->NameFileCopieWav);
 				g_free (conv.ArgConv);
 				conv.ArgConv = NULL;
-
+				
+				logs_writeln_datas ("FIX OGG");
+				logs_write_datas ("\t");
+				logs_writeln_datas (IndiFix->NameDestOgg);
+				
 				normalise.ElementActif ++;
 			}
 
@@ -496,8 +453,8 @@ void normalise_FIX_mp3 (void)
 
 			/* Conversion Mp3 vers Wav
 			*/
-			normalise.MessUser = g_strdup ("Conversion Mp3 vers Wav");
-			normalise.bool_etat = TRUE;
+
+			normalise_set_mess ("Conversion Mp3 vers Wav");
 
 			/*
 			ListNorm = g_list_append (ListNorm, g_strdup ("nice"));
@@ -544,8 +501,8 @@ void normalise_FIX_mp3 (void)
 
 			/* Normalisation du Wav
 			*/
-			normalise.MessUser = g_strdup ("Normalise Wav -> Fix");
-			normalise.bool_etat = TRUE;
+
+			normalise_set_mess ("Normalise Wav -> Fix");
 
 			ListNorm = g_list_append (ListNorm, g_strdup ("nice"));
 			ListNorm = g_list_append (ListNorm, g_strdup ("-n"));
@@ -572,8 +529,8 @@ void normalise_FIX_mp3 (void)
 			NameDestMp3 *
 			*/
 			if (IndiFix->BoolWithConvert == FALSE) {
-				normalise.MessUser = g_strdup ("Conversion du Wav vers Mp3");
-				normalise.bool_etat = TRUE;
+
+				normalise_set_mess ("Conversion du Wav vers Mp3");
 
 				param_filelc.type_conv            = LAME_WAV_TO_MP3;
 				param_filelc.With_CommandLineUser = FALSE;
@@ -591,7 +548,11 @@ void normalise_FIX_mp3 (void)
 				infosong_delete_file (IndiFix->NameFileCopieWav);
 				g_free (conv.ArgConv);
 				conv.ArgConv = NULL;
-
+				
+				logs_writeln_datas ("FIX MP3");
+				logs_write_datas ("\t");
+				logs_writeln_datas (IndiFix->NameDestMp3);
+				
 				normalise.ElementActif ++;
 			}
 
@@ -606,15 +567,15 @@ void normalise_PEAK_wav (void)
 	GList         *List = NULL;
 	GList         *ListNorm = NULL;
 	INDI_FIX      *IndiFix = NULL;
-
+	
 	List = g_list_first (normalise.ListPeakWav);
 	while (normalise.bool_set_end_of_user == FALSE && List) {
 		if ((IndiFix = (INDI_FIX *)List->data)) {
 
 			/* Copie temporaire
 			*/
-			normalise.MessUser = g_strdup ("Copie");
-			normalise.bool_etat = TRUE;
+
+			normalise_set_mess ("Copie");
 
 			conv_copy_src_to_dest (IndiFix->NameFile, IndiFix->NameFileCopieWav);
 			
@@ -622,8 +583,8 @@ void normalise_PEAK_wav (void)
 
 			/* Normalisation du Wav
 			*/
-			normalise.MessUser = g_strdup ("Normalise Wav -> Peak");
-			normalise.bool_etat = TRUE;
+
+			normalise_set_mess ("Normalise Wav -> Peak");
 
 			ListNorm = g_list_append (ListNorm, g_strdup ("nice"));
 			ListNorm = g_list_append (ListNorm, g_strdup ("-n"));
@@ -631,12 +592,8 @@ void normalise_PEAK_wav (void)
 			// ListNorm = g_list_append (ListNorm, g_strdup (PrgInit.name_normalize));
 			ListNorm = g_list_append (ListNorm, g_strdup (prginit_get_name (NMR_normalize)));
 			ListNorm = g_list_append (ListNorm, g_strdup ("--peak"));
-
-			ListNorm = g_list_append (ListNorm, g_strdup ("--"));
-			/*ListNorm = g_list_append (ListNorm, g_strdup ("-T"));
-			ListNorm = g_list_append (ListNorm, g_strdup ("0,2"));*/
-
 			ListNorm = g_list_append (ListNorm, g_strdup (IndiFix->NameFileCopieWav));
+			ListNorm = g_list_append (ListNorm, g_strdup ("--"));
 			/* *IndiFix->EtatNormalise = NORM_SCAN_ACTIF; */
 			if (*IndiFix->EtatTrash == FILE_TRASH_OK) *IndiFix->EtatTrash = FILE_TRASH_VERIF_OK;
 
@@ -656,12 +613,16 @@ void normalise_PEAK_wav (void)
 			NameDestMp3
 			*/
 			if (IndiFix->BoolWithConvert == FALSE) {
-				normalise.MessUser = g_strdup ("Restitution");
-				normalise.bool_etat = TRUE;
+
+				normalise_set_mess ("Restitution");
 
 				conv_copy_src_to_dest (IndiFix->NameFileCopieWav, IndiFix->NameDestWav);
 				infosong_delete_file (IndiFix->NameFileCopieWav);
-			
+				
+				logs_writeln_datas ("PEAK WAV");
+				logs_write_datas ("\t");
+				logs_writeln_datas (IndiFix->NameDestWav);
+				
 				normalise.ElementActif ++;
 			}
 
@@ -682,8 +643,7 @@ void normalise_PEAK_ogg (void)
 
 			/* Conversion Ogg vers Wav
 			*/
-			normalise.MessUser = g_strdup ("Conversion Ogg vers Wav");
-			normalise.bool_etat = TRUE;
+			normalise_set_mess ("Conversion Ogg vers Wav");
 
 			ListNorm = g_list_append (ListNorm, g_strdup ("nice"));
 			ListNorm = g_list_append (ListNorm, g_strdup ("-n"));
@@ -705,20 +665,15 @@ void normalise_PEAK_ogg (void)
 		
 			/* Normalisation du Wav
 			*/
-			normalise.MessUser = g_strdup ("Normalise Wav -> Fix");
-			normalise.bool_etat = TRUE;
+			normalise_set_mess ("Normalise Wav -> Fix");
 
 			ListNorm = g_list_append (ListNorm, g_strdup ("nice"));
 			ListNorm = g_list_append (ListNorm, g_strdup ("-n"));
 			ListNorm = g_list_append (ListNorm, g_strdup_printf ("%d", options_get_val_nice ()));
 			// ListNorm = g_list_append (ListNorm, g_strdup (PrgInit.name_normalize));
 			ListNorm = g_list_append (ListNorm, g_strdup (prginit_get_name (NMR_normalize)));
-			ListNorm = g_list_append (ListNorm, g_strdup ("--peak"));
-
-			/*ListNorm = g_list_append (ListNorm, g_strdup ("-T"));
-			ListNorm = g_list_append (ListNorm, g_strdup ("0,2"));*/
-
 			ListNorm = g_list_append (ListNorm, g_strdup (IndiFix->NameFileCopieWav));
+			ListNorm = g_list_append (ListNorm, g_strdup ("--peak"));
 			/* *IndiFix->EtatNormalise = NORM_SCAN_ACTIF; */
 			if (*IndiFix->EtatTrash == FILE_TRASH_OK) *IndiFix->EtatTrash = FILE_TRASH_VERIF_OK;
 
@@ -738,8 +693,8 @@ void normalise_PEAK_ogg (void)
 			NameDestMp3
 			*/
 			if (IndiFix->BoolWithConvert == FALSE) {
-				normalise.MessUser = g_strdup ("Conversion Wav vers Ogg");
-				normalise.bool_etat = TRUE;
+
+				normalise_set_mess ("Conversion Wav vers Ogg");
 
 				param_filelc.type_conv             = OGGENC_WAV_TO_OGG;
 				param_filelc.With_CommandLineUser  = FALSE;
@@ -756,7 +711,11 @@ void normalise_PEAK_ogg (void)
 				infosong_delete_file (IndiFix->NameFileCopieWav);
 				g_free (conv.ArgConv);
 				conv.ArgConv = NULL;
-
+				
+				logs_writeln_datas ("PEAK OGG");
+				logs_write_datas ("\t");
+				logs_writeln_datas (IndiFix->NameDestOgg);
+				
 				normalise.ElementActif ++;
 			}
 
@@ -777,8 +736,7 @@ void normalise_PEAK_mp3 (void)
 
 			/* Conversion Mp3 vers Wav
 			*/
-			normalise.MessUser = g_strdup ("Conversion Mp3 vers Wav");
-			normalise.bool_etat = TRUE;
+			normalise_set_mess ("Conversion Mp3 vers Wav");
 
 			/*
 			ListNorm = g_list_append (ListNorm, g_strdup ("nice"));
@@ -825,8 +783,7 @@ void normalise_PEAK_mp3 (void)
 
 			/* Normalisation du Wav
 			*/
-			normalise.MessUser = g_strdup ("Normalise Wav -> Peak");
-			normalise.bool_etat = TRUE;
+			normalise_set_mess ("Normalise Wav -> Peak");
 
 			ListNorm = g_list_append (ListNorm, g_strdup ("nice"));
 			ListNorm = g_list_append (ListNorm, g_strdup ("-n"));
@@ -855,8 +812,8 @@ void normalise_PEAK_mp3 (void)
 			NameDestMp3 *
 			*/
 			if (IndiFix->BoolWithConvert == FALSE) {
-				normalise.MessUser = g_strdup ( "Conversion du Wav vers Mp3");
-				normalise.bool_etat = TRUE;
+
+				normalise_set_mess ("Conversion du Wav vers Mp3");
 
 				param_filelc.type_conv            = LAME_WAV_TO_MP3;
 				param_filelc.With_CommandLineUser = FALSE;
@@ -873,7 +830,11 @@ void normalise_PEAK_mp3 (void)
 				infosong_delete_file (IndiFix->NameFileCopieWav);
 				g_free (conv.ArgConv);
 				conv.ArgConv = NULL;
-
+				
+				logs_writeln_datas ("PEAK MP3");
+				logs_write_datas ("\t");
+				logs_writeln_datas (IndiFix->NameDestMp3);
+				
 				normalise.ElementActif ++;
 			}
 
@@ -895,15 +856,17 @@ void normalise_MIX_RMS_GROUP_wav_ogg_mp3 (void)
 	/* COPIE  WAV OGG MP3
 	*/
 	if (normalise.bool_set_end_of_user == FALSE && normalise.ListMixGroupWav != NULL) {
-		normalise.MessUser = g_strdup ("(MIX)RMS/GROUPE (Temp): Copie 'wav' vers dossier temporaire");
-		normalise.bool_etat = TRUE;
+
+		normalise_set_mess ("(MIX)RMS/GROUPE (Temp): Copie 'wav' vers dossier temporaire");
+		
 		conv.bool_percent_conv = TRUE;
 		normalise_copy_wav_to_tmp (normalise.ListMixGroupWav);
 	}
 	/* Conversion Ogg vers Wav */
 	if (normalise.bool_set_end_of_user == FALSE && normalise.ListMixGroupOgg != NULL) {
-		normalise.MessUser = g_strdup ("(MIX)RMS/GROUPE (Temp): Conversion Ogg vers Wav");
-		normalise.bool_etat = TRUE;
+
+		normalise_set_mess ("(MIX)RMS/GROUPE (Temp): Conversion Ogg vers Wav");
+		
 		List = g_list_first (normalise.ListMixGroupOgg);
 		while (List) {
 			if ((IndiFix = (INDI_FIX *)List->data)) {
@@ -930,8 +893,8 @@ void normalise_MIX_RMS_GROUP_wav_ogg_mp3 (void)
 	}
 	/* Conversion Mp3 vers Wav */
 	if (normalise.bool_set_end_of_user == FALSE && normalise.ListMixGroupMp3 != NULL) {
-		normalise.MessUser = g_strdup ("(MIX)RMS/GROUPE (Temp): Conversion Mp3 vers Wav");
-		normalise.bool_etat = TRUE;
+
+		normalise_set_mess ("(MIX)RMS/GROUPE (Temp): Conversion Mp3 vers Wav");
 
 		List = g_list_first (normalise.ListMixGroupMp3);
 		while (List) {
@@ -987,8 +950,9 @@ void normalise_MIX_RMS_GROUP_wav_ogg_mp3 (void)
 	/* NORMALISE  WAV
 	*/
 	if (normalise.bool_set_end_of_user == FALSE) {
-		normalise.MessUser = g_strdup ("(MIX)RMS/GROUPE: Normalise Wav");
-		normalise.bool_etat = TRUE;
+
+		normalise_set_mess ("(MIX)RMS/GROUPE: Normalise Wav");
+		
 		ListNorm = g_list_append (ListNorm, g_strdup ("nice"));
 		ListNorm = g_list_append (ListNorm, g_strdup ("-n"));
 		ListNorm = g_list_append (ListNorm, g_strdup_printf ("%d", options_get_val_nice ()));
@@ -1041,8 +1005,9 @@ void normalise_MIX_RMS_GROUP_wav_ogg_mp3 (void)
 	if (normalise.bool_set_end_of_user == FALSE) {
 		/* Restitue liste WAV */
 		if (IndiFix->BoolWithConvert == FALSE) {
-			normalise.MessUser = g_strdup ("(MIX)RMS/GROUPE (Restitution): Restitution des fichiers 'wav'");
-			normalise.bool_etat = TRUE;
+
+			normalise_set_mess ("(MIX)RMS/GROUPE (Restitution): Restitution des fichiers 'wav'");
+			
 			List = g_list_first (normalise.ListMixGroupWav);
 			while (List) {
 				if ((IndiFix = (INDI_FIX *)List->data)) {
@@ -1050,14 +1015,19 @@ void normalise_MIX_RMS_GROUP_wav_ogg_mp3 (void)
 					infosong_delete_file (IndiFix->NameFileCopieWav);
 					normalise.ElementActif ++;
 					conv.bool_percent_conv = TRUE;
+				
+					logs_writeln_datas ("(MIX)RMS/GROUPE: WAV");
+					logs_write_datas ("\t");
+					logs_writeln_datas (IndiFix->NameDestWav);
 				}
 				List = g_list_next(List);
 			}
 		}
 		/* Restitue liste OGG */
 		if (IndiFix->BoolWithConvert == FALSE) {
-			normalise.MessUser = g_strdup ("(MIX)RMS/GROUPE (Restitution): Conversion Wav vers Ogg");
-			normalise.bool_etat = TRUE;
+
+			normalise_set_mess ("(MIX)RMS/GROUPE (Restitution): Conversion Wav vers Ogg");
+			
 			List = g_list_first (normalise.ListMixGroupOgg);
 			while (List) {
 				if ((IndiFix = (INDI_FIX *)List->data)) {
@@ -1079,14 +1049,19 @@ void normalise_MIX_RMS_GROUP_wav_ogg_mp3 (void)
 					infosong_delete_file (IndiFix->NameFileCopieWav);
 
 					normalise.ElementActif ++;
+				
+					logs_writeln_datas ("(MIX)RMS/GROUPE: OGG");
+					logs_write_datas ("\t");
+					logs_writeln_datas (IndiFix->NameDestOgg);
 				}
 				List = g_list_next(List);
 			}
 		}
 		/* Restitue liste MP3 */
 		if (IndiFix->BoolWithConvert == FALSE) {
-			normalise.MessUser = g_strdup ("(MIX)RMS/GROUPE (Restitution): Conversion Wav vers Mp3");
-			normalise.bool_etat = TRUE;
+
+			normalise_set_mess ("(MIX)RMS/GROUPE (Restitution): Conversion Wav vers Mp3");
+			
 			List = g_list_first (normalise.ListMixGroupMp3);
 			while (List) {
 				if ((IndiFix = (INDI_FIX *)List->data)) {
@@ -1109,6 +1084,10 @@ void normalise_MIX_RMS_GROUP_wav_ogg_mp3 (void)
 					infosong_delete_file (IndiFix->NameFileCopieWav);
 
 					normalise.ElementActif ++;
+				
+					logs_writeln_datas ("(MIX)RMS/GROUPE: MP3");
+					logs_write_datas ("\t");
+					logs_writeln_datas (IndiFix->NameDestMp3);
 				}
 				List = g_list_next(List);
 			}
@@ -1121,18 +1100,20 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 	GList         *ListNorm = NULL;
 	INDI_FIX      *IndiFix = NULL;
 	PARAM_FILELC   param_filelc;
-
+	
 	/* COPIE  WAV OGG MP3
 	*/
 	if (normalise.bool_set_end_of_user == FALSE && normalise.ListPeakGroupWav != NULL) {
-		normalise.MessUser = g_strdup ("PEAK/GROUPE (Temp): Copie 'wav' vers dossier temporaire");
-		normalise.bool_etat = TRUE;
+
+		normalise_set_mess ("PEAK/GROUPE (Temp): Copie 'wav' vers dossier temporaire");
+		
 		normalise_copy_wav_to_tmp (normalise.ListPeakGroupWav);
 	}
 	/* Conversion Ogg vers Wav */
 	if (normalise.bool_set_end_of_user == FALSE && normalise.ListPeakGroupOgg != NULL) {
-		normalise.MessUser = g_strdup ("PEAK/GROUPE (Temp): Conversion Ogg vers Wav");
-		normalise.bool_etat = TRUE;
+
+		normalise_set_mess ("PEAK/GROUPE (Temp): Conversion Ogg vers Wav");
+		
 		List = g_list_first (normalise.ListPeakGroupOgg);
 		while (List) {
 			if ((IndiFix = (INDI_FIX *)List->data)) {
@@ -1159,8 +1140,9 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 	}
 	/* Conversion Mp3 vers Wav */
 	if (normalise.bool_set_end_of_user == FALSE && normalise.ListPeakGroupMp3 != NULL) {
-		normalise.MessUser = g_strdup ("PEAK/GROUPE (Temp): Conversion Mp3 vers Wav");
-		normalise.bool_etat = TRUE;
+
+		normalise_set_mess ("PEAK/GROUPE (Temp): Conversion Mp3 vers Wav");
+		
 		List = g_list_first (normalise.ListPeakGroupMp3);
 		while (List) {
 			if ((IndiFix = (INDI_FIX *)List->data)) {
@@ -1218,15 +1200,15 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 		
 		GList *ListFile = NULL;
 		
-		normalise.MessUser = g_strdup ("PEAK/GROUPE: Chercher la moyenne Peak");
-		normalise.bool_etat = TRUE;
+		normalise_set_mess ("PEAK/GROUPE: Chercher la moyenne Peak");
 		
 		/* CHERCHER LA MOYENNE PEAK */
 		ListFile = g_list_append (ListFile, g_strdup ("nice"));
 		ListFile = g_list_append (ListFile, g_strdup ("-n"));
 		ListFile = g_list_append (ListFile, g_strdup_printf ("%d", options_get_val_nice ()));
 		// ListFile = g_list_append (ListFile, g_strdup (PrgInit.name_normalize));
-		ListNorm = g_list_append (ListNorm, g_strdup (prginit_get_name (NMR_normalize)));
+		ListFile = g_list_append (ListFile, g_strdup (prginit_get_name (NMR_normalize)));
+
 		ListFile = g_list_append (ListFile, g_strdup ("-n"));
 		/* Creation liste WAV */
 		List = g_list_first (normalise.ListPeakGroupWav);
@@ -1256,11 +1238,11 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 		conv.ArgConv = conv_alloc_arg (ListFile);
 		conv_exec (FALSE, NORMALISE_GET_LEVEL, ListFile, "NORMALISE_GET_LEVEL TEST -> PEAK/GROUP");
 		ListFile = normalise_remove_glist (ListFile);
-		g_print ("-> conv.value_PEAK_RMS_GROUP_ARGS = %f\n", conv.value_PEAK_RMS_GROUP_ARGS);
 		
 		/* APPLIQUER LA MOYENNE PEAK */
-		normalise.MessUser = g_strdup ("PEAK/GROUPE: Normalise Wav");
-		normalise.bool_etat = TRUE;
+
+		normalise_set_mess ("PEAK/GROUPE: Normalise Wav");
+		
 		ListNorm = g_list_append (ListNorm, g_strdup ("nice"));
 		ListNorm = g_list_append (ListNorm, g_strdup ("-n"));
 		ListNorm = g_list_append (ListNorm, g_strdup_printf ("%d", options_get_val_nice ()));
@@ -1312,8 +1294,9 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 	if (normalise.bool_set_end_of_user == FALSE) {
 		/* Restitue liste WAV */
 		if (IndiFix->BoolWithConvert == FALSE) {
-			normalise.MessUser = g_strdup ("PEAK/GROUPE (Restitution): Restitution des fichiers 'wav'");
-			normalise.bool_etat = TRUE;
+
+			normalise_set_mess ("PEAK/GROUPE (Restitution): Restitution des fichiers 'wav'");
+			
 			List = g_list_first (normalise.ListPeakGroupWav);
 			while (List) {
 				if ((IndiFix = (INDI_FIX *)List->data)) {
@@ -1324,14 +1307,18 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 					}
 					infosong_delete_file (IndiFix->NameFileCopieWav);
 					normalise.ElementActif ++;
+				
+					logs_writeln_datas ("PEAK/GROUPE: WAV");
+					logs_write_datas ("\t");
+					logs_writeln_datas (IndiFix->NameDestWav);
 				}
 				List = g_list_next(List);
 			}
 		}
 		/* Restitue liste OGG */
 		if (IndiFix->BoolWithConvert == FALSE) {
-			normalise.MessUser = g_strdup ("PEAK/GROUPE (Restitution): Conversion Wav vers Ogg");
-			normalise.bool_etat = TRUE;
+
+			normalise_set_mess ("PEAK/GROUPE (Restitution): Conversion Wav vers Ogg");
 
 			List = g_list_first (normalise.ListPeakGroupOgg);
 			while (List) {
@@ -1354,14 +1341,18 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 					infosong_delete_file (IndiFix->NameFileCopieWav);
 
 					normalise.ElementActif ++;
+				
+					logs_writeln_datas ("PEAK/GROUPE: OGG");
+					logs_write_datas ("\t");
+					logs_writeln_datas (IndiFix->NameDestOgg);
 				}
 				List = g_list_next(List);
 			}
 		}
 		/* Restitue liste MP3 */
 		if (IndiFix->BoolWithConvert == FALSE) {
-			normalise.MessUser = g_strdup ("PEAK/GROUPE (Restitution): Conversion Wav vers Mp3");
-			normalise.bool_etat = TRUE;
+
+			normalise_set_mess ("PEAK/GROUPE (Restitution): Conversion Wav vers Mp3");
 
 			List = g_list_first (normalise.ListPeakGroupMp3);
 			while (List) {
@@ -1385,6 +1376,10 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 					infosong_delete_file (IndiFix->NameFileCopieWav);
 
 					normalise.ElementActif ++;
+				
+					logs_writeln_datas ("PEAK/GROUPE: MP3");
+					logs_write_datas ("\t");
+					logs_writeln_datas (IndiFix->NameDestMp3);
 				}
 				List = g_list_next(List);
 			}
@@ -1394,7 +1389,7 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 
 void normalise_action (void)
 {
-	PRINT_FUNC_LF();
+	// PRINT_FUNC_LF();
 
 	normalise.bool_pass_conv = TRUE;
 	
@@ -1555,49 +1550,51 @@ gboolean normalise_with_convert (DETAIL *detail)
 	return (FALSE);
 }
 
-void normalise_verif (gchar *Name)
-{
-	GList            *List = NULL;
-	DETAIL           *detail = NULL;
-	FIC              *Fic = NULL;
 
+void normalise_force_scan (gchar *p_Name)
+{
+	GList		*List = NULL;
+	DETAIL		*detail = NULL;
+	FIC		*Fic = NULL;
+	
 	List = g_list_first (entetefile);
 	while (List) {
-		if ((detail = (DETAIL *)List->data)) {
-			if ((Fic = (FIC *)detail->fic)) {
-				if (strcmp (Name, detail->namefile) == 0) {
-					if (detail->type_infosong_file_is == FILE_IS_WAV ||
-					    detail->type_infosong_file_is == FILE_IS_OGG ||
-					    detail->type_infosong_file_is == FILE_IS_MP3) {
-
-						/* Fic->Etat_Normalise = NORM_SCAN_ACTIF; */
+		if ((detail = (DETAIL *)List->data) != NULL) {
+			if ((Fic = (FIC *)detail->fic) != NULL) {
+			
+				if (detail->type_infosong_file_is == FILE_IS_WAV ||
+				    detail->type_infosong_file_is == FILE_IS_OGG ||
+				    detail->type_infosong_file_is == FILE_IS_MP3) {
+				    	
+				    	if (strcmp (detail->namefile, p_Name) == 0) {
+				    	
+				    		if (Fic->Etat_Normalise == NORM_RMS_MIX_ALBUM || Fic->Etat_Normalise == NORM_RMS_FIX) {
+							Fic->Etat_Scan = ETAT_SCAN_NONE;
+							break;
+						}
 					}
 				}
 			}
-			List = g_list_next(List);
-		}
-	}
-}
-
-void normalise_set_verif (GList *p_list)
-{
-	/*
-	GList     *List = NULL;
-	INDI_FIX  *IndiFix = NULL;
-	
-	List = g_list_first (p_list);
-	while (List) {
-		if ((IndiFix = (INDI_FIX *)List->data)) {
-			
-			if (*IndiFix->EtatNormalise == NORM_SCAN_ACTIF) {
-				normalise_verif (IndiFix->NameDestWav);
-				normalise_verif (IndiFix->NameDestOgg);
-				normalise_verif (IndiFix->NameDestMp3);
-			}
 		}
 		List = g_list_next(List);
 	}
-	*/
+}
+
+void normalise_set_verif (GList *p_List)
+{
+	GList		*List = NULL;
+	INDI_FIX	*IndiFix = NULL;
+
+	List = g_list_first (p_List);
+	while (List) {
+		if ((IndiFix = (INDI_FIX *)List->data) != NULL) {
+			normalise_force_scan (IndiFix->NameFile);
+			normalise_force_scan (IndiFix->NameDestWav);
+			normalise_force_scan (IndiFix->NameDestOgg);
+			normalise_force_scan (IndiFix->NameDestMp3);
+		}
+		List = g_list_next(List);
+	}
 }
 
 static void normalise_struct_lists (void *arg)
@@ -1607,7 +1604,7 @@ static void normalise_struct_lists (void *arg)
 	FIC              *Fic = NULL;
 	INDI_FIX         *IndiFix = NULL;
 
-	PRINT_FUNC_LF();
+	// PRINT_FUNC_LF();
 
 	normalise.bool_thread_end = FALSE;
 	normalise.bool_set_end_of_user = FALSE;
@@ -1680,6 +1677,8 @@ static void normalise_struct_lists (void *arg)
 							IndiFix->EtatTrash     = &Fic->EtatTrash;
 							
 							normalise_get_NameFileCopie (IndiFix, g_list_position (entetefile, List));
+							// GList *g_list_nth (GList *list, guint n);
+										
 							if ((IndiFix->BoolWithConvert = normalise_with_convert (detail)) == TRUE) {
 								detail->namefileCopie = g_strdup (IndiFix->NameFileCopieWav);
 							}
@@ -1888,57 +1887,53 @@ static gint normalise_timeout (gpointer data)
 	}
 
 	if (normalise.bool_etat == TRUE) {
-		/*WinNormReplay_set_etat (normalise.MessUser);*/
-		g_free (normalise.MessUser);
-		normalise.MessUser = NULL;
+		if (normalise.MessUser != NULL) {
+			// WinNormReplay_set_etat (normalise.MessUser);
+			g_free (normalise.MessUser);
+			normalise.MessUser = NULL;
+		}
 		normalise.bool_etat = FALSE;
 	}
 
 	if (normalise.bool_pass_conv == TRUE) {
 
-		/*
 		gchar *str = NULL;
     		gchar *spinner="|/-\\";
-		
-		str = g_strdup_printf ("<b>En cours: %d sur %d   %c </b>", normalise.ElementActif +1, normalise.NbrElementsInList, spinner[normalise.pass_conv++%4]);
-		WinNormReplay_set_compteur (str);
-		g_free (str);
-		str = NULL;
-		*/
-		
-		gchar *str = NULL;
-    		gchar *spinner="|/-\\";
-		gchar *Ptr = NULL;
+		// gchar *Ptr = NULL;
 		gchar  foo [ 2 ];
 		
 		foo [ 0 ] = spinner[normalise.pass_conv++%4];
 		foo [ 1 ] = '\0';
-		Ptr = utils_convert_string (foo, TRUE);
+		// Ptr = utils_convert_string (foo, TRUE);
 		
 		str = g_strdup_printf ("<b>En cours: %d sur %d   %s</b>",
 					normalise.ElementActif +1,
 					normalise.NbrElementsInList,
-					Ptr);
+					foo
+					);
 		WinNormReplay_set_compteur (str);
 		g_free (str);
 		str = NULL;
-		g_free (Ptr);
-		Ptr = NULL;
+		// g_free (Ptr);
+		// Ptr = NULL;
 
 		return (TRUE);
 	}
 
 	else if (normalise.bool_thread_end == TRUE && normalise.bool_set_end_of_user == TRUE) {
+		
 		/* FIX */
+		
 		normalise_set_verif (normalise.ListFixWav);
 		normalise_set_verif (normalise.ListFixOgg);
 		normalise_set_verif (normalise.ListFixMp3);
-	
+		
 		normalise.ListFixWav		= normalise_remove_glist_STRUCT (normalise.ListFixWav);
 		normalise.ListFixOgg		= normalise_remove_glist_STRUCT (normalise.ListFixOgg);
 		normalise.ListFixMp3		= normalise_remove_glist_STRUCT (normalise.ListFixMp3);
 		
 		/* PEAK */
+		
 		normalise_set_verif (normalise.ListPeakWav);
 		normalise_set_verif (normalise.ListPeakOgg);
 		normalise_set_verif (normalise.ListPeakMp3);
@@ -1948,28 +1943,30 @@ static gint normalise_timeout (gpointer data)
 		normalise.ListPeakMp3		= normalise_remove_glist_STRUCT (normalise.ListPeakMp3);
 		
 		/* MIX */
+		
 		normalise_set_verif (normalise.ListMixGroupWav);
 		normalise_set_verif (normalise.ListMixGroupOgg);
 		normalise_set_verif (normalise.ListMixGroupMp3);
-	
+		
 		normalise.ListMixGroupWav	= normalise_remove_glist_STRUCT (normalise.ListMixGroupWav);
 		normalise.ListMixGroupOgg	= normalise_remove_glist_STRUCT (normalise.ListMixGroupOgg);
 		normalise.ListMixGroupMp3	= normalise_remove_glist_STRUCT (normalise.ListMixGroupMp3);
 		
 		/* PEAK-GROUP */
+		
 		normalise_set_verif (normalise.ListPeakGroupWav);
 		normalise_set_verif (normalise.ListPeakGroupOgg);
 		normalise_set_verif (normalise.ListPeakGroupMp3);
-	
+		
 		normalise.ListPeakGroupWav	= normalise_remove_glist_STRUCT (normalise.ListPeakGroupWav);
 		normalise.ListPeakGroupOgg	= normalise_remove_glist_STRUCT (normalise.ListPeakGroupOgg);
 		normalise.ListPeakGroupMp3	= normalise_remove_glist_STRUCT (normalise.ListPeakGroupMp3);
 
-		file_pixbuf_update_glist_file ();
 		WinNormReplay_close ();
 		fileaction_set_end ();
 		gtk_timeout_remove (normalise.Handler_Timeout);
 		conv_set_struct_not_used ();
+		file_pixbuf_update_glist_file ();
 	}
 
 	return (TRUE);
@@ -1982,8 +1979,10 @@ static gint normalise_timeout (gpointer data)
 */
 void normalise_file (void)
 {
-	/*PRINT_FUNC_LF();*/
+	// PRINT_FUNC_LF();
 
+	logs_add_datas_session ("FROM FILE->NORMALISE");
+	
 	normalise.bool_thread_end = FALSE;
 	normalise.bool_set_end_of_user = FALSE;
 	normalise.bool_pass_conv = FALSE;
@@ -1994,7 +1993,7 @@ void normalise_file (void)
 
 	conv_reset_struct ();
 	
-	WinNormReplay_Create ("Normalise");
+	WinNormReplay_Create (_("Normalise"));
 	WinNormReplay_reset_progressBar ();
 	pthread_create (&normalise.nmr_tid, NULL ,(void *)normalise_struct_lists, (void *)NULL);
 	normalise.Handler_Timeout = gtk_timeout_add (100, normalise_timeout, 0);
