@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -32,7 +32,7 @@
 
 
 #include <gtk/gtk.h>
-#include "support.h"
+
 #include <string.h>
 #include "global.h"
 #include "config_user.h"
@@ -152,7 +152,9 @@ void options_make_combobox_nice (GtkWidget *widget)
 	gchar *Ptr = NULL;
 
 	/* PRINT_FUNC_LF(); */
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	for (i = 0; i < 20; i++) {
 		Ptr = g_strdup_printf ("%d", i);
 		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), Ptr);
@@ -302,33 +304,6 @@ void options_init (void)
 }
 
 
-/* La gestion de l'installation des paquets sera faite sur systeme DEBIAN par:
-*     0 = apt-get
-*     1 = aptitude
-*/
-void options_set_administrator_of_packets (void)
-{
-	/*
-	frame_choix_install_debian
-	radiobutton_install_aptget
-	radiobutton_install_aptitude
-	*/
-	if (Config_User.AdministratorOfPackets == 0)
-		gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "radiobutton_install_aptget"))), TRUE);
-	else
-		gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "radiobutton_install_aptitude"))), TRUE);
-	
-	if (var_options.Type_Package != _DEBIAN_)
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "frame_choix_install_debian")), FALSE);
-}
-gint options_get_administrator_of_packets (void)
-{
-	Config_User.AdministratorOfPackets = 0;
-	if (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GTK_WIDGET (lookup_widget (wind_main, "radiobutton_install_aptitude")))))
-		Config_User.AdministratorOfPackets = 1;
-	return (Config_User.AdministratorOfPackets);
-}
-
 /*
 *---------------------------------------------------------------------------
 * Dossier temporaire
@@ -412,7 +387,7 @@ void options_default_values (GtkButton *button)
 	/*
 	PRINT_FUNC_LF();
 	*/
-	if (button == GTK_BUTTON (lookup_widget (wind_main, "button_defaut_lame"))){
+	if (button == GTK_BUTTON (XCFA_GET_OBJECT("button_defaut_lame"))){
 		/* Set ABR/CBR/VBR/VBR-NEW qui passe le debit par defaut */
 		Config_User.RateMp3OggOptions.Bitrate_type_Lame = ConfigUserSave.RateMp3OggOptions.Bitrate_type_Lame;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_abr_cbr_vbr), Config_User.RateMp3OggOptions.Bitrate_type_Lame);
@@ -441,7 +416,7 @@ void options_default_values (GtkButton *button)
 		Config_User.RateMp3OggOptions.Mode_Lame = ConfigUserSave.RateMp3OggOptions.Mode_Lame;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_Mode), Config_User.RateMp3OggOptions.Mode_Lame);
 	}
-	else if (button == GTK_BUTTON (lookup_widget (wind_main, "button_defaut_oggenc"))){
+	else if (button == GTK_BUTTON (XCFA_GET_OBJECT("button_defaut_oggenc"))){
 		/* Debit */
 		Config_User.RateMp3OggOptions.Bitrate_Oggenc = ConfigUserSave.RateMp3OggOptions.Bitrate_Oggenc;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_Oggenc_bitrate), Config_User.RateMp3OggOptions.Bitrate_Oggenc);
@@ -452,17 +427,17 @@ void options_default_values (GtkButton *button)
 		Config_User.RateMp3OggOptions.Downmix_Oggenc = ConfigUserSave.RateMp3OggOptions.Downmix_Oggenc;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_Oggenc_downmix), Config_User.RateMp3OggOptions.Downmix_Oggenc);
 	}
-	else if (button == GTK_BUTTON (lookup_widget (wind_main, "button_defaut_flac"))){
+	else if (button == GTK_BUTTON (XCFA_GET_OBJECT("button_defaut_flac"))){
 		/* Taux de compression */
 		Config_User.compression_level_flac = ConfigUserSave.compression_level_flac;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_flac_compression), Config_User.compression_level_flac);
 	}
-	else if (button == GTK_BUTTON (lookup_widget (wind_main, "button_defaut_mac"))){
+	else if (button == GTK_BUTTON (XCFA_GET_OBJECT("button_defaut_mac"))){
 		/* Qualite */
 		Config_User.compression_level_ape = ConfigUserSave.compression_level_ape;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_ape_compression), Config_User.compression_level_ape);
 	}
-	else if (button == GTK_BUTTON (lookup_widget (wind_main, "button_defaut_wavpack"))){
+	else if (button == GTK_BUTTON (XCFA_GET_OBJECT("button_defaut_wavpack"))){
 		/* Compression */
 		Config_User.compression_wavpack = ConfigUserSave.compression_wavpack;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_wavpack), Config_User.compression_wavpack);
@@ -485,12 +460,12 @@ void options_default_values (GtkButton *button)
 		Config_User.wavpack_extra_encoding = ConfigUserSave.wavpack_extra_encoding;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_wavpack_extra_encoding), Config_User.wavpack_extra_encoding);
 	}
-	else if (button == GTK_BUTTON (lookup_widget (wind_main, "button_defaut_musepack"))){
+	else if (button == GTK_BUTTON (XCFA_GET_OBJECT("button_defaut_musepack"))){
 		/* Extra encoding */
 		Config_User.quality_mppenc = ConfigUserSave.quality_mppenc;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_Mppenc), Config_User.quality_mppenc);
 	}
-	else if (button == GTK_BUTTON (lookup_widget (wind_main, "button_defaut_faac"))){
+	else if (button == GTK_BUTTON (XCFA_GET_OBJECT("button_defaut_faac"))){
 		Config_User.faac_conteneur      = ConfigUserSave.faac_conteneur;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_conteneur), Config_User.faac_conteneur);
 		
@@ -500,14 +475,484 @@ void options_default_values (GtkButton *button)
 		Config_User.faac_set_choice_vbr = ConfigUserSave.faac_set_choice_vbr;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), Config_User.faac_set_choice_vbr);
 	}
-	else if (button == GTK_BUTTON (lookup_widget (wind_main, "button_defaut_aacplusenc"))){
+	else if (button == GTK_BUTTON (XCFA_GET_OBJECT("button_defaut_aacplusenc"))){
 		Config_User.aacplusenc_choice_mono = ConfigUserSave.aacplusenc_choice_mono;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_aacplusenc_mono), Config_User.aacplusenc_choice_mono);
 		Config_User.aacplusenc_choice_stereo = ConfigUserSave.aacplusenc_choice_stereo;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_aacplusenc_stereo), Config_User.aacplusenc_choice_stereo);
 	}
-	
-	
 }
 
 
+
+
+
+gchar *options_get_param_oggenc (FIC_MP3OGG *Fic)
+{
+	gchar StrOggenc[ 1000 ];
+
+	gchar *val[] = {
+	"--bitrate=45",
+	"--bitrate=64",
+	"--bitrate=80",
+	"--bitrate=96",
+	"--bitrate=112",
+	"--bitrate=128",
+	"--bitrate=160",
+	"--bitrate=192",
+	"--bitrate=224",
+	"--bitrate=256",
+	"--bitrate=320",
+	"--quality=-1",
+	"--quality=0",
+	"--quality=1",
+	"--quality=2",
+	"--quality=3",
+	"--quality=4",
+	"--quality=5",
+	"--quality=6",
+	"--quality=7",
+	"--quality=8",
+	"--quality=9",
+	"--quality=10"
+	};
+	
+	
+	// Fic->Oggenc.type
+	// Fic->Oggenc.debit
+	// Fic->Oggenc.mode
+	
+	// val
+	// 0 = --managed || 1 = ""
+	// 0 = --downmix || 1 = ""
+	
+	// PRINT_FUNC_LF();
+
+	if (var_file.Adr_Widget_Oggenc_bitrate == NULL) return ((gchar *)NULL);
+
+	strcpy (StrOggenc, val[ Fic->Oggenc.type ]);
+	
+	if (Fic->Oggenc.type < 11 && Fic->Oggenc.debit == 0) {
+		if (*StrOggenc != '\0') strcat (StrOggenc, " ");
+		strcat (StrOggenc, "--managed");
+	}
+	if (Fic->Oggenc.type < 9 && Fic->Oggenc.mode == 0) {
+		if (*StrOggenc != '\0') strcat (StrOggenc, " ");
+		strcat (StrOggenc, "--downmix");
+	}
+
+	return ((gchar *)g_strdup (StrOggenc));
+}
+
+gchar *options_get_param_OptionsOggenc (void)
+{
+	gchar StrOggenc[ 1000 ];
+
+	gchar *val[] = {
+	"--bitrate=45",
+	"--bitrate=64",
+	"--bitrate=80",
+	"--bitrate=96",
+	"--bitrate=112",
+	"--bitrate=128",
+	"--bitrate=160",
+	"--bitrate=192",
+	"--bitrate=224",
+	"--bitrate=256",
+	"--bitrate=320",
+	"--quality=-1",
+	"--quality=0",
+	"--quality=1",
+	"--quality=2",
+	"--quality=3",
+	"--quality=4",
+	"--quality=5",
+	"--quality=6",
+	"--quality=7",
+	"--quality=8",
+	"--quality=9",
+	"--quality=10"
+	};
+
+	// PRINT_FUNC_LF();
+
+	strcpy (StrOggenc, "");
+	
+	// val
+	// 0 = --managed || 1 = ""
+	// 0 = --downmix || 1 = ""
+	
+	if (var_options.Adr_Widget_Oggenc_bitrate != NULL) {
+		strcat (StrOggenc, (gchar *)val[ gtk_combo_box_get_active (var_options.Adr_Widget_Oggenc_bitrate) ]);
+	}
+	if (gtk_combo_box_get_active (var_options.Adr_Widget_Oggenc_bitrate) < 11) {
+		if (gtk_combo_box_get_active (var_options.Adr_Widget_Oggenc_managed) == 0) {
+			if (*StrOggenc != '\0') strcat (StrOggenc, " ");
+			strcat (StrOggenc, "--managed");
+		}
+	}
+	if (gtk_combo_box_get_active (var_options.Adr_Widget_Oggenc_bitrate) < 9) {
+		if (gtk_combo_box_get_active (var_options.Adr_Widget_Oggenc_downmix) == 0) {
+			if (*StrOggenc != '\0') strcat (StrOggenc, " ");
+			strcat (StrOggenc, "--downmix");
+		}
+	}
+
+	return ((gchar *)g_strdup (StrOggenc));
+}
+
+gchar *options_get_param_OptionsLame (void)
+{
+	gchar StrLame[ 1000 ];
+	
+	gchar *str_abr [] = {
+	"-b 32",
+	"-b 40",
+	"-b 48",
+	"-b 56",
+	"-b 64",
+	"-b 80",
+	"-b 96",
+	"-b 112",
+	"-b 128",
+	"-b 160",
+	"-b 192",
+	"-b 224",
+	"-b 256",
+	"-b 320"
+	};
+
+	gchar *str_cbr [] = {
+	"-b 32",
+	"-b 40",
+	"-b 48",
+	"-b 56",
+	"-b 64",
+	"-b 80",
+	"-b 96",
+	"-b 112",
+	"-b 128",
+	"-b 160",
+	"-b 192",
+	"-b 224",
+	"-b 256",
+	"-b 320",
+	"--preset insane"
+	};
+
+	gchar *str_vbr [] = {
+	"--preset medium",
+	"--preset standard",
+	"--preset extreme",
+	"--preset fast standard",
+	"--preset fast extreme",
+	"-V0",
+	"-V1",
+	"-V2",
+	"-V3",
+	"-V4",
+	"-V5",
+	"-V6",
+	"-V7",
+	"-V8",
+	"-V9"
+	};
+
+	gchar *str_vbr_new [] = {
+	"--vbr-new",
+	"--vbr-new --preset medium",
+	"--vbr-new --preset standard",
+	"--vbr-new --preset extreme",
+	"--vbr-new --preset fast standard",
+	"--vbr-new --preset fast extreme",
+	"--vbr-new -V0",
+	"--vbr-new -V1",
+	"--vbr-new -V2",
+	"--vbr-new -V3",
+	"--vbr-new -V4",
+	"--vbr-new -V5",
+	"--vbr-new -V6",
+	"--vbr-new -V7",
+	"--vbr-new -V8",
+	"--vbr-new -V9"
+	};
+	
+	gchar *str_val_mode[] = {
+	"",	/* Defaut		*/
+	"-m s",	/* Stereo		*/
+	"-m j",	/* Join Stereo		*/
+	"-m f",	/* Forced Join Stereo	*/
+	"-m d",	/* Duo Channels		*/
+	"-m m"	/* Mono			*/
+	};
+	
+	// PRINT_FUNC_LF();
+
+	StrLame [ 0 ] = '\0';
+
+	if (var_options.Adr_Widget_Lame_bitrate != NULL || var_options.Adr_Widget_Lame_abr_cbr_vbr != NULL) {
+		
+		gint ValBitrate = gtk_combo_box_get_active (var_options.Adr_Widget_Lame_bitrate);
+		
+		switch (gtk_combo_box_get_active (var_options.Adr_Widget_Lame_abr_cbr_vbr)) {
+		
+		/* ABR */
+		case 0 :
+			strcpy (StrLame, str_abr [ ValBitrate ]);
+			break;
+		
+		/* CBR */
+		case 1 :
+			strcpy (StrLame, str_cbr [ ValBitrate ]);
+			break;
+		
+		/* VBR */
+		case 2 :
+			strcpy (StrLame, str_vbr [ ValBitrate ]);
+			break;
+			
+		/* VBR_NEW */
+		case 3 :
+			strcpy (StrLame, str_vbr_new [ ValBitrate ]);
+			break;
+		}
+	}
+	if (var_options.Adr_Widget_Lame_Mode != NULL) {
+		
+		gint Mode = gtk_combo_box_get_active (var_options.Adr_Widget_Lame_Mode);
+		
+		if (Mode > 0) {
+			if (*StrLame != '\0') strcat (StrLame, " ");
+			strcat (StrLame, str_val_mode[ Mode ]);
+		}
+	}
+	
+	return ((gchar *)g_strdup (StrLame));
+}
+
+
+
+
+gchar *options_get_param_lame (FIC_MP3OGG *Fic)
+{
+	gchar StrLame[ 1000 ];
+
+	gchar *str_abr [] = {
+	"-b 32",
+	"-b 40",
+	"-b 48",
+	"-b 56",
+	"-b 64",
+	"-b 80",
+	"-b 96",
+	"-b 112",
+	"-b 128",
+	"-b 160",
+	"-b 192",
+	"-b 224",
+	"-b 256",
+	"-b 320"
+	};
+	gchar *str_cbr [] = {
+	"-b 32",
+	"-b 40",
+	"-b 48",
+	"-b 56",
+	"-b 64",
+	"-b 80",
+	"-b 96",
+	"-b 112",
+	"-b 128",
+	"-b 160",
+	"-b 192",
+	"-b 224",
+	"-b 256",
+	"-b 320",
+	"--preset insane"
+	};
+	gchar *str_vbr [] = {
+	"--preset medium",
+	"--preset standard",
+	"--preset extreme",
+	"--preset fast standard",
+	"--preset fast extreme",
+	"-V0",
+	"-V1",
+	"-V2",
+	"-V3",
+	"-V4",
+	"-V5",
+	"-V6",
+	"-V7",
+	"-V8",
+	"-V9"
+	};
+	gchar *str_vbr_new [] = {
+	"--vbr-new",
+	"--vbr-new --preset medium",
+	"--vbr-new --preset standard",
+	"--vbr-new --preset extreme",
+	"--vbr-new --preset fast standard",
+	"--vbr-new --preset fast extreme",
+	"--vbr-new -V0",
+	"--vbr-new -V1",
+	"--vbr-new -V2",
+	"--vbr-new -V3",
+	"--vbr-new -V4",
+	"--vbr-new -V5",
+	"--vbr-new -V6",
+	"--vbr-new -V7",
+	"--vbr-new -V8",
+	"--vbr-new -V9"
+	};
+
+	gchar *str_val_mode[] = {
+	"",	/* Defaut		*/
+	"-m s",	/* Stereo		*/
+	"-m j",	/* Join Stereo		*/
+	"-m f", /* Forced Join Stereo	*/
+	"-m d",	/* Duo Channels		*/
+	"-m m"	/* Mono			*/
+	};
+
+
+	// PRINT_FUNC_LF();
+	
+	StrLame [ 0 ] = '\0';
+
+	if (var_file.Adr_Widget_Lame_bitrate != NULL || var_file.Adr_Widget_Lame_abr_cbr_vbr != NULL) {
+
+		// switch (gtk_combo_box_get_active (var_file.Adr_Widget_Lame_abr_cbr_vbr)) {
+		switch (Fic->Lame.type) {
+		
+		/* ABR */
+		case 0 :
+			strcat (StrLame, str_abr [ Fic->Lame.debit ]);
+			break;
+
+		/* CBR */
+		case 1 :
+			strcat (StrLame, str_cbr [ Fic->Lame.debit ]);
+			break;
+
+		/* VBR */
+		case 2 :
+			strcat (StrLame, str_vbr [ Fic->Lame.debit ]);
+			break;
+
+		/* VBR_NEW */
+		case 3 :
+			strcat (StrLame, str_vbr_new [ Fic->Lame.debit ]);
+			break;
+		}
+	}
+	if (var_file.Adr_Widget_Lame_Mode != NULL) {
+
+		if (Fic->Lame.mode > 0) {
+			if (*StrLame != '\0') strcat (StrLame, " ");
+			strcat (StrLame, str_val_mode[ Fic->Lame.mode ]);
+		}
+	}
+
+	return ((gchar *)g_strdup (StrLame));
+}
+
+/*
+	TYPE_CONV
+		LAME_WAV_TO_MP3 | OGGENC_WAV_TO_OGG
+	PARAM_FILELC
+		FALSE : Parametres depuis l'onglet Preferences
+		TRUE  : Parametres du fichier pointe par *FIC depuis Fichiers->Mp3Ogg
+	FIC_MP3OGG
+		Pointeur de structure
+*/
+gchar *options_get_params (TYPE_CONV TypeConv, PARAM_FILELC ParamFileLc, FIC_MP3OGG *Fic)
+{
+	if (TypeConv == LAME_WAV_TO_MP3) {
+						
+		if (ParamFileLc.BoolSetBitrate == TRUE) {
+			
+			// file_get_param_lame ()
+			// g_print("ParamFileLc.BoolSetBitrate == TRUE\n");
+			// g_print("Fic->Lame.type  = %d\n", Fic->Lame.type);
+			// g_print("Fic->Lame.debit = %d\n", Fic->Lame.debit);
+			// g_print("Fic->Lame.mode  = %d\n", Fic->Lame.mode);
+			return ((gchar *)options_get_param_lame (Fic));
+		}
+		else if (ParamFileLc.BoolSetBitrate == FALSE) {
+			
+			// options_get_param_OptionsLame ()
+			// g_print("ParamFileLc.BoolSetBitrate == FALSE\n");
+			return ((gchar *)options_get_param_OptionsLame ());
+		}
+	}
+	else if (TypeConv == OGGENC_WAV_TO_OGG || TypeConv == OGGENC_FLAC_TO_OGG) {
+		
+		if (TypeConv == OGGENC_WAV_TO_OGG && ParamFileLc.BoolSetBitrate == TRUE) {
+			
+			// file_get_param_oggenc ()
+			// g_print("ParamFileLc.BoolSetBitrate == TRUE\n");
+			// g_print("Fic->Oggenc.type  = %d\n", Fic->Oggenc.type);
+			// g_print("Fic->Oggenc.debit = %d\n", Fic->Oggenc.debit);
+			// g_print("Fic->Oggenc.mode  = %d\n", Fic->Oggenc.mode);
+			return ((gchar *)options_get_param_oggenc (Fic));
+		}
+		else if (ParamFileLc.BoolSetBitrate == FALSE) {
+			
+			// optionsOggenc_get_param_oggenc ()
+			// g_print("ParamFileLc.BoolSetBitrate == FALSE\n");
+			return ((gchar *)options_get_param_OptionsOggenc ());
+		}
+	}
+	
+	return ((gchar *)NULL);
+}
+/*
+typedef struct {
+	gint			type;
+	gint			debit;
+	gint			mode;
+
+} TYPE_MP3OGG;
+
+
+	TYPE_MP3OGG		Lame;
+	TYPE_MP3OGG		Oggenc;
+	
+} FIC_MP3OGG;
+void options_get_param_combo_lame (FIC_MP3OGG *Fic)
+{
+	Fic->Lame.type  = gtk_combo_box_get_active (GTK_COMBO_BOX(XCFA_GET_OBJECT("combobox_lame_abr_cbr_vbr_mp3ogg")));
+	Fic->Lame.debit = gtk_combo_box_get_active (GTK_COMBO_BOX(XCFA_GET_OBJECT("combobox_lame_type_bitrate_mp3ogg")));
+	Fic->Lame.mode  = gtk_combo_box_get_active (GTK_COMBO_BOX(XCFA_GET_OBJECT("combobox_lame_mode_mp3ogg")));
+
+	Fic->Lame.type  = Config_User.RateMp3OggFile.Bitrate_type_Lame;
+	switch (Config_User.RateMp3OggFile.Bitrate_type_Lame) {
+	case 0 :
+		Fic->Lame.debit = Config_User.RateMp3OggFile.If_abr;
+		break;
+	case 1 :
+		Fic->Lame.debit = Config_User.RateMp3OggFile.If_cbr;
+		break;
+	case 2 :
+		Fic->Lame.debit = Config_User.RateMp3OggFile.If_vbr;
+		break;
+	case 3:
+		Fic->Lame.debit = Config_User.RateMp3OggFile.If_vbr_new;
+		break;
+	default :
+		Fic->Lame.debit = 0;
+	}
+	Fic->Lame.mode  = Config_User.RateMp3OggFile.Mode_Lame;
+}
+void options_get_param_combo_oggenc (FIC_MP3OGG *Fic)
+{
+	Fic->Oggenc.type  = gtk_combo_box_get_active (GTK_COMBO_BOX(XCFA_GET_OBJECT("combobox_oggenc_bitrate_mp3ogg")));
+	Fic->Oggenc.debit = gtk_combo_box_get_active (GTK_COMBO_BOX(XCFA_GET_OBJECT("combobox_oggenc_managed_mp3ogg")));
+	Fic->Oggenc.mode  = gtk_combo_box_get_active (GTK_COMBO_BOX(XCFA_GET_OBJECT("combobox_oggenc_downmix_m3ogg")));
+	Fic->Oggenc.type  = Config_User.RateMp3OggFile.Bitrate_Oggenc;
+	Fic->Oggenc.debit = Config_User.RateMp3OggFile.Managed_Oggenc;
+	Fic->Oggenc.mode  = Config_User.RateMp3OggFile.Downmix_Oggenc;
+}
+*/
+
