@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -171,12 +171,12 @@ void		options_entry_op_internal_changed (GtkEditable *editable);
 void		options_init (void);
 gboolean	options_get_entry_is_valid (TYPE_CONV p_verif_conv);
 gboolean	options_bool_add_line_command (TYPE_CONV p_type_conv, gchar **entry);
-void		options_set_administrator_of_packets (void);
 gint		options_get_administrator_of_packets (void);
 void		options_button_dossier_de_conversion_realize (GtkWidget *widget);
 void		options_button_dossier_de_conversion_clicked (void);
 gboolean	options_verif_dossier_is_ok (gchar *path);
 void		options_default_values (GtkButton *button);
+gchar          *options_get_params (TYPE_CONV TypeConv, PARAM_FILELC ParamFileLc, FIC_MP3OGG *Fic);
 
 /*
 *---------------------------------------------------------------------------
@@ -192,7 +192,6 @@ void      optionsLame_make_combobox_lame_mode_realize (GtkWidget *widget);
 void      optionsLame_combobox_lame_mode_changed (void);
 gchar    *optionsLame_get_str_val_bitrate_abr_vbr_lame (void);
 gchar    *optionsLame_get_str_val_mode_lame (void);
-gchar    *optionsLame_get_param_lame (void);
 
 /*
 *---------------------------------------------------------------------------
@@ -219,7 +218,6 @@ void      optionsOggenc_combobox_oggenc_downmix_realize (GtkWidget *widget);
 void      optionsOggenc_combobox_oggenc_downmix_changed (void);
 gboolean  optionsOggenc_get_bool_managed_oggenc (void);
 gboolean  optionsOggenc_get_bool_downmix_oggenc (void);
-gchar    *optionsOggenc_get_param_oggenc (void);
 
 /*
 *---------------------------------------------------------------------------
