@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -32,7 +32,7 @@
 
 
 #include <gtk/gtk.h>
-#include "support.h"
+
 #include <string.h>
 #include "global.h"
 #include "config_user.h"
@@ -68,6 +68,7 @@
 */
 void optionsaacplusenc_combobox_accplusenc_mono_realize (GtkWidget *widget)
 {
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "10");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "12");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "14");
@@ -82,6 +83,7 @@ void optionsaacplusenc_combobox_accplusenc_mono_realize (GtkWidget *widget)
 
 void optionsaacplusenc_combobox_accplusenc_stereo_realize (GtkWidget *widget)
 {
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "18");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "24");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "32");
