@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -32,7 +32,7 @@
 
 
 #include <gtk/gtk.h>
-#include "support.h"
+
 #include <string.h>
 #include "global.h"
 #include "config_user.h"
@@ -63,7 +63,8 @@ void OptionsFaac_combobox_faac_set_choice_vbr_abr_changed_ (void)
 	if (var_options.bool_changed == FALSE) return;
 	var_options.bool_changed = FALSE;
 	
-	utils_clear_elements_combobox (GTK_WIDGET (var_options.Adr_Widget_faac_set_choice_vbr_abr));
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr));
+	utils_alloc_combo (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr));
 	
 	switch (gtk_combo_box_get_active (var_options.Adr_Widget_faac_choice_vbr_abr)) {
 	
@@ -111,7 +112,8 @@ void OptionsFaac_combobox_faac_conteneur_realize (GtkWidget *widget)
 {
 	/*PRINT_FUNC_LF();*/
 	
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
 
 	/*
 	Titre de l'option = Conteneur
@@ -137,7 +139,8 @@ void OptionsFaac_combobox_faac_choice_vbr_abr_realize (GtkWidget *widget)
 {
 	/*PRINT_FUNC_LF();*/
 	
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
      	/*
 	Titre de l'option = VBR / ABR
 	Choix = VBR /OU/ ABR
@@ -163,7 +166,8 @@ void OptionsFaac_combobox_faac_set_choice_vbr_abr_realize (GtkWidget *widget)
 {
 	/*PRINT_FUNC_LF();*/
 	
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
 
 	var_options.Adr_Widget_faac_set_choice_vbr_abr = GTK_COMBO_BOX (widget);
 	var_options.bool_changed = TRUE;
