@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -37,8 +37,6 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 
-#include "support.h"
-
 #include "global.h"
 #include "config_user.h"
 #include "cd_audio.h"
@@ -134,7 +132,9 @@
 void optionsLame_combobox_lame_abr_cbr_vbr_realize (GtkWidget *widget)
 {
 	var_options.Adr_Widget_Lame_abr_cbr_vbr = GTK_COMBO_BOX (widget);
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "ABR");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "CBR");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "VBR");
@@ -146,7 +146,8 @@ void optionsLame_combobox_lame_abr_cbr_vbr_changed (void)
 	if (var_options.Adr_Widget_Lame_abr_cbr_vbr == NULL || var_options.Adr_Widget_Lame_bitrate == NULL) return;
 
 	var_options.bool_changed = FALSE;
-	utils_clear_elements_combobox (GTK_WIDGET (var_options.Adr_Widget_Lame_bitrate));
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate));
+	utils_alloc_combo (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate));
 	
 	Config_User.RateMp3OggOptions.Bitrate_type_Lame = gtk_combo_box_get_active (var_options.Adr_Widget_Lame_abr_cbr_vbr);
 
@@ -292,7 +293,8 @@ void optionsLame_make_combobox_lame_mode_realize (GtkWidget *widget)
 	(m)ono
 	*/
 
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
 
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Defaut");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Stereo");
@@ -520,139 +522,4 @@ void optionsLame_combobox_lame_mode_changed (void)
 	options_set_datas_interne (COLOR_LAME_MODE, var_options.Adr_label_lame_mp3, LAME_WAV_TO_MP3);
 }
 
-gchar *optionsLame_get_param_lame (void)
-{
-	gchar StrLame[ 1000 ];
-	
-	gchar *str_abr [] = {
-	"-b 32",
-	"-b 40",
-	"-b 48",
-	"-b 56",
-	"-b 64",
-	"-b 80",
-	"-b 96",
-	"-b 112",
-	"-b 128",
-	"-b 160",
-	"-b 192",
-	"-b 224",
-	"-b 256",
-	"-b 320"
-	};
-
-	gchar *str_cbr [] = {
-	"-b 32",
-	"-b 40",
-	"-b 48",
-	"-b 56",
-	"-b 64",
-	"-b 80",
-	"-b 96",
-	"-b 112",
-	"-b 128",
-	"-b 160",
-	"-b 192",
-	"-b 224",
-	"-b 256",
-	"-b 320",
-	"--preset insane"
-	};
-
-	gchar *str_vbr [] = {
-	"--preset medium",
-	"--preset standard",
-	"--preset extreme",
-	"--preset fast standard",
-	"--preset fast extreme",
-	"-V0",
-	"-V1",
-	"-V2",
-	"-V3",
-	"-V4",
-	"-V5",
-	"-V6",
-	"-V7",
-	"-V8",
-	"-V9"
-	};
-
-	gchar *str_vbr_new [] = {
-	"--vbr-new",
-	"--vbr-new --preset medium",
-	"--vbr-new --preset standard",
-	"--vbr-new --preset extreme",
-	"--vbr-new --preset fast standard",
-	"--vbr-new --preset fast extreme",
-	"--vbr-new -V0",
-	"--vbr-new -V1",
-	"--vbr-new -V2",
-	"--vbr-new -V3",
-	"--vbr-new -V4",
-	"--vbr-new -V5",
-	"--vbr-new -V6",
-	"--vbr-new -V7",
-	"--vbr-new -V8",
-	"--vbr-new -V9"
-	};
-	
-	gchar *str_val_mode[] = {
-	"",	/* Defaut		*/
-	"-m s",	/* Stereo		*/
-	"-m j",	/* Join Stereo		*/
-	"-m f",	/* Forced Join Stereo	*/
-	"-m d",	/* Duo Channels		*/
-	"-m m"	/* Mono			*/
-	};
-	
-	gchar *PtrOne = NULL;
-
-	/*PRINT_FUNC_LF();*/
-
-	strcpy (StrLame, "");
-
-	if (var_options.Adr_Widget_Lame_bitrate != NULL || var_options.Adr_Widget_Lame_abr_cbr_vbr != NULL) {
-	
-		switch (gtk_combo_box_get_active (var_options.Adr_Widget_Lame_abr_cbr_vbr)) {
-		
-		/* ABR */
-		case 0 :
-			Config_User.RateMp3OggOptions.If_abr = gtk_combo_box_get_active (var_options.Adr_Widget_Lame_bitrate);
-			PtrOne = (gchar *)str_abr [ Config_User.RateMp3OggOptions.If_abr ];
-			break;
-		
-		/* CBR */
-		case 1 :
-			Config_User.RateMp3OggOptions.If_cbr = gtk_combo_box_get_active (var_options.Adr_Widget_Lame_bitrate);
-			PtrOne = (gchar *)str_cbr [ Config_User.RateMp3OggOptions.If_cbr ];
-			break;
-		
-		/* VBR */
-		case 2 :
-			Config_User.RateMp3OggOptions.If_vbr = gtk_combo_box_get_active (var_options.Adr_Widget_Lame_bitrate);
-			PtrOne = (gchar *)str_vbr [ Config_User.RateMp3OggOptions.If_vbr ];
-			break;
-			
-		/* VBR_NEW */
-		case 3 :
-			Config_User.RateMp3OggOptions.If_vbr_new = gtk_combo_box_get_active (var_options.Adr_Widget_Lame_bitrate);
-			PtrOne = (gchar *)str_vbr_new [ Config_User.RateMp3OggOptions.If_vbr_new ];
-			break;
-		}
-		
-		if (PtrOne != NULL)
-			strcat (StrLame, PtrOne);
-	}
-	if (var_options.Adr_Widget_Lame_Mode != NULL) {
-		
-		PtrOne = (gchar *)str_val_mode[ gtk_combo_box_get_active (var_options.Adr_Widget_Lame_Mode) ];
-		if (PtrOne != NULL && *PtrOne != '\0') {
-			if (*StrLame != '\0')
-				strcat (StrLame, " ");	
-			strcat (StrLame, PtrOne);
-		}
-	}
-	
-	return ((gchar *)strdup (StrLame));
-}
 
