@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -32,7 +32,7 @@
 
 
 #include <gtk/gtk.h>
-#include "support.h"
+
 #include <string.h>
 #include "global.h"
 #include "config_user.h"
@@ -58,7 +58,9 @@
 void optionsApe_combobox_ape_compression_realize (GtkWidget *widget)
 {
 	var_options.Adr_Widget_ape_compression =  GTK_COMBO_BOX (widget);
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Compress (fast):          '-c1000'");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Compress (normal):     '-c2000'");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Compress (high):          '-c3000'");
