@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -32,8 +32,9 @@
 
 
 #include <gtk/gtk.h>
-#include "support.h"
+
 #include <string.h>
+
 #include "global.h"
 #include "config_user.h"
 #include "cd_audio.h"
@@ -58,7 +59,8 @@
 void optionsMusepack_combobox_mppenc_realize (GtkWidget *widget)
 {
 	var_options.Adr_Widget_Mppenc = GTK_COMBO_BOX (widget);
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
 	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("telephone: lowest quality              :   32 ..  48 kbit/s"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("thumb      : low quality/internet     :   58 ..  86 kbit/s"));
