@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -32,7 +32,7 @@
 
 
 #include <gtk/gtk.h>
-#include "support.h"
+
 #include <string.h>
 #include "global.h"
 #include "config_user.h"
@@ -139,19 +139,19 @@ void optionstags_checkbutton_tag_clicked (GtkButton *button)
 	
 	/*PRINT_FUNC_LF();*/
 
-	if (GTK_TOGGLE_BUTTON (button) == GTK_TOGGLE_BUTTON (lookup_widget (wind_main, "checkbutton_artist_tag"))) {
+	if (GTK_TOGGLE_BUTTON (button) == GTK_TOGGLE_BUTTON (XCFA_GET_OBJECT("checkbutton_artist_tag"))) {
 		ColorLineCommand = COLOR_TAG_ARTIST;
-	} else if (GTK_TOGGLE_BUTTON (button) == GTK_TOGGLE_BUTTON (lookup_widget (wind_main, "checkbutton_title_tag"))) {
+	} else if (GTK_TOGGLE_BUTTON (button) == GTK_TOGGLE_BUTTON (XCFA_GET_OBJECT("checkbutton_title_tag"))) {
 		ColorLineCommand = COLOR_TAG_TITLE;
-	} else if (GTK_TOGGLE_BUTTON (button) == GTK_TOGGLE_BUTTON (lookup_widget (wind_main, "checkbutton_album_tag"))) {
+	} else if (GTK_TOGGLE_BUTTON (button) == GTK_TOGGLE_BUTTON (XCFA_GET_OBJECT("checkbutton_album_tag"))) {
 		ColorLineCommand = COLOR_TAG_ALBUM;
-	} else if (GTK_TOGGLE_BUTTON (button) == GTK_TOGGLE_BUTTON (lookup_widget (wind_main, "checkbutton_numerate_tag"))) {
+	} else if (GTK_TOGGLE_BUTTON (button) == GTK_TOGGLE_BUTTON (XCFA_GET_OBJECT("checkbutton_numerate_tag"))) {
 		ColorLineCommand = COLOR_TAG_NUMERATE;
-	} else if (GTK_TOGGLE_BUTTON (button) == GTK_TOGGLE_BUTTON (lookup_widget (wind_main, "checkbutton_genre_tag"))) {
+	} else if (GTK_TOGGLE_BUTTON (button) == GTK_TOGGLE_BUTTON (XCFA_GET_OBJECT("checkbutton_genre_tag"))) {
 		ColorLineCommand = COLOR_TAG_GENRE;
-	} else if (GTK_TOGGLE_BUTTON (button) == GTK_TOGGLE_BUTTON (lookup_widget (wind_main, "checkbutton_year_tag"))) {
+	} else if (GTK_TOGGLE_BUTTON (button) == GTK_TOGGLE_BUTTON (XCFA_GET_OBJECT("checkbutton_year_tag"))) {
 		ColorLineCommand = COLOR_TAG_YEAR;
-	} else if (GTK_TOGGLE_BUTTON (button) == GTK_TOGGLE_BUTTON (lookup_widget (wind_main, "checkbutton_comment_tag"))) {
+	} else if (GTK_TOGGLE_BUTTON (button) == GTK_TOGGLE_BUTTON (XCFA_GET_OBJECT("checkbutton_comment_tag"))) {
 		ColorLineCommand = COLOR_TAG_COMMENT;
 	}
 	
