@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -32,7 +32,7 @@
 
 
 #include <gtk/gtk.h>
-#include "support.h"
+
 #include <string.h>
 #include "global.h"
 #include "config_user.h"
@@ -58,7 +58,9 @@
 void optionsWavpack_combobox_wavpack_realize (GtkWidget *widget)
 {
 	var_options.Adr_Widget_wavpack = GTK_COMBO_BOX (widget);
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	/*
 	-f   Mode rapide de compression
 	-h   Ume bonne qualite de compression dans tous les modes mais plus lent
@@ -79,7 +81,8 @@ gchar *optionsWavpack_get_wavpack_compression (void)
 void optionsWavpack_combobox_wavpack_sound_realize (GtkWidget *widget)
 {
 	var_options.Adr_Widget_wavpack_sound = GTK_COMBO_BOX (widget);
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
 	
 	/*
 	-jn  Joint-stereo override (0 = left/right, 1 = mid/side)
@@ -104,10 +107,10 @@ void optionsWavpack_combobox_wavpack_mode_hybride_changed (void)
 	gboolean bool = *optionsWavpac_get_wavpack_hybride () == '\0' ? FALSE : TRUE;
 	
 	if (var_options.Adr_Widget_wavpack_correction_file)
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "combobox_wavpack_fichier_de_correction")), bool);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("combobox_wavpack_fichier_de_correction")), bool);
 	
 	if (var_options.Adr_Widget_wavpack_maximum_compression)
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "combobox_wavpack_compression_maximum")), bool);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("combobox_wavpack_compression_maximum")), bool);
 	
 
 	options_set_datas_interne (COLOR_WAVPACK_MODE_HYBRIDE, var_options.Adr_label_wavpack_wv, WAVPACK_WAV_TO_WAVPACK);
@@ -117,7 +120,8 @@ void optionsWavpack_combobox_wavpack_mode_hybride_realize (GtkWidget *widget)
 {
 	/*PRINT_FUNC_LF();*/
 
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
 	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Non"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "320 kbit/s");
@@ -140,7 +144,8 @@ void optionsWavpack_combobox_wavpack_fichier_de_correction_realize (GtkWidget *w
 	/*PRINT_FUNC_LF();*/
 
 	var_options.Adr_Widget_wavpack_correction_file = GTK_COMBO_BOX (widget);
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
 	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Non"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Oui"));
@@ -159,7 +164,8 @@ void optionsWavpack_combobox_wavpack_compression_maximum_realize (GtkWidget *wid
 	/*PRINT_FUNC_LF();*/
 
 	var_options.Adr_Widget_wavpack_maximum_compression = GTK_COMBO_BOX (widget);
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
 	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Non"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Oui"));
@@ -178,7 +184,8 @@ void optionsWavpack_combobox_wavpack_signature_md5_realize (GtkWidget *widget)
 	/*PRINT_FUNC_LF();*/
 
 	var_options.Adr_Widget_wavpack_signature_md5 = GTK_COMBO_BOX (widget);
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
 	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Non"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Oui"));
@@ -195,7 +202,8 @@ void optionsWavpack_combobox_wavpack_extra_encoding_realize (GtkWidget *widget)
 	/*PRINT_FUNC_LF();*/
 
 	var_options.Adr_Widget_wavpack_extra_encoding = GTK_COMBO_BOX (widget);
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
 	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget),  _("Non"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("1 (fast / rapide)"));
