@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -41,7 +41,7 @@
 #include <glib/gprintf.h>
 #include <string.h>
 #include <stdlib.h>
-#include "support.h"
+
 #include "global.h"
 #include "info_song.h"
 #include "config_user.h"
@@ -252,12 +252,13 @@ void pochedir_recherche (gchar *path)
 	DIR    *dp;
 	struct  dirent *entry;
 	struct  stat statbuf;
+	gint	Dummy;
 	
 	if ((dp = opendir (path)) == NULL) {
 		return;
 	}
 	
-	chdir (path);
+	Dummy = chdir (path);
 	/*pptrdir = g_get_current_dir ();*/
 	pptrdir = get_current_dir_name ();
 
@@ -283,7 +284,7 @@ void pochedir_recherche (gchar *path)
 
 	g_free (pptrdir);
 	pptrdir = NULL;
-	chdir ("..");
+	Dummy = chdir ("..");
 	closedir (dp);
 }
 /* LES APPELS A LA GLIB NE SONT PAS REENTRANTS DONC PLANTAGE !
@@ -344,13 +345,14 @@ void pochedir_recherche_recursive (gchar *path)
 	DIR    *dp;
 	struct  dirent *entry;
 	struct  stat statbuf;
+	gint	Dummy;
 
 	/* PRINT_FUNC_LF(); */
 
 	if ((dp = opendir (path)) == NULL) {
 		return;
 	}
-	chdir (path);
+	Dummy = chdir (path);
 	while ((entry = readdir (dp)) != NULL) {
 		if (pochedir_event.CancelClicked == TRUE) {
 			g_print ("DEMANDE D ANNULATION DEPUIS: ");
@@ -378,7 +380,7 @@ void pochedir_recherche_recursive (gchar *path)
 			nname = NULL;
 		}
 	}
-	chdir ("..");
+	Dummy = chdir ("..");
 	closedir (dp);
 }
 
