@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -38,7 +38,7 @@
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gprintf.h>
-#include "support.h"
+
 #include "global.h"
 #include "info_song.h"
 #include "utils.h"
@@ -229,7 +229,7 @@ void pocheevnt_togglebutton_clicked (GtkButton *button, gpointer user_data)
 	if (bool_togglebutton_clicked_reentrance == TRUE) return;
 	bool_togglebutton_clicked_reentrance = TRUE;
 
-	/* PRINT_FUNC_LF(); */
+	// PRINT_FUNC_LF();
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gl->togglebutton), FALSE);
 
@@ -317,7 +317,7 @@ void pocheevnt_table_add_images (void)
 			gtk_container_set_border_width (GTK_CONTAINER (gl->togglebutton), 5);
 
 			/* image */
-			gl->image = create_pixmap (wind_main, NULL);
+			gl->image = create_pixmap (wind_main.AdrWin, NULL);
 			gtk_widget_show (gl->image);
 			gtk_container_add (GTK_CONTAINER (gl->togglebutton), gl->image);
 			gtk_image_set_from_file (GTK_IMAGE (gl->image), gl->name_png);
@@ -1645,7 +1645,9 @@ gdouble pocheevnt_get_percent_zoom (void)
 }
 void pocheevnt_combobox_zoom_choiximage_realize (GtkWidget *widget)
 {
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "  50 %  ");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "  55 %  ");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "  60 %  ");
@@ -1680,38 +1682,38 @@ void pocheevnt_combobox_zoom_choiximage_changed (void)
 void pocheevnt_set_flag (gboolean Enable)
 {
 	/* Image */
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "image_preview")), Enable);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("image_preview")), Enable);
 	/* Choix images*/
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "frame59")), Enable);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("frame59")), Enable);
 	/* Notebook */
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "notebook_pochette")), Enable);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("notebook_pochette")), Enable);
 	/* Voir / Avec */
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "frame60")), Enable);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("frame60")), Enable);
 	/* Construire */
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "frame92")), Enable);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("frame92")), Enable);
 }
 void pocheevnt_set_flag_buttons_preview (void)
 {
 	if (PrgInit.bool_convert == FALSE) {
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "togglebutton_recto")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "togglebutton_verso")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "eventbox_combobox_zoom_choiximage")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_load_choiximage")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "togglebutton_remove")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("togglebutton_recto")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("togglebutton_verso")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("eventbox_combobox_zoom_choiximage")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_load_choiximage")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("togglebutton_remove")), FALSE);
 	}
 	else if (poche.bool_destroy_image == TRUE) {
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "togglebutton_recto")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "togglebutton_verso")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "eventbox_combobox_zoom_choiximage")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_load_choiximage")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "togglebutton_remove")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("togglebutton_recto")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("togglebutton_verso")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("eventbox_combobox_zoom_choiximage")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_load_choiximage")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("togglebutton_remove")), TRUE);
 	}
 	else {
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "togglebutton_recto")), TRUE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "togglebutton_verso")), TRUE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "eventbox_combobox_zoom_choiximage")), TRUE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_load_choiximage")), TRUE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "togglebutton_remove")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("togglebutton_recto")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("togglebutton_verso")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("eventbox_combobox_zoom_choiximage")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_load_choiximage")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("togglebutton_remove")), TRUE);
 	}
 }
 void pocheevnt_togglebutton_remove_clicked (void)
@@ -1757,10 +1759,9 @@ void pocheevnt_togglebutton_remove_realize (GtkWidget *widget)
 *---------------------------------------------------------------------------
 */
 
+/*
 static void pocheevnt_initialisation_thread (void *arg)
 {
-	/* Si ok par utilisateur */
-
 	pochevent_event.EndThread = FALSE;
 	
 	if (pocheevnt_get_load_images_init_xcfa () == TRUE) {
@@ -1776,7 +1777,6 @@ static gint pocheevnt_initialisation_timeout (gpointer data)
 {
 	if (pochevent_event.EndThread == TRUE) {
 
-		/* Si ok par utilisateur */
 		if (pocheevnt_get_load_images_init_xcfa () == TRUE) {
 			pocheevnt_table_add_images ();
 		}
@@ -1786,6 +1786,7 @@ static gint pocheevnt_initialisation_timeout (gpointer data)
 	}
 	return (TRUE);
 }
+*/
 
 void pocheevnt_init (void)
 {
@@ -1833,11 +1834,11 @@ void pocheevnt_init (void)
 	
 	poche.bool_with_get_grille_img = TRUE;
 
+	/*
 	if (prginit_get_etat () == TRUE && pocheevnt_init_images_xcfa () == TRUE && fileanalyze_linecommand_exist () == FALSE) {
 		if (pocheevnt_get_load_images_init_xcfa () == TRUE) {
-			/* La creation GTK n'est pas permise de puis un thread
-	  		 * ---------------------------------------------------
-	  		 */
+			// La creation GTK n'est pas permise de puis un thread
+	  		// ---------------------------------------------------
 			winpulse_create ();
 			winpulse_set_init_pulse ();
 			winpulse_set_title (_("Chargement des images"));
@@ -1850,10 +1851,11 @@ void pocheevnt_init (void)
 			secu_thread_add ();
 			pthread_create (&pochevent_event.nmr_tid, NULL ,(void *)pocheevnt_initialisation_thread, (void *)NULL);
 
-			/* DEBUG */
+			// DEBUG
 			pthread_detach (pochevent_event.nmr_tid);
 		}
 	}
+	*/
 }
 
 /*
@@ -1951,7 +1953,7 @@ void pocheevnt_set_flag_buttons_recto (void)
 		bool_bas_vers_haut = FALSE;
 		bool_bas_vers_bas = FALSE;
 	}
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "spinbutton_zoom_recto")), bool_recto_zoom);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("spinbutton_zoom_recto")), bool_recto_zoom);
 }
 
 
@@ -2009,7 +2011,7 @@ void pocheevnt_set_flag_buttons_verso (void)
 		bool_bas_vers_haut = FALSE;
 		bool_bas_vers_bas = FALSE;
 	}
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "spinbutton_zoom_verso")), bool_verso_zoom);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("spinbutton_zoom_verso")), bool_verso_zoom);
 }
 
 
@@ -2209,14 +2211,16 @@ void pocheevnt_entry_titre_ps_changed (void)
 
 	if (!poche.Adr_combobox_entry_title) return;
 	bool = *pocheevnt_get_entry_titre_ps () ? TRUE : FALSE;
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "eventbox_combobox_entry_title")), bool);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("eventbox_combobox_entry_title")), bool);
 	num = gtk_combo_box_get_active (GTK_COMBO_BOX (poche.Adr_combobox_entry_title));
 	if (num != 3)
 		pochetimer_action (PTIMER_ENABLE, GENPOSTSCRIPT, PRINTIMAGE, FLAGSRECTO, FLAGSVERSO);
 }
 void pocheevnt_combobox_entry_title_realize (GtkWidget *widget)
 {
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Recto");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Verso");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Recto et Verso");
@@ -2261,7 +2265,7 @@ void pocheevnt_entry_foottext_ps_changed (void)
 	if (!poche.Adr_combobox_entry_foottext) return;
 	if (!poche.Adr_entry_foottext) return;
 	bool = *pocheevnt_get_entry_foottext_ps () ? TRUE : FALSE;
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "eventbox_combobox_foottext_ps")), bool);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("eventbox_combobox_foottext_ps")), bool);
 
 	num = gtk_combo_box_get_active (GTK_COMBO_BOX (poche.Adr_combobox_entry_foottext));
 	if (num != 3)
@@ -2269,7 +2273,9 @@ void pocheevnt_entry_foottext_ps_changed (void)
 }
 void pocheevnt_combobox_foottext_ps_realize (GtkWidget *widget)
 {
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Recto");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Verso");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Recto et Verso");
@@ -2296,7 +2302,9 @@ void pocheevnt_combobox_foottext_ps_changed (void)
 */
 void pocheevnt_combobox_text_recto_realize (GtkWidget *widget)
 {
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Auteur - titre - temps");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Auteur - titre");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Auteur - temps");
@@ -2315,7 +2323,9 @@ void pocheevnt_combobox_text_recto_changed (void)
 }
 void pocheevnt_combobox_text_verso_realize (GtkWidget *widget)
 {
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Auteur - titre - temps");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Auteur - titre");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Auteur - temps");
@@ -2334,7 +2344,9 @@ void pocheevnt_combobox_text_verso_changed (void)
 }
 void pocheevnt_combobox_link_fields_realize (GtkWidget *widget)
 {
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Recto");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Verso");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Recto et Verso");
@@ -2385,6 +2397,7 @@ gboolean pocheevnt_get_bool_numerate_texte (void)
 	GtkTextIter    End;
 	gint           Total_Line = 0;
 	gint           Cpt;
+	gchar         *PtrDummy = NULL;
 
 	Buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (poche.Adr_textview));
 	Total_Line = gtk_text_buffer_get_line_count (Buf);
@@ -2392,7 +2405,12 @@ gboolean pocheevnt_get_bool_numerate_texte (void)
 		Buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (poche.Adr_textview));
 		gtk_text_buffer_get_iter_at_line_offset (Buf, &Start, Cpt, 0);
 		gtk_text_buffer_get_end_iter (Buf, &End);
-		Ptr = Ptr_Buf = g_locale_from_utf8 (gtk_text_buffer_get_text (Buf, &Start, &End, FALSE), -1, NULL, NULL, NULL);
+				
+		PtrDummy = gtk_text_buffer_get_text (Buf, &Start, &End, FALSE);
+		Ptr_Buf = g_locale_from_utf8 (PtrDummy, -1, NULL, NULL, NULL);
+		g_free (PtrDummy);
+		PtrDummy = NULL;
+		// Ptr = Ptr_Buf = g_locale_from_utf8 (gtk_text_buffer_get_text (Buf, &Start, &End, FALSE), -1, NULL, NULL, NULL);
 
 		while (*Ptr && (*Ptr == ' ' || *Ptr == '\t')) Ptr ++;
 		if (*Ptr && (*Ptr >= '0') && (*Ptr <= '9')) return (TRUE);
@@ -2412,6 +2430,7 @@ void pocheevnt_button_numerate_texte (void)
 	gchar         *Ptr_Buf = NULL;
 	gint           Count_Line = 1;
 	gint           Count_Num_Del;
+	gchar         *PtrDummy = NULL;
 
 	Bool_Toggle = pocheevnt_get_bool_numerate_texte ();
 
@@ -2429,7 +2448,12 @@ void pocheevnt_button_numerate_texte (void)
 			gtk_text_buffer_get_iter_at_line_offset (Buf, &Start, Cpt, 0);
 			gtk_text_buffer_get_end_iter (Buf, &End);
 			/*Ptr_Buf = gtk_text_buffer_get_text (Buf, &Start, &End, FALSE);*/
-			Ptr_Buf = g_locale_from_utf8 (gtk_text_buffer_get_text (Buf, &Start, &End, FALSE), -1, NULL, NULL, NULL);
+
+			PtrDummy = gtk_text_buffer_get_text (Buf, &Start, &End, FALSE);
+			Ptr_Buf = g_locale_from_utf8 (PtrDummy, -1, NULL, NULL, NULL);
+			g_free (PtrDummy);
+			PtrDummy = NULL;
+			// Ptr_Buf = g_locale_from_utf8 (gtk_text_buffer_get_text (Buf, &Start, &End, FALSE), -1, NULL, NULL, NULL);
 
 			if (Ptr_Buf && *Ptr_Buf >= ' ') {
 				gtk_text_buffer_get_iter_at_line (Buf, &Start, Cpt);
@@ -2445,7 +2469,12 @@ void pocheevnt_button_numerate_texte (void)
 			gtk_text_buffer_get_iter_at_line_offset (Buf, &Start, Cpt, 0);
 			gtk_text_buffer_get_end_iter (Buf, &End);
 			/*Ptr_Buf = gtk_text_buffer_get_text (Buf, &Start, &End, FALSE);*/
-			Ptr_Buf = g_locale_from_utf8 (gtk_text_buffer_get_text (Buf, &Start, &End, FALSE), -1, NULL, NULL, NULL);
+
+			PtrDummy = gtk_text_buffer_get_text (Buf, &Start, &End, FALSE);
+			Ptr_Buf = g_locale_from_utf8 (PtrDummy, -1, NULL, NULL, NULL);
+			g_free (PtrDummy);
+			PtrDummy = NULL;
+			// Ptr_Buf = g_locale_from_utf8 (gtk_text_buffer_get_text (Buf, &Start, &End, FALSE), -1, NULL, NULL, NULL);
 
 			if ( (Count_Num_Del = pocheevnt_get_nbr_car_to_del (Ptr_Buf)) > 0) {
 				gtk_text_buffer_get_iter_at_line_offset (Buf, &End, Cpt, Count_Num_Del);
@@ -2480,10 +2509,16 @@ gchar *pocheevnt_get_etat_textview (void)
 	gchar         *Ptr = NULL;
 	GtkTextIter    Start;
 	GtkTextIter    End;
+	gchar         *PtrDummy = NULL;
 
 	Buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (poche.Adr_textview));
 	gtk_text_buffer_get_bounds (Buf, &Start, &End);
-	Ptr = g_locale_from_utf8 (gtk_text_buffer_get_text (Buf, &Start, &End, FALSE), -1, NULL, NULL, NULL);
+
+	PtrDummy = gtk_text_buffer_get_text (Buf, &Start, &End, FALSE);
+	Ptr = g_locale_from_utf8 (PtrDummy, -1, NULL, NULL, NULL);
+	g_free (PtrDummy);
+	PtrDummy = NULL;
+	// Ptr = g_locale_from_utf8 (gtk_text_buffer_get_text (Buf, &Start, &End, FALSE), -1, NULL, NULL, NULL);
 
 	return (Ptr);
 }
@@ -2496,10 +2531,10 @@ void pocheevnt_texte_changed_in_textview (GtkTextBuffer *textbuffer, gpointer us
 	if (*pocheevnt_get_etat_textview () != '\0') {
 		bool = TRUE;
 	}
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "eventbox_combobox_text_recto")), bool);
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "eventbox_combobox_text_verso")), bool);
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "eventbox_combobox_link_fields")), bool);
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_liste_numerate")), bool);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("eventbox_combobox_text_recto")), bool);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("eventbox_combobox_text_verso")), bool);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("eventbox_combobox_link_fields")), bool);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_liste_numerate")), bool);
 
 	if (textbuffer) {
 		if (gtk_combo_box_get_active (GTK_COMBO_BOX (poche.Adr_combobox_text_recto)) < 6 ||
@@ -2653,59 +2688,20 @@ void pocheevnt_textview_text_poche_realize (GtkWidget *widget)
 *---------------------------------------------------------------------------
 */
 
+// void on_entry_web_search_realize (GtkWidget *widget, gpointer user_data)
 void pocheevnt_comboboxentry_cdaudio_realize (GtkWidget *widget)
 {
-	utils_clear_elements_combobox (widget);
-	/*
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "melissa theuriau");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "clara morgane");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Lorie");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Emma Daumas");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "l'ame du Blues - d'hier et d'ajourd'hui-disc 1");
-	*/
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "<Titre cd-audio>");
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
-	poche.Adr_comboboxentry_cdaudio = GTK_COMBO_BOX (widget);
+	poche.Adr_entry_web_search = widget;
+	gtk_entry_set_text (GTK_ENTRY (poche.Adr_entry_web_search), "xcfa GNU/Linux");
 }
+	
 gchar *pocheevnt_get_comboboxentry_cdaudio (void)
 {
-	if (!poche.Adr_comboboxentry_cdaudio) return ((gchar *)NULL);
-	return ((gchar *)gtk_combo_box_get_active_text (GTK_COMBO_BOX (poche.Adr_comboboxentry_cdaudio)));
+	// if (!poche.Adr_comboboxentry_cdaudio) return ((gchar *)NULL);
+	// return ((gchar *)gtk_combo_box_get_active_text (GTK_COMBO_BOX (poche.Adr_comboboxentry_cdaudio)));
+	return ((gchar *)gtk_entry_get_text (GTK_ENTRY( poche.Adr_entry_web_search)));
 }
 
-gint pocheevnt_comboboxentry_total (void)
-{
-	gint total = 0;
-
-	while (TRUE) {
-		gtk_combo_box_set_active (GTK_COMBO_BOX (poche.Adr_comboboxentry_cdaudio), total ++);
-		if (gtk_combo_box_get_active (GTK_COMBO_BOX (poche.Adr_comboboxentry_cdaudio)) <= -1) {
-			break;
-		}
-	}
-	if (total > 0) total --;
-	return (total);
-}
-void pocheevnt_comboboxentry_text_exist (gchar *text)
-{
-	gchar    *ptr = NULL;
-	gint      total_entry;
-	gint      i;
-	gboolean  bool_exist = FALSE;
-
-	total_entry = pocheevnt_comboboxentry_total ();
-	for (i = 0; i < total_entry; i++) {
-		gtk_combo_box_set_active (GTK_COMBO_BOX (poche.Adr_comboboxentry_cdaudio), i);
-		ptr = (gchar *)gtk_combo_box_get_active_text (GTK_COMBO_BOX (poche.Adr_comboboxentry_cdaudio));
-		if (bool_exist == FALSE && strcmp ((gchar *)ptr, text) == 0) {
-			bool_exist = TRUE;
-			break;
-		}
-	}
-	if (bool_exist == FALSE)
-		gtk_combo_box_append_text ( GTK_COMBO_BOX (poche.Adr_comboboxentry_cdaudio), text);
-	gtk_combo_box_set_active (GTK_COMBO_BOX (poche.Adr_comboboxentry_cdaudio), total_entry);
-}
 void pocheevnt_button_get_from_web_clicked (void)
 {
 	gchar *ptr = NULL;
@@ -2727,21 +2723,13 @@ void pocheevnt_button_get_from_web_clicked (void)
 
 	ptr = pocheevnt_get_comboboxentry_cdaudio ();
 
-	g_print ("%s\n", *ptr == '\0' ? "CHAINE VIDE" : ptr);
+	// g_print ("%s\n", *ptr == '\0' ? "CHAINE VIDE" : ptr);
 	if (*ptr != '\0') {
-		pocheevnt_comboboxentry_text_exist (ptr);
+		// pocheevnt_comboboxentry_text_exist (ptr);
 		pocheweb_get ();
 	}
 }
-void pocheevnt_comboboxentry_cdaudio_changed (void)
-{
-	gboolean bool;
 
-	if (!poche.Adr_comboboxentry_cdaudio) return;
-	/*PRINT_FUNC_LF();*/
-	bool = *pocheevnt_get_comboboxentry_cdaudio () != '\0' ? TRUE : FALSE;
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_get_from_web")), bool);
-}
 void pocheevnt_button_get_title_cdaudio_clicked (void)
 {
 	gchar *ptr = cdaudio_get_TitleCD ();
@@ -2762,11 +2750,11 @@ void pocheevnt_button_get_title_cdaudio_clicked (void)
 			  "");
 	}
 	else {
-		gint      total_entry;
+		// gint      total_entry;
 
-		total_entry = pocheevnt_comboboxentry_total ();
-		gtk_combo_box_append_text ( GTK_COMBO_BOX (poche.Adr_comboboxentry_cdaudio), ptr);
-		gtk_combo_box_set_active (GTK_COMBO_BOX (poche.Adr_comboboxentry_cdaudio), total_entry);
+		// total_entry = pocheevnt_comboboxentry_total ();
+		// gtk_combo_box_append_text ( GTK_COMBO_BOX (poche.Adr_comboboxentry_cdaudio), ptr);
+		// gtk_combo_box_set_active (GTK_COMBO_BOX (poche.Adr_comboboxentry_cdaudio), total_entry);
 
 		/*
 		gtk_combo_box_set_text (GTK_COMBO_BOX (poche.Adr_comboboxentry_cdaudio), ptr);
@@ -2831,26 +2819,15 @@ void pocheevnt_button_importation_titre_cd_clicked (void)
 *---------------------------------------------------------------------------
 */
 
-void pocheevnt_checkbutton_load_images_init_xcfa_realize (GtkWidget *widget)
-{
-	poche.Adr_checkbutton_load_img_init_xcfa = widget;
-	gtk_toggle_button_set_active (
-		GTK_TOGGLE_BUTTON (poche.Adr_checkbutton_load_img_init_xcfa),
-		Config_User.Bool_init_img_xcfa);
-}
 gboolean pocheevnt_init_images_xcfa (void)
 {
-	return (PrgInit.bool_convert == TRUE && Config_User.Bool_init_img_xcfa == TRUE);
+	return (PrgInit.bool_convert);
 }
 gboolean pocheevnt_get_load_images_init_xcfa (void)
 {
 	/*return (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (poche.Adr_checkbutton_load_img_init_xcfa)));*/
-	return (Config_User.Bool_init_img_xcfa);
-}
-void pocheevnt_checkbutton_load_images_init_xcfa_clicked (void)
-{
-	Config_User.Bool_init_img_xcfa =
-		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (poche.Adr_checkbutton_load_img_init_xcfa));
+	// return (Config_User.Bool_init_img_xcfa);
+	return (TRUE);
 }
 
 /*
@@ -2883,7 +2860,9 @@ void pocheevnt_button_preview_postscript_clicked (void)
 }
 void pocheevnt_combobox_choice_preview_postscript_realize (GtkWidget *widget)
 {
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
 	poche.Adr_combobox_choice_preview_postscript = GTK_COMBO_BOX (widget);
 
@@ -2896,7 +2875,9 @@ void pocheevnt_combobox_choice_preview_postscript_changed (void)
 }
 void pocheevnt_combobox_generate_ps_pdf_realize (GtkWidget *widget)
 {
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Choix:"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("     Generation fichier PostScript"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("     Generation fichier PDF"));
@@ -2946,7 +2927,9 @@ void pocheevnt_add_elements_combobox_preview (void)
 
 	if (!poche.Adr_combobox_choice_preview_postscript) return;
 
-	utils_clear_elements_combobox (GTK_WIDGET (poche.Adr_combobox_choice_preview_postscript));
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (poche.Adr_combobox_choice_preview_postscript));
+	utils_alloc_combo (GTK_COMBO_BOX (poche.Adr_combobox_choice_preview_postscript));
+	
 	list = prgpostscript_get_glist_prog_ps ();
 	while (list) {
 		if ((ptr = (gchar *)list->data)) {
@@ -2958,18 +2941,7 @@ void pocheevnt_add_elements_combobox_preview (void)
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (poche.Adr_combobox_choice_preview_postscript), 0);
 
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_preview_postscript")), bool);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_preview_postscript")), bool);
 }
 
 
-
-
-
-
-
-
-
-
-
-
-
