@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -47,7 +47,6 @@
 #include <sys/wait.h>
 #include <sys/types.h>
 
-#include "support.h"
 #include "global.h"
 #include "info_song.h"
 #include "config_user.h"
@@ -184,6 +183,8 @@ GList *pochegen_get_glist_from_textview (void)
 	gint           i;
 	gint           separator = 0;
 	FIELDS_PS     *ps = NULL;
+	gchar         *PtrDummy = NULL;
+	
 
 	/*PRINT_FUNC_LF();*/
 
@@ -192,7 +193,12 @@ GList *pochegen_get_glist_from_textview (void)
 		Buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (poche.Adr_textview));
 		gtk_text_buffer_get_iter_at_line_offset (Buf, &Start, Cpt, 0);
 		gtk_text_buffer_get_end_iter (Buf, &End);
-		Ptr_buf = g_locale_from_utf8 (gtk_text_buffer_get_text (Buf, &Start, &End, FALSE), -1, NULL, NULL, NULL);
+		
+		PtrDummy = gtk_text_buffer_get_text (Buf, &Start, &End, FALSE);
+		Ptr_buf = g_locale_from_utf8 (PtrDummy, -1, NULL, NULL, NULL);
+		g_free (PtrDummy);
+		PtrDummy = NULL;
+		// Ptr_buf = g_locale_from_utf8 (gtk_text_buffer_get_text (Buf, &Start, &End, FALSE), -1, NULL, NULL, NULL);
 
 		if (*Ptr_buf == '\n' || *Ptr_buf == '\0')
 			gtk_text_buffer_delete (Buf, &Start, &End);
@@ -202,7 +208,12 @@ GList *pochegen_get_glist_from_textview (void)
 	/* Get start-end buffer text with coord. in utf8 */
 	Buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (poche.Adr_textview));
 	gtk_text_buffer_get_bounds (Buf, &Start, &End);
-	Ptr_buf = g_locale_from_utf8 (gtk_text_buffer_get_text (Buf, &Start, &End, FALSE), -1, NULL, NULL, NULL);
+	
+	PtrDummy = gtk_text_buffer_get_text (Buf, &Start, &End, FALSE);
+	Ptr_buf = g_locale_from_utf8 (PtrDummy, -1, NULL, NULL, NULL);
+	g_free (PtrDummy);
+	PtrDummy = NULL;
+	// Ptr_buf = g_locale_from_utf8 (gtk_text_buffer_get_text (Buf, &Start, &End, FALSE), -1, NULL, NULL, NULL);
 
 	/* Decompose le buffer en lignes de texte */
 	Larrbuf = g_strsplit(Ptr_buf, "\n", 0);
@@ -630,6 +641,7 @@ gboolean pochegen_creation_postscript_recto (void)
 	FILE           *fp_recto_tmp = NULL;
 #define MAX_CARS 255
 	gchar  buf   [ MAX_CARS +1 ];
+	gchar		*Dummy;
 
 	/*PRINT_FUNC_LF();*/
 
@@ -669,8 +681,8 @@ gboolean pochegen_creation_postscript_recto (void)
 			break;
 		}
 	}
-	fgets (buf, MAX_CARS, fp_recto_tmp);
-	fgets (buf, MAX_CARS, fp_recto_tmp);
+	Dummy = fgets (buf, MAX_CARS, fp_recto_tmp);
+	Dummy = fgets (buf, MAX_CARS, fp_recto_tmp);
 	while (fgets (buf, MAX_CARS, fp_recto_tmp) != NULL) {
 		if (buf [ 0 ] == '%' && buf [ 1 ] == '%') break;
 		fprintf (fp_recto, "%s", buf);
@@ -696,6 +708,7 @@ gboolean pochegen_creation_postscript_verso (void)
 	FILE           *fp_verso_tmp = NULL;
 #define MAX_CARS 255
 	gchar  buf   [ MAX_CARS +1 ];
+	gchar		*Dummy;
 
 	/*PRINT_FUNC_LF();*/
 
@@ -735,8 +748,8 @@ gboolean pochegen_creation_postscript_verso (void)
 			break;
 		}
 	}
-	fgets (buf, MAX_CARS, fp_verso_tmp);
-	fgets (buf, MAX_CARS, fp_verso_tmp);
+	Dummy = fgets (buf, MAX_CARS, fp_verso_tmp);
+	Dummy = fgets (buf, MAX_CARS, fp_verso_tmp);
 	while (fgets (buf, MAX_CARS, fp_verso_tmp) != NULL) {
 		if (buf [ 0 ] == '%' && buf [ 1 ] == '%') break;
 		fprintf (fp_verso, "%s", buf);
