@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -36,17 +36,18 @@
 #endif
 
 #include <gtk/gtk.h>
-#include "support.h"
+#include <stdlib.h>
+#include <stdio.h>
+#include <string.h>
+
 #include "global.h"
 #include "poche.h"
 #include "file.h"
 #include "utils.h"
 #include "popup.h"
 #include "dvd_audio.h"
+#include "prg_audio.h"
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
 
 
 /* INTERNATIONALISATION DE DATAS DEPUIS LES STRUCTURES :
@@ -128,6 +129,48 @@ void popup_for_pocheevent (gboolean bool_recto)
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 3, 0);
 }
 
+
+void on_popup_for_player (GtkMenuItem *menuitem, gpointer user_data)
+{
+	gchar *PName = user_data;
+
+	// PRINT_FUNC_LF();
+	PRINT("At the request of @Zarer, choosing a player from a popup");
+	g_print("\tPlayer = %s\n", PName);
+	
+	prgaudio_activate (PName);
+}
+void popup_for_player (void)
+{
+	GtkWidget	*menu;
+	GtkWidget	*widget;
+	GList		*list = NULL;
+	PRGAUDIO_SAVE	*PrgAudioSave = NULL;
+	
+	// PRINT_FUNC_LF();
+	
+	menu = gtk_menu_new ();
+	gtk_widget_set_extension_events (menu, GDK_EXTENSION_EVENTS_ALL);
+
+	list = prgaudio_get_glist_prog (list);
+	while (list) {
+		if ((PrgAudioSave = (PRGAUDIO_SAVE *)list->data)) {
+			widget = gtk_menu_item_new_with_mnemonic (PrgAudioSave->Name);
+			gtk_widget_show (widget);
+			gtk_container_add (GTK_CONTAINER (menu), widget);
+			g_signal_connect ((gpointer) widget, "activate", G_CALLBACK (on_popup_for_player), PrgAudioSave->Name);
+		}
+		list = g_list_next(list);
+	}
+
+	/* Store pointers to all widgets, for use by lookup_widget(). */
+	GLADE_HOOKUP_OBJECT_NO_REF (menu, menu, "menu");
+	
+	list = prgaudio_remove_glist_prog (list);
+	
+	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 3, 0);
+}
+
 /*
 *---------------------------------------------------------------------------
 * POPUP DVD
@@ -546,7 +589,7 @@ POP_MENU PopMenuPiste[ MAX_POP_MENU_PISTE ] = {
 
 #define CASE_POP_MENU_QUANTIFICATION_CELL 90
 #define CASE_POP_MENU_QUANTIFICATION_COL 100
-#define MAX_POP_MENU_QUANTIFICATION 14
+#define MAX_POP_MENU_QUANTIFICATION 16
 POP_MENU PopMenuQuantification[ MAX_POP_MENU_QUANTIFICATION ] = {
 /*
  Widget    Title                         Type Val Call
@@ -554,6 +597,7 @@ POP_MENU PopMenuQuantification[ MAX_POP_MENU_QUANTIFICATION ] = {
 {NULL, gettext_noop("   Cellule"),				{TRUE,     -3,    0, -1}},
 {NULL, gettext_noop("    8  bits"),				{TRUE,    -10,    8, CASE_POP_MENU_QUANTIFICATION_CELL}},
 {NULL, gettext_noop("   16  bits"),				{TRUE,    -10,   16, CASE_POP_MENU_QUANTIFICATION_CELL}},
+{NULL, gettext_noop("   24  bits"),				{TRUE,    -10,   24, CASE_POP_MENU_QUANTIFICATION_CELL}},
 {NULL, gettext_noop("   32  bits"),				{TRUE,    -10,   32, CASE_POP_MENU_QUANTIFICATION_CELL}},
 {NULL, gettext_noop("   64  bits"),				{TRUE,    -10,   64, CASE_POP_MENU_QUANTIFICATION_CELL}},
 {NULL, gettext_noop("   --------------------"),			{FALSE,   -10,    0, -1}},
@@ -562,6 +606,7 @@ POP_MENU PopMenuQuantification[ MAX_POP_MENU_QUANTIFICATION ] = {
 {NULL, gettext_noop("   Colonne"),				{TRUE,     -3,    0, -1}},
 {NULL, gettext_noop("    8  bits"),				{TRUE,    -10,    8, CASE_POP_MENU_QUANTIFICATION_COL}},
 {NULL, gettext_noop("   16  bits"),				{TRUE,    -10,   16, CASE_POP_MENU_QUANTIFICATION_COL}},
+{NULL, gettext_noop("   24  bits"),				{TRUE,    -10,   24, CASE_POP_MENU_QUANTIFICATION_COL}},
 {NULL, gettext_noop("   32  bits"),				{TRUE,    -10,   32, CASE_POP_MENU_QUANTIFICATION_COL}},
 {NULL, gettext_noop("   64  bits"),				{TRUE,    -10,   64, CASE_POP_MENU_QUANTIFICATION_COL}},
 {NULL, gettext_noop("   --------------------"),			{FALSE,   -10,    0, -1}},
