@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -32,7 +32,7 @@
 
 
 #include <gtk/gtk.h>
-#include "support.h"
+
 #include <string.h>
 #include "global.h"
 #include "utils.h"
@@ -436,16 +436,16 @@ void prgaudio_entry_name_audio_changed (void)
 	Name = (gchar *)gtk_entry_get_text (GTK_ENTRY (VarPrgAudio.Adr_entry_name_audio));
 
 	if (*Name == '\0' || strcmp (Name, READER_AUDIO_XCFA) == 0) {
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_add_audio")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_del_audio")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_add_audio")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_del_audio")), FALSE);
 	}
 	else if (prgaudio_is_find (Name)) {
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_add_audio")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_del_audio")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_add_audio")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_del_audio")), TRUE);
 	}
 	else {
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_add_audio")), TRUE);
-		gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_del_audio")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_add_audio")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_del_audio")), FALSE);
 	}
 	prgaudio_test_is_selected ();
 }
@@ -594,7 +594,7 @@ void prgaudio_affiche (void)
 				PRGAUDIO_PARAM,			Foo.Param,
 				PRGAUDIO_PARAM_EDITABLE,	Foo.BoolEdit,
 				-1);
-
+	
 	/* Affichage de la liste */
 	if ((list = g_list_first (VarPrgAudio.ListLecteurs)) == NULL) {
 		prgaudio_set_name ("vlc", 		"");
