@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -36,7 +36,6 @@
 #endif
 
 #include <gtk/gtk.h>
-#include "support.h"
 
 #include <string.h>
 
@@ -96,18 +95,6 @@ NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
 
-{"abcde",							// PACKAGEDEBIAN_64
-"abcde",							// PACKAGEDEBIAN_32
-"abcde",							// NAME1
-"",								// NAME2
-"",								// NAME3
-&PrgInit.bool_abcde,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
-NULL,								// NAME TREE-VIEW
-NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
-
 {"cdparanoia",							// PACKAGEDEBIAN_64
 "cdparanoia",							// PACKAGEDEBIAN_32
 "cdparanoia",							// NAME1
@@ -228,6 +215,19 @@ NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
 
+// ADD
+{"monkeys-audio",						// PACKAGEDEBIAN_64
+"monkeys-audio",						// PACKAGEDEBIAN_32
+"mac",						// NAME1
+"",								// NAME2
+"",								// NAME3
+&PrgInit.bool_ape,						// FOUND
+"",								// DEPOTDEBIAN_64
+"",								// DEPOTDEBIAN_32
+NULL,								// NAME TREE-VIEW
+NULL,								// PIXBUF TREE-VIEW
+NULL},								// DESCRIPTION
+/*
 {"mac",								// PACKAGEDEBIAN_64
 "mac",								// PACKAGEDEBIAN_32
 "mac",								// NAME1
@@ -239,7 +239,34 @@ NULL},								// DESCRIPTION
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
+*/
+// ADD TO amd64 and i386
+{"musepack-tools",						// PACKAGEDEBIAN_64
+"musepack-tools",						// PACKAGEDEBIAN_32
+"mpcdec",							// NAME1
+"mppdec",							// NAME2
+"mpc123",							// NAME3
+&PrgInit.bool_mpc123_mppdec,					// FOUND
+"",								// DEPOTDEBIAN_64
+"",								// DEPOTDEBIAN_32
+NULL,								// NAME TREE-VIEW
+NULL,								// PIXBUF TREE-VIEW
+NULL},								// DESCRIPTION
 
+{"musepack-tools",						// PACKAGEDEBIAN_64
+"musepack-tools",						// PACKAGEDEBIAN_32
+"mpcenc",							// NAME1
+"mppenc",							// NAME2
+"",								// NAME3
+&PrgInit.bool_mppenc,						// FOUND
+"",								// DEPOTDEBIAN_64
+"",								// DEPOTDEBIAN_32
+NULL,								// NAME TREE-VIEW
+NULL,								// PIXBUF TREE-VIEW
+NULL},								// DESCRIPTION
+
+
+/*
 {"mpc123",							// PACKAGEDEBIAN_64
 "mpc123",							// PACKAGEDEBIAN_32
 "mppdec",							// NAME1
@@ -263,7 +290,7 @@ NULL},								// DESCRIPTION
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
-
+*/
 {"mplayer",							// PACKAGEDEBIAN_64
 "mplayer",							// PACKAGEDEBIAN_32
 "mplayer",							// NAME1
@@ -326,8 +353,8 @@ NULL},								// DESCRIPTION
 
 {"libnotify-bin",						// PACKAGEDEBIAN_64
 "libnotify-bin",						// PACKAGEDEBIAN_32
-"notify-send",							// NAME1
-"",								// NAME2
+"libnotify-bin",						// NAME1
+"notify-send",							// NAME2
 "",								// NAME3
 &PrgInit.bool_notify_send,					// FOUND
 "",								// DEPOTDEBIAN_64
@@ -384,6 +411,18 @@ NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
 
+{"txt2html",							// PACKAGEDEBIAN_64
+"txt2html",							// PACKAGEDEBIAN_32
+"txt2html",							// NAME1
+"",								// NAME2
+"",								// NAME3
+&PrgInit.bool_txt2html,						// FOUND
+"",								// DEPOTDEBIAN_64
+"",								// DEPOTDEBIAN_32
+NULL,								// NAME TREE-VIEW
+NULL,								// PIXBUF TREE-VIEW
+NULL},								// DESCRIPTION
+
 {"vorbis-tools",						// PACKAGEDEBIAN_64
 "vorbis-tools",							// PACKAGEDEBIAN_32
 "oggenc",							// NAME1
@@ -466,10 +505,6 @@ gboolean prginit_elem_is_present (TYPE_PROGINIT TypeEnum)
 {
 	return ((gboolean)*TableauPrgExtern [ TypeEnum ] . BoolFound);
 }
-gboolean prginit_elem_is_ready (TYPE_PROGINIT TypeEnum)
-{
-	return ((gboolean)(TableauPrgExtern [ TypeEnum ] . Pixbuf == var_prgextern.Pixbuf_Selected) ? TRUE : FALSE);
-}
 
 void prginit_affiche_glist (void)
 {
@@ -513,53 +548,6 @@ void prginit_affiche_glist (void)
 }
 
 
-gboolean prginit_is_selected (void)
-{
-	gint		 index;
-
-	for (index = 0; index < NMR_MAX_TABLEAU; index ++) {
-		if (TableauPrgExtern[ index ].Pixbuf == var_prgextern.Pixbuf_Selected) return (TRUE);
-	}
-	
-	return (FALSE);
-}
-
-gboolean prginit_set_selected (void)
-{
-	gint		index;
-	gboolean	bool_sel = FALSE;
-
-	for (index = 0; index < NMR_MAX_TABLEAU; index ++) {
-		if (TableauPrgExtern[ index ].Pixbuf == var_prgextern.Pixbuf_Coche) {
-			TableauPrgExtern[ index ].Pixbuf = var_prgextern.Pixbuf_Selected;
-			bool_sel = TRUE;
-		}
-	}
-	prginit_update_glist ();
-	return (bool_sel);
-}
-
-gboolean prginit_get_bool_install (void)
-{
-	gint		index;
-	
-	for (index = 0; index < NMR_MAX_TABLEAU; index ++) {
-		if (TableauPrgExtern[ index ].Pixbuf == var_prgextern.Pixbuf_Selected) return (TRUE);
-	}
-	
-	return (FALSE);
-}
-gboolean prginit_is_not_installed (void)
-{
-	gint		index;
-	
-	for (index = 0; index < NMR_MAX_TABLEAU; index ++) {
-		if (*TableauPrgExtern[ index ].BoolFound == FALSE) return (TRUE);
-	}
-	
-	return (FALSE);
-}
-
 void prginit_print_info (void)
 {
 	gint	index;
@@ -574,17 +562,6 @@ void prginit_print_info (void)
 	g_print ("!------------------------------\n\n");
 }
 
-void prginit_var_default (void)
-{
-	gint	index;
-	
-	for (index = 0; index < NMR_MAX_TABLEAU; index ++) {
-		*TableauPrgExtern [ index ] . BoolFound = FALSE;
-		TableauPrgExtern [ index ] . PtrName    = NULL;
-		TableauPrgExtern [ index ] . Pixbuf     = NULL;
-	}
-}
-
 void prginit_scan (void)
 {
 	gint	index;
@@ -630,11 +607,9 @@ void prginit_scan (void)
 		
 		// FIXER LE PIXBUF SI PAS EN SELECTION
 		
-		if (TableauPrgExtern [ index ] . Pixbuf != var_prgextern.Pixbuf_Selected) {
-			if (*TableauPrgExtern [ index ] . BoolFound == TRUE)
-				TableauPrgExtern [ index ] . Pixbuf = var_prgextern.Pixbuf_Ok;
-			else	TableauPrgExtern [ index ] . Pixbuf = var_prgextern.Pixbuf_Coche;
-		}
+		if (*TableauPrgExtern [ index ] . BoolFound == TRUE)
+			TableauPrgExtern [ index ] . Pixbuf = var_prgextern.Pixbuf_Ok;
+		else	TableauPrgExtern [ index ] . Pixbuf = var_prgextern.Pixbuf_Not_Ok;
 	}
 	
 	prginit_affiche_glist ();
@@ -672,7 +647,6 @@ gboolean prginit_get_etat (void)
 		PrgInit.bool_cuetools &
 		PrgInit.bool_aacplusenc;
 		// PrgInit.bool_notify_send;
-		// PrgInit.bool_abcde;
 	
 	return (var_prgextern.Bool_Goto_Page_Options);
 
@@ -693,61 +667,8 @@ void prginit_update_glist (void)
 	file_pixbuf_update_glist_file ();
 	file_set_flag_buttons_audio_file ();
 	cdaudio_set_flag_buttons_audio_cd ();
-
-	if (var_prgextern.button_selection_globale)
-		gtk_widget_set_sensitive (GTK_WIDGET (var_prgextern.button_selection_globale), prginit_is_not_installed ());
-	if(var_prgextern.button_goto_install)
-		gtk_widget_set_sensitive (GTK_WIDGET (var_prgextern.button_goto_install), prginit_get_bool_install ());
 }
 
-/* Evenements souris pour le scrolledwindow
-*/
-gboolean prginit_traite_button_press_event (GtkWidget *treeview, GdkEventButton *event, gpointer data)
-{
-	GtkTreePath        *path;
-	GtkTreeViewColumn  *column;
-	gint                Pos_X = 0, Pos_Y = 0;
-	GtkTreeIter         iter;
-	GtkTreeModel       *model = (GtkTreeModel *)data;
-	gint		    num;
-	
-	/* PRINT_FUNC_LF(); */
-
-	/* Single clicks only */
-	if (event->type != GDK_BUTTON_PRESS) return (FALSE);
-
-	/* Si pas de selection a cet endroit retour */
-	if (!gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW(treeview),
-					  (gint)event->x, (gint)event->y,
-					   &path, &column, &Pos_X, &Pos_Y)) return (FALSE);
-
-	/* Recuperation de la structure */
-	gtk_tree_model_get_iter (model, &iter, path);
-	gtk_tree_model_get (var_prgextern.Adr_Tree_Model, &iter, PRGEXT_NUM_COLUMN, &num, -1);
-
-	if (gtk_tree_view_get_column (GTK_TREE_VIEW(treeview), NUM_TREE_Status) == column) {
-	
-		/* position du curseur a l'instant du click */
-		if (Pos_X < 18 || Pos_X > 30) return (FALSE);
-		if (Pos_Y < 6 || Pos_Y > 18) return (FALSE);
-		
-		if (TableauPrgExtern[ num ].Pixbuf == var_prgextern.Pixbuf_Selected) {
-			TableauPrgExtern[ num ].Pixbuf = var_prgextern.Pixbuf_Coche;
-			gtk_list_store_set (var_prgextern.Adr_List_Store, &iter, PRGEXT_STATUS, var_prgextern.Pixbuf_Coche, -1);
-		}
-		else if (TableauPrgExtern[ num ].Pixbuf == var_prgextern.Pixbuf_Coche) {
-			TableauPrgExtern[ num ].Pixbuf = var_prgextern.Pixbuf_Selected;
-			gtk_list_store_set (var_prgextern.Adr_List_Store, &iter, PRGEXT_STATUS, var_prgextern.Pixbuf_Selected, -1);
-		}
-	}
-
-	if (var_prgextern.button_selection_globale)
-		gtk_widget_set_sensitive (GTK_WIDGET (var_prgextern.button_selection_globale), prginit_is_not_installed ());
-	if(var_prgextern.button_goto_install)
-		gtk_widget_set_sensitive (GTK_WIDGET (var_prgextern.button_goto_install), prginit_get_bool_install ());
-	
-	return (FALSE);
-}
 
 /* Creation du scrolledwindow et des evenements associes
 */
@@ -755,17 +676,10 @@ static void prginit_add_columns (GtkTreeView *treeview)
 {
 	GtkCellRenderer   *renderer;
 	GtkTreeViewColumn *column;
-	GtkTreeModel      *model = gtk_tree_view_get_model (treeview);
+	// GtkTreeModel      *model = gtk_tree_view_get_model (treeview);
 
 	/*PRINT_FUNC_LF();*/
 
-	/* SIGNAL : 'button-press-event'
-	*/
-	g_signal_connect(G_OBJECT(treeview),
-			 "button-press-event",
-                    	 (GCallback) prginit_traite_button_press_event,
-			 model);
-
 	/* SIGNAL 'changed'
 	*/
 	var_prgextern.Adr_Line_Selected = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
@@ -860,36 +774,41 @@ void prginit_remove_comment (void)
 
 void prginit_init_comment (void)
 {
-	TableauPrgExtern[ NMR_aacplusenc ].Description 		= g_strdup (_(" AAC+ encoder"));
-	TableauPrgExtern[ NMR_abcde ].Description 		= g_strdup (_(" Recherche les infos d'un cd audio"));
-	TableauPrgExtern[ NMR_cdparanoia ].Description 		= g_strdup (_(" Extracteur cd audio"));
-	TableauPrgExtern[ NMR_checkmp3 ].Description 		= g_strdup (_(" Cherche des renseignements sur les formats mp3"));
-	TableauPrgExtern[ NMR_imagemagick_convert ].Description = g_strdup (_(" [imagemagick] Manipulation de formats d'images"));
-	TableauPrgExtern[ NMR_cuetools ].Description 		= g_strdup (_(" Decoupage de fichiers sans decodage"));
-	TableauPrgExtern[ NMR_faac ].Description 		= g_strdup (_(" Audio Codeur freeware"));
-	TableauPrgExtern[ NMR_faad ].Description 		= g_strdup (_(" MPEG-4 AAC decodeur"));
-	TableauPrgExtern[ NMR_flac ].Description 		= g_strdup (_(" Conversion wav : flac / <b><i>METAFLAC DOIT ETRE SUPERIEUR A LA VERSION: 1.1.2</i></b>"));
-	TableauPrgExtern[ NMR_icedax ].Description 		= g_strdup (_(" Extracteur cd audio"));
-	TableauPrgExtern[ NMR_lame ].Description 		= g_strdup (_(" Conversion wav : mp3"));
-	TableauPrgExtern[ NMR_lsdvd ].Description 		= g_strdup (_(" Cherche les informations d'un dvd"));
-	TableauPrgExtern[ NMR_mac ].Description 		= g_strdup (_(" Monkey's Audio"));
-	TableauPrgExtern[ NMR_mpc123_mppdec ].Description 	= g_strdup (_(" MPC Decodeur"));
-	TableauPrgExtern[ NMR_mppenc ].Description 		= g_strdup (_(" MPC Encodeur"));
-	TableauPrgExtern[ NMR_mplayer ].Description 		= g_strdup (_(" Lecteur et extracteur"));
-	TableauPrgExtern[ NMR_mp3gain ].Description 		= g_strdup (_(" Normaliseur de fichier mp3"));
-	TableauPrgExtern[ NMR_mpg321 ].Description 		= g_strdup (_(" Conversion mp3 : wav"));
-	TableauPrgExtern[ NMR_mp3splt ].Description 		= g_strdup (_(" Decoupage de fichiers sans decodage"));
-	TableauPrgExtern[ NMR_normalize ].Description 		= g_strdup (_(" Normaliseur de fichier wav"));
-	TableauPrgExtern[ NMR_libnotify_bin ].Description 	= g_strdup (_(" A program to send desktop notifications"));
-	TableauPrgExtern[ NMR_ps2pdf ].Description 		= g_strdup (_(" Conversion  fichier  *.PS vers  *.PDF"));
-	TableauPrgExtern[ NMR_shorten ].Description 		= g_strdup (_(" Forte compression au format wave"));
-	TableauPrgExtern[ NMR_shntool ].Description		= g_strdup (_(" Decoupage de fichiers sans decodage"));
-	TableauPrgExtern[ NMR_sox ].Description 		= g_strdup (_(" Transformation universelle de fichiers son"));
-	TableauPrgExtern[ NMR_vorbis_tools_oggenc ].Description = g_strdup (_(" [Vorbis-tools] Conversion wav : ogg"));
-	TableauPrgExtern[ NMR_vorbisgain ].Description 		= g_strdup (_(" Normaliseur de fichier ogg"));
-	TableauPrgExtern[ NMR_wavsplit ].Description 		= g_strdup (_(" Decoupage de fichiers sans decodage"));
-	TableauPrgExtern[ NMR_wavpack ].Description 		= g_strdup (_(" [wavpack] WAVPACK  Hybrid Lossless Audio Compressor"));
-	TableauPrgExtern[ NMR_wXXcodecs	].Description 		= g_strdup (_(" Codecs video non supportes par mplayer / <b><i>PAS indispensable</i></b>"));
+	TableauPrgExtern[ NMR_aacplusenc ].Description 			= g_strdup (_(" [ aacplusenc ] AAC+ encoder"));
+	TableauPrgExtern[ NMR_cdparanoia ].Description 			= g_strdup (_(" [ cdparanoia ] Extracteur cd audio"));
+	TableauPrgExtern[ NMR_checkmp3 ].Description 			= g_strdup (_(" [ checkmp3 ] Cherche des renseignements sur les formats mp3"));
+	TableauPrgExtern[ NMR_imagemagick_convert ].Description 	= g_strdup (_(" [ imagemagick ] Manipulation de formats d'images"));
+	TableauPrgExtern[ NMR_cuetools ].Description 			= g_strdup (_(" [ cuetools ] Decoupage de fichiers sans decodage"));
+	TableauPrgExtern[ NMR_faac ].Description 			= g_strdup (_(" [ faac ] Audio Codeur freeware"));
+	TableauPrgExtern[ NMR_faad ].Description 			= g_strdup (_(" [ faad ] MPEG-4 AAC decodeur"));
+	TableauPrgExtern[ NMR_flac ].Description 			= g_strdup (_(" [ flac ] Conversion wav : flac / <b><i>METAFLAC DOIT ETRE SUPERIEUR A LA VERSION: 1.1.2</i></b>"));
+	TableauPrgExtern[ NMR_icedax ].Description 			= g_strdup (_(" [ icedax ] Extracteur cd audio"));
+	TableauPrgExtern[ NMR_lame ].Description 			= g_strdup (_(" [ lame ] Conversion wav : mp3"));
+	TableauPrgExtern[ NMR_lsdvd ].Description 			= g_strdup (_(" [ lsdvd ] Cherche les informations d'un dvd"));
+	
+	TableauPrgExtern[ NMR_mac ].Description 			= g_strdup (_(" [ monkeys-audio ] Monkey's Audio Console Front End : APE"));
+	
+	// TableauPrgExtern[ NMR_mpc123_mppdec ].Description 		= g_strdup (_(" MPC Decodeur"));
+	// TableauPrgExtern[ NMR_mppenc ].Description 			= g_strdup (_(" MPC Encodeur"));
+	TableauPrgExtern[ NMR_musepack_tools_mppdec ].Description 	= g_strdup (_(" [ musepack-tools ] MusePack commandline utilities : mppdec"));
+	TableauPrgExtern[ NMR_musepack_tools_mppenc ].Description 	= g_strdup (_(" [ musepack-tools ] MusePack commandline utilities : mppenc"));
+	
+	TableauPrgExtern[ NMR_mplayer ].Description 			= g_strdup (_(" [ mplayer ] Lecteur et extracteur"));
+	TableauPrgExtern[ NMR_mp3gain ].Description 			= g_strdup (_(" [ mp3gain ] Normaliseur de fichier mp3"));
+	TableauPrgExtern[ NMR_mpg321 ].Description 			= g_strdup (_(" [ mpg321 ] Conversion mp3 : wav"));
+	TableauPrgExtern[ NMR_mp3splt ].Description 			= g_strdup (_(" [ mp3splt ] Decoupage de fichiers sans decodage"));
+	TableauPrgExtern[ NMR_normalize ].Description 			= g_strdup (_(" [ normalize-audio ] Normaliseur de fichier wav"));
+	TableauPrgExtern[ NMR_libnotify_bin ].Description 		= g_strdup (_(" [ libnotify-bin ] A program to send desktop notifications"));
+	TableauPrgExtern[ NMR_ps2pdf ].Description 			= g_strdup (_(" [ ghostscript ] Conversion  fichier  *.PS vers  *.PDF"));
+	TableauPrgExtern[ NMR_shorten ].Description 			= g_strdup (_(" [ shorten ] Forte compression au format wave"));
+	TableauPrgExtern[ NMR_shntool ].Description			= g_strdup (_(" [ shntool ] Decoupage de fichiers sans decodage"));
+	TableauPrgExtern[ NMR_sox ].Description 			= g_strdup (_(" [ sox ] Transformation universelle de fichiers son"));
+	TableauPrgExtern[ NMR_txt2html ].Description 			= g_strdup (_(" [ txt2html ] Convertir des fichiers texte au format HTML"));
+	TableauPrgExtern[ NMR_vorbis_tools_oggenc ].Description		= g_strdup (_(" [ Vorbis-tools ] Conversion wav : ogg"));
+	TableauPrgExtern[ NMR_vorbisgain ].Description 			= g_strdup (_(" [ vorbisgain ] Normaliseur de fichier ogg"));
+	TableauPrgExtern[ NMR_wavsplit ].Description 			= g_strdup (_(" [ wavsplit ] Decoupage de fichiers sans decodage"));
+	TableauPrgExtern[ NMR_wavpack ].Description 			= g_strdup (_(" [ wavpack ] WAVPACK  Hybrid Lossless Audio Compressor"));
+	TableauPrgExtern[ NMR_wXXcodecs	].Description 			= g_strdup (_(" [ wXXcodecs ] Codecs video non supportes par mplayer / <b><i>PAS indispensable</i></b>"));
 }
 
 /* Initialisation du scrolledwindow
@@ -902,9 +821,8 @@ void prginit_make_scrolledwindow (GtkWidget *widget)
 
 	/* PRINT_FUNC_LF(); */
 
-	var_prgextern.Pixbuf_Coche     = prginit_init_pixbufs_file ("coche.png");
-	var_prgextern.Pixbuf_Selected  = prginit_init_pixbufs_file ("selected.png");
 	var_prgextern.Pixbuf_Ok        = prginit_init_pixbufs_file ("prg-ok.png");
+	var_prgextern.Pixbuf_Not_Ok    = prginit_init_pixbufs_file ("dbfs-no.png");
 
 	var_prgextern.Adr_scroll = widget;
 	var_prgextern.Adr_List_Store =
