@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -40,11 +40,10 @@ typedef struct {
 	GtkWidget         *Adr_scroll;
 	GtkTreeSelection  *Adr_Line_Selected;
 	gboolean           Bool_Goto_Page_Options;
-	GdkPixbuf         *Pixbuf_Coche;
-	GdkPixbuf         *Pixbuf_Selected;
+	// GdkPixbuf         *Pixbuf_Coche;
+	// GdkPixbuf         *Pixbuf_Selected;
 	GdkPixbuf         *Pixbuf_Ok;
-	GtkWidget         *button_goto_install;
-	GtkWidget         *button_selection_globale;
+	GdkPixbuf         *Pixbuf_Not_Ok;
 
 } VAR_PRGEXTERN;
 
@@ -54,7 +53,6 @@ extern VAR_PRGEXTERN var_prgextern;
 
 typedef enum {
 	NMR_aacplusenc = 0,
-	NMR_abcde,
 	NMR_cdparanoia,
 	NMR_checkmp3,
 	NMR_imagemagick_convert,
@@ -65,9 +63,14 @@ typedef enum {
 	NMR_icedax,
 	NMR_lame,
 	NMR_lsdvd,
+	
 	NMR_mac,
-	NMR_mpc123_mppdec,
-	NMR_mppenc,
+	
+	// NMR_mpc123_mppdec,
+	// NMR_mppenc,
+	NMR_musepack_tools_mppdec,
+	NMR_musepack_tools_mppenc,
+	
 	NMR_mplayer,
 	NMR_mp3gain,
 	NMR_mpg321,
@@ -78,6 +81,7 @@ typedef enum {
 	NMR_shorten,
 	NMR_shntool,
 	NMR_sox,
+	NMR_txt2html,
 	NMR_vorbis_tools_oggenc,
 	NMR_vorbisgain,
 	NMR_wavsplit,
@@ -109,7 +113,6 @@ extern TABLEAU_PRG_EXTERN TableauPrgExtern [  ];
 
 typedef struct {
 	gboolean	bool_notify_send;
-	gboolean	bool_abcde;
 	gboolean	bool_ape;
 	gboolean	bool_mpc123_mppdec;
 	gboolean	bool_mppenc;
@@ -138,6 +141,7 @@ typedef struct {
 	gboolean	bool_shntool;
 	gboolean	bool_cuetools;
 	gboolean	bool_aacplusenc;
+	gboolean	bool_txt2html;
 
 } PRGINIT;
 
@@ -149,14 +153,7 @@ void       prginit_remove_comment (void);
 void       prginit_make_scrolledwindow (GtkWidget *widget);
 gboolean   prginit_get_etat (void);
 void       prginit_update_glist (void);
-gboolean   prginit_set_selected (void);
-gboolean   prginit_get_bool_install (void);
-gboolean   prginit_is_not_installed (void);
-gboolean   prginit_is_selected (void);
-
 gchar     *prginit_get_name (TYPE_PROGINIT TypeEnum);
-gboolean   prginit_elem_is_ready (TYPE_PROGINIT TypeEnum);
-void       prginit_var_default (void);
 
 #endif
 
