@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -38,8 +38,6 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#include "support.h"
-
 #include <string.h>
 #include <ctype.h>
 #include <stdlib.h>
@@ -54,6 +52,7 @@
 #include "options.h"
 #include "win_control.h"
 #include "win_norm_replay.h"
+#include "logs.h"
 #include "replaygain.h"
 
 
@@ -412,33 +411,25 @@ static gint replaygain_timeout (gpointer data)
 	
 	if (rpg.bool_compteur == TRUE) {
 		
-		/*
 		gchar *str = NULL;
     		gchar *spinner="|/-\\";
-		
-		str = g_strdup_printf ("<b>En cours: %d / %d   %c</b>", rpg.ElementActif, rpg.NbrElementsInList, spinner[rpg.pass_conv++%4]);
-		WinNormReplay_set_compteur (str);
-		g_free (str);
-		str = NULL;
-		*/
-		gchar *str = NULL;
-    		gchar *spinner="|/-\\";
-		gchar *Ptr = NULL;
+		// gchar *Ptr = NULL;
 		gchar  foo [ 2 ];
 		
 		foo [ 0 ] = spinner[rpg.pass_conv++%4];
 		foo [ 1 ] = '\0';
-		Ptr = utils_convert_string (foo, TRUE);
+		// Ptr = utils_convert_string (foo, TRUE);
 		
 		str = g_strdup_printf (_("<b>En cours: %d sur %d   %s</b>"),
 					rpg.ElementActif,
 					rpg.NbrElementsInList,
-					Ptr);
+					foo
+					);
 		WinNormReplay_set_compteur (str);
 		g_free (str);
 		str = NULL;
-		g_free (Ptr);
-		Ptr = NULL;
+		// g_free (Ptr);
+		// Ptr = NULL;
 		
 		return (TRUE);
 	}
@@ -543,6 +534,8 @@ void replaygain_get_list_Apply (void)
 */
 void replaygain_action (TYPE_REPLAYGAIN type_replaygain)
 {
+	logs_add_datas_session ("FROM FILE->REPLAYGAIN");
+	
 	g_snprintf (conv.valuenice ,    4, "%d", options_get_val_nice ());
 	
 	rpg.bool_thread_end = FALSE;
