@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -38,9 +38,6 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#include "support.h"
-#include "interface.h"
-
 #include <string.h>
 #include <stdlib.h>
 
@@ -53,6 +50,7 @@
 #include "split.h"
 #include "config_user.h"
 #include "showhide_treeview.h"
+#include "win_control.h"
 
 
 
@@ -64,6 +62,7 @@
 
 typedef struct {
 	GtkWidget	*AdrWin;
+	gboolean	 Bool;
 	gboolean	 BoolNoEnter;
 	guint		 PageNotebook;
 } VAR_SHOWHIDE;
@@ -329,22 +328,24 @@ gint showhidetreeview_get_etat_fields (void)
 	return (cpt);
 }
 
+void showhidetreeview_quit (void)
+{
+	NEW_wincontrol_realize_window (&ShowHide.AdrWin, "wind_treeview", &ShowHide.Bool, WIND_IS_SHOW, WIND_USE_STRUCT, WIND_IS_MODAL, WIND_IS_TRANSIENT);
+}
+
 gboolean showhidetreeview_delete_event (void)
 {
-	gtk_widget_destroy(ShowHide.AdrWin);
-	wincontrol_remove_last ();
-	return (FALSE);
+	showhidetreeview_quit ();
+	return TRUE;
 }
 gboolean showhidetreeview_destroy_event (void)
 {
-	gtk_widget_destroy(ShowHide.AdrWin);
-	wincontrol_remove_last ();
-	return (FALSE);
+	showhidetreeview_quit ();
+	return TRUE;
 }
 void showhidetreeview_button_quit_windtreeview_clicked (void)
 {
-	gtk_widget_destroy(ShowHide.AdrWin);
-	wincontrol_remove_last ();
+	showhidetreeview_quit ();
 }
 void showhidetreeview_notebook_windtreeview_switch_page (guint page_num)
 {
@@ -352,7 +353,7 @@ void showhidetreeview_notebook_windtreeview_switch_page (guint page_num)
 
 	switch(page_num) {
 	case 0 :
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 				NOTEBOOK_DVD_AUDIO);
 		break;
 	case 1 :
@@ -360,30 +361,30 @@ void showhidetreeview_notebook_windtreeview_switch_page (guint page_num)
 		Config_User.BoolEtatExpanderCd = TRUE;
 		gtk_expander_set_expanded (GTK_EXPANDER (var_cd.Adr_Expander), Config_User.BoolEtatExpanderCd);
 		*/
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 				NOTEBOOK_CD_AUDIO);
 		break;
 	case 2 :
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 				NOTEBOOK_FICHIERS);
-			gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_in_file")),
+			gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_in_file")),
 					NOTEBOOK_FICHIERS_CONVERSION);
 		break;
 	case 3 :
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 				NOTEBOOK_FICHIERS);
-			gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_in_file")),
+			gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_in_file")),
 					NOTEBOOK_FICHIERS_WAV);
 		break;
 	case 4 :
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 				NOTEBOOK_FICHIERS);
-			gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_in_file")),
+			gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_in_file")),
 					NOTEBOOK_FICHIERS_MP3OGG);
 		break;
 	case 5 :
 		/*
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 				NOTEBOOK_SPLIT);
 		*/
 		break;
@@ -404,7 +405,7 @@ void showhidetreeview_get_adr_widget (void)
 	for (cpt = POS_STRUCT_DVD; cpt < MAX_DATAS_STRUCT_TREEVIEW; cpt ++) {
 
 		/* Prend l'adresse du widget */
-		TabShowHide [ cpt ].AdrCheckButton = GTK_WIDGET (lookup_widget (ShowHide.AdrWin, TabShowHide [ cpt ].Name));
+		TabShowHide [ cpt ].AdrCheckButton = GTK_WIDGET (XCFA_GET_OBJECT(TabShowHide [ cpt ].Name));
 
 		/* Prend l'etat de visibilite */
 		TabShowHide [ cpt ].BoolIsVisible = TRUE;
@@ -557,15 +558,15 @@ void showhidetreeview_set_pos_radiobutton (void)
 		GtkWidget *Widget = NULL;
 
 		if (TabPosName [ cpt ].Pos == 0) {
-			if ((Widget = GTK_WIDGET (lookup_widget (ShowHide.AdrWin, TabPosName [ cpt ].NameLeft))) != NULL)
+			if ((Widget = GTK_WIDGET (XCFA_GET_OBJECT(TabPosName [ cpt ].NameLeft))) != NULL)
 				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (Widget), TRUE);
 		}
 		else if (TabPosName [ cpt ].Pos == 1) {
-			if ((Widget = GTK_WIDGET (lookup_widget (ShowHide.AdrWin, TabPosName [ cpt ].NameCenter))) != NULL)
+			if ((Widget = GTK_WIDGET (XCFA_GET_OBJECT(TabPosName [ cpt ].NameCenter))) != NULL)
 				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (Widget), TRUE);
 		}
 		else if (TabPosName [ cpt ].Pos == 2) {
-			if ((Widget = GTK_WIDGET (lookup_widget (ShowHide.AdrWin, TabPosName [ cpt ].NameRight))) != NULL)
+			if ((Widget = GTK_WIDGET (XCFA_GET_OBJECT(TabPosName [ cpt ].NameRight))) != NULL)
 				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (Widget), TRUE);
 		}
 	}
@@ -573,23 +574,17 @@ void showhidetreeview_set_pos_radiobutton (void)
 
 void showhidetreeview_open_window (guint OngletGeneral, guint OngletFichier)
 {
-	ShowHide.AdrWin = create_wind_treeview ();
-	wincontrol_set_adr (
-		ShowHide.AdrWin,		/* Window adress                */
-		"showhide",			/* Window name			*/
-		TRUE,				/* gtk_window_set_transient_for */
-		TRUE				/* gtk_window_set_modal         */
-		);
+	NEW_wincontrol_realize_window (&ShowHide.AdrWin, "wind_treeview", &ShowHide.Bool, WIND_IS_SHOW, WIND_USE_STRUCT, WIND_IS_MODAL, WIND_IS_TRANSIENT);
 
 	switch (OngletGeneral) {
 	case NOTEBOOK_DVD_AUDIO :
 		gtk_notebook_set_current_page (
-				GTK_NOTEBOOK (lookup_widget (ShowHide.AdrWin, "notebook_windtreeview")),
+				GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_windtreeview")),
 				0);
 		break;
 	case NOTEBOOK_CD_AUDIO :
 		gtk_notebook_set_current_page (
-				GTK_NOTEBOOK (lookup_widget (ShowHide.AdrWin, "notebook_windtreeview")),
+				GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_windtreeview")),
 				1);
 		break;
 	case NOTEBOOK_FICHIERS :
@@ -597,17 +592,17 @@ void showhidetreeview_open_window (guint OngletGeneral, guint OngletFichier)
 		case NOTEBOOK_FICHIERS_CONVERSION :
 		case NOTEBOOK_FICHIERS_TAGS :
 			gtk_notebook_set_current_page (
-					GTK_NOTEBOOK (lookup_widget (ShowHide.AdrWin, "notebook_windtreeview")),
+					GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_windtreeview")),
 					2);
 			break;
 		case NOTEBOOK_FICHIERS_WAV :
 			gtk_notebook_set_current_page (
-					GTK_NOTEBOOK (lookup_widget (ShowHide.AdrWin, "notebook_windtreeview")),
+					GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_windtreeview")),
 					3);
 			break;
 		case NOTEBOOK_FICHIERS_MP3OGG :
 			gtk_notebook_set_current_page (
-					GTK_NOTEBOOK (lookup_widget (ShowHide.AdrWin, "notebook_windtreeview")),
+					GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_windtreeview")),
 					4);
 			break;
 		}
@@ -615,13 +610,13 @@ void showhidetreeview_open_window (guint OngletGeneral, guint OngletFichier)
 	case NOTEBOOK_SPLIT :
 		/*
 		gtk_notebook_set_current_page (
-				GTK_NOTEBOOK (lookup_widget (ShowHide.AdrWin, "notebook_windtreeview")),
+				GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_windtreeview")),
 				5);
 		*/
 		break;
 	}
 	if (OngletGeneral > 3) {
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")),
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")),
 				NOTEBOOK_DVD_AUDIO);
 	}
 
@@ -636,21 +631,21 @@ void showhidetreeview_radiobutton_modif_treeview_clicked (GtkButton *button)
 	gint cpt;
 
 	for (cpt = POS_STRUCT_DVD; cpt < MAX_DATAS_STRUCT_RADIOBUTTONS; cpt ++) {
-		if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (ShowHide.AdrWin, TabPosName [ cpt ].NameLeft)))) {
+		if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT(TabPosName [ cpt ].NameLeft)))) {
 			Config_User.StringPosFieldsName [ cpt ] = '0';
 			TabPosName [ cpt ].Pos = 0;
 			gtk_tree_view_column_set_alignment (GTK_TREE_VIEW_COLUMN (*TabPosName [ cpt ].AdrTreeViewColumn), 0.0);
 			g_object_set (*TabPosName [ cpt ].AdrRenderer, "xalign", 0.0, NULL);
 			break;
 		}
-		if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (ShowHide.AdrWin, TabPosName [ cpt ].NameCenter)))) {
+		if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT(TabPosName [ cpt ].NameCenter)))) {
 			Config_User.StringPosFieldsName [ cpt ] = '1';
 			TabPosName [ cpt ].Pos = 1;
 			gtk_tree_view_column_set_alignment (GTK_TREE_VIEW_COLUMN (*TabPosName [ cpt ].AdrTreeViewColumn), 0.5);
 			g_object_set (*TabPosName [ cpt ].AdrRenderer, "xalign", 0.5, NULL);
 			break;
 		}
-		if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (lookup_widget (ShowHide.AdrWin, TabPosName [ cpt ].NameRight)))) {
+		if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (XCFA_GET_OBJECT(TabPosName [ cpt ].NameRight)))) {
 			Config_User.StringPosFieldsName [ cpt ] = '2';
 			TabPosName [ cpt ].Pos = 2;
 			gtk_tree_view_column_set_alignment (GTK_TREE_VIEW_COLUMN (*TabPosName [ cpt ].AdrTreeViewColumn), 1.0);
