@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -38,7 +38,6 @@
 #include <string.h>
 #include <stdlib.h>
 
-#include "support.h"
 #include "global.h"
 #include "config_user.h"
 #include "fileselect.h"
@@ -48,11 +47,10 @@
 #include "dragNdrop.h"
 #include "prg_init.h"
 #include "split.h"
-#include "player.h"
 #include "win_info.h"
 #include "split_shuttle.h"
 #include "cursor.h"
-#include "play_alsa.h"
+#include "mplayer.h"
 
 
 
@@ -130,7 +128,6 @@ void split_button_ajouter_tache_clicked (void)
 {
 	FIC_SPLIT	*FicSplit = NULL;
 	FIC_SPLIT	*NewFicSplit = NULL;
-	// GList		*ListDecoupe = NULL;
 	
 	if (VarSplit.Detail == NULL && VarSplit.FicSplit == NULL) return;
 			
@@ -146,15 +143,6 @@ void split_button_ajouter_tache_clicked (void)
 	
 	FicSplit->ListDecoupes = g_list_append (FicSplit->ListDecoupes, NewFicSplit);
 	
-	/*
-	ListDecoupe = g_list_first (FicSplit->ListDecoupes);
-	while (ListDecoupe) {
-		if ((FicSplit = (FIC_SPLIT *)ListDecoupe->data) != NULL) {
-			g_print("%s\n",FicSplit->Name);
-		}
-		ListDecoupe = g_list_next(ListDecoupe);
-	}
-	*/	
 	split_affiche_glist ();
 }
 
@@ -170,38 +158,39 @@ void split_button_importer_split_clicked (void)
 void split_with_mplayer (gdouble percent)
 {
 	splitshuttle_set_ActivePlayPercent (percent);
-	// printf("percent = %f\n", percent);
 }
 void split_set_flag_buttons_audio (void)
-{	
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_importer_split")), TRUE);
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "eventbox_combobox_dest_split")), TRUE);
+{
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_importer_split")), TRUE);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("eventbox_combobox_dest_split")), TRUE);
 
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_remove_file_split")), VarSplit.BoolLineSelected);
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_nettoyer_tout_split")), VarSplit.BoolLineSelected);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_remove_file_split")), VarSplit.BoolLineSelected);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_nettoyer_tout_split")), VarSplit.BoolLineSelected);
 	
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "checkbutton_contour_split")), VarSplit.BoolLineSelected);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("checkbutton_contour_split")), VarSplit.BoolLineSelected);
 
 	// TEMPS DEBUT
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "spinbutton_secondes_mark_A_split")), VarSplit.BoolLineSelected);
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "spinbutton_centiemes_mark_A_split")), VarSplit.BoolLineSelected);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("spinbutton_secondes_mark_A_split")), VarSplit.BoolLineSelected);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("spinbutton_centiemes_mark_A_split")), VarSplit.BoolLineSelected);
 
 	// TEMPS FIN
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "spinbutton_secondes_mark_B_split")), VarSplit.BoolLineSelected);
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "spinbutton_centiemes_mark_B_split")), VarSplit.BoolLineSelected);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("spinbutton_secondes_mark_B_split")), VarSplit.BoolLineSelected);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("spinbutton_centiemes_mark_B_split")), VarSplit.BoolLineSelected);
 
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_stop_lecture_split")), splitshuttle_if_play() );
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_lecture_split")), splitshuttle_if_play () );
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_stop_lecture_split")), splitshuttle_if_play() );
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_lecture_split")), splitshuttle_if_play () );
 
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_ajouter_tache_split")), VarSplit.BoolLineSelected);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_ajouter_tache_split")), VarSplit.BoolLineSelected);
 	
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "button_action_split")), split_get_elements () > 0 ? TRUE : FALSE);
-	gtk_widget_set_sensitive (GTK_WIDGET (lookup_widget (wind_main, "hbox_splitshuttle")), VarSplit.BoolLineSelected);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("button_action_split")), split_get_elements () > 0 ? TRUE : FALSE);
+	gtk_widget_set_sensitive (GTK_WIDGET (XCFA_GET_OBJECT("hbox_splitshuttle")), VarSplit.BoolLineSelected);
 }
 
 void split_set_combobox_dest (GtkWidget *widget)
 {
-	utils_clear_elements_combobox (widget);
+	// utils_clear_elements_combobox (GTK_COMBO_BOX (widget));
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Conversion(s) vers la source"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Choix d'une nouvelle destination"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), Config_User.Path_Destination_split);
@@ -346,7 +335,7 @@ void split_affiche_glist (void)
 			continue;
 		}
 					//<b>%s%s</b>   <span color=\"blue\"><b>%s</b></span>   <b><i>%s</i></b>",
-		Str = g_strdup_printf ("<span color=\"blue\"><b>%s%s</b>   <b>%s</b>   <b><i>%s</i></b></span>",
+		Str = g_strdup_printf ("<span color=\"black\"><b>%s%s</b>   <b>%s</b>   <b><i>%s</i></b></span>",
 					detail->BoolCueFile == TRUE ? "Cue/" : "", 
 					infosong_get_str_type_file_is (detail->type_infosong_file_is),
 					file_get_time_file (detail),
@@ -423,15 +412,15 @@ static void split_drag_data_received_file (GtkWidget	   *widget,
 gboolean split_test_prg_extern (void)
 {
 	if (PrgInit.bool_mp3splt == FALSE && PrgInit.bool_mplayer == FALSE) {
-		utils_puts_statusbar_global (_("mplayer + mp3splt NOT FOUND / ABSENT"));
+		utils_puts_statusbar_global (_("mplayer + mp3splt ABSENT"));
 		return (FALSE);
 	}
 	else if (PrgInit.bool_mp3splt == FALSE) {
-		utils_puts_statusbar_global (_("mp3splt NOT FOUND / ABSENT"));
+		utils_puts_statusbar_global (_("mp3splt ABSENT"));
 		return (FALSE);
 	}
 	else if (PrgInit.bool_mplayer == FALSE) {
-		utils_puts_statusbar_global (_("mplayer NOT FOUND / ABSENT"));
+		utils_puts_statusbar_global (_("mplayer ABSENT"));
 		return (FALSE);
 	}
 	utils_puts_statusbar_global ("");
@@ -755,6 +744,7 @@ gboolean split_key_press_event (GtkWidget *widget, GdkEventKey *event, gpointer
 
 gboolean split_event (GtkWidget *treeview, GdkEvent *event, gpointer user_data)
 {
+	/*
 	gint                x, y;
 	GdkModifierType     state;
 	GtkTreeIter         iter;
@@ -762,8 +752,6 @@ gboolean split_event (GtkWidget *treeview, GdkEvent *event, gpointer user_data)
 	GtkTreePath        *path;
 	GtkTreeViewColumn  *column;
 	GtkTreeModel       *model = (GtkTreeModel *)user_data;
-
-	return (FALSE);
 	
 	gdk_window_get_pointer (((GdkEventButton*)event)->window, &x, &y, &state);
 	if (!gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW(treeview),
@@ -772,15 +760,15 @@ gboolean split_event (GtkWidget *treeview, GdkEvent *event, gpointer user_data)
 
 		return (FALSE);
 	}
+PRINT_FUNC_LF();
 
 	gtk_tree_model_get_iter (model, &iter, path);
 	VarSplit.Detail   = NULL;
 	VarSplit.FicSplit = NULL;
 	gtk_tree_model_get (model, &iter, SPLIT_POINTER_STRUCT_DETAIL, &VarSplit.Detail, -1);
 	gtk_tree_model_get (model, &iter, SPLIT_POINTER_STRUCT_FICSPLIT, &VarSplit.FicSplit, -1);
-	
-	PRINT_FUNC_LF();
-	
+g_print("\tSELECTION DE: %s\n", VarSplit.Detail->namefile);
+	*/
 	return (FALSE);
 }
 
@@ -883,7 +871,7 @@ void split_changed_selection_row (GtkTreeSelection *selection, GtkTreeModel *mod
 	GList			*List = NULL;
 	
 	// PRINT_FUNC_LF();
-	
+
 	VarSplit.Adr_Line_Selected = selection;
 	
 	split_NEW_StopPlay ();
@@ -900,6 +888,8 @@ void split_changed_selection_row (GtkTreeSelection *selection, GtkTreeModel *mod
 	VarSplit.Detail   = NULL;
 	VarSplit.FicSplit = NULL;
 			
+	cursor_set_watch ();
+	
 	List = g_list_first (List);
 	if ((path = (GtkTreePath *)List->data) != NULL) {
 		gtk_tree_model_get_iter (model, &iter, path);
@@ -914,15 +904,22 @@ void split_changed_selection_row (GtkTreeSelection *selection, GtkTreeModel *mod
 	}
 	
 	if (VarSplit.Detail != NULL) {
-		cursor_set_watch ();
-		splitshuttle_read_file_spectre (VarSplit.Detail->namefile);
-		cursor_set_old ();
+		// gboolean split_event (GtkWidget *treeview, GdkEvent *event, gpointer user_data)
+		// g_print("SELECTION DE: %s\n", VarSplit.Detail->namefile);
+		
+		splitshuttle_read_file_spectre (VarSplit.Detail);
+		
+		// g_print("VarSplit.Detail->type_infosong_file_is = %d\n", VarSplit.Detail->type_infosong_file_is);
 	}
-	
+
 	splitshuttle_reset_play ();
 	
 	// ADAPTATION DES WIDGETS AU CONTEXTE
 	split_set_flag_buttons_audio ();
+	// gboolean split_event (GtkWidget *treeview, GdkEvent *event, gpointer user_data)
+	// g_print("--SELECTION DE: %s\n", VarSplit.Detail->namefile);
+	
+	cursor_set_old ();
 }
 
 static void split_cell_edited_namefile (GtkCellRendererText *cell,
@@ -970,7 +967,7 @@ static void split_add_columns_scrolledwindow_file (GtkTreeView *treeview)
 	GtkCellRenderer   *renderer;
 	GtkTreeViewColumn *column;
 	GtkTreeModel      *model = gtk_tree_view_get_model (treeview);
-	
+
 	/* SIGNAL 'key-press-event'
 	*/
 	g_signal_connect(G_OBJECT(treeview),
@@ -980,7 +977,7 @@ static void split_add_columns_scrolledwindow_file (GtkTreeView *treeview)
 	
 	/* SIGNAL : 'event'
 	*/
-	g_signal_connect(G_OBJECT(treeview), "event", (GCallback) split_event, model);
+	// g_signal_connect(G_OBJECT(treeview), "event", (GCallback) split_event, model);
 
 	/* SIGNAL : 'button-press-event'
 	*/
@@ -1088,9 +1085,9 @@ void split_scrolledwindow_file_split_realize (GtkWidget *widget)
 	VarSplit.FicSplit            = NULL;
 	VarSplit.OldSelectedFicSplit = NULL;
 	VarSplit.Detail              = NULL;
-	
+
 	VarSplit.Adr_scroll = widget;
-	
+
 	VarSplit.Adr_Tree_Model =
 	(GtkTreeModel *) gtk_tree_store_new (SPLIT_NUM_COLUMNS,
 					     G_TYPE_STRING,		/* SPLIT_FILE_NAME			*/
@@ -1110,47 +1107,46 @@ void split_scrolledwindow_file_split_realize (GtkWidget *widget)
 
 void split_button_lecture_split_clicked (void)
 {
-	/*
+
 	gdouble		 PercentBegin = splitshuttle_get_percent_play_begin ();
 	gdouble		 PercentEnd   = splitshuttle_get_percent_play_end ();
 	gint		 sec;
 	GList		*List = NULL;	
+
+	gtk_widget_hide (GTK_WIDGET (VarSplit.AdrButtonPlay));
+	gtk_widget_show (GTK_WIDGET (VarSplit.AdrButtonStop));
+	gtk_widget_set_sensitive (GTK_WIDGET (VarSplit.AdrButtonPlay), TRUE);
+	gtk_widget_set_sensitive (GTK_WIDGET (VarSplit.AdrButtonStop), TRUE);
+
+	// PlayAlsa_song (VarSplit.Detail->namefile,
+	// 		splitshuttle_get_percent_play_begin (),
+	// 		splitshuttle_get_percent_play_end ()
+	// 		);
 	
-	PRINT("");
-	g_print("\tBEGIN = %f\n\tEND   = %f\n", PercentBegin, PercentEnd);
+	// PRINT_FUNC_LF();
+	//g_print("\tBEGIN = %f\n\tEND   = %f\n", PercentBegin, PercentEnd);
 		
 	sec = (gint) ((splitshuttle_get_TimeSongSec () * PercentBegin) / 100.0);
 	List = g_list_append (List, g_strdup ("-ss"));
 	List = g_list_append (List, g_strdup_printf ("%d", sec));
 	List = g_list_append (List, g_strdup (VarSplit.Detail->namefile));
 		
-	PlayerExec_set_list (LIST_PLAY_FROM_SPLIT, PercentEnd, splitshuttle_get_TimeSongSec (), List);
+	mplayer_set_list (LIST_MPLAYER_FROM_SPLIT, PercentEnd, splitshuttle_get_TimeSongSec (), List);
 	splitshuttle_set_BoolActivePlayPercent ();
+	
+	List = utils_clear_list (List);
 
-	*/
-	gtk_widget_hide (GTK_WIDGET (VarSplit.AdrButtonPlay));
-	gtk_widget_show (GTK_WIDGET (VarSplit.AdrButtonStop));
-	gtk_widget_set_sensitive (GTK_WIDGET (VarSplit.AdrButtonPlay), TRUE);
-	gtk_widget_set_sensitive (GTK_WIDGET (VarSplit.AdrButtonStop), TRUE);
-
-	PlayAlsa_song (VarSplit.Detail->namefile,
-			splitshuttle_get_percent_play_begin (),
-			splitshuttle_get_percent_play_end ()
-			);
 	splitshuttle_set_BoolActivePlayPercent ();
 }
 
 void split_button_stop_lecture_split_clicked (void)
 {
-	/*
-	VarPlayer.BoolPushButton = PUSH_BUTTON_STOP;
-	PlayerExec_fifo_quit ();
-	*/
 	gtk_widget_show (GTK_WIDGET (VarSplit.AdrButtonPlay));
 	gtk_widget_hide (GTK_WIDGET (VarSplit.AdrButtonStop));
 	
-	PlayAlsa_stop ();
-
+	// PlayAlsa_stop ();
+	split_NEW_StopPlay ();
+	
 	splitshuttle_set_BoolStopPlayPercent ();
 }
 
@@ -1245,49 +1241,9 @@ gboolean split_foreach_affiche_time (GtkTreeModel *model, GtkTreePath *path, Gtk
 	return FALSE;
 }
 
-
-void split_WaitPlay (void)
-{
-	gdouble		 PercentBegin = splitshuttle_get_percent_play_begin ();
-	gdouble		 PercentEnd   = splitshuttle_get_percent_play_end ();
-	gint		 sec;
-	GList		*List = NULL;	
-	
-	PRINT("");
-	// g_print("void main_WaitPlay (void)\n");
-	// g_print("\tBEGIN = %f\n\tEND   = %f\n", PercentBegin, PercentEnd);
-		
-	sec = (gint) ((splitshuttle_get_TimeSongSec () * PercentBegin) / 100.0);
-	List = g_list_append (List, g_strdup ("-ss"));
-	List = g_list_append (List, g_strdup_printf ("%d", sec));
-	List = g_list_append (List, g_strdup (VarSplit.Detail->namefile));
-	
-	// PlayerExec_set_time_in_seconds (splitshuttle_get_TimeSongSec ());
-	PlayerExec_set_list (LIST_PLAY_FROM_SPLIT, PercentEnd, splitshuttle_get_TimeSongSec (), List);
-	splitshuttle_set_BoolActivePlayPercent ();
-
-	gtk_widget_hide (GTK_WIDGET (VarSplit.AdrButtonPlay));
-	gtk_widget_show (GTK_WIDGET (VarSplit.AdrButtonStop));
-	gtk_widget_set_sensitive (GTK_WIDGET (VarSplit.AdrButtonPlay), TRUE);
-	gtk_widget_set_sensitive (GTK_WIDGET (VarSplit.AdrButtonStop), TRUE);
-	
-}
-
-void split_StopPlay (void)
-{
-	// g_print("void main_StopPlay (void)\n");
-	PlayerExec_fifo_quit ();
-	splitshuttle_set_BoolStopPlayPercent ();
-
-	gtk_widget_show (GTK_WIDGET (VarSplit.AdrButtonPlay));
-	gtk_widget_hide (GTK_WIDGET (VarSplit.AdrButtonStop));
-	split_set_flag_buttons_audio ();
-}
-
-
 void split_spinbutton_set_mark_A_split_value_changed (void)
 {
-	// PRINT("");
+	// PRINT_FUNC_LF();
 	if (BoolSplitValueChangedEnable == FALSE) return;
 	if (VarSplit.AdrSpinbuttonSecondesDebut && VarSplit.AdrSpinbuttonCentiemeDebut) {
 		
@@ -1348,7 +1304,7 @@ void split_spinbutton_set_mark_A_split_value_changed (void)
 
 void split_spinbutton_set_mark_B_split_value_changed (void)
 {
-	// PRINT("");
+	// PRINT_FUNC_LF();
 	if (BoolSplitValueChangedEnable == FALSE) return;
 	if (VarSplit.AdrSpinbuttonSecondesFin && VarSplit.AdrSpinbuttonCentiemeFin) {
 		
@@ -1469,17 +1425,17 @@ void split_NEW_set_debut (gdouble Percent)
 	gint		 H, M, S, C;
 
 	Mess = splitshuttle_get_time (Percent, TRUE, FALSE, TRUE, FALSE);
-	gtk_label_set_markup (GTK_LABEL (GTK_WIDGET (lookup_widget (wind_main, "label_split_heure_debut"))), Mess);
+	gtk_label_set_markup (GTK_LABEL (GTK_WIDGET (XCFA_GET_OBJECT("label_split_heure_debut"))), Mess);
 	
 	g_free (Mess);
 	Mess = NULL;	
 	Mess = splitshuttle_get_time (Percent, TRUE, FALSE, FALSE, TRUE);
-	gtk_label_set_markup (GTK_LABEL (GTK_WIDGET (lookup_widget (wind_main, "label_split_minute_debut"))), Mess);
+	gtk_label_set_markup (GTK_LABEL (GTK_WIDGET (XCFA_GET_OBJECT("label_split_minute_debut"))), Mess);
 	
 	g_free (Mess);
 	Mess = NULL;	
 	Mess = splitshuttle_get_time (Percent, TRUE, TRUE, FALSE, FALSE);
-	gtk_label_set_markup (GTK_LABEL (GTK_WIDGET (lookup_widget (wind_main, "label_split_percent_debut"))), Mess);
+	gtk_label_set_markup (GTK_LABEL (GTK_WIDGET (XCFA_GET_OBJECT("label_split_percent_debut"))), Mess);
 	
 	g_free (Mess);
 	Mess = NULL;
@@ -1509,17 +1465,17 @@ void split_NEW_set_fin (gdouble Percent)
 	gint		 H, M, S, C;
 	
 	Mess = splitshuttle_get_time (Percent, TRUE, FALSE, TRUE, FALSE);
-	gtk_label_set_markup (GTK_LABEL (GTK_WIDGET (lookup_widget (wind_main, "label_split_heure_fin"))), Mess);
+	gtk_label_set_markup (GTK_LABEL (GTK_WIDGET (XCFA_GET_OBJECT("label_split_heure_fin"))), Mess);
 	
 	g_free (Mess);
 	Mess = NULL;	
 	Mess = splitshuttle_get_time (Percent, TRUE, FALSE, FALSE, TRUE);
-	gtk_label_set_markup (GTK_LABEL (GTK_WIDGET (lookup_widget (wind_main, "label_split_minute_fin"))), Mess);
+	gtk_label_set_markup (GTK_LABEL (GTK_WIDGET (XCFA_GET_OBJECT("label_split_minute_fin"))), Mess);
 	
 	g_free (Mess);
 	Mess = NULL;	
 	Mess = splitshuttle_get_time (Percent, TRUE, TRUE, FALSE, FALSE);
-	gtk_label_set_markup (GTK_LABEL (GTK_WIDGET (lookup_widget (wind_main, "label_split_percent_fin"))), Mess);
+	gtk_label_set_markup (GTK_LABEL (GTK_WIDGET (XCFA_GET_OBJECT("label_split_percent_fin"))), Mess);
 	
 	g_free (Mess);
 	Mess = NULL;
@@ -1545,50 +1501,48 @@ void split_NEW_set_fin (gdouble Percent)
 
 void split_NEW_WaitPlay (void)
 {
-	/*
+
 	gdouble		 PercentBegin = splitshuttle_get_percent_play_begin ();
 	gdouble		 PercentEnd   = splitshuttle_get_percent_play_end ();
-	gdouble		 sec;
+	gint		 sec;
 	GList		*List = NULL;	
-	
-	sec = (gint) ((splitshuttle_get_TimeSongSec () * PercentBegin) / 100.0);
-	
-	// g_print("\n\tBEGIN = %f\n\tEND   = %f\n", PercentBegin, PercentEnd);
-	// g_print("\tSEC   = %f\n", sec);
-	// g_print("\tSEC   = %d\n", (gint)sec);
-	// g_print("\tsplitshuttle_get_TimeSongSec () = %f\n", splitshuttle_get_TimeSongSec ());
-	// g_print("\tsplitshuttle_get_TimeSongSec () = %d\n", (gint)splitshuttle_get_TimeSongSec ());
-	
-	List = g_list_append (List, g_strdup ("-ss"));
-	List = g_list_append (List, g_strdup_printf ("%d", (gint)sec));
-	List = g_list_append (List, g_strdup (VarSplit.Detail->namefile));
-		
-	PlayerExec_set_list (LIST_PLAY_FROM_SPLIT, PercentEnd, splitshuttle_get_TimeSongSec (), List);
-	splitshuttle_set_BoolActivePlayPercent ();
 
-	*/
 	gtk_widget_hide (GTK_WIDGET (VarSplit.AdrButtonPlay));
 	gtk_widget_show (GTK_WIDGET (VarSplit.AdrButtonStop));
 	gtk_widget_set_sensitive (GTK_WIDGET (VarSplit.AdrButtonPlay), TRUE);
 	gtk_widget_set_sensitive (GTK_WIDGET (VarSplit.AdrButtonStop), TRUE);
 	
-	PlayAlsa_song (VarSplit.Detail->namefile,
-			splitshuttle_get_percent_play_begin (),
-			splitshuttle_get_percent_play_end ()
-			);
+	// PlayAlsa_song (VarSplit.Detail->namefile,
+	// 		splitshuttle_get_percent_play_begin (),
+	// 		splitshuttle_get_percent_play_end ()
+	// 		);
+	
+	// PRINT_FUNC_LF();
+	// g_print("\tBEGIN = %f\n\tEND   = %f\n", PercentBegin, PercentEnd);
+		
+	sec = (gint) ((splitshuttle_get_TimeSongSec () * PercentBegin) / 100.0);
+	List = g_list_append (List, g_strdup ("-ss"));
+	List = g_list_append (List, g_strdup_printf ("%d", sec));
+	List = g_list_append (List, g_strdup (VarSplit.Detail->namefile));
+		
+	mplayer_set_list (LIST_MPLAYER_FROM_SPLIT, PercentEnd, splitshuttle_get_TimeSongSec (), List);
+	splitshuttle_set_BoolActivePlayPercent ();
+	
+	List = utils_clear_list (List);
+	
 	splitshuttle_set_BoolActivePlayPercent ();
 }
 void split_NEW_StopPlay (void)
 {
 	splitshuttle_set_BoolStopPlayPercent ();
-	PlayerExec_fifo_quit ();
 	splitshuttle_set_BoolStopPlayPercent ();
 
 	gtk_widget_show (GTK_WIDGET (VarSplit.AdrButtonPlay));
 	gtk_widget_hide (GTK_WIDGET (VarSplit.AdrButtonStop));
 	split_set_flag_buttons_audio ();
 	
-	PlayAlsa_stop ();
+	// PlayAlsa_stop ();
+	mplayer_fifo_quit ();
 }
 
 
