@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -38,7 +38,6 @@
 #include <string.h>
 #include <stdlib.h>
 
-#include "support.h"
 #include "global.h"
 #include "file.h"
 #include "prg_init.h"
@@ -102,6 +101,7 @@ void SplitAction_create_file_cue (gint index)
 	gchar	*PathNameFile = NULL;
 	gchar	*LineCommand = NULL;
 	GList	*list = NULL;
+	gint	 Dummy;
 
 	/* PRINT_FUNC_LF(); */
 
@@ -134,7 +134,7 @@ g_print("%s", VarSplitAlloc [ index ].StrfileBash);
 	/* Rendre le fichier executable */
 GDK_THREADS_ENTER();
 	LineCommand = g_strdup_printf ("chmod +x %s", PathNameFile);
-	system (LineCommand);
+	Dummy = system (LineCommand);
 
 	/* Free memory */
 
@@ -315,8 +315,8 @@ void splitaction_button_action_split_clicked (void)
 	    PrgInit.bool_shntool == FALSE  ||
 	    PrgInit.bool_cuetools == FALSE ||
 	    PrgInit.bool_checkmp3 == FALSE) {
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")), NOTEBOOK_PRGEXTERNES);
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_app_externes")), NOTEBOOK_OPTIONS_PRGEXTERNES);
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")), NOTEBOOK_PRGEXTERNES);
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_app_externes")), NOTEBOOK_OPTIONS_PRGEXTERNES);
 
 		wininfo_create (
 			_("PACKAGE(s) ABSENT(s) pour SPLIT"),
@@ -332,10 +332,6 @@ void splitaction_button_action_split_clicked (void)
 		return;
 	}
 
-	/**
-	PlayerExec_user_to_quit ();*/
-
-	/*if (VarSplit.TmpRep)  VarSplit.TmpRep  = utils_remove_temporary_rep (VarSplit.TmpRep);*/
 	if (!VarSplit.TmpRep) VarSplit.TmpRep  = utils_create_temporary_rep (PATH_TMP_XCFA_SHNSPLIT);
 
 	// RECUPERAION DU NOMBRE TOTAL DE TACHES
@@ -766,7 +762,8 @@ void splitaction_button_action_split_clicked (void)
 
 						/*VarSplitAlloc [ NmrSplitAlloc ].BoolFileWav = FALSE;*/
 
-						/*
+						/* 
+						--- MP3 ---
 						!-----------------------------------------------------------!
 						!  [ 0 .. 11 .. 13 ]
 						!-----------------------------------------------------------!
@@ -775,19 +772,40 @@ void splitaction_button_action_split_clicked (void)
 						!-----------------------------------------------------------!
 						ArgConv[ 00 ] = nice
 						ArgConv[ 01 ] = -n
-						ArgConv[ 02 ] = 0
+						ArgConv[ 02 ] = 10
 						ArgConv[ 03 ] = mp3splt
-						ArgConv[ 04 ] = /home/cat/Musique/DOROTHEE.mp3
-						ArgConv[ 05 ] = -e
-						ArgConv[ 06 ] = 0.3.8
-						ArgConv[ 07 ] = 0.4.56
-						ArgConv[ 08 ] = -d
-						ArgConv[ 09 ] = /home/cat/Musique/EXTRACTIONS
+						ArgConv[ 04 ] = -f
+						ArgConv[ 05 ] = -d
+						ArgConv[ 06 ] = /home/cat/Musique/SPLIT
+						ArgConv[ 07 ] = /home/cat/Musique/MP3/Amy Macdonald - This Is The Life.mp3
+						ArgConv[ 08 ] = 0.23.67
+						ArgConv[ 09 ] = 0.55.40
 						ArgConv[ 10 ] = -o
-						ArgConv[ 11 ] = 001_split_[0_3_8 to 0_4_56]_DOROTHEE.mp3
+						ArgConv[ 11 ] = 01_Amy Macdonald - This Is The Life.mp3
 
-						mp3splt -f -d /home/cat/Musique/EXTRACTIONS/ 01.mp3 0.3.8 0.4.0 -o _01.mp3
-						mp3splt -f -d /home/cat/Musique/EXTRACTIONS/ 01.ogg 0.3.8 0.4.0 -o _01.ogg
+						mp3splt -f -d /home/cat/Musique/Song.mp3 0.56.62 2.52.81 -o Song.mp3
+						
+						--- OGG ---
+						!-----------------------------------------------------------!
+						!  [ 0 .. 11 .. 13 ]
+						!-----------------------------------------------------------!
+						!  --Without Expert Parameters--
+						!  SPLIT
+						!-----------------------------------------------------------!
+						ArgConv[ 00 ] = nice
+						ArgConv[ 01 ] = -n
+						ArgConv[ 02 ] = 10
+						ArgConv[ 03 ] = mp3splt
+						ArgConv[ 04 ] = -f
+						ArgConv[ 05 ] = -d
+						ArgConv[ 06 ] = /home/cat/Musique/SPLIT
+						ArgConv[ 07 ] = /home/cat/Musique/MP3/Amy Macdonald - This Is The Life.ogg
+						ArgConv[ 08 ] = 0.56.62
+						ArgConv[ 09 ] = 2.52.81
+						ArgConv[ 10 ] = -o
+						ArgConv[ 11 ] = 01_Amy Macdonald - This Is The Life.ogg
+						
+						mp3splt -f -d /home/cat/Musique/Song.ogg 0.56.62 2.52.81 -o Song.ogg
 						*/
 						VarSplitAlloc [ NmrSplitAlloc ].list = g_list_append (VarSplitAlloc [ NmrSplitAlloc ].list, g_strdup ("nice"));
 						VarSplitAlloc [ NmrSplitAlloc ].list = g_list_append (VarSplitAlloc [ NmrSplitAlloc ].list, g_strdup ("-n"));
