@@ -1,11 +1,12 @@
  /*
  * file    : tags.c
- * project : xcfa
- * with    : Gtk-2
+ * project   : xcfa
+ * with      : Gtk-2
+ *
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
- * 2003,2004,2005,2006,2007,2008,2009 Claude Bulin
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +33,6 @@
 
 
 #include <gtk/gtk.h>
-#include "support.h"
 
 #include <pthread.h>
 #include <sys/types.h>
