@@ -3,9 +3,10 @@
  * project : xcfa
  * with    : Gtk-2
  *
+ * copyright : (C) 2003 - 2010 by Claude Bulin
+ *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
- * 2003,2004,2005,2006,2007,2008,2009 Claude Bulin
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,20 +39,21 @@
 #include "file.h"
 
 
-typedef struct {
-	guchar		IdRiff [ 4 ];	//	4 "RIFF" [52h 49h 46h 46h] identifiant le format
-	guint32		Size;		//	4 CALCUL ET ECRITURE DE LA TAILLE TOTAL DU FICHIER
-	guchar		IdWaveFmt [ 8 ];//	8 "WAVEfmt "  [57h 41h 56h 45h 66h 6dh 74h 20h]
-	guint32		BitPerSample;	//	4 TAILLE DE LA fmt: 8 | 16 | 24 ...
-	guint16		Encodage;	//	2 TYPE D'ENCODAGE AUDIO (1 pour mono ou 2 pour stereo)
-	guint16		Channels;	//	2 NOMBRE DE CANAUX
-	guint32		Frequence;	//	4 FREQUENCE D ECHANTILLONAGE EN HERTZ
-	guint32		Bitrate;	//	4 ECRITURE DU BITRATE
-	guint16		NbrOctets;	//	2 ECRITURE DU NOMBRE D OCTETS PAR BLOCK
-	guint16		NbrBytes;	//	2 NOMBRE DE BITS PAR ECHANTILLON: 8, 16, 24, ...
+typedef struct {				//    SIZE    COMMENT
+						//    ----    ----------------------------------------------------
+	guchar		IdRiff [ 4 ];		//	4     "RIFF" [52h 49h 46h 46h] identifiant le format
+	guint32		Size;			//	4     CALCUL ET ECRITURE DE LA TAILLE TOTAL DU FICHIER
+	guchar		IdWaveFmt [ 8 ];	//	8     "WAVEfmt "  [57h 41h 56h 45h 66h 6dh 74h 20h]
+	guint32		BitPerSample;		//	4     TAILLE DE LA fmt: 8 | 16 | 24 | 32 | 64 ...
+	guint16		Encodage;		//	2     TYPE D'ENCODAGE AUDIO (1 pour mono ou 2 pour stereo)
+	guint16		Channels;		//	2     NOMBRE DE CANAUX
+	guint32		Frequence;		//	4     FREQUENCE D ECHANTILLONAGE EN HERTZ
+	guint32		Bitrate;		//	4     ECRITURE DU BITRATE
+	guint16		NbrOctets;		//	2     ECRITURE DU NOMBRE D OCTETS PAR BLOCK
+	guint16		NbrBytes;		//	2     NOMBRE DE BITS PAR ECHANTILLON: 8, 16, 24, ...
 
 } NEW_HEADER_WAV;
-gboolean TagsWavGetHearder (gchar *NameFile, NEW_HEADER_WAV *HeaderWav);
+void TagsWavGetHearder (gchar *NameFile, NEW_HEADER_WAV *HeaderWav);
 
 /*
 *---------------------------------------------------------------------------
@@ -165,6 +167,33 @@ gboolean      tagswavpack_file_is_wavpack (gchar *namefile);
 INFO_WAVPACK *tagswavpack_remove_info (INFO_WAVPACK *info);
 INFO_WAVPACK *tagswavpack_get_info (DETAIL *detail, gchar *namefile);
 
+/*
+*---------------------------------------------------------------------------
+* TAGS_RM.C
+*---------------------------------------------------------------------------
+*/
+gboolean tagsrm_file_is_rm (gchar *namefile);
+INFO_RM *tagsrm_remove_info (INFO_RM *info);
+INFO_RM *tagsrm_get_info (gchar *namefile);
+
+/*
+*---------------------------------------------------------------------------
+* TAGS_DTS.C
+*---------------------------------------------------------------------------
+*/
+INFO_DTS *tagsdts_remove_info (INFO_DTS *info);
+INFO_DTS *tagsdts_get_info (gchar *namefile);
+
+
+/*
+*---------------------------------------------------------------------------
+* TAGS_AIFF.C
+*---------------------------------------------------------------------------
+*/
+gboolean tagsaiff_file_is_aiff (gchar *namefile);
+INFO_AIFF *tagsaiff_remove_info (INFO_AIFF *info);
+INFO_AIFF *tagsaiff_get_info (gchar *namefile);
+
 #endif
 
 
