@@ -3,9 +3,10 @@
  * project : xcfa
  * with    : Gtk-2
  *
+ * copyright : (C) 2003 - 2010 by Claude Bulin
+ *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
- * 2003,2004,2005,2006,2007,2008,2009 Claude Bulin
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +34,6 @@
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-#include "support.h"
 
 #include <pthread.h>
 #include <sys/types.h>
@@ -84,16 +84,17 @@ gboolean tagsmp3_file_is_mp3 (gchar *namefile)
 	gboolean bool = FALSE;
 	gint     i;
 	size_t   size;
+	size_t   Dummy;
 
 	/*PRINT_FUNC_LF();*/
 
 	fp = fopen (namefile, "rb");
 	if (!fp) return (FALSE);
 
-	fread ( &begin, 128, 1, fp );
+	Dummy = fread ( &begin, 128, 1, fp );
 	fseek ( fp, 0, SEEK_END );
 	fseek ( fp, ftell( fp ) - 128, SEEK_SET );
-	fread ( &end, 128, 1, fp );
+	Dummy = fread ( &end, 128, 1, fp );
 	fclose (fp);
 
 	if (begin.magic[0] == 'I' && begin.magic[1] == 'D' && begin.magic[2] == '3') return (TRUE);
@@ -102,7 +103,7 @@ gboolean tagsmp3_file_is_mp3 (gchar *namefile)
 	size = infosong_get_size_file (namefile);
 	buf = g_malloc0 (sizeof (gchar) * (size + 10));
 	if ((fp = fopen (namefile, "rb"))) {
-		fread (buf, 1, size, fp);
+		Dummy = fread (buf, 1, size, fp);
 		fclose (fp);
 		for (i = 0; i < size; i ++) {
 			if (buf[i+0] == 'L' && buf[i+1] == 'A' && buf[i+2] == 'M' && buf[i+3] == 'E') {
@@ -170,7 +171,7 @@ gint tagsmp3_type_mpeg (gchar *namefile)
 
 	gstr = get_with_checkmp3 (namefile);
 	Lout = gstr->str;
-
+//g_print("lout=%s\n",Lout);
 	for (i = 0; i < 3; i ++) {
 		if ((ptr = strstr (Lout, term[ i ]))) {
 			/* Init la chaine de stockage */
@@ -190,15 +191,15 @@ gint tagsmp3_type_mpeg (gchar *namefile)
 
 			switch ( i ) {
 			case 0 :
-				/*g_print ("----------------------------MPV_1  str=%s\n", str);*/
+				// g_print ("----------------------------MPV_1  str=%s\n", str);
 				if (str[0] == '1') Ret = 0;
 				break;
 			case 1 :
-				/*g_print ("----------------------------MPV_2  str=%s\n", str);*/
+				// g_print ("----------------------------MPV_2  str=%s\n", str);
 				if (str[0] == '1') Ret = 1;
 				break;
 			case 2 :
-				/*g_print ("----------------------------MPV_25 str=%s\n", str);*/
+				// g_print ("----------------------------MPV_25 str=%s\n", str);
 				if (str[0] == '1') Ret = 2;
 				break;
 			}
@@ -249,7 +250,6 @@ INFO_MP3 *tagsmp3_get_info (DETAIL *detail, gchar *namefile)
 		/*ptrinfo->tags->Comment   = g_strdup (utils_convert_string (taglib_tag_comment(tag), TRUE));*/
 		ptrinfo->tags->Comment   = utils_convert_string (taglib_tag_comment(tag), TRUE);
 		
-		
 		ptrinfo->tags->IntNumber = taglib_tag_track(tag);
 		ptrinfo->tags->Number    = g_strdup_printf ("%d", ptrinfo->tags->IntNumber);
 		/*ptrinfo->tags->Genre     = g_strdup (utils_convert_string (taglib_tag_genre(tag), TRUE));*/
