@@ -3,9 +3,10 @@
  * project : xcfa
  * with    : Gtk-2
  *
+ * copyright : (C) 2003 - 2010 by Claude Bulin
+ *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
- * 2003,2004,2005,2006,2007,2008,2009 Claude Bulin
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +34,6 @@
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-#include "support.h"
 
 #include <pthread.h>
 #include <sys/types.h>
@@ -202,9 +202,11 @@ gboolean tagsmpc_file_is_mpc (gchar *namefile)
 	}
 	
 	for (cpt = 0; cpt < 1024; cpt ++) {
-		if (buf [ cpt + 0 ] == 73 &&
-		    buf [ cpt + 1 ] == 68 &&
-		    buf [ cpt + 2 ] == 51) {
+		if (
+		    buf [ cpt + 0 ] == 0x4d &&	// M
+		    buf [ cpt + 1 ] == 0x50 &&	// P
+		    buf [ cpt + 2 ] == 0x2b	// +
+		    ) {
 		    bool_signature = TRUE;
 		    break;
 		}
