@@ -3,9 +3,10 @@
  * project : xcfa
  * with    : Gtk-2
  *
+ * copyright : (C) 2003 - 2010 by Claude Bulin
+ *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
- * 2003,2004,2005,2006,2007,2008,2009 Claude Bulin
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +34,6 @@
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-#include "support.h"
 
 #include <pthread.h>
 #include <sys/types.h>
@@ -50,20 +50,12 @@
 #include "get.h"
 
 
-/*
-*---------------------------------------------------------------------------
-* VARIABLES
-*---------------------------------------------------------------------------
-*/
-
-
 
 /*
 *---------------------------------------------------------------------------
 * FILE IS SHN ?
 *---------------------------------------------------------------------------
 */
-
 gboolean tagsshn_file_is_shn (gchar *namefile)
 {
 	FILE      *fp = NULL;
@@ -80,12 +72,12 @@ gboolean tagsshn_file_is_shn (gchar *namefile)
 	return (FALSE);
 }
 
+
 /*
 *---------------------------------------------------------------------------
-* GET HEADER
+* REMOVE HEADER
 *---------------------------------------------------------------------------
 */
-
 INFO_SHN *tagsshn_remove_info (INFO_SHN *info)
 {
 	if (info) {
@@ -101,6 +93,12 @@ INFO_SHN *tagsshn_remove_info (INFO_SHN *info)
 	return ((INFO_SHN *)NULL);
 }
 
+
+/*
+*---------------------------------------------------------------------------
+* GET HEADER
+*---------------------------------------------------------------------------
+*/
 INFO_SHN *tagsshn_get_info (gchar *namefile)
 {
 	INFO_SHN	*ptrinfo = NULL;
@@ -118,5 +116,5 @@ INFO_SHN *tagsshn_get_info (gchar *namefile)
 	
 	ShnTag = get_free_shntool (ShnTag);
 	
-	return (ptrinfo);
+	return ((INFO_SHN *)ptrinfo);
 }
