@@ -3,9 +3,10 @@
  * project : xcfa
  * with    : Gtk-2
  *
+ * copyright : (C) 2003 - 2010 by Claude Bulin
+ *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
- * 2003,2004,2005,2006,2007,2008,2009 Claude Bulin
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +34,6 @@
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-#include "support.h"
 
 #include <pthread.h>
 #include <sys/types.h>
@@ -48,6 +48,49 @@
 #include "level.h"
 #include "tags.h"
 
+/*
+
+	http://www.siteduzero.com/forum-83-464647-p1-le-format-wave.html
+
+typedef struct wave {
+
+	char riff[4];			// Le mot "RIFF"
+
+	int32_t taille;			// La taille du fichier - 8
+					// Ou subTaille2 + 44 - 8
+
+	char wave[4];			// Le mot "WAVE"
+	
+	char fmt[4];			// Le mot "fmt "
+
+	int32_t subTaille1;		// Taille du header jusqu'à "data"
+
+	int16_t formatAudio;		// Format du fichier
+
+	int16_t nombreCanaux;		// Nombres de canaux
+
+	int32_t freqEch;		// Fréquence d'échantillonnage
+
+	int32_t ByteRate;		// ByteRate
+					// Nombre d'octets par seconde
+					// Calcul :
+					// freqEch * nombreCanaux * bitsParEch / 8
+					
+	int16_t align;			// Alignement
+					// Nombre d'octets par échantillon
+					// Englobe tous les canaux !
+					// Calcul :
+					// nombreCanaux * bitsParEch / 8
+	
+	int16_t bitsParEch;		// Bits par échantillon
+	
+	char Ndata[4];			// Le mot "data" et la taille des données
+					
+	int32_t subTaille2;		// Taille des données
+	
+	void *data;			// A allouer dynamiquement. Contiendra les données
+};
+*/
 
 /*
 *---------------------------------------------------------------------------
@@ -150,13 +193,15 @@ typedef struct {			// entete fichier WAV */
 
 
 
-gboolean TagsWavGetHearder (gchar *NameFile, NEW_HEADER_WAV *HeaderWav)
+void TagsWavGetHearder (gchar *NameFile, NEW_HEADER_WAV *HeaderWav)
 {
-	FILE        *fp = NULL;
+	FILE	*fp = NULL;
 	
-	if ((fp = fopen (NameFile, "r")) == NULL) return (FALSE);
-	fread(HeaderWav, 1, sizeof(NEW_HEADER_WAV), fp);
-	fclose (fp);
+	if ((fp = fopen (NameFile, "r")) != NULL) {
+		size_t	 Dummy;
+		Dummy = fread(HeaderWav, 1, sizeof(NEW_HEADER_WAV), fp);
+		fclose (fp);
+	}
 	
 	/*
 	g_print("%s\n", NameFile);
@@ -173,7 +218,6 @@ gboolean TagsWavGetHearder (gchar *NameFile, NEW_HEADER_WAV *HeaderWav)
 	g_print("( 2 octets) : Octets par block                             : %d\n", HeaderWav->NbrOctets);
 	g_print("( 2 octets) : Bits par echantillons                        : %d\n", HeaderWav->NbrBytes);
 	*/
-	return (TRUE);
 }
 
 
@@ -187,12 +231,13 @@ gboolean tagswav_file_is_wav (gchar *namefile)
 {
 	FILE        *fp = NULL;
 	HEADER_WAV   buf;
+	size_t	 Dummy;
 	
 	if ((fp = fopen (namefile, "r")) == NULL) return (FALSE);
-	fread(&buf.tag1, 1, 4, fp);
+	Dummy = fread(&buf.tag1, 1, 4, fp);
 	buf.tag1 [ 4 ] = '\0';
-	fread(&buf.tag2, 1, 4, fp);
-	fread(&buf.tag2, 1, 14, fp);
+	Dummy = fread(&buf.tag2, 1, 4, fp);
+	Dummy = fread(&buf.tag2, 1, 14, fp);
 	fclose (fp);
 /*
 g_print("buf.tag1 = %s\n", buf.tag1);
@@ -283,16 +328,17 @@ gboolean read_le_short(FILE * file, guint16 *ret)
 
 gboolean tagswav_file_is_mono (gchar *namefile)
 {
-	FILE        *fp = NULL;
-	HEADER_WAV   buf;
+	FILE		*fp = NULL;
+	HEADER_WAV	 buf;
+	size_t	 	 Dummy;
 	
 	if ((fp = fopen (namefile, "r")) == NULL) return (FALSE);
 
 	/* Lecture entete WAV inspiree de: xmms-1.2.10+20070601
 	*/
-	fread (&buf.tag1, 1, 4, fp);
+	Dummy = fread (&buf.tag1, 1, 4, fp);
 	read_le_long (fp, &buf.size1);
-	fread (&buf.tag2, 1, 14, fp);
+	Dummy = fread (&buf.tag2, 1, 14, fp);
 	read_le_short (fp, &buf.mode);
 	read_le_long (fp, &buf.freq);
 	read_le_long (fp, &buf.bytepersec);
@@ -311,16 +357,17 @@ PRINTBOOL("buf.mode",((buf.mode == 1) ? TRUE : FALSE));
 
 gboolean tagswav_file_ChangeBitrate (gchar *namefile, gint *Channels, gint *Hertz, gint *Bits)
 {
-	FILE        *fp = NULL;
-	HEADER_WAV   buf;
+	FILE		*fp = NULL;
+	HEADER_WAV	 buf;
+	size_t		 Dummy;
 	
 	if ((fp = fopen (namefile, "r")) == NULL) return (FALSE);
 
 	/* Lecture entete WAV inspiree de: xmms-1.2.10+20070601
 	*/
-	fread (&buf.tag1, 1, 4, fp);
+	Dummy = fread (&buf.tag1, 1, 4, fp);
 	read_le_long (fp, &buf.size1);
-	fread (&buf.tag2, 1, 14, fp);
+	Dummy = fread (&buf.tag2, 1, 14, fp);
 	read_le_short (fp, &buf.mode);
 	read_le_long (fp, &buf.freq);
 	read_le_long (fp, &buf.bytepersec);
@@ -334,6 +381,10 @@ gboolean tagswav_file_ChangeBitrate (gchar *namefile, gint *Channels, gint *Hert
 	if (Channels)	*Channels = buf.mode;
 	if (Hertz)	*Hertz    = buf.freq;
 	if (Bits)	*Bits     = buf.format;
+	
+	g_print("Channels = %d\n", buf.mode);
+	g_print("Hertz    = %d\n", buf.freq);
+	g_print("Bits     = %d\n", buf.format);
 
 	return ((buf.mode != 2 || buf.freq != 44100 || buf.format != 16) ? TRUE : FALSE);
 }
@@ -366,9 +417,9 @@ INFO_WAV *tagswav_get_info (DETAIL *detail, gchar *namefile)
 
 	/* Lecture entete WAV inspiree de: xmms-1.2.10+20070601
 	*/
-	fread (&buf.tag1, 1, 4, fp);
+	len = fread (&buf.tag1, 1, 4, fp);
 	read_le_long (fp, &buf.size1);
-	fread (&buf.tag2, 1, 14, fp);
+	len = fread (&buf.tag2, 1, 14, fp);
 	read_le_short (fp, &buf.mode);
 	read_le_long (fp, &buf.freq);
 	read_le_long (fp, &buf.bytepersec);
@@ -398,7 +449,8 @@ g_print ("\n");
 	len = infosong_get_size_file (namefile);
 	buf.size2 = len - 116;
 	if (buf.nbrbyte <= 1) buf.nbrbyte = 4;
-	if (buf.format <= 0) buf.format = 16;
+
+	// if (buf.format <= 0) buf.format = 16;
 	
 	/* RE-Ecriture de l'entete
 	*/
