@@ -3,9 +3,10 @@
  * project : xcfa
  * with    : Gtk-2
  *
+ * copyright : (C) 2003 - 2010 by Claude Bulin
+ *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
- * 2003,2004,2005,2006,2007,2008,2009 Claude Bulin
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +34,6 @@
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-#include "support.h"
 
 #include <pthread.h>
 #include <sys/types.h>
@@ -63,12 +63,12 @@
 *---------------------------------------------------------------------------
 */
 
+
 /*
 *---------------------------------------------------------------------------
-* GET HEADER
+* REMOVE HEADER
 *---------------------------------------------------------------------------
 */
-
 INFO_WMA *tagswma_remove_info (INFO_WMA *info)
 {
 	if (info) {
@@ -82,6 +82,12 @@ INFO_WMA *tagswma_remove_info (INFO_WMA *info)
 	return ((INFO_WMA *)NULL);
 }
 
+
+/*
+*---------------------------------------------------------------------------
+* GET HEADER
+*---------------------------------------------------------------------------
+*/
 INFO_WMA *tagswma_get_info (gchar *namefile)
 {
 	INFO_WMA     *ptrinfo = NULL;
@@ -95,6 +101,6 @@ INFO_WMA *tagswma_get_info (gchar *namefile)
 	ptrinfo->tags = (TAGS *)tags_alloc (FALSE);
 	tags_set (namefile, ptrinfo->tags);
 
-	return (ptrinfo);
+	return ((INFO_WMA *)ptrinfo);
 }
 
