@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -42,11 +42,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <time.h>
-#include <ctype.h>
 #include <sys/utsname.h>
-#include <sys/sysinfo.h>
-
-#include "support.h"
 
 #include "global.h"
 #include "secu.h"
@@ -325,14 +321,17 @@ gint utils_hexa_to_int (gchar *Ptr_Hexa)
 	return (Gint_Ret);
 }
 
-gchar *utils_get_infos_ordi (gboolean bool_uname, gboolean bool_sysinfo, gboolean bool)
+
+// gchar *utils_get_infos_ordi (gboolean bool_uname, gboolean bool_sysinfo, gboolean bool)
+gchar *utils_get_infos_ordi (gboolean bool_uname, gboolean bool)
 {
 	struct utsname utsname;
-	struct sysinfo info;
 	gchar  *ptruname = NULL;
-	gchar  *ptrsysinfo = NULL;
 	gchar  *ptr = NULL;
+	gchar  *ModelName = NULL;
 	
+	ModelName = get_set_cpu_info ();
+
 	HostConf.NbCpu   = sysconf(_SC_NPROCESSORS_ONLN);
 	HostConf.TypeCpu = 8 * sizeof(void*);
 	
@@ -351,9 +350,11 @@ gchar *utils_get_infos_ordi (gboolean bool_uname, gboolean bool_sysinfo, gboolea
 					"release\n\t<b> %s</b>\n"
 					"version\n\t<b> %s</b>\n"
 					"machine\n\t<b> %s</b>\n"
-					"\t<b> %d CPU (%d bits)</b>\n",
+					"\t<b> %d CPU (%d bits)</b>\n"
+					"\t<b> %s</b>\n",
 				utsname.sysname, utsname.nodename, utsname.release, utsname.version, utsname.machine,
-				HostConf.NbCpu, HostConf.TypeCpu);
+				HostConf.NbCpu, HostConf.TypeCpu,
+				ModelName);
 		}
 		else {
 			ptruname = g_strdup_printf (
@@ -363,57 +364,32 @@ gchar *utils_get_infos_ordi (gboolean bool_uname, gboolean bool_sysinfo, gboolea
 					"release\t\t= %s\n"
 					"version\t\t= %s\n"
 					"machine\t\t= %s\n"
-					"       \t\t= %d CPU (%d bits)\n",
+					"       \t\t= %d CPU (%d bits)\n"
+					"       \t\t= %s\n",
 				utsname.sysname, utsname.nodename, utsname.release, utsname.version, utsname.machine,
-				HostConf.NbCpu, HostConf.TypeCpu);
+				HostConf.NbCpu, HostConf.TypeCpu,
+				ModelName);
 		}
 	}
-	if (bool_sysinfo && sysinfo (&info) == 0) {
-		ptrsysinfo = g_strdup_printf (
-				"Nb secondes depuis boot           : %ld\n"
-				"Charge systeme depuis  1 minute   : %.2f%%\n"
-				"Charge systeme depuis  5 minutes  : %.2f%%\n"
-				"Charge systeme depuis 10 minutes  : %.2f%%\n"
-				"Memoire disponible                : %ld Mo\n"
-				"Memoire partagee                  : %ld Mo\n"
-				"Memoire dans buffer               : %ld Mo\n"
-				"Espace de swap total              : %ld Mo\n"
-				"Espace de swap libre              : %ld Mo\n"
-				"Nb processus en cours             : %d\n",
-				info.uptime,
-				info.loads[0] / 655.36,
-				info.loads[1] / 655.36,
-				info.loads[2] / 655.36,
-				info.freeram >> 20,
-				info.sharedram >> 20,
-				info.bufferram >> 20,
-				info.totalswap >> 20,
-				info.freeswap >> 20,
-				info.procs);
-	}
-	if (bool_uname && bool_sysinfo) {
-		ptr = g_strdup_printf ("%s\n%s",
-				ptruname ? ptruname : "ERREUR APPEL A: uname",
-				ptrsysinfo ? ptrsysinfo : "ERREUR APPEL A: sysinfo");
+	g_free (ModelName);
+	ModelName = NULL;
+	if (bool_uname) {
+		ptr = g_strdup_printf ("%s\n", ptruname ? ptruname : "ERREUR APPEL A: uname");
+
 	}
 	else if (bool_uname) {
 		ptr = g_strdup_printf ("%s\n", ptruname ? ptruname : "ERREUR APPEL A: uname");
 	}
-	else if (bool_sysinfo) {
-		ptr = g_strdup_printf ("%s\n", ptrsysinfo ? ptrsysinfo : "ERREUR APPEL A: sysinfo");
-	}
 
 	g_free (ptruname);
 	ptruname = NULL;
-	g_free (ptrsysinfo);
-	ptrsysinfo = NULL;
 	return (ptr);
 }
 void utils_infos_ordi (void)
 {
 	gchar *ptr = NULL;
 
-	ptr = utils_get_infos_ordi (TRUE, TRUE, FALSE);
+	ptr = utils_get_infos_ordi (TRUE, FALSE);
 	g_print ("%s\n", ptr);
 	g_free (ptr);
 	ptr = NULL;
@@ -519,7 +495,8 @@ gchar *utils_get_pathname (gchar *file)
 	return (LineCommand);
 }
 
-void utils_clear_elements_combobox (GtkWidget *widget)
+void OLDutils_clear_elements_combobox (GtkComboBox *widget)
+// void utils_clear_elements_combobox (GtkWidget *widget)
 {
 	if (GTK_COMBO_BOX (widget) != NULL) {
 		while (TRUE) {
@@ -530,6 +507,15 @@ void utils_clear_elements_combobox (GtkWidget *widget)
 		}
 	}
 }
+void utils_clear_elements_combobox (GtkComboBox *widget)
+{
+	GtkListStore	*store = NULL;
+	
+	if ((store = GTK_LIST_STORE (gtk_combo_box_get_model(widget))) != NULL)
+	{
+		gtk_list_store_clear (store);
+	}
+}
 
 /*
 *---------------------------------------------------------------------------
@@ -744,7 +730,7 @@ void utils_set_mess_from_file_ETAT_PLAY (ETAT_PLAY_FILE etat)
 		str = g_strdup ("FILE_ETAT_PLAY_PRG_ABSENT");
 		break;
 	case FILE_ETAT_PLAY_ATTENTE :
-		str = g_strdup (_("En attente de selection."));
+		str = g_strdup (_("En attente de selection. Un click droit permet le choix du player"));
 		break;
 	case FILE_ETAT_PLAY :
 		str = g_strdup (_("En ecoute."));
@@ -1009,9 +995,14 @@ gchar *utils_convert_string_1 (const gchar *string,
 	/* Suppression des ESPACES de fin de chaine */
 	for (ptr = (gchar *)string; *ptr; ptr ++);
 	ptr --;
-	while (ptr >= string && *ptr == ' ') ptr --;
+	while (ptr >= (gchar *)string && *ptr == ' ') ptr --;
 	ptr ++;
 	*ptr = '\0';
+	
+	for (ptr = (gchar *)string; *ptr; ptr ++) {
+		if (g_ascii_isalnum (*ptr) == FALSE) *ptr = '_';
+	}
+	
 	/* Si transformation deja faite quit */
 	if (g_utf8_validate(string, -1, NULL)) return ((gchar *)g_strdup(string));
 
@@ -1087,9 +1078,13 @@ gchar *utils_get_datas_on_disk (void)
 	
 	size = infosong_get_size_file ("/tmp/data_xcfa.txt");
 	buf = (gchar *)g_malloc0 (sizeof(gchar) * (size + 10));
-	fp = fopen ("/tmp/data_xcfa.txt", "r");
-	fread (buf, 1, size, fp);
-	fclose (fp);
+	if ((fp = fopen ("/tmp/data_xcfa.txt", "r")) != NULL) {
+		size = fread (buf, 1, size, fp);
+		fclose (fp);
+	} else {
+		g_free (buf);
+		buf = NULL;
+	}
 	
 	infosong_delete_file ("/tmp/data_xcfa.txt");
 
@@ -1166,16 +1161,17 @@ gboolean utils_test_write (gchar *path)
 
 gchar *utils_create_temporary_rep (gchar *path_tmprep)
 {
-	gchar *LineCommand = NULL;
-	gchar *Path = NULL;
-
+	gchar	*LineCommand = NULL;
+	gchar	*Path = NULL;
+	gint	 Dummy;
+	
 	/* PRINT_FUNC_LF(); */
 	if (path_tmprep != NULL) {
 		Path = g_strdup_printf ("%s/%s", Config_User.Path_TMP, path_tmprep);
 		if (infosong_file_is_dir (Path) == FALSE) {
 			g_print ("CREATE TEMPORARY REP:\n\t%s\n", Path);
 			LineCommand = g_strdup_printf ("mkdir -p %s", Path);
-			system (LineCommand);
+			Dummy = system (LineCommand);
 			g_free (LineCommand);
 			LineCommand = NULL;
 		}
@@ -1237,5 +1233,92 @@ GList *utils_clear_list (GList *p_list)
 }
 
 
+//
+//
+//
+typedef struct {
+	GtkComboBox	*combo;
+	gboolean	 Bool;
+} ALLOC;
+
+ALLOC *AllocStore = NULL;
+
+GList *ListAlloc = NULL;
+
+
+void utils_remove_combo (void)
+{
+	GList		*list = NULL;
+	ALLOC		*New = NULL;
+	
+	list = g_list_first (ListAlloc);
+	while (list) {
+		if ((New = (ALLOC *)list->data) != NULL) {
+			g_free (New);
+			New = NULL;
+			list->data = NULL;
+		}
+		list = g_list_next (list);
+	}
+	g_list_free (ListAlloc);
+	ListAlloc = NULL;
+}
+/*
+
+	utils_alloc_combo (GTK_COMBO_BOX (widget));
+*/
+GtkListStore *utils_alloc_combo (GtkComboBox *p_combo)
+{
+	GtkListStore	*store = NULL;
+	GtkCellRenderer *renderer = NULL;
+	GList		*list = NULL;
+	ALLOC		*New = NULL;
+	gboolean	 BoolInListe = FALSE;
+	
+	// PRINT_FUNC_LF();
+	
+	// CHERCHE SI PAS DANS LA LISTE
+	list = g_list_first (ListAlloc);
+	while (list) {
+		if ((New = (ALLOC *)list->data) != NULL) {
+			if (New->combo == p_combo) {
+				BoolInListe = TRUE;
+				break;
+			}
+		}
+		list = g_list_next (list);
+	}
+	// SI PAS DANS LA LISTE ALORS INSERTION
+	if (BoolInListe == FALSE) {
+		New = (ALLOC *)g_malloc0 (sizeof(ALLOC));
+		New->combo = p_combo;
+		New->Bool  = FALSE;
+		ListAlloc = g_list_append (ListAlloc, New);
+	}
+	
+	// RECUP OU CREATION DE store
+	list = g_list_first (ListAlloc);
+	while (list) {
+		if ((New = (ALLOC *)list->data) != NULL) {
+			if (New->combo == p_combo) {
+				if (New->Bool == FALSE) {
+					store = gtk_list_store_new (1, G_TYPE_STRING);
+					gtk_combo_box_set_model (GTK_COMBO_BOX(p_combo), GTK_TREE_MODEL(store));
+					renderer = gtk_cell_renderer_text_new ();
+					gtk_cell_layout_pack_start (GTK_CELL_LAYOUT(p_combo), renderer, TRUE);
+					gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT(p_combo), renderer, "text", 0, NULL);
+					New->Bool = TRUE;
+				}
+				else {
+					store = GTK_LIST_STORE (gtk_combo_box_get_model(p_combo));
+					gtk_list_store_clear (store);
+				}
+				break;
+			}
+		}
+		list = g_list_next (list);
+	}
+	return ((GtkListStore *)store);
+}
 
 
