@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -32,12 +32,12 @@
 
 
 #include <gtk/gtk.h>
-#include "support.h"
 
 #include <sys/types.h>
 #include <unistd.h>
 #include <string.h>
 #include <pthread.h>
+#include <stdlib.h>
 
 #include "win_info.h"
 #include "global.h"
@@ -50,11 +50,26 @@
 typedef struct {
 	gchar *Navigateur;
 	gchar *NameNavi;
+	gchar *TemporaryRep;
 } VAR_WEB ;
 
-VAR_WEB VarWeb;
+VAR_WEB VarWeb = { NULL, NULL, NULL };
 
 
+
+void web_remove (void)
+{
+	if (VarWeb.Navigateur != NULL) {
+		g_free (VarWeb.Navigateur);
+		VarWeb.Navigateur = NULL;
+	}
+	
+	if (VarWeb.NameNavi != NULL) {
+		g_free (VarWeb.NameNavi);
+		VarWeb.NameNavi = NULL;
+	}
+}
+
 /* Appelle un navigateur pour aller sur le site d'XCFA et cela en thread
 *  --
 *  entree :
@@ -92,7 +107,7 @@ void web_call_navigator (void)
 			EXEMPLE:
 				firefox -new-window -new-tab http:/www.google.fr
 			*/
-			g_print("%s -new-window -new-tab %s\n", VarWeb.Navigateur,VarWeb.NameNavi);
+			// g_print("%s -new-window -new-tab %s\n", VarWeb.Navigateur,VarWeb.NameNavi);
 			execlp (VarWeb.Navigateur,
 				VarWeb.Navigateur,
 				"-new-window",
@@ -137,8 +152,8 @@ void web_goto_xcfa_page (gchar *str_web)
 	/*PRINT_FUNC_LF();*/
 
 	if ((name_navi = prgnavigator_get_name_is_actived ()) == NULL) {
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_general")), NOTEBOOK_PRGEXTERNES);
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (lookup_widget (wind_main, "notebook_app_externes")), NOTEBOOK_OPTIONS_PRGNAVIGATOR);
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")), NOTEBOOK_PRGEXTERNES);
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_app_externes")), NOTEBOOK_OPTIONS_PRGNAVIGATOR);
 		
 		wininfo_create (
 			_("PAS de navigateur present"),
@@ -164,13 +179,100 @@ void web_goto_xcfa_page (gchar *str_web)
 		return;
 	}
 	
-	VarWeb.Navigateur = name_navi;
-	VarWeb.NameNavi   = str_web;
+	web_remove ();
+	VarWeb.Navigateur = g_strdup (name_navi);
+	VarWeb.NameNavi   = g_strdup (str_web);
 	
 	pthread_create (&nmr_tid, NULL ,(void *)web_thread, (void *)NULL);
 	/*web_call_navigator ();*/
 }
 
+void web_make_file (gchar *StrMakeManFile)
+{
+	pid_t  pid;
+
+	// PRINT_FUNC_LF();
+	
+	pid = fork ();
+	if (pid == 0) {
+		system (StrMakeManFile);
+		_exit (0);
+	}
+}
+
+void web_goto_manpage (gchar *NameManPage)
+{
+	gchar		*name_navi = NULL;
+	pthread_t	 nmr_tid;
+	gchar		*LineCommand = NULL;
+ 	
+	/*PRINT_FUNC_LF();*/
+
+	if ((name_navi = prgnavigator_get_name_is_actived ()) == NULL) {
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_general")), NOTEBOOK_PRGEXTERNES);
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (XCFA_GET_OBJECT("notebook_app_externes")), NOTEBOOK_OPTIONS_PRGNAVIGATOR);
+		
+		wininfo_create (
+			_("PAS de navigateur present"),
+			  "\n",
+			_("   L'acces au web est impossible car aucun navigateur"),
+			  "        \n",
+			_("   n'est present dans votre configuration."),
+			  "\n\n",
+			_("   Veuillez installez un navigateur."),
+			  "\n",
+			  "");
+		return;
+	}
+
+	if (utils_scan_by_which (NameManPage, NULL) == FALSE) {
+		g_print("The application is missing, you must install [ %s ]\n", NameManPage);
+		return;
+	}
+	
+	if (utils_scan_by_which ("txt2html", NULL) == FALSE) {
+		// g_print("The application is missing, you must install [ txt2html ]\n");
+		wininfo_create (
+			_("txt2html absent"),
+			  "\n",
+			_("   txt2html est absent de votre configuration."),
+			  "\n\n",
+			_("   Veuillez l'installer."),
+			  "\n",
+			  "");
+		return;
+	}
+	
+	// Create rep	
+	// gchar *utils_create_temporary_rep (gchar *path_tmprep)
+	// gchar *utils_remove_temporary_rep (gchar *path_tmprep)
+	if (VarWeb.TemporaryRep == NULL) {
+		VarWeb.TemporaryRep = utils_create_temporary_rep (PATH_MANPAGE);
+	}
+	
+	// INIT var
+	web_remove ();
+	VarWeb.Navigateur = g_strdup (name_navi);
+	VarWeb.NameNavi   = g_strdup_printf ("%s/%s.html", VarWeb.TemporaryRep, NameManPage);
+	
+	// IF VarWeb.NameNavi NOT EXIST
+	if (infosong_file_is_reg (VarWeb.NameNavi) == FALSE) {	
+		LineCommand = g_strdup_printf ("man %s | txt2html > %s/%s.html", NameManPage, VarWeb.TemporaryRep, NameManPage);
+		web_make_file (LineCommand);
+		g_free (LineCommand);
+		LineCommand = NULL;
+		sleep(20);
+	}
+		
+	pthread_create (&nmr_tid, NULL ,(void *)web_thread, (void *)NULL);
+}
 
 
-
+void web_remove_temporary_rep (void)
+{
+	web_remove ();
+	if (VarWeb.TemporaryRep != NULL) {
+		VarWeb.TemporaryRep = utils_remove_temporary_rep (VarWeb.TemporaryRep);
+		VarWeb.TemporaryRep = NULL;
+	}
+}
