@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -36,6 +36,8 @@
 
 
 void web_goto_xcfa_page (gchar *str_web);
+void web_goto_manpage (gchar *PathManPage);
+void web_remove_temporary_rep (void);
 
 
 #endif
