@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
+ * copyright : (C) 2003 - 2010 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -33,7 +33,7 @@
 
 #include <gtk/gtk.h>
 #include <string.h>
-#include "support.h"
+
 #include "global.h"
 #include "win_control.h"
 #include "utils.h"
@@ -63,22 +63,31 @@ WININFO wininfo;
 
 gboolean wininfo_on_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
-	PRINT_FUNC_LF();
-	gtk_widget_destroy (wincontrol_get_last_adr ());
+	GtkWidget *AdrWin = GTK_WIDGET(user_data);
+	
+	// PRINT_FUNC_LF();
+	// gtk_widget_destroy (wincontrol_get_last_adr ());
+	gtk_widget_destroy (AdrWin);
 	wincontrol_remove_last ();
 	return FALSE;
 }
 gboolean wininfo_on_destroy_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
-	PRINT_FUNC_LF();
-	gtk_widget_destroy (wincontrol_get_last_adr ());
+	GtkWidget *AdrWin = GTK_WIDGET(user_data);
+	
+	// PRINT_FUNC_LF();
+	// gtk_widget_destroy (wincontrol_get_last_adr ());
+	gtk_widget_destroy (AdrWin);
 	wincontrol_remove_last ();
 	return FALSE;
 }
 void wininfo_on_ok_button_clicked (GtkButton *button, gpointer user_data)
 {
-	PRINT_FUNC_LF();
-	gtk_widget_destroy (wincontrol_get_last_adr ());
+	GtkWidget *AdrWin = GTK_WIDGET(user_data);
+	
+	// PRINT_FUNC_LF();
+	// gtk_widget_destroy (wincontrol_get_last_adr ());
+	gtk_widget_destroy (AdrWin);
 	wincontrol_remove_last ();
 }
 
@@ -153,7 +162,7 @@ void wininfo_create_window (void)
 	GLADE_HOOKUP_OBJECT (dialog, vbox1, "vbox1");
 	GLADE_HOOKUP_OBJECT (dialog, label_text, "label_text");
 	GLADE_HOOKUP_OBJECT_NO_REF (dialog, dialog_action_area1, "dialog_action_area1");
-	GLADE_HOOKUP_OBJECT (dialog, ok_button, "ok_button");
+	// GLADE_HOOKUP_OBJECT (dialog, ok_button, "ok_button");
 
 	utils_set_default_icone_xcfa (dialog);
 	gtk_widget_show (dialog);
@@ -164,7 +173,7 @@ void wininfo_create (gchar *title, ...)
 	va_list    Arguments;
 	gchar     *PtrArg = NULL;
 	
-	/* PRINT_FUNC_LF(); */
+	// PRINT_FUNC_LF();
 
 	wininfo.title = g_strdup (title);				/* Stokage du titre		*/
 	wininfo.text  = g_string_new (NULL);				/* Creation du GString		*/
